@@ -103,10 +103,11 @@ AcceptDeny.visible = false;
 AcceptDeny.hide = function() {
     hideNode("acceptdeny_object");
     $("acceptdeny_object").style.display="none";
-    hideNode("disable_background_window");
-    $("disable_background_window").style.display="none";
-    $("disable_background_window").style.width = "100%";
-    $("disable_background_window").style.height = "100%";
+    ox.api.setModal(false);
+//    hideNode("modal-dialog");
+//    $("modal-dialog").style.display="none";
+//    $("modal-dialog").style.width = "100%";
+//    $("modal-dialog").style.height = "100%";
     AcceptDeny.visible = false;
 };
 AcceptDeny.prototype = {
@@ -121,8 +122,9 @@ AcceptDeny.prototype = {
 		if(acceptdenyobjectarray && acceptdenyobjectarray.length == 1 && acceptdenyobjectarray[0].com) {
 			comment.value=acceptdenyobjectarray[0].com;
 		}
-		showNode("disable_background_window");
-		$("disable_background_window").style.display="block";
+		ox.api.setModal(true);
+//		showNode("modal-dialog");
+//		$("modal-dialog").style.display="block";
 		showNode("acceptdeny_object");
 		centerPopupWindow($("acceptdeny_object"));
 		$("acceptdeny_object").style.display="block";
@@ -162,7 +164,7 @@ AcceptDeny.prototype = {
                 grid = AcceptDeny.grid = new LiveGrid([
                 {
                 	width: "30px",
-                	style: "padding: 0px, margin: 0px",
+                	style: { padding: 0, margin: 0 },
                 	text: "&#x00a0;",
                 	set: function(div, data) {
                         var src = getFullImgSrc("img/calendar/mod_calendar.gif");
@@ -183,16 +185,42 @@ AcceptDeny.prototype = {
                     }
                 },{
                     i18n: "description"/*i18n context*/, text: "Title"/*i18n*/,
-                    clear: defaultClear,
+                    clear: function(div) {
+                        if (!div.firstChild) {
+                            div.appendChild(newnode("div", 0, 0,
+                                [newtext("")]));
+                            div.appendChild(newnode("div", 0, 0,
+                                [newtext("")]));
+                        } else {
+                            div.firstChild.firstChild.data = "";
+                            div.firstChild.nextSibling.firstChild.data = "";
+                        }
+                    },
                     set: function(div, data) {
                         var text = data.location
-                            ? format("%s - %s", (data.title || ""), data.location)
+                            //#. Appointment description in the confirmation dialog.
+                            //#. %1$s is the title.
+                            //#. %2$s is the location.
+                            //#, c-format
+                            ? format("%1$s - %2$s", (data.title || ""),
+                                                    data.location)
                             : (data.title || "");
                         if (!div.firstChild) {
-                            div.appendChild(document.createTextNode(text));
+                            div.appendChild(newnode("div", 0, 0,
+                                [newtext(text)]));
+                            div.appendChild(newnode("div", 0, 0,
+                                [newtext("")]));
                         } else {
-                            div.firstChild.data = text;
+                            div.firstChild.firstChild.data = text;
+                            div.firstChild.nextSibling.firstChild.data = "";
                         }
+                        internalCache.getUsers([data.created_by], function(u) {
+                            div.firstChild.nextSibling.firstChild.data =
+                                //#. Second line in the grid of the notification dialog
+                                //#. %s is the name of the appointment creator
+                                //#, c-format
+                                format(_("created by %s"), u[data.created_by].display_name);
+                        });
                     }
                 }, {
                     text: "Start"/*i18n*/, i18n: true, index: "startdate",
@@ -204,6 +232,7 @@ AcceptDeny.prototype = {
                     set: LiveGrid.dateSetTime
                 }], new Selection());
                 $("acceptdeny_list_header").appendChild(grid.getHeader());
+                grid.columns[1].style = { height: "3.2em" };
                 grid.getTable($("acceptdeny_list_body"));
                 var setDisabled = classNameSetter("font-color-disabled");
                 grid.events.register("Selected", function(count) {
@@ -250,8 +279,9 @@ AcceptDeny.prototype = {
                             setActiveFolder(object.folder_id, null, true);
                             triggerEvent("OX_Switch_Module", activemodule,
                                          "newfolder");
-                            $("disable_background_window").style.width = 0;
-                            $("disable_background_window").style.height = 0;
+                            ox.api.setModal(false);
+//                            $("modal-dialog").style.width = 0;
+//                            $("modal-dialog").style.height = 0;
                         });
                 });
             }
@@ -267,8 +297,9 @@ AcceptDeny.prototype = {
             $("acceptdeny_notnew").style.display =
                 acceptdenyobject.confirmation ? "none" : "";
 	    }
-		showNode("disable_background_window");
-		$("disable_background_window").style.display="block";
+	    ox.api.setModal(true);
+//		showNode("modal-dialog");
+//		$("modal-dialog").style.display="block";
 		showNode("acceptdeny_object");
 		centerPopupWindow($("acceptdeny_object"));
 		$("acceptdeny_object").style.display="block";
