@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -30,6 +30,7 @@ function Cache(size) {
 	this.ressourcefromserver=new Array();
 	this.userfromserver=new Array();
 	this.groupfromserver=new Array();
+	this.userInterfaceEnabled = true; // private
 }
 Cache.prototype = 
 {
@@ -119,7 +120,7 @@ Cache.prototype =
 			Self.cache_request_id[myobject.id+":"+myobject.type]=true;
 		}
 				
-		if(Self.userfromserver.length>0) {
+		if (Self.userfromserver.length>0) {
 			 var cache_addUsers = function(allrequests) {
                 var daten=allrequests.data;
 				for (var i=0;i<daten.length;i++) {    
@@ -139,11 +140,24 @@ Cache.prototype =
             }   
             Self.openrequests++;
 			
-            internalCachejson.put(AjaxRoot + "/user?session=" + session +
-                "&action=list&columns=524,500,555,614", requestArray, null,
-                cache_addUsers);
-
-//            cache_addUsers({ data: [] });
+            var use_GAL_interface = function() {
+            	internalCachejson.put(AjaxRoot + "/contacts?session=" + session + 
+                    	"&action=listuser&columns=524,500,555,1", requestArray, null, cache_addUsers);
+            }
+            
+            if (!this.userInterfaceEnabled) {
+            	use_GAL_interface();
+            } else {
+	            internalCachejson.put(AjaxRoot + "/user?session=" + session +
+	                "&action=list&columns=524,500,555,614", requestArray, null,
+	                cache_addUsers, 
+	                function(error) {
+	            		use_GAL_interface();
+	            		Self.userInterfaceEnabled = false;
+	            		return true;
+	            	}
+	            );	            
+            }
 		}
 		if(Self.groupfromserver.length>0) {
 		  cache_addGroup = function(allrequests) {
