@@ -16,7 +16,7 @@
 var globalclickdisable2=true;
 var activeComboBox = null;
 
-function changePopUpMenuText3(obj, n,noevent)
+function changePopUpMenuText3(obj, n, noevent)
 {
 	var myValues = new Array();
 	myValues = obj.elements[n];
@@ -25,9 +25,9 @@ function changePopUpMenuText3(obj, n,noevent)
 	obj.currentI18nNode.update();
         	
     obj.selected = n;
- 	var key =  myValues.key;
+ 	var key = myValues.key;
     
-	if(obj.targetDiv) {
+	if (obj.targetDiv) {
 		if(obj.form) {
 			obj.targetDiv.value = key;
 		} else {
@@ -43,9 +43,7 @@ function changePopUpMenuText3(obj, n,noevent)
 				
 		}		
 	}
-    if (obj.onChange && !noevent) obj.onChange(key);
-//	if(obj.eventname && obj.eventname != "" && !noevent) 
-//		triggerEvent(obj.eventname, key, obj.eventparam);
+    if (obj.onChange && !noevent) obj.onChange(key, obj.currentResult);
 		
 	obj.currentResult = key;
 	obj.myboxComboDiv.style.display="none";
@@ -67,7 +65,7 @@ function changePopUpMenuText3(obj, n,noevent)
 
 function ComboBox3(window, elementid, width, selected, style, eventname, maxscrollbar,eventParam) 
 {
-    return new ComboBox3.impl(window, $ALL(elementid), width, selected, style,
+    return new ComboBox3.impl(window, ($ALL(elementid) || newnode("div")), width, selected, style,
         maxscrollbar,
         function(key) { triggerEvent(eventname, key, eventParam); } );
 }
@@ -443,9 +441,11 @@ ComboBox3.impl.prototype = {
 		var Self = this;
 						
 		Self.clickOnCombobox = function (e) { 
-			if(!Self.disabled)
+			if(!Self.disabled) {
 				showHideBox3(Self,e);
-			stopEvent(e);
+	            cancelBubbling(e);
+			}
+			cancelDefault(e);
 		}
 		Self.headTable.style.width=this.width;	
 		setTimeout(function() {
@@ -485,7 +485,7 @@ ComboBox3.impl.prototype = {
 	},
 	
 	addElement: function(value, key, callback) {
-		if(typeof value == "string") {
+		if (typeof value == "string") {
 			if(value.length > 0) {
 				var indexKeySearchSingle = value.substr(0,1).toLowerCase();
 				if(typeof this.keySearch[indexKeySearchSingle] == "undefined") this.keySearch[indexKeySearchSingle] = new Array();
@@ -503,12 +503,32 @@ ComboBox3.impl.prototype = {
 		this.elements.push({
 			value: value,
 			key: key,
-			callback: callback || function() { return _(value); }
+			callback: callback || function() { 
+				return (value.nodeType ? value : _(value));
+			}
 		});
 	},
 	
+	getElement: function(key) {
+		for (var i in this.elements) {
+			if (this.elements[i].key == key)  {
+				return this.elements[i];
+				break;
+			}
+		}
+	},
+	
 	getDomNode : function(sortedAfterTranslation) {	
 		
+		function fakeI18n(callback) {
+			this.callback = callback;
+			this.node = newnode("div",0,0,[callback().cloneNode(true)]);
+			this.update = function() {
+				removeChildNodes(this.node);
+				this.node.appendChild(this.callback().cloneNode(true));
+			}
+		}
+		
 		while(this.myboxComboDiv.childNodes.length>0)		
 			this.myboxComboDiv.removeChild(this.myboxComboDiv.firstChild);
 
@@ -516,30 +536,38 @@ ComboBox3.impl.prototype = {
 		this.currentValue = this.currentValues.value;
 		this.currentResult = this.currentValues.key;	
 		while(this.headTableColumn1div.childNodes.length>0)		
-			this.headTableColumn1div.removeChild(this.headTableColumn1div.firstChild);			
-		this.currentI18nNode = new I18nNode(this.currentValues.callback);
+			this.headTableColumn1div.removeChild(this.headTableColumn1div.firstChild);	
+		if (this.currentValues.value.nodeType) {
+			this.currentI18nNode = new fakeI18n(this.currentValues.callback);			
+		} else {
+			this.currentI18nNode = new I18nNode(this.currentValues.callback);
+		}
 		this.headTableColumn1div.appendChild(this.currentI18nNode.node);
-
 		var Self = this;			
 		Self.myboxComboDiv.className="smallpopupborder smallpopuplist background-color-content font-weight-default font-color-default border-color-design";
 		Self.myboxComboDiv.style.display="none";
 		Self.myboxComboDiv.style.textAlign="left";
         Self.myboxComboDiv.style.whiteSpace = "nowrap";	
-		
+		       
 		for(var el1 in Self.elements)
 		{
 			(function(n) {
 				var myValues = new Array();           			 			 
-       			myValues = Self.elements[n];       			 
-				myValues.i18nNode = new I18nNode(myValues.callback);				
+       			myValues = Self.elements[n];
+       			if (myValues.value.nodeType) {
+       				myValues.i18nNode = new fakeI18n(myValues.callback);
+       			} else {
+       				myValues.i18nNode = new I18nNode(myValues.callback);
+       			}
 			})(el1);
 		}
 		
-		if(sortedAfterTranslation) {
+		if (sortedAfterTranslation) {
 			this.sorti18nValue();	
        		Self.keySearch = {};
        		Self.indexForKeySearch = 0;		
 		}
+        
 		
 		for(var el in Self.elements)
 		{
@@ -566,7 +594,7 @@ ComboBox3.impl.prototype = {
        			 			 
        			 myValues = Self.elements[n];
        			 
-       			 if(sortedAfterTranslation) {
+       			 if (sortedAfterTranslation) {
 					if(typeof myValues.i18nNode.node.nodeValue == "string" && myValues.value != "please select") {
 						if(myValues.i18nNode.node.nodeValue.length > 0) {
 							var indexKeySearchSingle = myValues.i18nNode.node.nodeValue.substr(0,1).toLowerCase();
@@ -577,16 +605,22 @@ ComboBox3.impl.prototype = {
 					Self.indexForKeySearch++;
        			 }
        			 
-       			 if(Self.viewValue) {
+       			 if (Self.viewValue) {
        			 	if(myValues.key != "")
 						childDiv.className="height16 font-color-default background-color-content";
        			 	else					
 						childDiv.className="height16 font-color-disabled background-color-content";
        			}
-				myValues.i18nNode = new I18nNode(myValues.callback);
-				childDiv.appendChild(myValues.i18nNode.node);
+       			if (!myValues.i18nNode) {
+	       			if (myValues.value.nodeType) {
+	       				myValues.i18nNode = new fakeI18n(myValues.callback);
+	       			} else {	       				
+	       				myValues.i18nNode = new I18nNode(myValues.callback);
+	       			}
+       			}
+       			childDiv.appendChild(myValues.i18nNode.node);
 				
-				if(!Self.rowHeight) {
+				if (!Self.rowHeight) {
 					var tmpnode=childDiv.cloneNode(true);
 					tmpnode.style.display="block";
 					tmpnode.style.zIndex=-1;
@@ -616,7 +650,7 @@ ComboBox3.impl.prototype = {
 			this.childOffsetTopValues[j] = tmpnode2.childNodes[j].offsetTop;
 		}
 		body.removeChild(tmpnode2);
-		
+		return Self.rootDiv;
 	}
 }
 function ComboBoxSpecial(window, elementid, width, selected, style, eventname, maxscrollbar,eventParam) 
@@ -666,7 +700,7 @@ function ComboBoxSpecial(window, elementid, width, selected, style, eventname, m
 	this.currentResult = "";
 	
 	if(eventname)
-        this.onChange = function(key) {
+        this.onChange = function(key, key_before) {
             triggerEvent(eventname, key, eventParam);
         };
 	
@@ -776,7 +810,6 @@ ComboBoxSpecial.prototype = {
 	}
 	,
 	getDomNode: function (){
-		
 		this.currentValues = this.elements[this.selected];
 		this.currentValue = this.currentValues.value;
 		this.currentResult = this.currentValues.key;	
