@@ -86,12 +86,41 @@ Print.prototype =
 	setTitle : function (title) {
 		this.printName=title;
 	},
-	printDetail: function (detailarray) {
-		this.printwindow = newWindow("newInfoItemHidden.html","width="+this.width+",height="+this.height+",resizable=yes,menubar=yes,toolbar=yes,status=yes,scrollbars=yes");
-		var printdoc = this.printwindow.document;
+	
+	printDetail: function (detailarray, closer) {
+	    
+	    var self = this;
+	    
+	    ox.api.window.open("newInfoItemHidden.html", {
+	        options: {
+	            width: parseInt(this.width),
+	            height: parseInt(this.height),
+	            resizable: "yes",
+	            menubar: "yes",
+	            toolbar: "no",
+	            location: "no",
+	            status: "yes",
+	            scrollbars: "yes"
+	        },
+	        closer: closer !== undefined && closer !== jQuery.noop ? closer : function (opt) {
+	            ox.api.window.close(opt.guid);
+	        },
+	        success: function (win, guid) {
+	            self.printwindow = win;
+	            self.printDetailCont(detailarray, guid);
+	        }
+	    });
+	},
+	
+	printDetailCont: function (detailarray, guid) {
+		//this.printwindow = newWindow("newInfoItemHidden.html","width="+this.width+",height="+this.height+",resizable=yes,menubar=yes,toolbar=yes,status=yes,scrollbars=yes");
+		
+        // write document
+        var printdoc = this.printwindow.document;
 		printdoc.open();
-		printdoc.write("<html style=\"overflow:auto\"><head><title>"+this.printName+"</title><link rel=\"stylesheet\" type=\"text/css\" href=\"css/print.css\"/></head>");
-		printdoc.write("<body style=\"width:95%; height:95%\" onload=\"setTimeout(function() {window.print();window.close()},1000)\">");		
+		printdoc.write("<html style=\"overflow:auto\"><head><title>"+this.printName+"</title><link rel=\"stylesheet\" type=\"text/css\" href=\"print.css\"/>");
+		printdoc.write('</script></head>');
+		printdoc.write("<body style=\"width:95%; height:95%\" onload='setTimeout(function () { window.print(); }, 10)'>");
 		printdoc.write("<table class=\"detailprint\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" style=\"width:100%\">");
 
         function tryToPlugTheGapingSecurityHole(s) {
@@ -162,10 +191,9 @@ Print.prototype =
 						printdoc.write("<td style=\"width:90px\"><div class=\"printimage\"><img src=\""+detailarray[i2].src+"\" style=\"width:"+detailarray[i].width+";height:"+detailarray[i2].height+"\"/></div></td></tr>");
 					}
 				}
-
 			}
 		}
-		printdoc.write("</table>")
+		printdoc.write("</table>");
 		printdoc.write("</body>");
 		printdoc.write("</html>");
 		printdoc.close();
@@ -185,7 +213,7 @@ Print.prototype =
 		var printdoc =this.printwindow.document;
 		printdoc.open();
 		printdoc.write("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">");
-		printdoc.write("<html><head><title>"+this.printName+"</title><link rel=\"stylesheet\" type=\"text/css\" href=\"css/print.css\"/></head>");
+		printdoc.write("<html><head><title>"+this.printName+"</title><link rel=\"stylesheet\" type=\"text/css\" href=\"print.css\"/></head>");
 		printdoc.write("<body style=\"width:95%;height:95%\" onload=\"setTimeout(function() {window.print();window.close()},1000);\">");
 		printdoc.write(this.printdiv.innerHTML);
 		printdoc.write("</body>");
