@@ -100,7 +100,7 @@ SeriesObject.prototype = {
 		else if(this.old_occurrences != this.occurrences) { return false; }
 		return true;		
 	},
-	setParameters : function(responseobject,createseries) {
+	setParameters : function(responseobject,createseries, forceNew) {
 		if(!responseobject) {
 			return;
 		}
@@ -110,39 +110,37 @@ SeriesObject.prototype = {
 			return;
 		}
 		if(responseobject.recurrence_type != undefined) {
-			this.old_recurrence_type=parseInt(responseobject.recurrence_type);
+			if (!forceNew) this.old_recurrence_type=parseInt(responseobject.recurrence_type);
 			this.recurrence_type=parseInt(responseobject.recurrence_type);
 		}
 		if(responseobject.days != undefined) {
-			this.old_days=parseInt(responseobject.days);
+		    if (!forceNew) this.old_days=parseInt(responseobject.days);
 			this.days=parseInt(responseobject.days);
 		}
 		if(responseobject.day_in_month != undefined) {
-			this.old_day_in_month=parseInt(responseobject.day_in_month);
+		    if (!forceNew) this.old_day_in_month=parseInt(responseobject.day_in_month);
 			this.day_in_month=parseInt(responseobject.day_in_month);
 		}
 		if(responseobject.month != undefined) {
-			this.old_month=parseInt(responseobject.month);
+		    if (!forceNew) this.old_month=parseInt(responseobject.month);
 			this.month=parseInt(responseobject.month);
 		}
 		if(responseobject.interval != undefined) {
-			this.old_interval=parseInt(responseobject.interval);
+		    if (!forceNew) this.old_interval=parseInt(responseobject.interval);
 			this.interval=parseInt(responseobject.interval);
 		}
 		if(responseobject.until != undefined) {
-			this.old_until=responseobject.until;
+		    if (!forceNew) this.old_until=responseobject.until;
 			this.until=responseobject.until;
 		}
 		if(responseobject.occurrences != undefined) {
-			this.old_occurrences=parseInt(responseobject.occurrences);
+		    if (!forceNew) this.old_occurrences=parseInt(responseobject.occurrences);
 			this.occurrences=parseInt(responseobject.occurrences);
 		}
 	},
 	getSeriesString : function() {
 		function getCountString (countint) {
 			switch (countint) {
-				case -1:
-					return _("last"); 
 				case 1:
 					return _("first");
 				case 2:
@@ -151,6 +149,9 @@ SeriesObject.prototype = {
 					return _("third");
 				case 4:
 					return _("fourth");
+				case 5:
+				case -1:
+					return _("last"); 
 			}
 		}
 		function getMonthString(monthint) {
@@ -268,8 +269,8 @@ SeriesView.prototype = {
 			tmp.style.display = "none";
 		}
 	},
-	setParameters : function(responseobject) {
-		this.seriesobject.setParameters(responseobject);
+	setParameters : function(responseobject, forceNew) {
+		this.seriesobject.setParameters(responseobject, false, forceNew);
 		triggerEvent("OX_Series_Data_Init", this.getSeriesString());
 	},
 	getParameters : function(responseobject, moduleCase) {
@@ -296,11 +297,15 @@ SeriesView.prototype = {
 			}
 			if (this.seriesobject.occurrences != null) { 
 				responseobject["occurrences"]=this.seriesobject.occurrences; 
+			} else {
+			    delete responseobject.occurrences;
 			}
 			if (this.seriesobject.until != null) { 
 				var tmpdate=new Date(this.seriesobject.until);
 				tmpdate=new Date(Date.UTC(tmpdate.getUTCFullYear(),tmpdate.getUTCMonth(),tmpdate.getUTCDate(),0,0,0));
 				responseobject["until"]=tmpdate.getTime(); 
+			} else {
+			    delete responseobject.until;
 			}
 			if (this.seriesobject.until == null && this.seriesobject.occurrences == null) {
 	            if (this.seriesobject.old_until != null) {
@@ -327,7 +332,7 @@ SeriesView.prototype = {
 			Self.series_content_month_day_in_month1.addElement(_("second"),2);
 			Self.series_content_month_day_in_month1.addElement(_("third"),3);
 			Self.series_content_month_day_in_month1.addElement(_("fourth"),4);
-			Self.series_content_month_day_in_month1.addElement(_("last"),-1);
+			Self.series_content_month_day_in_month1.addElement(_("last"),5);
 			Self.series_content_month_day_in_month1.getDomNode();
 			Self.series_content_month_days1 = new ComboBox3(window, "series_content_month_days:1", "9em", 0, true, null, 4);
 			Self.series_content_month_days1.addElement(_("Monday"),2);
@@ -386,7 +391,7 @@ SeriesView.prototype = {
 			Self.series_content_year_day_in_month1.addElement(_("second"),2);
 			Self.series_content_year_day_in_month1.addElement(_("third"),3);
 			Self.series_content_year_day_in_month1.addElement(_("fourth"),4);
-			Self.series_content_year_day_in_month1.addElement(_("last"),-1);
+			Self.series_content_year_day_in_month1.addElement(_("last"),5);
 			Self.series_content_year_day_in_month1.getDomNode();
 		}
 
@@ -395,8 +400,9 @@ SeriesView.prototype = {
 	},
 	showView : function (module,startdate,enddate) {
 		if(!this.seriesobject.disabled) {
-			showNode("disable_background_window");
-			$("disable_background_window").style.display="block";
+		    ox.api.setModal(true);
+//			showNode("modal-dialog");
+//			$("modal-dialog").style.display="block";
 			showNode("series_window");
 			$("series_window").style.display="block";
 			this.openView(module,startdate,enddate);
@@ -541,8 +547,8 @@ SeriesView.prototype = {
 					this.series_content_month_day_in_month1.setKey(parseInt(4));
 					this.series_content_year_day_in_month1.setKey(parseInt(4));
 				} else if (prefill_dayOfMonth > 28){
-					this.series_content_month_day_in_month1.setKey(parseInt(-1));
-					this.series_content_year_day_in_month1.setKey(parseInt(-1));
+					this.series_content_month_day_in_month1.setKey(parseInt(5));
+					this.series_content_year_day_in_month1.setKey(parseInt(5));
 				}				
 			}
 		}
@@ -551,7 +557,8 @@ SeriesView.prototype = {
 		hideNode("series_window");
 		$("series_window").style.display="none";
 		hideNode("series_window");
-		$("disable_background_window").style.display="none";
+		ox.api.setModal(false);
+//		$("modal-dialog").style.display="none";
 	},
 	cancelView : function() {
 		this.seriesobject.recurrence_type=this.seriesobject.tmp_recurrence_type;
@@ -564,7 +571,7 @@ SeriesView.prototype = {
 				this.seriesobject.day_in_month=null;
 				this.seriesobject.month=null;
     			this.seriesobject.interval=null;
-			
+                break;
 			case 1:
 				this.seriesobject.days=null;
 				this.seriesobject.day_in_month=null;
@@ -651,6 +658,10 @@ SeriesView.prototype = {
 				$("series_recurrence_type:"+i).checked=true;
 			}
 		}
+		for (var i = 0; i < 3; i++) {
+	       $("series_ending_date_" + i).parentNode.parentNode.style.visibility =
+	           type ? "" : "hidden";
+		}
 	},
 	getSeriesString : function() {
 		return this.seriesobject.getSeriesString();
