@@ -169,9 +169,10 @@ attachmentDialog.prototype = {
 			this.curr_file_input_id = this.createFileInput();	
 		this.open = true;			
 		this.temp_list = new Array();
-		if ($("disable_background_window")) {
-            showNode("disable_background_window");
-            $("disable_background_window").style.display = "block";
+		if ($("modal-dialog")) {
+		    ox.api.setModal(true);
+//            showNode("modal-dialog");
+//            $("modal-dialog").style.display = "block";
         }
         centerPopupWindow(this.popup);
 		this.popup.style.display = 'block';		
@@ -219,9 +220,10 @@ attachmentDialog.prototype = {
 				this.form.removeChild(oNode);
 			}
 		}*/
-		if ($("disable_background_window")) {
-            hideNode("disable_background_window");
-            $("disable_background_window").style.display = "none";
+		if ($("modal-dialog")) {
+		    ox.api.setModal(false);
+//            hideNode("modal-dialog");
+//            $("modal-dialog").style.display = "none";
         }
 		this.popup.style.display = 'none';	
 		/*
@@ -243,9 +245,10 @@ attachmentDialog.prototype = {
 	},	
 	commitPopup:function ()
 	{
-		if ($("disable_background_window")) {
-            hideNode("disable_background_window");
-            $("disable_background_window").style.display = "none";
+		if ($("modal-dialog")) {
+		    ox.api.setModal(false);
+//            hideNode("modal-dialog");
+//            $("modal-dialog").style.display = "none";
         }
 		this.popup.style.display = 'none';	
 		this.file_name_list = this.file_name_list.concat(this.temp_list);
@@ -455,16 +458,30 @@ function attachmentGrid(sContainerId,nId,nFolder,sModule,oDialog)
 			case "contacts": 	nNumModule = 7;
 								break;																
 		}
-		propertiesPopUp = newWindow(
-		      "newInfoItemMain.html#attachmodule=" + nNumModule+ "&edit_id=" + -1
-		      + "&filename=" + encodeURIComponent(Self.selectedFilename)
-              + "&attid=" + encodeURIComponent(Self.selectedId)
-              + "&attobjid=" + encodeURIComponent(Self.nItemId)                        
-              + "&attobjfolder=" + encodeURIComponent((Self.folder || Self.folder_id))      
-              + "&folder=" + encodeURIComponent(configGetKey("folder.infostore")), 
-		      getWindowOptions(), 
-		      [ Self.selectedId, Self.nItemId, (Self.folder || Self.folder_id)]);	
-		propertiesPopUp.focus();			
+		
+		// use new api
+		ox.api.infostore.compose({
+		    params: {
+		        attachmodule: nNumModule,
+		        filename: Self.selectedFilename,
+		        attid: Self.selectedId,
+		        attobjid: Self.nItemId,
+		        attobjfolder: Self.folder || Self.folder_id,
+		        folder: configGetKey("folder.infostore")
+		    },
+		    id: [ Self.selectedId, Self.nItemId, (Self.folder || Self.folder_id)]
+		});
+		// TODO: remove this block
+//		propertiesPopUp = newWindow(
+//		      "newInfoItemMain.html#attachmodule=" + nNumModule+ "&edit_id=" + -1
+//		      + "&filename=" + encodeURIComponent(Self.selectedFilename)
+//              + "&attid=" + encodeURIComponent(Self.selectedId)
+//              + "&attobjid=" + encodeURIComponent(Self.nItemId)                        
+//              + "&attobjfolder=" + encodeURIComponent((Self.folder || Self.folder_id))      
+//              + "&folder=" + encodeURIComponent(configGetKey("folder.infostore")), 
+//		      getWindowOptions(), 
+//		      [ Self.selectedId, Self.nItemId, (Self.folder || Self.folder_id)]);	
+//		propertiesPopUp.focus();			
 	}
 	
 	var Self = this;
