@@ -288,6 +288,11 @@ AutoComplete.prototype.search = function(str) {
 		        emailAutoComplete: true
         	}
         }];
+        
+        if (configGetKey("modules.contacts.allFoldersForAutoComplete") == true) {
+        	delete(multiple[0].data.folder);
+        }
+        
         // search for resource?
         if (parent.includeResources) {
         	multiple.push({
@@ -309,7 +314,9 @@ AutoComplete.prototype.search = function(str) {
         		}
 
         		// process contacts
-        		if (cb.length > 0) {
+        		if (cb[0].error) {
+        		    newServerError(4, cb[0]);
+        		} else {
 	        		var response = cb[0];
 	                for (var i = 0; i < response.data.length; i++) {
 	                	var data = response.data[i];
@@ -371,7 +378,7 @@ AutoComplete.prototype.search = function(str) {
         		}
 
                 // process resources
-                if (cb.length > 1) {
+                if (cb.length > 1 && !cb[1].error) {
                 	var response = cb[1];
                 	for (var i = 0; i < response.data.length; i++) {
 	                	var data = response.data[i];
@@ -385,6 +392,8 @@ AutoComplete.prototype.search = function(str) {
                         parent.cache.add(key, [key]);
                         parent.nameIndex[key] = objectData;
                 	}
+                } else {
+                    newServerError(4, cb[1]);
                 }
                 
                 // add search pattern
