@@ -144,8 +144,10 @@ ConflictsPopup.open = function (object,conflicts,closecb,cbcancel,cbignore) {
 	    $("conflict_window_appointments").appendChild(finalNode);
 	}
 
-	showNode("disable_background_window");
-	$("disable_background_window").style.display="block";
+	ox.api.setModal(true);
+	//showNode("modal-dialog");
+	//$("modal-dialog").style.display="block";
+	
 	
 	showNode("disable_confirm_window");
 	$("disable_confirm_window").style.display="block"
@@ -164,7 +166,7 @@ ConflictsPopup.close = function () {
 	$("conflict_window").style.display="none";	
 	hideNode("disable_confirm_window");
 	$("disable_confirm_window").style.display="none";
-	var childs=	$("disable_background_window").childNodes;
+	var childs=	$("modal-dialog").childNodes;
 	var closeall=true;
 	for(var i=0; i<childs.length; i++) {
 		if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -175,8 +177,9 @@ ConflictsPopup.close = function () {
 	}
 	
 	if(closeall) {
-		hideNode("disable_background_window");
-		$("disable_background_window").style.display="none";
+	    ox.api.setModal(false);
+		//hideNode("modal-dialog");
+		//$("modal-dialog").style.display="none";
 	}
 }
 
