@@ -41,17 +41,23 @@ calendar_makeID = function (x) {
         mObj["created_by"]=x[4];
     }
 	return mObj;
-}
+};
 
 var calendarhovers=new Object();
 function register_Calendar() {
 	
 	registerView("calendar",null,
 	function () { 
-		register("OX_New_Search", calendarSearch); 		
+		register("OX_New_Search", calendarSearch);
+        register("OX_All_Categories", setCalCategories);
+        register("OX_Add_Categories", addCalCategories);
+        register("OX_Delete_All_Categories", deleteCalCategories);
 	},
 	function () { 
 		unregister("OX_New_Search", calendarSearch); 
+		unregister("OX_All_Categories", setCalCategories);
+        unregister("OX_Add_Categories", addCalCategories);
+        unregister("OX_Delete_All_Categories", deleteCalCategories);
 	},
 	function () {
 		menuclearSearch();
@@ -288,7 +294,7 @@ function register_Calendar() {
 	var storeTeamViewSettings = function(param) {
 		var grid = getCalendarGrid("teamview");
 		if (typeof(grid) != undefined) {
-			configSetKey("gui.calendar.team.zoom", grid.zoom);
+			configSetKey("gui.calendar.teamview.zoom", grid.zoom);
 		}
 	}
 	
@@ -299,20 +305,23 @@ function register_Calendar() {
 	    return function() {
     	    showNode("calendarTeamDay");
             var grid = getCalendarGrid("teamview");
-//            if (configContainsKey("gui.calendar.team.zoom")) {
-//                grid.zoom = configGetKey("gui.calendar.team.zoom");
-//            }
-            grid.zoom = zoom;
-            grid.setFirstDayOfWeek(firstDayOfWeek || 1);
-            grid.setGridIntervalLength(intervalLength);
+            // get last zoom level from config
+            if (configContainsKey("gui.calendar.teamview.zoom")) {
+                grid.zoom = configGetKey("gui.calendar.teamview.zoom");
+            } else {
+            	grid.zoom = zoom;
+            }
+            grid.applyView(view, firstDayOfWeek || 1);
+            //grid.setFirstDayOfWeek(firstDayOfWeek || 1);
+            //grid.setGridIntervalLength(intervalLength);
             grid.setParentDOMNode($("teamViewCalendarGrid"));
             grid.setSelectionChangedEvent("SubSelected");
             grid.setTeamMemberChangedEvent("OX_Teammember_Changed");
             grid.setZoomLevelChangedEvent("OX_Zoom_Level_Changed");
             // align with week month?
-            if (view == "MONTH" || view == "WORKWEEK") {
-                grid.setGridIntervalToWeek(null, intervalLength);
-            } 
+            //if (view == "MONTH" || view == "WORKWEEK") {
+            //    grid.setGridIntervalToWeek(null, intervalLength);
+            //} 
             grid.validateOrUpdate();
             register("OX_Zoom_Level_Changed", storeTeamViewSettings);
             calendarGridHandlers.registerAll();
@@ -341,6 +350,9 @@ function register_Calendar() {
                     })(i)));
                 }
             };
+            $("menu_calendar_teammember_change").oxSubmenu = function(menu) {
+                menu.onShow = calendarTeamViewChangeTeamPopup.onShow;
+            };
         }
         if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamday"]) {
             calendarhovers["teamday"].enable();
@@ -399,7 +411,7 @@ function register_Calendar() {
             function() {
                 // config not available now
                 var days = configGetKey("gui.calendar.custom.countdays");
-                teamView_show(days, 100)();
+                teamView_show(days, 100, "CUSTOM")();
             },
             teamView_enter,
             teamView_leave,
@@ -503,6 +515,26 @@ function register_Calendar() {
 		 	initLiveGridCalendar("week"); 
 		 }
 	);
+    registerView("calendar/list/custom",
+        null, 
+        function() {
+            calendarFolderPath.drawDOMNode("calendaroflistview", activefolder);
+            cwwdaysinweek = configGetKey("gui.calendar.custom.countdays");
+            var oDateLoc = new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0));  
+            startofweek=oDateLoc.getUTCDay();
+            if(!calendarGrid){
+                initCalenderLiveGridOnLoad();
+            }
+            initLiveGridCalendar("custom");
+         }, 
+         null,
+         null,
+         function() {
+            calendarFolderPath.drawDOMNode("calendaroflistview", activefolder);
+            displayNameDayView();
+            initLiveGridCalendar("custom"); 
+         }
+    );
 	registerView("calendar/list/search",
 		null, 
 		function() { 
@@ -689,45 +721,49 @@ register("OX_Configuration_Loaded",
 )
 
 function calendar_printDay() {
-    var start = Date.UTC(activeYear, activeMonth, activeDay);
-    calendar_print("cp_dayview_table.tmpl", start, start + 864e5); // ms/day
+    ox.api.calendar.print({ view: "day" });
+//    var start = Date.UTC(activeYear, activeMonth, activeDay);
+//    calendar_print("cp_dayview_table.tmpl", start, start + 864e5); // ms/day
 }
 
 function calendar_printWorkweek() {
-    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
-    var start = getDayInSameWeek(date, startofweek) * 864e5; // ms/day
-    var numdays = configGetKey("gui.calendar.workweek.countdays");
-    calendar_print("cp_weekview_table.tmpl", start,
-                   start + numdays * 864e5, numdays); // ms/day
+    ox.api.calendar.print({ view: "workweek" });
+//    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
+//    var start = getDayInSameWeek(date, startofweek) * 864e5; // ms/day
+//    var numdays = configGetKey("gui.calendar.workweek.countdays");
+//    calendar_print("cp_weekview_table.tmpl", start,
+//                   start + numdays * 864e5, numdays); // ms/day
 }
 
 function calendar_printWeek() {
-    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
-    var start = getDayInSameWeek(date, weekStart) * 864e5; // ms/day
-    calendar_print("cp_weekview_table.tmpl", start, start + 6048e5); // ms/week
+    ox.api.calendar.print({ view: "week" });
+//    var date = new Date(Date.UTC(activeYear, activeMonth, activeDay));
+//    var start = getDayInSameWeek(date, weekStart) * 864e5; // ms/day
+//    calendar_print("cp_weekview_table.tmpl", start, start + 6048e5); // ms/week
 }
 
 function calendar_printMonth() {
-    calendar_print("cp_monthview_table.tmpl",
-        Date.UTC(activeYear, activeMonth, 1),
-        Date.UTC(activeYear, activeMonth + 1, 1));
+    ox.api.calendar.print({ view: "month" });
+//    calendar_print("cp_monthview_table.tmpl",
+//        Date.UTC(activeYear, activeMonth, 1),
+//        Date.UTC(activeYear, activeMonth + 1, 1));
 }
 
-function calendar_print(template, start, end, numdays) {
-    ox.JSON.get(AjaxRoot + "/printCalendar?start=" + start + "&end=" + end +
-        "&template=" + template +
-        (calendar_getAllFoldersAttribute() ? "" : "&folder=" + activefolder) +
-        "&work_day_start_time=" + getWWStartTime() +
-        "&work_day_end_time=" + getWWEndTime() +
-        (numdays ? "&work_week_day_amount=" + numdays : "") +
-        "&session=" + session, function(reply) {
-            var w = newWindow("newInfoItemHidden.html",
-                "location=no,menubar=no,resizable=yes, scrollbars=yes,status=no,toolbar=no");
-            w.document.open();
-            w.document.write(reply);
-            w.document.close();
-        }, null, true);
-}
+//function calendar_print(template, start, end, numdays) {
+//    ox.JSON.get(AjaxRoot + "/printCalendar?start=" + start + "&end=" + end +
+//        "&template=" + template +
+//        (calendar_getAllFoldersAttribute() ? "" : "&folder=" + activefolder) +
+//        "&work_day_start_time=" + getWWStartTime() +
+//        "&work_day_end_time=" + getWWEndTime() +
+//        (numdays ? "&work_week_day_amount=" + numdays : "") +
+//        "&session=" + session, function(reply) {
+//            var w = newWindow("newInfoItemHidden.html",
+//                "location=no,menubar=no,resizable=yes, scrollbars=yes,status=no,toolbar=no");
+//            w.document.open();
+//            w.document.write(reply);
+//            w.document.close();
+//        }, null, true);
+//}
 
 function default_calendar_create_object(module,folder) {
 	if (module=="calendar") {
@@ -748,45 +784,77 @@ function default_calendar_create_object(module,folder) {
 	}
 }
 
-function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail,endDate) {	
-	var checkfolder;
-	var wholeday=wholeday;
-	var folder_id_tocheck  = (infolder)?infolder:((activefolder)?activefolder:config.folder.calendar);
-	oMainFolderTree.cache.get_folder(folder_id_tocheck,function (checkfolder){
-		calendar_createNewAppointmentCb(checkfolder);
-	});
+function calendar_createNewAppointment(startdate,infolder,wholeday,oFromMail,endDate) {
 
-	function calendar_createNewAppointmentCb(myfolder) {		
-		if (myfolder.oxfolder.data.module != "calendar") {
-			triggerEvent("OX_New_Error",4,_("Can not create appointment in a folder other than appointment folder"));
-			
-		} else {
-			var wholeDay=wholeday;
-			if(!startdate) {
-				startdate=new Date();
-			}
-			// Private folder or shared then add owner to list of participants
-			if(myfolder.oxfolder.data.type == 1 || myfolder.oxfolder.data.type == 3) {
-				var userId = myfolder.oxfolder.data.created_by;
-			} else {
-				var userId = configGetKey('identifier');
-			}
-			// end date given?
-            endDate = endDate ? endDate.getTime() : "";
-            var uri = "newAppointment.html#modul=new&folder_id="+infolder+"&view="+currentCalendarView+"&start_date="+startdate.getTime()+"&end_date="+endDate+"&folderOwner="+userId;
-            // is all day?
-			if (wholeDay){
-			    uri += "&full_time="+wholeDay;
-			}
-			// open window
-			var windowRef = newWindow(uri, getWindowOptions());
-			if (oFromMail) {
-			    // to add participants for example
-				windowRef.sFromModule = oFromMail.module;
-				windowRef.oFromMail = oFromMail.data;
-			}				
-		}
-	}
+    // open window
+    ox.api.calendar.compose({
+        params: {
+            folder: infolder,
+            start_date: startdate !== undefined ? startdate.getTime() : undefined,
+            end_date: endDate !== undefined ? endDate.getTime() : undefined,
+            full_time: wholeday
+        },
+        data: oFromMail ? { sFromModule: oFromMail.module, oFromMail: oFromMail.data } : {}
+    });
+    return;
+    
+//	var checkfolder;
+//	var wholeday=wholeday;
+//	var folder_id_tocheck  = (infolder)?infolder:((activefolder)?activefolder:config.folder.calendar);
+//	oMainFolderTree.cache.get_folder(folder_id_tocheck,function (checkfolder){
+//		calendar_createNewAppointmentCb(checkfolder);
+//	});
+//
+//	function calendar_createNewAppointmentCb(myfolder) {		
+//		if (myfolder.oxfolder.data.module != "calendar") {
+//			triggerEvent("OX_New_Error",4,_("Can not create appointment in a folder other than appointment folder"));
+//			
+//		} else {
+//			var wholeDay=wholeday;
+//			if(!startdate) {
+//				startdate=new Date();
+//			}
+//			// Private folder or shared then add owner to list of participants
+//			if(myfolder.oxfolder.data.type == 1 || myfolder.oxfolder.data.type == 3) {
+//				var userId = myfolder.oxfolder.data.created_by;
+//			} else {
+//				var userId = configGetKey('identifier');
+//			}
+//			// end date given?
+//            endDate = endDate ? endDate.getTime() : "";
+////            var uri = "newAppointment.html#modul=new&folder_id="+infolder+"&view="+currentCalendarView+"&start_date="+startdate.getTime()+"&end_date="+endDate+"&folderOwner="+userId;
+////            // is all day?
+////			if (wholeDay){
+////			    uri += "&full_time="+wholeDay;
+////			}
+//			// open window
+//            var data = {};
+//            if (oFromMail) {
+//			    // to add participants for example
+//				data.sFromModule = oFromMail.module;
+//				data.oFromMail = oFromMail.data;
+//			}
+//			ox.api.calendar.compose({
+//				params: {
+//					modul: "new",
+//					folder_id: infolder,
+//					view: currentCalendarView,
+//					start_date: startdate.getTime(),
+//					end_date: endDate,
+//					folderOwner: userId,
+//					full_time: wholeDay
+//				},
+//				data: data
+//			});
+//			
+////			var windowRef = newWindow(uri, getWindowOptions(null, 680));
+////			if (oFromMail) {
+////			    // to add participants for example
+////				windowRef.sFromModule = oFromMail.module;
+////				windowRef.oFromMail = oFromMail.data;
+////			}				
+//		}
+//	}
 }
 
 var detailAppointmentLoading = false;
@@ -840,150 +908,6 @@ register("OX_Calendar_Delete", deleteAppointment);
 var currentCalendarRange = "";
 var currentCalendarView = "CALENDAR";
 
-	//   1 object_id
-	//  20 folder_id
-	// 100 categories
-	// 101 private flag
-	// 200 title
-	// 201 start_date
-	// 202 end_date
-	// 203 description
-	// 209 recurrence type 0=none 1=daily 2=weekly 3=monthly 4=yearly
-	// 217 notification
-	// 220 participents
-	// 400 location
-	// 401 full_time
-	// 402 shown_as	
-	// 403 colorlabel
-	
-
-fieldsToGet = new Array(1, 20, 207, 206, 2, 200, 201, 202, 203, 220, 401, 402, 209, 400, 101, 102);
-
-function calObj(objFromServer){
-	
-	var count = 0;
-	var startDate;
-	this.id = objFromServer[count++];	// objectID			
-	this.folderID = objFromServer[count++];	// folderID
-	
-	for(var q = 2; q < fieldsToGet.length; q++){
-		switch (fieldsToGet[q]) {
-			case 100:
-				this.categories = objFromServer[count++];	// categories
-				break;
-			case 101:
-				this.private_flag = objFromServer[count++];
-				break;
-			case 102:
-				this.color = objFromServer[count++];	// color label
-				break;
-			case 200:
-				this.title = objFromServer[count++];	// title				
-				break;
-			case 201:
-				startDate = new Date(objFromServer[count]);
-				this.startDate = new Date(objFromServer[count++]);
-				this.start = parseInt(((startDate.getUTCHours() * 60) + startDate.getUTCMinutes())/(60/hoursplit));
-				this.starthuman = formatDate(startDate, "time");	// human readable start time
-				if((this.starthuman.length - (this.starthuman.lastIndexOf(":"))) < 3)
-					this.starthuman = this.starthuman + "0";
-				if(this.starthuman.length < 5)
-					this.starthuman = "0" + this.starthuman;
-				break;
-			case 202:
-				var endDate = new Date(objFromServer[count]);
-				this.endDate = new Date(objFromServer[count++]);
-				this.endhuman = formatDate(endDate, "time");	// human readable end time
-				var activeDate = (new Date(activeYear, activeMonth, activeDay)).getTime();
-				var startDateTmp = (new Date(startDate.getUTCFullYear(), startDate.getUTCMonth(), startDate.getUTCDate())).getTime();
-				var endDateTmp = (new Date(endDate.getUTCFullYear(), endDate.getUTCMonth(), endDate.getUTCDate())).getTime();
-				if(startDateTmp != endDateTmp){
-					if(startDateTmp == activeDate && endDateTmp > activeDate){
-						endDate.setUTCMonth(activeMonth);
-						endDate.setUTCDate(activeDay);
-						endDate.setUTCHours(24);
-						endDate.setUTCMinutes(0);
-					} else if(startDateTmp < activeDate && endDateTmp > activeDate){
-							if(startDate.getUTCDate() != 31){
-								startDate.setUTCMonth(activeMonth);
-								startDate.setUTCDate(activeDay);
-							} else {
-								startDate.setUTCDate(activeDay);
-								startDate.setUTCMonth(activeMonth);
-							}
-							startDate.setUTCHours(0);
-							startDate.setUTCMinutes(0);
-							startDate.setUTCSeconds(0);
-							if(endDate.getUTCDate() != 31){					
-								endDate.setUTCMonth(activeMonth);
-								endDate.setUTCDate(activeDay);
-							} else {
-								endDate.setUTCDate(activeDay);
-								endDate.setUTCMonth(activeMonth);
-							}
-							endDate.setUTCHours(24);
-							endDate.setUTCMinutes(0);
-							endDate.setUTCSeconds(0);
-							this.start = startDate.getUTCHours() + "." + (parseInt((startDate.getUTCMinutes()/15), 10)*25);	// startdate to calculating
-					} else if(startDateTmp < activeDate && endDateTmp == activeDate) {
-							if(startDate.getUTCDate() != 31){
-								startDate.setUTCMonth(activeMonth);
-								startDate.setUTCDate(activeDay);
-							} else {
-								startDate.setUTCDate(activeDay);
-								startDate.setUTCMonth(activeMonth);
-							}
-							startDate.setUTCHours(0);
-							startDate.setUTCMinutes(0);
-							this.start = startDate.getUTCHours() + "." + (parseInt((startDate.getUTCMinutes()/15), 10)*25);	// startdate to calculating
-					}
-				}
-				this.start = Number(this.start);
-				var minutes = ((endDate.getTime() - startDate.getTime())/60000);
-				this.end = minutes/(60/hoursplit); // duration for calculating;
-				//TODO calculate the correct length dependent on the hoursplit
-				if(this.end > 24*hoursplit)
-					this.end = 24*hoursplit-this.start;
-				if(this.end == 0)
-					this.end += 1;
-				if((this.endhuman.length - (this.endhuman.lastIndexOf(":"))) < 3)
-					this.endhuman = this.endhuman.substring(0, this.endhuman.indexOf(":")) + ":0" + this.endhuman.substring(this.endhuman.indexOf(":")+1);					
-				break;
-			case 203:
-				this.discription = objFromServer[count++];	// discription
-				break;
-			case 207:
-				this.recurrence_position = objFromServer[count++];
-				break;				
-			case 209:
-				this.recurrence_type = objFromServer[count++];
-				break;				
-			case 217:
-				this.notification = objFromServer[count++];
-				break;
-			case 220:
-				this.participants = objFromServer[count++];
-				break;
-			case 400:
-				this.locat = objFromServer[count++];		// location
-				break;
-			case 401:
-				this.fulltime = objFromServer[count++];	// hole day appointment
-				break;	
-			case 402:
-				this.shown = objFromServer[count++];	// 
-				break;
-			case 206:
-                this.recurrence_id = objFromServer[count++]; 
-                break;
-            case 2:
-                this.created_by = objFromServer[count++];
-            default:            
-				break;
-		}
-	}
-}	
-
 function displayNameDayView(){
 	oMainFolderTree.cache.get_folder(activefolder,displayNameDayViewCb);
 }
@@ -1041,6 +965,13 @@ function showAllAppointments(){
 }
 
 function openMailToApp(oDate, oMailObjects, sMod) {
+	
+	// for PIM this feature isn't allowed, so triggering the upsell dialog
+	if (corewindow.configGetKey('participants.showDialog') == false) {  
+		corewindow.triggerEvent('Feature_Not_Available','modules/calendar/new/add_participants', window);
+		return;
+	}
+	
 	if (sMod == "contacts") {
 		var aIds=new Array();
 		for(var indx=0; indx<oMailObjects.length; indx++) {
@@ -1073,13 +1004,38 @@ function openAppointmentPopup(e) {
 
 	function edit_whole_series() {
 		var app_id = selappoint.recurrence_id || selappoint.id;
-		appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+app_id+"&recurrence_position=0&folder_id="+selappoint.folder, getWindowOptions(), selappoint);
+		ox.api.calendar.edit({
+			params: {
+				id: app_id,
+				recurrence_position: 0,
+				folder: selappoint.folder
+			},
+			id: selappoint
+		});
+		//appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+app_id+"&recurrence_position=0&folder_id="+selappoint.folder, getWindowOptions(null, 680), selappoint);
 	}
 	function edit_single_series() {
-		appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+selappoint.id+"&recurrence_position="+selappoint.recurrence_position+"&folder_id="+selappoint.folder+"&singleappointment=yes", getWindowOptions(), selappoint);
+		ox.api.calendar.edit({
+			params: {
+				id: selappoint.id,
+				recurrence_position: selappoint.recurrence_position,
+				folder: selappoint.folder,
+				singleappointment: "yes"
+			},
+			id: selappoint
+		});
+		//appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+selappoint.id+"&recurrence_position="+selappoint.recurrence_position+"&folder_id="+selappoint.folder+"&singleappointment=yes", getWindowOptions(null, 680), selappoint);
 	}
 	function edit_single_appointment() {
-		appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+selappoint.id+"&recurrence_position=0&folder_id="+selappoint.folder, getWindowOptions(), selappoint);
+		ox.api.calendar.edit({
+			params: {
+				id: selappoint.id,
+				recurrence_position: 0,
+				folder: selappoint.folder
+			},
+			id: selappoint
+		});
+		//appointmentPopup=newWindow("newAppointment.html#modul=edit&view="+currentCalendarView+"&id="+selappoint.id+"&recurrence_position=0&folder_id="+selappoint.folder, getWindowOptions(null, 680), selappoint);
 	}
 	
 	if(selectedAppointment.length){
@@ -1090,9 +1046,7 @@ function openAppointmentPopup(e) {
     if (!menucheckRight("WRITE")) {
         triggerEvent("OX_New_Error", 4,
             _("You do not have write permission for this object."));
-    } else if(   selappoint.recurrence_position > 0 && selappoint.recurrence_id
-              && selappoint.recurrence_id == selappoint.id)
-    {
+    } else if (selappoint.recurrence_position > 0 && selappoint.recurrence_id) {
 		newConfirm(_("Edit Appointment"),_("Do you want to edit the whole series or a single series appointment? Please note when changing a serial appointment, exceptions to the series are reset."),AlertPopup.SERIESBUTTON,null,null,null,null,edit_whole_series,edit_single_series);
 	} else {
 		edit_single_appointment();
@@ -1100,6 +1054,10 @@ function openAppointmentPopup(e) {
 	if (e) { stopEvent(e) };
 }
 
+function getLastCalendarView() {
+    return menulastviews.calendar || getDefaultCalendarView();
+}
+
 function deleteAppointment(){
     
     // the team view has its own handling of deleting appointments
@@ -1158,7 +1116,7 @@ function deleteAppointment(){
 						calendarSearch(lastCalendarSearch.module, lastCalendarSearch.searchstring, null, null, lastCalendarSearch.folder);
 					}
 				} else if(currentpath2[1] == "detail") {
-					triggerEvent("OX_Switch_View",configGetKey("gui.calendar.view"));
+					triggerEvent("OX_Switch_View", getLastCalendarView());
 				}
 			} 
 			selectedAppointment={};	
@@ -1250,6 +1208,115 @@ function calendar_HeaderUpdate(num) {
 	calendarFolderPath.drawDOMNode(view, activefolder);
 }
 
+function setCalCategories(action, category) {
+	if (currentview.name.match(/team/) && calendarGridHandlers) {
+		calendarGridHandlers.setCategories(action, category);
+	
+	} else {
+		var objects = [];
+		if (Object.prototype.toString.call(selectedAppointment) == "[object Array]") {
+			objects = clone(selectedAppointment);
+		} else {
+			objects = [ clone(selectedAppointment) ];
+		}
+		
+		for (var i = 0; i < objects.length; i++) {
+            objects[i].module = "calendar";
+            objects[i].folder_id = objects[i].folder;
+            delete objects[i].folder;
+        }
+		
+		var collection = { columns: ["created_by", "users", "title", "location",
+                                     "start_date", "end_date", "categories"],
+                           objects: objects };
+		OXCache.newRequest(null, "calendar", collection, null, 
+		function (data) {
+        	var cats = [], apps = data.objects;
+            for (var i in apps) {
+            	if (apps[i].categories) {
+            		cats.push(apps[i].categories);
+            	}
+            }            
+            function update(list, str) {
+            	// update appointments
+            	var multiple = [], $l = apps.length;
+                for (var i = 0; i < $l; i++) {
+                    var request = {
+                        "action": "update",
+                        "module": "calendar",
+                        "folder": apps[i].folder_id,
+                        "id": apps[i].id,
+                        "data": {
+                        	"categories": (str || apps[i].categories || null)
+                        },
+                        "timestamp": apps[i].timestamp
+                    };
+                    // add recurrence_position?
+                    if (apps[i].recurrence_position) {
+                        request.recurrence_position = apps[i].recurrence_position;
+                    }
+                    multiple.push(request);
+                }
+                json.put(AjaxRoot + "/multiple?session=" + session, multiple, null, function(response) {            	
+                	if (currentpath[0] == "calendar") {
+        				if (currentpath2[1] == "calendar") {
+        					window.setTimeout("storageCache.update()", 300);
+        				} else if (currentpath2[1] == "list") {
+        					storageCache.update();
+        				} else if (currentpath2[1] == "detail") {
+        					triggerEvent("OX_Switch_View", getLastCalendarView());
+        				}        				
+        				//triggerEvent("Selected", [selectedAppointment]);
+        				
+        				// don't ask. as long as all modules doesn't use the cache we have
+        				// to force an update here. otherwise re-selection of a previous
+        				// edit object fails with old data. highly needs to be recoded!
+        				OXCache.newRequest(null, "calendar", { columns: [ "categories"],
+        		            objects: apps }, null, emptyFunction, true);
+        			}
+                });
+            }
+            
+            if (action == "add") { 
+            	// iterate over all apps and add the new category to 
+            	// each of it
+            	for (var i in apps) {
+                	if (apps[i].categories) {
+                		apps[i].categories = ox.categories.utils.paramToString(            			
+                    			ox.categories.getByString(
+                    					(category[0] + ", " + apps[i].categories), 
+                    						ox.categories.match.ALL, true), "name");
+                	} else {
+                		apps[i].categories = category[0];
+                	}
+                }
+            	update();
+            	
+            } else if (action == "delete_all") { 
+            	// just in case, delete the old categories
+            	for (var i in apps) {
+            		delete (apps[i].categories);
+                }
+            	update(cats, null);
+            	
+            } else {
+            	// open dialog
+            	ox.categories.ui.open(cats.join(","), update);
+            }
+        	
+        });
+	}
+}
+
+function addCalCategories(categories) {
+	setCalCategories("add", categories);
+}
+
+function deleteCalCategories(category) {
+	setCalCategories("delete_all", category);
+}
+
+
 /*
  *	Simple Calendar API
  */
@@ -1289,7 +1356,9 @@ ox.calendar.get = function(folder_id, id, recurrence_position, callback) {
 		
 		// server request
 		ox.JSON.get(AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + id +
-			"&folder=" + folder_id + "&recurrence_position=" + recurrence_position,
+            "&folder=" + folder_id +
+            (recurrence_position ? "&recurrence_position=" + recurrence_position
+                                 : ""),
 			// success handler
 			function(response) {
 				// debug?
@@ -1443,10 +1512,17 @@ ox.calendar.ui.editNew = function(param) {
 				app.end_date = app.start_date + 2 * ox.calendar.HOUR; // default length: two hours
 			}			
 			// open new window
-			newWindow(
-				"newAppointment.html#modul=new&folder_id=" + app.folder_id + 
-				"&start_date=" + app.start_date + "&end_date=" + app.end_date+"", getWindowOptions()
-			);
+			ox.api.calendar.compose({
+				params: {
+					folder: app.folder_id,
+					start_date: app.start_date,
+					end_date: app.end_date
+				}
+			});
+//			newWindow(
+//				"newAppointment.html#modul=new&folder_id=" + app.folder_id + 
+//				"&start_date=" + app.start_date + "&end_date=" + app.end_date+"", getWindowOptions(null, 680)
+//			);
 		};
 		// has general write privileges?
 		rightshandler.checkRights("calendar", null, app, cont, function() {});
@@ -1466,7 +1542,7 @@ ox.calendar.isRecurrence = function(app) {
 };
 
 ox.calendar.isSeries = function(app) {
-	return app.recurrence_position == 0 && app.recurrence_type > 0;
+	return !app.recurrence_position && app.recurrence_type > 0;
 };
 
 ox.calendar.isSingle = function(app) {
@@ -1485,17 +1561,32 @@ ox.calendar.ui.edit = function(app) {
 		triggerEvent("OX_Clear_All_Edit_Lines");
 		// dialog handlers
 		var edit = function() {
-			newWindow(
-				"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
-				"&recurrence_position=0&folder_id=" + app.folder_id, getWindowOptions(), app
-			);
+			ox.api.calendar.edit({
+				params: {
+					id: app.id,
+					folder: app.folder_id,
+					recurrence_position: 0
+				}
+			});
+//			newWindow(
+//				"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
+//				"&recurrence_position=0&folder_id=" + app.folder_id, getWindowOptions(null, 680), app
+//			);
 		};
 		var editRecurrence = function() {
-			newWindow(
-					"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
-					"&recurrence_position=" + app.recurrence_position + "&folder_id=" + app.folder_id +
-					"&singleappointment=yes", getWindowOptions(), app
-				);
+			ox.api.calendar.edit({
+				params: {
+					id: app.id,
+					folder: app.folder_id,
+					recurrence_position: app.recurrence_position,
+					singleappointment: "yes"
+				}
+			});
+//			newWindow(
+//					"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
+//					"&recurrence_position=" + app.recurrence_position + "&folder_id=" + app.folder_id +
+//					"&singleappointment=yes", getWindowOptions(null, 680), app
+//				);
 		};
 		// write privileges?
 		menuhasRightandLoad([app], "WRITE",
@@ -1557,7 +1648,7 @@ ox.calendar.update = function(app, callback) {
 				delete requestData.recurrence_start;
 				delete requestData.recurrence_date_position;
 				delete requestData.days;
-				delete requestData.days_in_month;
+				delete requestData.day_in_month;
 				delete requestData.month;
 				delete requestData.interval;
 				delete requestData.occurrences;
