@@ -22,7 +22,7 @@ function calendarDeleteSearch()
 	calendarGrid.sort = function(id, order) {
 		initLiveGridCalendar(currentpath2[2]);
 	};	
-	triggerEvent("OX_Switch_View", menulastviews["calendar"] || configGetKey("gui.calendar.view"));
+	triggerEvent("OX_Switch_View", getLastCalendarView());
 }
 function initCalenderLiveGridOnLoad() {
 	
@@ -216,7 +216,7 @@ function initCalenderLiveGridOnLoad() {
 	// livegrid double click 
 	calendarGrid.events.register("Activated", function(ids){
 		if(ids && ids.length > 0) {
-			if(menuhasRight(ids,"WRITE")) {
+			if(menuhasRight(ids,"WRITE") && !isPrivateApp()) {
 				selectedAppointment = ids;
 				openAppointmentPopup();
 			} else {
@@ -271,6 +271,10 @@ function initLiveGridCalendar(range) {
 				start = getDayInSameWeek(new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)), weekStart) * 864e5;
 				end = start + 604800000;
 				break;
+        case "custom":
+            start = Date.UTC(activeYear,activeMonth,activeDay);              
+            end = start +(cwwdaysinweek*1000*60*60*24);
+            break;
 		case "search":
 				calendarGrid.sort = function (sort, order) {
 					calendarSearch(lastCalendarSearch.module, 
@@ -280,6 +284,7 @@ function initLiveGridCalendar(range) {
                         )};
 				calendarGrid.disablehover=!configGetKey("gui.effects.hover.calendar");
 				calendarGrid.enable(tmpStorage);
+				storageCache.setCurrent(tmpStorage);
 				break;
 	}
 	if(end != null && start != null){
@@ -289,6 +294,7 @@ function initLiveGridCalendar(range) {
 					options.sort = calendarGrid.sort_id;
 					options.order = calendarGrid.sort_order;
 				}
+				options.showPrivate = true;
 				storageCache.get(
 					AjaxRoot + "/calendar",
 					options,
@@ -308,6 +314,7 @@ function initLiveGridCalendar(range) {
 				options.sort = calendarGrid.sort_id;
 				options.order = calendarGrid.sort_order;
 			}
+			options.showPrivate = true;
 			storageCache.get(
 				AjaxRoot + "/calendar",
 				options,
@@ -392,6 +399,7 @@ function goToNextListView(direction){
 		case "search":
 				calendarGrid.disablehover=!configGetKey("gui.effects.hover.calendar");
 				calendarGrid.enable(tmpStorage);
+                storageCache.setCurrent(tmpStorage);
 				break;
 	}
 	if(end != null && start != null){
@@ -455,6 +463,14 @@ function updateHeaderListView() {
 			$("calendarlistheaderdiv").style.visibility = "visible";		
 			$("calendarlistheader").firstChild.data = formatDateTime("MM/yyyy", new Date(Date.UTC(activeYear,activeMonth,activeDay,0,0,0)));
 			break;
+        case "custom":
+            $("calendarlistheaderdiv").style.visibility = "visible";        
+            var start = Date.UTC(activeYear, activeMonth, activeDay);
+            $("calendarlistheader").firstChild.data = cwwdaysinweek == 1
+                ? formatDate(start, "dateday")
+                : formatDate(start, "date") + " - " +
+                  formatDate(start + (cwwdaysinweek - 1) * 864e5, "date"); // ms/day
+            break;
 		case "search":
 			$("calendarlistheaderdiv").style.visibility = "hidden";
 			$("calendarlistheader").firstChild.data = ' ';
@@ -588,6 +604,7 @@ function calendarSearch(module, searchstring, order, callback, folder) {
 					} else {
 						calendarGrid.disablehover=!configGetKey("gui.effects.hover.calendar");
 						calendarGrid.enable(tmpStorage);
+                        storageCache.setCurrent(tmpStorage);
 					}					
 	});	
 }
