@@ -41,7 +41,8 @@ function fn_minicalendar_action() {
 	triggerEvent("OX_Mini_Calendar_Date_Picked", activeYear, activeMonth, activeDay);
 
 	if(currentpath[0] == "calendar") {
-		if (currentpath[2] == "month") {
+		if (currentpath[1] != "team" && currentpath[2] == "month") {
+			// this routine is not required in team view; might do too much in other views anyway...
 	        loadMonthView();
 		} 	
 		triggerEvent("OX_Switch_View",currentpath.join("/"));			
