@@ -54,13 +54,13 @@ function detailAppointmentOnload(callback)
 //	gridatt = makeDetailAppointmentAttachmentGrid();
 
 	var json = new JSON();
-	var recurrencePosition = (selectedAppointment.recurrence_position) ? selectedAppointment.recurrence_position : 0;
 	
-	json.get(AjaxRoot + "/calendar?action=get&session=" + session 
-									+"&id="+selectedAppointment.id
-									+"&folder="+selectedAppointment.folder
-									+"&recurrence_position="+recurrencePosition+"&"
-		,
+    json.get(AjaxRoot + "/calendar?action=get&session=" + session +
+        "&id=" + selectedAppointment.id +
+        "&folder=" + selectedAppointment.folder +
+        (selectedAppointment.recurrence_position ?
+            "&recurrence_position=" + selectedAppointment.recurrence_position :
+            ""),
 		null,
 		function(fieldsToGet) {
 			if (fieldsToGet) {				
@@ -87,6 +87,7 @@ function detailAppointmentOnload(callback)
 					else if(aDetailFieldsToClear[idDetailFieldsToClear] == "setInput")	
 						$(idDetailFieldsToClear).value = " "; 	
 				}
+				removeChildNodes($("a_d_categories"));
 				removeChildNodes($("a_d_note")); // clean-up notes
 				
 				var participantTabDiv = $("a_d_count_participants");
@@ -260,11 +261,14 @@ function detailAppointmentOnload(callback)
 							break;
 							
 						case 'categories':
-							$("a_d_categories").firstChild.data = fieldsToGet.data[a_d_data];
-							aPrintDetailApp[8] = Print.createContent(_("Tags:"),fieldsToGet.data[a_d_data]);	
-							aDetailFieldsToClear["a_d_categories"] = "set";
+							var cat = (fieldsToGet.data[a_d_data] || "");
+			                $("a_d_categories").style.display = cat.length ? "" : "none";                  
+			                if (cat.length) {
+				                ox.categories.ui.drawCategoriesList(ox.categories.getByString(cat), 
+				                		  $("a_d_categories"));
+			                }
+							aPrintDetailApp[8] = Print.createContent(_("Categories:"),fieldsToGet.data[a_d_data]);	
 							break;
-							
 						case 'users':
 							objAppDetailParticipants.usersD = fieldsToGet.data[a_d_data];
 							break;
@@ -297,7 +301,7 @@ function detailAppointmentOnload(callback)
 			
 		},
 		function(error) {
-			triggerEvent("OX_Switch_View", configGetKey("gui.calendar.view"));
+			triggerEvent("OX_Switch_View", getLastCalendarView());
 			return true;
 		}
 	); 
