@@ -295,7 +295,7 @@ function selectDayInMonthView(evt) {
 function monthView() {
 	this.dateIdAssoc = new Object();
 	this.aAppointmentAssoc = new Object();
-	this.calendarwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400);
+	this.calendarwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 100, 101);
 	this.oCalendarTool = new calendarTool(activeMonth, activeYear);
 	this.oCalendar;
 	this.storage = null;	
@@ -627,7 +627,7 @@ monthView.prototype = {
 			             start_date, calendarObjects.end_date, calendarObjects.note,
 			             calendarObjects.recurrence_type, calendarObjects.participants, 
 			             calendarObjects.full_time, calendarObjects.shown_as, calendarObjects.color_label, 
-			             calendarObjects.location, null, null),
+			             calendarObjects.location, calendarObjects.private_flag, null, calendarObjects.categories),
 	             sAppId, full_time, isMultiday);
 			
 			$2(sCurrId).appendChild(dAppDiv);
@@ -826,7 +826,7 @@ monthView.prototype = {
 		    var newObject = {
 		    	id: object[0], // 1
 		    	folder: object[1], // 20
-		    	recurrence_position: object[2], // 207
+		    	recurrence_position: object[2] || 0, // 207
 		    	recurrence_id: object[3], // 206
 		    	created_by: object[4], // 2
 		    	title: object[5], // 200
@@ -838,7 +838,9 @@ monthView.prototype = {
 		        full_time: object[11], // 401
 		        shown_as: object[12], // 402
 		        color_label: object[13], // 102
-		        location: object[14]    			    	
+		        location: object[14], // 400
+		        categories: object[15], // 100
+		        private_flag: object[16] // 101
 		    }
 		    newObject["indxxx"] = index;
 		    object["indxxx"] = index;
@@ -902,7 +904,7 @@ monthView.prototype = {
 		} else {		
 			var oParameters = { action:"all", start:starttime, end:endtime, folder:sFolderId, columns:"1,20,207,206,2" };
 		}	
-	
+		oParameters.showPrivate = true;
 		storageCache.get(AjaxRoot + "/calendar", oParameters, 
 		                function(storage) {
 						 	cb_fkt(storage);
@@ -1005,6 +1007,9 @@ monthView.prototype = {
 	},
 	
 	getAppointmentDiv: function(calendarObjects,sId,fullday,isMultiday) {
+		var owner = getFolderOwner(activefolder);
+		var isPrivateShared = (owner !== configGetKey('identifier') && calendarObjects.private_flag === true);
+		
 		var appointmentDate = new Date(calendarObjects.start_date);
 		if (isMultiday) appointmentDate.setUTCMinutes(0);
 		var formattedTime = formatDate(appointmentDate, "time");	
@@ -1012,8 +1017,20 @@ monthView.prototype = {
 	
 		var datDIV = newnode("div", {border: "1px solid"}, 
 					{ className: (fullday ? 
-						"showFullTimeAppointmentMonth wholeDayBackground border-color-image"	: 
-						"appInMonthView background-color-content border-color-image")} );
+						"showFullTimeAppointmentMonth wholeDayBackground border-color-image" : 
+						"appInMonthView border-color-image")} );
+		
+		// setting background color depending on categories, if set
+		var backColor = " background-color-content";
+		if (calendarObjects.categories) {
+			// getting the first color out of the categories list
+			var cat = ox.categories.getFirstMatch(calendarObjects.categories);
+			if (cat.color != 0) {
+				backColor = " colorLabel" + cat.color;
+			}
+		}
+		datDIV.className += backColor;
+						
 		var textDiv = newnode("div", { overflow: "hidden" }, 
 					{ className: "showAppointmentTextMonth" + (fullday ? "Full" : "") + " dateCalendarFontSize" });
 	
@@ -1059,41 +1076,44 @@ monthView.prototype = {
 			      editAppointment(calendarObjects, {title:sStr});
 			  }
 	    );
-	
-		registerSource(datDIV, "calendar", function () { 
-			objMoveCopy.begin("calendar", [calendarObjects]);
-			return objMoveCopy;
-		}, null, null, calendardefaultdisabled, defaultdisabledremove);
-		oInplEdit.input_height = "1em";
-		oInplEdit.input_fontsize = "8pt";
-        addDOMEvent(datDIV, "contextmenu", function(e) {
-            stopEvent(e);
-            getSelectMonthView(e);
-            globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                calendarSelection);
-        });
-	
-	    addDOMEvent(datDIV, "click", function(e) {
-	        var SelObj = calendarSelection.getID();
-	        if (SelObj && SelObj.id == calendarObjects.id &&
-	            SelObj.folder == calendarObjects.folder_id &&
-	            SelObj.recurrence_position == calendarObjects.recurrence_position) {
-	            if (window.event) {
-	                e = window.event;
-	            }
-	            oInplEdit.on();
-	            cancelBubbling(e);      
-	        } else {
+	 	oInplEdit.style.height = "1em";
+		oInplEdit.style.fontSize = "8pt"
+			
+	 	if (isPrivateShared == false) {
+	 		registerSource(datDIV, "calendar", function () { 
+				objMoveCopy.begin("calendar", [calendarObjects]);
+				return objMoveCopy;
+			}, null, null, calendardefaultdisabled, defaultdisabledremove);
+	 		
+	 		addDOMEvent(datDIV, "contextmenu", function(e) {
+	            stopEvent(e);
 	            getSelectMonthView(e);
-	        }
-	    });     
-//	    addDOMEvent(datDIV, "mousedown", function(e) { 
-//	        getSelectMonthView(e);
-//	    });
-	    addDOMEvent(datDIV, "dblclick", openAppointmentPopup);
-	
-		datDIV.oxcalobj = "" + calendarObjects.folder_id + "-" + calendarObjects.id 
-		                  + "-" + calendarObjects.recurrence_position;
+	            globalContextMenus.calendar.display(e.clientX, e.clientY,
+	                                                calendarSelection);
+	        });
+		
+		    addDOMEvent(datDIV, "click", function(e) {
+		        var SelObj = calendarSelection.getID();
+		        if (SelObj && SelObj.id == calendarObjects.id &&
+		            SelObj.folder == calendarObjects.folder_id &&
+		            SelObj.recurrence_position == calendarObjects.recurrence_position) {
+		            if (window.event) {
+		                e = window.event;
+		            }
+		            oInplEdit.on();
+		            cancelBubbling(e);      
+		        } else {
+		            getSelectMonthView(e);
+		        }
+		    });   
+		    addDOMEvent(datDIV, "dblclick", openAppointmentPopup);
+		    datDIV.oxcalobj = "" + calendarObjects.folder_id + "-" + calendarObjects.id 
+            	+ "-" + calendarObjects.recurrence_position;
+	 	} else {
+	 		// private app in shared folder, so default cursor
+	 		datDIV.style.cursor = "default";
+	 	}
+
 		return datDIV;
 	}
 }
