@@ -48,8 +48,7 @@ var configGetKey = corewindow.configGetKey;
 var configSetKey = corewindow.configSetKey;
 var savePending = false;
 var folderOwner = null;
-//var sFromModule;
-//var oFromMail;
+var data = {};
 var externalParticipants = null;
 
 //register("Loaded",initAppointment);
@@ -99,6 +98,8 @@ registerView("calendar_new/appointment",
 	}
 );
 
+var externalCounter = 0;
+
 registerView("calendar_new/participant",
 	function() { 
 		$("tab2").style.display="block";
@@ -123,10 +124,12 @@ registerView("calendar_new/participant",
 			            }
 			        }
 			        if (found.length) {
-			        	newAlert(_("Info"), format(_("The following addresses are already on the list of participants and therefore not been added: %s"), found.join(",")));
+			        	newAlert(_("Info"),
+			        	    //#, c-format
+			        	    format(_("The following addresses are already on the list of participants and therefore not been added: %s"), found.join(",")));
 			        } else {
 	                    extStorage.append(
-	                        [[ "contact_ext_" + new Date().getTime(), 0, 
+	                        [[ "contact_ext_" + externalCounter++, 0, 
 	                           data[i].displayName, _("not sent"), "", data[i].email, 
 	                           "contact", null ]]
 	                    );
@@ -234,7 +237,10 @@ function setBeforeUnload(on){
 
 function newAppointmentOnload(){
 	
-	activemodule="calendar_new";
+	// get passed data
+	data = jQuery.extend((url || {}), ox.api.window.getData(url.guid));
+	
+	activemodule = "calendar_new";
 	initContents("calendar_new");
 	initAll();
 	
@@ -249,6 +255,14 @@ function newAppointmentOnload(){
 	},0);
 }
 
+function openCategoriesDialog() {
+	ox.categories.ui.open((calenObj.categories || ""), function(list, str) {
+		calenObj.categories = str;
+		ox.categories.ui.drawCategoriesList(ox.categories.getByString(calenObj.categories), 
+				$("newappointment_categories_list"));
+	});
+}
+
 function initAppointment() {
 	session = corewindow.session;	
 		
@@ -258,25 +272,18 @@ function initAppointment() {
 	register("OX_SAVE_OBJECT", writeNewAppointment);
 	register("OX_Cancel_Object", closeNewAppointmentWindow);
 
-	if(url["folder_id"]){
-		clickedItem = url["folder_id"];
+	if (data["folder_id"]){
+		clickedItem = data["folder_id"];
 	} else {
 		clickedItem = configGetKey("folder.calendar");
 	}
-	newAppointment.categories = new Categories(configGetKey("global_categories"),
-											   configGetKey("gui.private_categories"),
-											   "newappointment_categories_div",
-											   document.forms.newAppointmentForm.newappointment_categories,
-											   "newappointment_categories_button",
-											   "newappointment_categories_divContent");
-	newAppointment.categories.getHTML();
-
+		
 	createComboxes();
 			
 	//Getting folder owner
 	folderOwner = configGetKey("identifier");
-	if (url["folderowner"]) {
-		folderOwner = url["folderowner"];
+	if (data["folderowner"]) {
+		folderOwner = data["folderowner"];
     } else if (clickedItem) {
     	// try to resolve the owner over folder cache
     	var _tmpF = oMainFolderTree.cache.find_folder(clickedItem);
@@ -298,12 +305,8 @@ function initAppointment() {
     }
 	
 	if (window.location.hash != "") {
+        createSeriesView();
 		fillFields();
-		if(url['modul'] == "edit" ) {
-			createSeriesView();
-		} else {
-			$("series_text").value = _("No series");
-		}
 	}
 	setTabLists(tabsList, panelsList, eventList);
 	loadingComplete();
@@ -320,6 +323,34 @@ function initAppointment() {
 	   oMainFolderTree.get_folder_path(clickedItem, cb_getpath);
 	   triggerEvent("OX_Switch_View",'calendar_new/appointment');
 	}, 0);
+	
+	// just in case it's not set
+	if (!calenObj.categories) {
+		calenObj.categories = "";
+	}
+	
+	// add click on categories button
+	addDOMEvent($("newappointment_categories_button"), "click", function(e) {
+		openCategoriesDialog();
+	});
+	// handle dbl click which attachs an inplace input field to div
+	addDOMEvent($("newappointment_categories_list"), "dblclick", function(e) {
+		ox.categories.ui.attachInplaceInput($("newappointment_categories_list"),
+			function(value) {				
+				// handle value
+				var list = clone(ox.categories.getByString(calenObj.categories, ox.categories.match.ALL, true));
+				// add only if not empty!
+				if (value && trimStr(value).length && !ox.categories.utils.existsInObject(trimStr(value), list)) {
+					var category = { name: value, color: 0 };
+					list.push(category);
+					calenObj.categories = ox.categories.utils.paramToString(list, "name");				
+				}
+				ox.categories.ui.drawCategoriesList(
+						ox.categories.getByString(calenObj.categories), 
+						$("newappointment_categories_list"));
+			}
+		);		
+	});
 }
 
 function createSeriesView(){
@@ -364,7 +395,7 @@ function createSeriesView(){
 		
 	});
 	if(calenObj)
-		globalseries.setParameters(calenObj);	
+		globalseries.setParameters(calenObj, data.modul == "new");
 }
 
 function showSeriesDialogue() {
@@ -376,7 +407,7 @@ function showSeriesDialogue() {
 }
 
 function initAttachmentsGrid() {
-	var nId = (url['modul'] && url['modul'] == "edit") ? url["id"] : false;
+	var nId = (data['modul'] && data['modul'] == "edit") ? data["id"] : false;
 	// take the origin folder when editing an object as we may run in trouble if the user
 	// change the folder and goes to the attachment tab, see bug #11336
 	var nFolder = calenObj && calenObj.folder_id ? calenObj.folder_id : clickedItem;
@@ -384,7 +415,9 @@ function initAttachmentsGrid() {
 }
 
 function closeTimeout() {
-	window.setTimeout("window.close()", 100);
+	window.setTimeout(function () {
+		ox.api.window.close(url.guid);
+	}, 100);
 }
 
 function createMiniCalendar(startdate,enddate)
@@ -730,27 +763,21 @@ function toggleMiniEnd(){
 	}
 }
 function fillFields(){
-	if (!url) { 
-		url = new Object(); 
-	}
-	if (!url['modul'] || !url['folder_id']) { 
-		return; 
+	if (!data.module) {
+		data.module = "new";
 	}
 	
-	if (url['modul'] == "edit") {		
-		//document.title = _("Edit appointment");			
-		//TODO "_" REMOVE
-		if(url["id"].indexOf("_") != -1) {
-			url["id"] = url["id"].substring(0, url["id"].indexOf("_"));
+	if (data['modul'] == "edit") {		
+		if (data["id"].indexOf("_") != -1) {
+			data["id"] = data["id"].substring(0, data["id"].indexOf("_"));
 		}
 		var uri;
-		if(url["recurrence_position"] && url["recurrence_position"] > -1 ) {
-			uri = AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + url["id"] + "&folder=" + url["folder_id"] + "&recurrence_position=" + url["recurrence_position"];	
+		if(data["recurrence_position"] && data["recurrence_position"] > 0 ) {
+			uri = AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + data["id"] + "&folder=" + data["folder_id"] + "&recurrence_position=" + data["recurrence_position"];	
 		} else {
-			uri = AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + url["id"] + "&folder=" + url["folder_id"]		
+			uri = AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + data["id"] + "&folder=" + data["folder_id"]		
 		}
-		if(url["singleappointment"] && url["singleappointment"] == "yes"){
-			//$("newappointment_personal_tr").style.display = "none";
+		if (data["singleappointment"] && data["singleappointment"] == "yes") {
 			$("newappointment_categories_tr").style.display = "none";
 		}
 		json.get(uri, null, 
@@ -761,7 +788,7 @@ function fillFields(){
 				}
 			}
 		);
-	} else if (url['modul'] == "new") {
+	} else if (data['modul'] == "new") {
 		
 		if (!calenObj.participants) {
             calenObj.participants = new Array();                
@@ -769,6 +796,9 @@ function fillFields(){
         if (!calenObj.users) {
             calenObj.users = new Array();
         }
+        if (!calenObj.confirmations) {
+            calenObj.confirmations = new Array();
+        }
         
         var _isPub = configGetKey("gui.calendar.autoadd_participant_public");
         var _tmpF = oMainFolderTree.cache.find_folder(clickedItem);
@@ -779,46 +809,54 @@ function fillFields(){
 	
         var extPart = {};
         // use clone to clean up the data provided by the core window
-        var oFromMail = window.oFromMail = clone(window.oFromMail, corewindow);
-        var sFromModule = window.sFromModule = clone(window.sFromModule, corewindow);
+        var oFromMail = data.oFromMail = clone(data.oFromMail, corewindow);
+        var sFromModule = data.sFromModule = clone(data.sFromModule, corewindow);
         // adding mail information
 		if (oFromMail != undefined && sFromModule == "mail") {
-			url['title'] = oFromMail[0].subject;
-			url["note"] = "";			
-			for (var i=0; i<oFromMail.length; i++) {
+			data['title'] = oFromMail[0].subject;
+			data["note"] = "", addresses = { "from":_("From:"), "to":_("To:"), "cc": _("Cc:") };			
+			for (var i=0; i < oFromMail.length; i++) {
 				var msg = oFromMail[i];
-				url["note"] += "---------- " + _("Original Message") + " ----------\n";
-				if (msg.from) {
-					url["note"] += _("From:") + " ";
-					for (var ia=0; ia<msg.from.length; ia++) {
-						extPart[msg.from[ia][1]] = msg.from[ia][0] || msg.from[ia][1];
-						url["note"] += msg.from[ia][1];
-						if (ia < msg.from.length-1) url["note"] += ", ";
+				data["note"] += "---------- " + _("Original Message") + " ----------\n";
+				for (var i in addresses) {					
+					if (msg[i]) {
+						data["note"] += addresses[i] + " ";
+						for (var ia=0; ia < msg[i].length; ia++) {
+							extPart[msg[i][ia][1]] = msg[i][ia][0] || msg[i][ia][1];
+							data["note"] += msg[i][ia][1];
+							if (ia < msg[i].length-1) data["note"] += ", ";
+						}
+						data["note"] += "\n";
 					}
-					url["note"] += "\n";
-				}
-				if (msg.to) {
-					url["note"] += _("To:") + " ";
-	                for (var ia=0; ia<msg.to.length; ia++) {
-	                	extPart[msg.to[ia][1]] = msg.to[ia][0] || msg.to[ia][1];
-	                    url["note"] += msg.to[ia][1];
-	                    if (ia < msg.to.length-1) url["note"] += ", ";
-	                }
-	                url["note"] += "\n";
-				}				
+				}			
 				if (msg.received_date) {
-                    url["note"] += _("Received:") + " " + formatDate(msg.received_date, "datetime") + "\n";
+                    data["note"] += _("Received:") + " " + formatDate(msg.received_date, "datetime") + "\n";
 	            }
 	            if (msg.subject) {
-	                url["note"] += _("Subject:") + " " + msg.subject + "\n";
+	                data["note"] += _("Subject:") + " " + msg.subject + "\n";
 	            }
-	            url["note"] += "\n";
+	            data["note"] += "\n";
 	            if (msg.attachments_plain && msg.attachments_plain.length) {
-	                url["note"] += msg.attachments_plain[0].content.replace(/<br>/gi, "\n");
+	                data["note"] += msg.attachments_plain[0].content.replace(/<br?(.\/)>/gi, "\n");
 	            }
-	            if (i < oFromMail.length-1) url["note"] += "\n\n";
-			}		
+	            if (i < oFromMail.length-1) data["note"] += "\n\n";
+			}
+			
+            // try to filter html parts out of mail text
+            var node = newnode("div");
+            node.innerHTML = data["note"];
+            if (node.innerText) {
+            	// IE needs <br>'s to show valid line breaks
+            	data["note"] = data["note"].replace(/\n/g, "<br/>\n");
+            	node.innerHTML = data["note"];
+            	data["note"] = node.innerText;
+            } else if (node.textContent) {
+            	// every other brother :)
+            	data["note"] = node.textContent;
+            }
+            node = null;
 		}
+		
 		// adding participants
 		if (oFromMail && sFromModule == "contacts") {			
 			for (var i = 0; i< oFromMail.length; i++) {
@@ -834,8 +872,23 @@ function fillFields(){
 		}
 		for (var ib in extPart) {
 			calenObj['participants'].push({display_name: extPart[ib], mail: ib, type: 5});
+			calenObj['confirmations'].push({display_name: extPart[ib], mail: ib, type: 5, status: 0, message: ""});
+		}
+		if (oFromMail && sFromModule == "calendar") {
+		    function copy(array) {
+		        if (oFromMail[array]) {
+		            for (var i = 0; i < oFromMail[array].length; i++) {
+		                calenObj[array].push(oFromMail[array][i]);
+		            }
+		        }
+		    }
+		    copy("participants");
+		    copy("users");
+		    copy("confirmations");
+		    setFields(oFromMail);
+		} else {
+		    setFields(data);
 		}
-		setFields(url);
 	}
 }
 
@@ -871,7 +924,10 @@ function setFields(object) {
 	var ap = $("newAppointmentForm");
 	(calenObj.title) ? ap.newappointment_description.value = calenObj.title : ap.newappointment_description.value = "";
 	(calenObj.location) ? ap.newappointment_location.value = calenObj.location : ap.newappointment_location.value = "";
-	(calenObj.categories) ? ap.newappointment_categories.value = calenObj.categories : ap.newappointment_categories.value = "";
+	if (calenObj.categories) {
+		ox.categories.ui.drawCategoriesList(ox.categories.getByString(calenObj.categories), 
+				$("newappointment_categories_list"));		
+	}
 	(calenObj.note) ? ap.newappointment_comments.value = calenObj.note : ap.newappointment_comments.value = "" ;		
 	(calenObj.recurrence_position) ? recurrencePosition = calenObj.recurrence_position : recurrencePosition = 0;
 	
@@ -914,8 +970,8 @@ function setFields(object) {
 		enddate = new Date(Date.UTC(mydate.getUTCFullYear(),mydate.getUTCMonth(),mydate.getUTCDate(),mydate.getUTCHours(),mydate.getUTCMinutes(),0));
 	} else {
 		enddate=new Date(startdate.getTime()+(1000*60*60));
-	} 
-	if(calenObj["full_time"]) {
+	}
+	if(calenObj["full_time"] === true || calenObj["full_time"] === "true") {
 		ap.newappointment_wholeday.checked = "checked";
 		window.setTimeout(function() {
 			$("newappointment_begins_time_td").style.visibility = "hidden";
@@ -947,7 +1003,7 @@ function setFields(object) {
 			reminderPopup.setKey(object.alarm);		
 		}
 		
-	} else if (url["modul"].match(/edit/,i)) {
+	} else if (data["modul"].match(/edit/,i)) {
 		// set back to -1 on edit if no reminder has been set
 		reminderPopup.setKey(-1);
 	}
@@ -971,7 +1027,7 @@ function setFields(object) {
 	
 	fillFieldsPrivate();
 	if(globalseries != null)
-		globalseries.setParameters(calenObj);
+		globalseries.setParameters(calenObj, data.modul == "new");
 	
 	// enable final participant object (and wait for callback)
 	newAppointment.participants.initalFillBigGrid(calenObj, function() {
@@ -1056,7 +1112,9 @@ function fn_afterUpload(errorUpdate) {
 	
 	// callback to close window
 	function fn_close() {
-		if (!errorUpdate) window.setTimeout("window.close()", 0);
+		if (!errorUpdate) window.setTimeout(function () {
+		    ox.api.window.close(url.guid);
+		}, 0);
 	}
 	
 	if (newAppointment.attachmentDialog.attach_changed()) {
@@ -1105,7 +1163,7 @@ function writeNewAppointment() {
 	$("newAppointmentForm").newappointment_ends_time_text.className = "dateTimeInput";
 	$("newAppointmentForm").newappointment_begins_time_text.className = "dateTimeInput";
 	
-	if (url['modul'] && url['modul'] == "new") {
+	if (data['modul'] && data['modul'] == "new") {
 		var ap = $("newAppointmentForm");
 		
 		var startdate = parseDateString(ap.newappointment_begins_date.value, "date");
@@ -1143,7 +1201,9 @@ function writeNewAppointment() {
 				if(ap.newappointment_comments.value != "Your comments") ap_object.note = ap.newappointment_comments.value;
 				if(ap.newappointment_location.value != "") ap_object.location = ap.newappointment_location.value;
 				if(ap.newappointment_wholeday.checked) ap_object.full_time = true; else ap_object.full_time = false;
-				if(ap.newappointment_categories.value != "") ap_object.categories = ap.newappointment_categories.value;
+				if(calenObj && calenObj.categories) {
+					ap_object.categories = calenObj.categories;
+				}
 				if(ap.newappointment_personal.checked && ($("newappointment_personal_tr").style.visibility == "visible" || $("newappointment_personal_tr").style.visibility == "")) 
 				{
 					ap_object.private_flag = true;
@@ -1247,7 +1307,7 @@ function writeNewAppointment() {
 			savePending = false;				
 		}
 
-	} else if(url['modul'] == "edit") {
+	} else if(data['modul'] == "edit") {
 		var ap = $("newAppointmentForm");
 		var startdate = parseDateString(ap.newappointment_begins_date.value, "date");
 		var enddate = parseDateString(ap.newappointment_ends_date.value, "date");
@@ -1295,7 +1355,9 @@ function writeNewAppointment() {
 				if (appComment != calenObj.note) ap_object.note = appComment.length != 0 ? appComment : null;
 				if(ap.newappointment_location.value != "" || ap.newappointment_location.value != calenObj.location) ap_object.location = ap.newappointment_location.value;
 				if(ap.newappointment_wholeday.checked) ap_object.full_time = true; else ap_object.full_time = false;
-				if(ap.newappointment_categories.value != null || ap.newappointment_categories.value != "" || ap.newappointment_categories.value != calenObj.categories) ap_object.categories = ap.newappointment_categories.value;
+				if (calenObj && calenObj.categories) {
+					ap_object.categories = calenObj.categories;
+				}
 				if(ap.newappointment_personal.checked  && ($("newappointment_personal_tr").style.visibility == "visible" || $("newappointment_personal_tr").style.visibility == ""))
 				{
 					ap_object.private_flag = true;
@@ -1349,7 +1411,7 @@ function writeNewAppointment() {
                     ap_object = globalseries.getParameters(ap_object);
                 }
                 
-				json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + url["id"] + "&timestamp=" + newappTimestamp + "&folder=" + url["folder_id"], ap_object, null, 
+				json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + data["id"] + "&timestamp=" + newappTimestamp + "&folder=" + data["folder_id"], ap_object, null, 
 					function(cb) {
 						if(cb && cb.data && !cb.data.conflicts) {
 							
@@ -1359,7 +1421,7 @@ function writeNewAppointment() {
 								var obj = new Object();
 								obj['attached'] = cb.data.id;
 								obj['module'] = 1;
-								obj['folder'] = ap_object.folder_id || ap_object.folder; //url["folder_id"];	
+								obj['folder'] = ap_object.folder_id || ap_object.folder; //data["folder_id"];	
 								newAppointment.attachmentDialog.do_post(obj,fn_afterUpload,null,null,cb_error);
 							}
 							else {
@@ -1421,10 +1483,10 @@ function cb_ignoreConflict(cb){
 	ap_object.ignore_conflicts = true;
 	
 	var uri = AjaxRoot + "/calendar";
-	if (url["modul"] != "edit") {
+	if (data["modul"] != "edit") {
 		uri += "?action=new";
 	} else {
-		uri += "?action=update&id=" + url["id"] + "&timestamp=" + 1154505988000*2 + "&folder=" + url["folder_id"];
+		uri += "?action=update&id=" + data["id"] + "&timestamp=" + 1154505988000*2 + "&folder=" + data["folder_id"];
 	}
 	uri += "&session=" + session;
 	
@@ -1474,7 +1536,7 @@ function wholedayNewAppointmentDisable(){
 function closeNewAppointmentWindow() {
 	function cbyes() {
 		window.onbeforeunload=null;
-		window.close();			
+		ox.api.window.close(url.guid);
 	}
 	if(messageOnCancel)
 		newConfirm(_("Close Window"),_("Do you really want to discard your changes and close the window?"),AlertPopup.YESNO,null,null,cbyes,null);	
