@@ -27,7 +27,7 @@ function WeekCalendarTool() {
 	this.oCalendarTool = new calendarTool(activeMonth,activeYear);
 	this.switchedToNext = 0;
 	this.oCalendarTool1970 = new calendarTool(1,1970);
-	this.calendarwfields = new Array(200, 201, 202, 203, 207, 221, 401, 402, 102, 400, 101, 206, 2, 220);
+	this.calendarwfields = new Array(200, 201, 202, 203, 207, 221, 401, 402, 102, 400, 101, 206, 2, 220, 100);
 	//title, startdate, enddate, note, seq(0-4), participants, fulltime(true|false), shownas, tag
 	this.calendarWeekTimer = null;
 	this.timer = 700;
@@ -369,6 +369,7 @@ WeekCalendarTool.prototype = {
 		end.setUTCDate(start.getUTCDate()+7);
 		this.starttime=start.getTime();
 		var endtime=end.getTime();
+		this.endtime = endtime;
 		var Self = this;
 		Self.params=new Object();
 		Self.params.action="all";
@@ -378,8 +379,9 @@ WeekCalendarTool.prototype = {
 		if(!Self.showallappointments) {
 			Self.params.folder= activefolder;
 		}
+		Self.params.showPrivate = true;
 		storageCache.get(AjaxRoot + "/calendar",
-		 Self.params ,
+		 Self.params,
 		 function(storage) {
 		 	Self.weekAppointments = new Array()
 		 	for (var t = 0; t< Self.displayedWeekLinks.length; t++)
@@ -395,7 +397,9 @@ WeekCalendarTool.prototype = {
 		 Self.calendarwfields.toString(),
 		 true,
 		 function(x) { return x.folder + "." + x.id + "." + x.recurrence_position; } ,
-		 function(x) { return { id: x[0], folder: x[1], recurrence_position : x[2] } }
+		 function(x) {
+		     return { id: x[0], folder: x[1], recurrence_position: x[2] || 0 };
+	     }
 		);
 	},
 	iterateStorage: function(storage) {		
@@ -488,165 +492,180 @@ WeekCalendarTool.prototype = {
 		
 		return datDIV;						
 	},
-	generateCalendarObjects: function(index, object) {		
-		this.index = index;
+	
+	generateCalendarObjects: function(index, object) {
 		this.object = object;
-		var id = this.object[0];
-		var folder_id = this.object[1];
-		var nRecPosition = this.object[2];
-		var nRecId = this.object[14];
-		var created_by = this.object[15];
 		this.object.index = index;
-		allcalendarWeekObjects[""+folder_id+"-"+id + "-"+nRecPosition]=this.object;
-		
-		var selectedAppointmentWeek = { 
-			id:id, folder:folder_id, recurrence_position:nRecPosition, 
-			recurrence_id:nRecId, created_by:created_by };
-		var divAppId = 'appInWeekView' + folder_id + "_" + id+"_"+nRecPosition;
-		
-		// additional clean-up? hack to fix bug #11406
-		if ($2(divAppId) && $2(divAppId).parentNode) {
-			$2(divAppId).parentNode.removeChild($2(divAppId));
-		}
 		
+		var id = this.object[0];
+		var folder = this.object[1];
+		var recurrencePos = this.object[2] || 0;	
 		var title = this.object[3];
 		var start_date = this.object[4];
 		var end_date = this.object[5];
 		var note = this.object[6];
-		var recurrence_type = this.object[7];
-		
-		// consolidate users and participants (field 220 and 221)
-		for (var i in object[16]) {
-			var a1 = object[16][i];
-			for (var ia in object[8]) {
-				if (object[8][ia].id == a1.id) {
-					a1.confirmation = object[8][ia].confirmation;
-					if (object[8][ia].confirmmessage) a1.confirmmessage = object[8][ia].confirmmessage;
-					break;
-				}
-			}
-		}
-		
-		var participants = this.object[16];
-		var full_time = this.object[9];
-		var shown_as = this.object[10];
-		var color_label = this.object[11];
+		var recurrenceType = this.object[7];
+		var isFullTime = this.object[9];
+		var shownAs = this.object[10];
+		var colorLabel = this.object[11];
 		var location = this.object[12];
-		var private_flag = this.object[13];
-		var appointmentDate = new Date(start_date);
-		var appointmentDateEnd = new Date(end_date);''	
-		var timeWeekpart1 = formatDate(appointmentDate, "time");
-		var timeWeekpart2 = formatDate(appointmentDateEnd, "time");
+		var privateFlag = this.object[13];
+		var recurrenceID = this.object[14];
+		var createdBy = this.object[15];
+		var participants = this.object[16];
+		var categories = this.object[17];
+		var owner = getFolderOwner(activefolder);
+		var oneday=1000*60*60*24;
 		
-		if (!title) title = "";		
-		var textToView = timeWeekpart1 + " - " + timeWeekpart2 + "  " + title;
-		if (full_time) {
-			textToView = title; 
+		var isPrivateShared = (owner !== configGetKey('identifier') && privateFlag === true);
+				
+		allcalendarWeekObjects[ folder + "-" + id + "-" + recurrencePos ] = this.object;
+		
+		var selectedAppointmentWeek = { 
+			id: id, folder: folder, recurrence_position: recurrencePos, 
+			recurrence_id: recurrenceID, created_by: createdBy 
+		};
+		
+		var	appObject = {
+				id: this.object[0],
+				folder: this.object[1], 
+			    folder_id: this.object[1],
+			    recurrence_id: this.object[14],
+			    recurrence_position: (this.object[2] || 0),
+			    recurrence_type: this.object[7]
+		};
+		
+		
+		// app start date before week start?
+		if (start_date < this.starttime) {
+			start_date = this.starttime;
 		}
-		var divId = "weekDayContent" + appointmentDate.getUTCDay();
 		
-		this.aAppointmentAssoc[divAppId] = this.object;
-		var divIconFlags = newnode("div", {flt:"right", marginLeft : "5px"});
-       		
+		// app end date after week end?
+		if (end_date > this.endtime) {
+			end_date = this.endtime-1;
+		}
+				
+		/******* INIT NODE TEMPLATE *******/
+		
 		var divIconParticipant = newnode("div", {},{ className: "showAppointmentSeqWeek"});
-		if(participants && participants.length > 1) {
+		if (participants && participants.length > 1) {
 			var imageGroupFlag=document.createElement("img");
 			imageGroupFlag.setAttribute("src",getFullImgSrc("img/calendar/group.gif"));
 			divIconParticipant.appendChild(imageGroupFlag);
 		}
 		
 		var divIconPrivate = newnode("div", {},{ className: "showAppointmentSeqWeek"});
-		if(private_flag) {
+		if (privateFlag) {
 			var imagePrivatFlag=document.createElement("img");
 			imagePrivatFlag.setAttribute("src",getFullImgSrc("img/private_flag.gif"));
 			divIconPrivate.appendChild(imagePrivatFlag);
 		}
 		
 		var divIconTag = newnode("div", {}, { className: "showAppointmentSeqWeek"});
-		if(color_label && color_label > 0) {
+		if (colorLabel && colorLabel > 0) {
 			var imageColorLabel=document.createElement("img");
-			imageColorLabel.setAttribute("src",getFullImgSrc("img/menu/tag_" + color_label + ".gif"));
+			imageColorLabel.setAttribute("src",getFullImgSrc("img/menu/tag_" + colorLabel + ".gif"));
 			divIconTag.appendChild(imageColorLabel);
 		}
 		
-		var oneday=1000*60*60*24;
-		var showappointment=true;		
-		var fulltimeStartBefore = false;
-		var fulltimeStartBeforeDiff = 0;
+		var appNode = newnode("div");
 		
-		// Setze Startzeit des Termins um , falls er vor der Anzeige beginnt
-		if (start_date < this.starttime) {
-			fulltimeStartBeforeDiff = (this.starttime - start_date)  / 1000 / 60 / 60 / 24;
-			start_date=this.starttime;
-			fulltimeStartBefore = true;
-		}
-		
-		if (fulltimeStartBefore && !full_time) {
-			end_date = end_date + oneday;
-		}
-		
-		// Setze Endzeit des Termins um , falls er nach der Anzeige endet
-		if (end_date > this.starttime + (7 * oneday)) {
-			end_date = this.starttime + (7 * oneday)
-		}
-		
-		/*
-		 * ms / d
-		 * calculating appointment duration in days
-		 */
-		var d_end = Math.ceil(end_date / 864e5);
-        var d_start = Math.floor(start_date / 864e5);
-		days = d_end-d_start;
-		
-		var titlesMultidays = [];
-		if (days > 1) {
-			var timeA = formatDate(new Date(Date.UTC(1970,1,1,0,0,0)), "time");
-			var timeB = formatDate(new Date(Date.UTC(1970,1,1,23,59,59)), "time");			
-			textToView = titlesMultidays[0] = timeWeekpart1 + " - " + timeB + "  " + title;
-			if (full_time) {
-				textToView = titlesMultidays[0] = title;
-			}
-			titlesMultidays[1] = timeA + " - " + timeB + "  " + title;
-			if (full_time) {
-				titlesMultidays[1] = title; 
-			}
-			titlesMultidays[2] = timeA + " - " + timeWeekpart2 + "  " + title;
-			if (full_time) {
-				titlesMultidays[2] = title;
-			}
-		}
-
-		var Self = this;
-		
-		var shownDiv = newnode('div');
-		switch (shown_as) {
+		switch (shownAs) {
 			case 1:
-				shownDiv.className = "appointmentRESERVED";
+				appNode.className = "appointmentRESERVED";
 				break;
 			case 2:
-				shownDiv.className = "appointmentTEMPORARY";
+				appNode.className = "appointmentTEMPORARY";
 				break;
 			case 3:
-				shownDiv.className = "appointmentABSENT";
+				appNode.className = "appointmentABSENT";
 				break;
 			case 4:
-				shownDiv.className = "appointmentFREE";
+				appNode.className = "appointmentFREE";
 				break;
 			default:
-				shownDiv.className = "appointmentNONE";
-				break;
+				appNode.className = "appointmentNONE";
 		}
-		shownDiv.className += ' showAppointmentShownWeek';
-		
-		var	paramObj = {
-			id: Self.object[0],
-			folder: Self.object[1], 
-		    folder_id: Self.object[1],
-		    recurrence_id: Self.object[14],
-		    recurrence_position: Self.object[7] || 0,
-		    recurrence_type: Self.object[7]
-		};
+		appNode.className += " showAppointmentShownWeek";
 
+		appNode.appendChild(document.createTextNode(" "));
+		var cName = "appInWeekView border-color-design borderDefault";
+		var backColor = "background-color-content";
+		if (isFullTime) {
+			cName = "textFullTimeWeek border-color-design borderDefault";
+			backColor = "wholeDayBackground";
+		}
+		
+		// setting background color depending on categories, if set
+		if (categories) {
+			// getting the first color out of the categories list
+			var cat = ox.categories.getFirstMatch(categories);
+			if (cat.color != 0) {
+				backColor = "colorLabel" + cat.color;
+			}
+		}
+		cName += " " + backColor;
+		
+		var contentDiv = newnode("div", 0, { className: cName });
+		if (selectedAppointmentWeekView == divAppId) {
+			contentDiv.className = removeClass(contentDiv.className,"borderDefault");
+			contentDiv.className += ' selectedAppMonth border-color-selection-elements';
+		}
+
+		var textDiv = newnode("div");
+		textDiv.className = "showAppointmentTextWeek";
+		var textToView = title;
+		if (location) {
+			textToView += " - " + location;
+		}
+		
+		// setting confirmation styles
+		if (participants.length) {
+			for (var i in participants) {
+				if (participants[i].id == owner) {
+					switch(participants[i].confirmation) {
+						case 0:
+							datDIV.style.opacity = ".6";
+							textDiv.style.fontStyle = "italic";
+							textToView = "(" + _("waiting") + ")";
+							break;
+						case 2:
+							textDiv.style.textDecoration = "line-through";
+							break;
+						case 3:											
+							textDiv.style.fontStyle = "italic";
+							textToView = "(" + _("tentative") + ")";
+							break;
+					}
+				}
+			}
+		}
+		textDiv.appendChild(document.createTextNode(textToView));
+		contentDiv.appendChild(appNode);	
+		contentDiv.appendChild(textDiv);
+		
+		if (divIconParticipant.firstChild) {
+			contentDiv.appendChild(divIconParticipant);
+		}
+		
+        if (divIconPrivate.firstChild) {
+        	contentDiv.appendChild(divIconPrivate);
+        }
+        
+        if (divIconTag.firstChild) {
+        	contentDiv.appendChild(divIconTag);
+        }
+		
+		if (recurrencePos > 0 && recurrenceID == id) {
+			var image = document.createElement("img");
+			image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
+			var seqDiv = newnode('div');
+			seqDiv.className = "showAppointmentSeqWeek";	
+			seqDiv.appendChild(image);
+			contentDiv.appendChild(seqDiv);	
+		}
+		
 		function disabled(e) {
 			var iconNode=$2("cww_node_dd");
 			if (iconNode == undefined) {
@@ -669,207 +688,120 @@ WeekCalendarTool.prototype = {
 				$2("cww_node_dd").parentNode.removeChild($2("cww_node_dd"));
 			}
 		}
-
-		shownDiv.appendChild(document.createTextNode(" "));
-		var cName = "appInWeekView background-color-content border-color-design borderDefault";
-		if (full_time) {
-			cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
-		}
-		
-		var datDIV = newnode("div", 0, { className: cName });
-		if (selectedAppointmentWeekView == divAppId) {
-			datDIV.className = removeClass(datDIV.className,"borderDefault");
-			datDIV.className += ' selectedAppMonth border-color-selection-elements';
-		}
-		datDIV.id = divAppId;
-		datDIV.oxcalobj = "" + folder_id + "-" + id + "-" + nRecPosition;
-		var textDiv = newnode('div');
-		textDiv.className = "showAppointmentTextWeek";
-		
-		if (location) {
-			textToView += " - " + location;
-		}
-		
-		var owner = getFolderOwner(activefolder);		
-		
-		// setting confirmation styles
-		if (participants.length) {
-			for (var i in participants) {
-				if (participants[i].id == owner) {
-					switch(participants[i].confirmation) {
-						case 0:
-							datDIV.style.opacity = ".6";
-							textDiv.style.fontStyle = "italic";
-							textToView += " (" + _("waiting") + ")";
-							break;
-						case 2:
-							textDiv.style.textDecoration = "line-through";
-							break;
-						case 3:											
-							textDiv.style.fontStyle = "italic";
-							textToView += " (" + _("tentative") + ")";
-							break;
-					}
-				}
-			}
-		}
-		
-		textDiv.appendChild(document.createTextNode(textToView));
-		datDIV.appendChild(shownDiv);	
-		datDIV.appendChild(textDiv);
-		
-		if (divIconParticipant.firstChild) {
-			datDIV.appendChild(divIconParticipant);
-		}
-        if (divIconPrivate.firstChild) {
-        	datDIV.appendChild(divIconPrivate);
-        }
-        if (divIconTag.firstChild) {
-        	datDIV.appendChild(divIconTag);
-        }
-		
-		if (nRecPosition > 0 && nRecId == id) {
-			var image=document.createElement("img");
-			image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
-			var seqDiv = newnode('div');
-			seqDiv.className = "showAppointmentSeqWeek";	
-			seqDiv.appendChild(image);
-			datDIV.appendChild(seqDiv);	
-		}			
-					
-		registerSource(datDIV, "calendar",
-		     function () {
-		     	objMoveCopy.begin("calendar",
-		     	[ new CalendarWorkWeekObject(
-		     	       object[0], object[1], object[2], object[14], object[15], object[3], object[4], 
-		     	       object[5], null, object[7], null, object[9], object[10],
-		     	       null,null,null)
-		     	]);
-			    return objMoveCopy;
-			     
-			 }, null,null, calendardefaultdisabled, defaultdisabledremove);
-		
-	 	var oInplEdit  = new inplaceEdit(textDiv, title, 
-	 	                    function (sStr,oObj) {
-	 	                    	editAppointment(paramObj,{title:sStr});
-							});
-
-		//fixed bug with auto selection													
+						
+		// fixed bug with auto selection													
 		if (calendarSelection) {
 			calendarSelection.reset();
 		}
-			
-		addDOMEvent(datDIV, "click", 
-			function(e) {
-				var SelObj = calendarSelection.getID();
-				if (SelObj && SelObj.id == paramObj.id &&
-							SelObj.folder == paramObj.folder_id &&
-									SelObj.recurrence_position == paramObj.recurrence_position) {
-					if (window.event) {
-						e = window.event;
-					}
-					oInplEdit.on();
-				} else {					
-					setSelectionWeekView(selectedAppointmentWeek);
-					selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-				}
-				stopEvent(e);
-			}
-		);
-        addDOMEvent(datDIV, "contextmenu", 
-        	function(e) {            	
-        		stopEvent(e);
-        		setSelectionWeekView(selectedAppointmentWeek);
-				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-            	globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
-        	}
-        );
-        
-		addDOMEvent(datDIV, "dblclick", 
-			function(e) {
-				setActivatedWeekView(selectedAppointmentWeek, e);
-				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-			}
-		);
 		
-		/*
-		 * draw the first appointment
-		 */																		
-		if (!fulltimeStartBefore) {
+		// calculating appointment duration in days
+		var appDuration = Math.ceil(end_date / 864e5) - Math.floor(start_date / 864e5);
+		
+		var timeA = formatDate(new Date(Date.UTC(1970,1,1,0,0,0)), "time");
+		var timeB = formatDate(new Date(Date.UTC(1970,1,1,23,59,59)), "time");	
+		
+		// iterate through days and draw appointments
+		for (var ia=1; ia <= appDuration; ia++) {
+			var datDIV = contentDiv.cloneNode(true);
+			
+			var textNode = datDIV.getElementsByTagName("div")[1];
+			var appointmentDate = new Date(start_date);
+			var appointmentDateEnd = new Date(end_date);
+			var timeWeekpart1 = formatDate(appointmentDate, "time");
+			var timeWeekpart2 = formatDate(appointmentDateEnd, "time");			
+			var textToView = timeWeekpart1 + " - " + timeWeekpart2 ;
+			
+			if (appDuration > 1) {				
+				if (ia == 1) {	
+					textToView = timeWeekpart1 + " - " + timeB;			
+				} else if (ia == appDuration) {
+					textToView = timeA + " - " + timeWeekpart2;
+				} else {
+					textToView = timeA + " - " + timeB;	
+				}
+			}			
+			
+			if (isFullTime) {
+				textToView = title; 
+			} else {
+				textToView = textToView + "  " + textNode.firstChild.nodeValue;
+			}
+			textNode.firstChild.data = textToView;
+						
+			var appId = 'appInWeekView' + folder + "_" + id + "_" + recurrencePos;
+			var divAppId = appId + "-" + ia;
+			
+			var divId = "weekDayContent" + appointmentDate.getUTCDay();
+			this.aAppointmentAssoc[appId] = this.object;
+			
+			// additional clean-up? hack to fix bug #11406
+			if ($2(divAppId) && $2(divAppId).parentNode) {
+				$2(divAppId).parentNode.removeChild($2(divAppId));
+			}		
+			
+			datDIV.id = divAppId;
+			
+			var oInplEdit = new inplaceEdit(textNode, title, 
+	                 function (sStr, oObj) {
+	                 	editAppointment(appObject, {title: sStr });
+					});
+			
+			if (isPrivateShared == false) {
+				registerSource(datDIV, "calendar", function () {
+					     	objMoveCopy.begin("calendar",
+					     	[ new CalendarWorkWeekObject(
+					     	       object[0], object[1], object[2], object[14], object[15], object[3], object[4], 
+					     	       object[5], null, object[7], null, object[9], object[10],
+					     	       null,null,null)
+					     	]);
+						    return objMoveCopy;
+						}, null,null, calendardefaultdisabled, defaultdisabledremove);
+				addDOMEvent(datDIV, "click", (function (divAppId, oInplEdit) {
+					return function(e) {
+						var SelObj = calendarSelection.getID();
+						if (SelObj && SelObj.id == appObject.id &&
+									SelObj.folder == appObject.folder_id &&
+											SelObj.recurrence_position == appObject.recurrence_position &&
+												selectedAppointmentWeekView == divAppId) {
+							if (window.event) {
+								e = window.event;
+							}
+							oInplEdit.on();
+						} else {
+							setSelectionWeekView(selectedAppointmentWeek);
+							selectAppointmentWeekView(divAppId, (isFullTime ? 2 : 1));
+						}
+						stopEvent(e);
+					}
+				})(appId, oInplEdit));
+									
+		        addDOMEvent(datDIV, "contextmenu", (function(divAppId) {
+		        		return function(e) {  
+			        		stopEvent(e);
+			        		setSelectionWeekView(selectedAppointmentWeek);
+							selectAppointmentWeekView(divAppId, (isFullTime ? 2 : 1));
+			            	globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+			        	}
+		        })(appId));
+		        
+				addDOMEvent(datDIV, "dblclick", (function(divAppId) {
+						return function(e) {
+							setActivatedWeekView(selectedAppointmentWeek, e);
+							selectAppointmentWeekView(divAppId, (isFullTime ? 2 : 1));
+						}
+				})(appId)); 
+				
+				datDIV.oxcalobj = folder + "-" + id + "-" + recurrencePos;
+			} else {
+				// is a private app in shared folder, so default cursor
+				datDIV.style.cursor = "default";
+			}
+
 			$(divId).appendChild(datDIV);
 			addTMPId(datDIV);
-		}
-		
-		/*
-		 * if appointment lasts longer then 1 day draw the rest
-		 */
-		for (var i=1; i<days; i++) {
-			var ccweek_template_app_time = datDIV.cloneNode(true);
-			if (i+1 == days) {
-				ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[2];
-			} else {
-				ccweek_template_app_time.childNodes[1].firstChild.nodeValue = titlesMultidays[1];
-			}
-
-			var	paramObj = { id:Self.object[0],folder:Self.object[1], folder_id: Self.object[1],
-											recurrence_position:(Self.object[7]) ? Self.object[7] : 0 };
-			if (!fulltimeStartBefore) {
-				start_date += oneday;
-			}
 			
-			var newId = new Date(start_date).getUTCDay();
-			divId = "weekDayContent" + newId;
-
-			ccweek_template_app_time.id = datDIV.id + "-" + i;
-			ccweek_template_app_time.oxcalobj= "" + folder_id + "-" + id + "-" + nRecPosition;
-
-			// remove if already exists!
-			if ($2(ccweek_template_app_time.id) && $2(ccweek_template_app_time.id).parentNode) {
-				$2(ccweek_template_app_time.id).parentNode.removeChild($2(ccweek_template_app_time.id));
-			}
-			
-			addDOMEvent(ccweek_template_app_time, "click", function(e) {					
-				var SelObj = calendarSelection.getID();
-				if (SelObj && SelObj.id == paramObj.id &&
-				    SelObj.folder == paramObj.folder_id &&
-					SelObj.recurrence_position == paramObj.recurrence_position) {
-					if (window.event) {
-						e = window.event;
-					}
-					oInplEdit.on();
-				} else {
-					setSelectionWeekView(selectedAppointmentWeek);
-					selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-				}
-				stopEvent(e);
-			});	
-			
-            addDOMEvent(ccweek_template_app_time, "contextmenu", 
-	            	function(e) {
-		                if (!calendarSelection.get(index)) {
-		                    calendarSelection.click(index, e);
-		                }
-		                stopEvent(e);
-		                globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
-	            	}
-            );
-			addDOMEvent(ccweek_template_app_time, "mousedown", 
-					function(e) {
-						setSelectionWeekView(selectedAppointmentWeek);
-						selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-					}
-			);
-			addDOMEvent(ccweek_template_app_time, "dblclick", 
-					function(e) {
-						setActivatedWeekView(selectedAppointmentWeek);
-						selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-					}
-			);
-			$(divId).appendChild(ccweek_template_app_time);	
-			addTMPId(ccweek_template_app_time);
-			if (fulltimeStartBefore) {
-				start_date += oneday;
-			}
+			// switch start date to next date
+			start_date += oneday;
 		}
 	}
 }
@@ -888,47 +820,33 @@ function setActivatedWeekView(selectedAppointmentWeek, evt) {
 	openAppointmentPopup(evt);
 }
 
-var selectedAppointmentWeekView = '';
-var selectedAppointmentWeekViewModus = 0;
+var selectedAppointmentWeekView = "";
 function selectAppointmentWeekView(divAppId, app) {
-	if ($2(divAppId)) {
-		$2(divAppId).className = removeClass($2(divAppId).className, "border-color-selection-elements");
-		$2(divAppId).className = removeClass($2(divAppId).className, "borderDefault");
-		$2(divAppId).className += " selectedAppMonth border-color-selection-elements";
-	}
-	
-	for (var i=0; i<=7; i++) {
-		if($2(divAppId + "-" + i)) {
-			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className, "border-color-selection-elements");
-			$2(divAppId + "-" + i).className = removeClass($2(divAppId + "-" + i).className, "borderDefault");			
-			$2(divAppId + "-" + i).className += " selectedAppMonth border-color-selection-elements";
+	// remove any selection first
+	if (selectedAppointmentWeekView) {
+		for (var i=0; i<=7; i++) {
+			var myDiv = $2(selectedAppointmentWeekView + "-" + i);
+			if (myDiv) {
+				var cname = myDiv.className;
+				cname = removeClass(cname, "selectedAppMonth");
+				cname = removeClass(cname, "border-color-selection-elements");
+				myDiv.className = trimStr(cname + " borderDefault");
+			}
 		}
 	}
 	
-				
-	if (selectedAppointmentWeekView != "" && $2(selectedAppointmentWeekView) && selectedAppointmentWeekView != divAppId) {
-		var cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
-		if (selectedAppointmentWeekViewModus == 1) {
-			cName = "appInWeekView background-color-content border-color-design borderDefault";
-		}		
-		$2(selectedAppointmentWeekView).className = cName;
-	}
-	
-	if (selectedAppointmentWeekView != "" && selectedAppointmentWeekView != divAppId) {
-		for (var i=0; i<=7; i++) {
-			if ($2(selectedAppointmentWeekView + "-" + i)) {
-				var cName = "textFullTimeWeek wholeDayBackground border-color-design borderDefault";
-				if (selectedAppointmentWeekViewModus == 1) {
-					cName = "appInWeekView background-color-content border-color-design borderDefault";
-				}
-				$2(selectedAppointmentWeekView + "-" + i).className = cName;
-			}
+	// reselect required divs
+	for (var i=0; i<=7; i++) {
+		var myDiv = $2(divAppId + "-" + i);
+		if (myDiv) {
+			var cname = myDiv.className;
+			cname = removeClass(cname, "borderDefault");
+			myDiv.className = trimStr(cname + " selectedAppMonth border-color-selection-elements");
 		}
 	}
 	
 	if (divAppId) {
 		selectedAppointmentWeekView = divAppId;
-		selectedAppointmentWeekViewModus = app;
 	}
 }
 
