@@ -87,7 +87,7 @@ function default_calendar_workweek_create_object(module,folder) {
 	calendar_activedate=null;
 	calendar_wholeday=null;
 }
-function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag,interval)
+function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag,interval,categories)
 {
 	this.index;
 	this.selected=false;
@@ -108,6 +108,7 @@ function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,cr
 	this.color_label=color_label;
 	this.private_flag=private_flag;
 	this.interval=interval;
+	this.categories=categories;
 	this.divs=new Object();
 }
 CalendarWorkWeekObject.prototype = {
@@ -126,7 +127,7 @@ function MatrixObject(folderid,id,recurrence_id,div_id,startpoint,endpoint) {
 
 var globalinterval = 0;
 var globalintervalcounts=0;
-var calendarwwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 101, 220, 215);
+var calendarwwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 101, 220, 215, 100);
 var calendarinittemplates=false;
 var firstenter=false;
 var cwwstorage;
@@ -393,6 +394,7 @@ function getCalendarObjectsWW(actualmonday) {
 	if(!showallappointments) {
 		params.folder= activefolder;
 	}
+	params.showPrivate = true;
 	storageCache.get(AjaxRoot + "/calendar", params, initCalendarObjectsWW,
         calendarwwfields.toString(), true,
 		function (x) { 
@@ -400,7 +402,7 @@ function getCalendarObjectsWW(actualmonday) {
                 + "." + x.recurrence_id + "." + x.created_by;
 		},
 		function (x) { 
-		 	var mObj = { id: x[0], folder: x[1], recurrence_position: x[2],
+		 	var mObj = { id: x[0], folder: x[1], recurrence_position: x[2] || 0,
 		 	    recurrence_id: x[3], created_by: x[4] }; 
 		    return mObj;
 		}
@@ -453,7 +455,10 @@ function showCalendarObject(index,object) {
 		}
 	}
 	
-	var calendarobject = new CalendarWorkWeekObject(object[0],object[1],object[2],object[3],object[4],object[5],object[6],object[7],object[8],object[9],object[16],object[11],object[12],object[13],object[14],object[15],object[17]);
+    var calendarobject = new CalendarWorkWeekObject(object[0], object[1],
+        object[2] || 0, object[3], object[4], object[5], object[6], object[7],
+        object[8], object[9], object[16], object[11], object[12], object[13],
+        object[14], object[15], object[17], object[18]);
 	calendarobject.index=index;
 	allcalendarobjects[""+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position]=calendarobject;		
 	cwwdrawAppointment(calendarobject);
@@ -497,21 +502,16 @@ function cwwchangeSelected(elementid) {
 				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"border-color-image");											
 			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
 				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"appointmentBGWW");					
-			if(elementid == myzaehler)
-			{
+			if (elementid == myzaehler) {
 				allcalendarobjects[myzaehler].divs[myzaehler2].className += " selectedAppointmentWW background-color-selection-elements border-color-selection-elements";
-				if(tds[1])
+				if (tds[1])
 					tds[1].className += " border-color-selection-elements";	
-				if(tds[2])
+				if (tds[2])
 					tds[2].className += " background-color-selection-elements font-color-selected font-weight-high";
-				if(wholeDayEl)
-				{
-					divs[2].className += " background-color-selection-elements font-color-selected font-weight-high";
-					//divs[2].className = removeClass(divs[2].className,"background-color-selection-elements");					
+				if (wholeDayEl) {
+					divs[2].className += " background-color-selection-elements font-color-selected font-weight-high";			
 				}
-			}
-			else
-			{
+			} else {
 				allcalendarobjects[myzaehler].divs[myzaehler2].className += "  border-color-image deselectedAppointmentWW appointmentBGWW";
 				if(tds[1])
 					tds[1].className += " border-color-content-default";									
@@ -533,29 +533,14 @@ function cwwchangeSelected(elementid) {
 	}	
 }
 function cwwchangeSelectedFull(elementid) {
-	if(calendarSelection.count != 0)
+	if (calendarSelection.count != 0){
 		calendarSelection.reset();
-	for(var myzaehler in allcalendarobjects) {
-		for(var myzaehler2 in allcalendarobjects[myzaehler].divs) {
-			/*
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"border-color-selection-elements");
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"background-color-selection-elements");				
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"wholeDayBackground");
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"selectedAppointmentWW");				
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"deselectedAppointmentWW");											
-			allcalendarobjects[myzaehler].divs[myzaehler2].className = 
-				removeClass(allcalendarobjects[myzaehler].divs[myzaehler2].className,"appointmentTitleBG");
-			*/
-			if(elementid == myzaehler)
+	}
+	for (var myzaehler in allcalendarobjects) {
+		for (var myzaehler2 in allcalendarobjects[myzaehler].divs) {
+			if (elementid == myzaehler) {
 				allcalendarobjects[myzaehler].divs[myzaehler2].className += " selectedAppointmentWW background-color-selection-elements border-color-selection-elements";
-//			else
-//				allcalendarobjects[myzaehler].divs[myzaehler2].className += " deselectedAppointmentWW wholeDayBackground";
-				
+			}
 		}
 	}
 	
@@ -600,145 +585,152 @@ function cwwdrawAppointment(calendarobject) {
 	}
 	
 	var owner = getFolderOwner(activefolder);
+	var isPrivateShared = (owner !== configGetKey('identifier') && calendarobject.private_flag === true);
 	
 	var sdttmp=sdt;
 	// IST es ein Ganztagstermin
-	if (calendarobject.full_time){		
+	if (calendarobject.full_time) {
 		// Kann Termin angezeigt werden???
 		showappointment=true;
 		while (sdttmp<edt) {
 			if (!document.getElementById(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3))	{
 				// Hol mir den Tag der Woche
-				var sdd=(new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
+				var sdd = (new Date(sdttmp).getUTCDay()-new Date(cwwactualday.getUTCDay()) +7) % 7;
+
+				//Zeichne Ganztagstermin					
+				showappointment=true;
+				var appointmentcontainer = cwwdaysfull[sdd].node;
+				var myappointment=$("cww_appointment_template_full_time").cloneNode(true);
+				var	paramObj = { 
+					id: calendarobject.id, folder_id: calendarobject.folder_id,
+				    recurrence_position: calendarobject.recurrence_position,
+				    recurrence_id: calendarobject.recurrence_id, created_by: calendarobject.created_by
+				};	
+				var divs = myappointment.getElementsByTagName("div");			
 				
-				/*
-				// Hat dieser Tag schon einen Ganztagstermin, wenn ja Listenbild einblenden
-				if (cwwdaysfull[sdd].node.hasChildNodes()) {
-					showappointment=false;
-					if ($2("cwwmoreappointments"+sdd).style.display != "") {
-						$2("cwwmoreappointments"+sdd).style.display="";
-					}
-				} else {
-				*/
-					//Zeichne Ganztagstermin					
-					showappointment=true;
-					var appointmentcontainer = cwwdaysfull[sdd].node;
-					var myappointment=$("cww_appointment_template_full_time").cloneNode(true);
-					var	paramObj = { 
-						id: calendarobject.id, folder_id: calendarobject.folder_id,
-					    recurrence_position: calendarobject.recurrence_position,
-					    recurrence_id: calendarobject.recurrence_id, created_by: calendarobject.created_by
-					};	
-					var divs = myappointment.getElementsByTagName("div");			
-					
-					var oInplEdit  = new inplaceEdit(divs[2], calendarobject.title, function (sStr, oObj) {
-						editAppointment(paramObj,{title:sStr});
-					});
-					oInplEdit.input_fontcolor = "#FFFFFF";
-					oInplEdit.input_fontsize = "8pt";
-					oInplEdit.input_height = "1.2em";
-						//fixed bug with auto selection													
-					calendarSelection.reset();	
-					var myfunc1 = function(oInplEdit) {
-						return function(e) {
-							var SelObj = calendarSelection.getID();
-							if(SelObj && SelObj.id == paramObj.id &&
-								SelObj.folder == paramObj.folder_id &&
-								SelObj.recurrence_position == paramObj.recurrence_position)
-								{
-									if(window.event) {
-										e = window.event;
-									}
-									oInplEdit.on();
-									stopEvent(e);
-							}
-						} 
+				var oInplEdit  = new inplaceEdit(divs[2], calendarobject.title, function (sStr, oObj) {
+					editAppointment(paramObj,{title:sStr});
+				});
+				oInplEdit.style.color = "#FFFFFF";
+				oInplEdit.style.fontSize = "8pt";
+				oInplEdit.style.height = "1.2em";
+				//fixed bug with auto selection													
+				calendarSelection.reset();	
+				var myfunc1 = function(oInplEdit) {
+					return function(e) {
+						var SelObj = calendarSelection.getID();
+						if(SelObj && SelObj.id == paramObj.id &&
+							SelObj.folder == paramObj.folder_id &&
+							SelObj.recurrence_position == paramObj.recurrence_position)
+							{
+								if(window.event) {
+									e = window.event;
+								}
+								oInplEdit.on();
+								stopEvent(e);
+						}
 					};
+				};
+                var tds = myappointment.getElementsByTagName("td");
+                var title = tds[1].getElementsByTagName("span")[0];
+                
+                var backColor = "appointmentTitleBG";
+                if (calendarobject.categories) {
+        			// getting the first color out of the categories list
+        			var cat = ox.categories.getFirstMatch(calendarobject.categories);
+        			if (cat.color != 0) {
+        				backColor = "colorLabel" + cat.color;
+        			}
+        		}
+                tds[1].className += " " + backColor;
+		
+				myappointment.id=calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;				
+				addTMPId(myappointment,"calendar/calendar/workweek");
+				zaehler3++;
+				
+				if (isPrivateShared == false) {
+					myappointment.oxcalobj = calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
+					
 					addDOMEvent(myappointment,"mousedown",function (e) {
 						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
 						cancelBubbling(e);
 					});
-                    var tds = myappointment.getElementsByTagName("td");
-                    var title = tds[1].getElementsByTagName("span")[0];
 					addDOMEvent(tds[1], "mousedown", myfunc1(oInplEdit));		
 					addDOMEvent(myappointment, "click", function(e) {
-							var SelObj = calendarSelection.getID();
-							if (SelObj && SelObj.id == paramObj.id &&
-								SelObj.folder == paramObj.folder_id &&
-								SelObj.recurrence_position == paramObj.recurrence_position) {
-							} else {
-								cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
-							}
-							cancelBubbling(e);
-						});								
-			
+						var SelObj = calendarSelection.getID();
+						if (SelObj && SelObj.id == paramObj.id &&
+							SelObj.folder == paramObj.folder_id &&
+							SelObj.recurrence_position == paramObj.recurrence_position) {
+						} else {
+							cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
+						}
+						cancelBubbling(e);
+					});
+					
 					/* Drag & Drop Source */
 					registerSource(myappointment,"calendar",function () { 
 						var mymove=new MoveCopy(); 
 						mymove.begin("calendar",[calendarobject]); 
 						return mymove; 
 					},null,null,calendardefaultdisabled,defaultdisabledremove);
-					myappointment.id=calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
-					myappointment.oxcalobj=calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
-					addTMPId(myappointment,"calendar/calendar/workweek");
-					zaehler3++
-					addDOMEvent(myappointment,"dblclick",cww_doDblClick);
-					 					
-                    addDOMEvent(myappointment, "contextmenu", function(e) {
-                        stopEvent(e);
-                        globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                            calendarSelection);
-                    });
-					allcalendarobjects[calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position].addDiv(myappointment.id,myappointment);
-					/** Shown As **/
-					switch (calendarobject.shown_as) {
-						case 1:
-							tds[0].className = "appointmentRESERVED";
-							break;
-						case 2:
-							tds[0].className = "appointmentTEMPORARY";
-							break;
-						case 3:
-							tds[0].className = "appointmentABSENT";
-							break;
-						case 4:
-							tds[0].className = "appointmentFREE";
-							break;
-					}
 					
-					// title & location
-					var appTitle = [];
-					if (calendarobject.title) appTitle.push(calendarobject.title);
-					if (calendarobject.location) appTitle.push(calendarobject.location);
-					title.firstChild.data = appTitle.join(" - ") || "";
-										
-					// setting confirmation styles
-					if (calendarobject.participants.length) {
-						for (var i in calendarobject.participants) {
-							if (calendarobject.participants[i].id == owner) {
-								switch(calendarobject.participants[i].confirmation) {
-									case 0:
-										myappointment.style.opacity = ".6";
-										title.style.fontStyle = "italic";
-										calendarobject.title += " (" + _("waiting") + ")";
-										break;
-									case 2:
-										title.style.textDecoration = "line-through";
-										break;
-									case 3:											
-										title.style.fontStyle = "italic";
-										calendarobject.title += " (" + _("tentative") + ")";
-										break;
-								}
-								break;
+					addDOMEvent(myappointment, "dblclick", cww_doDblClick);
+	                addDOMEvent(myappointment, "contextmenu", function(e) {
+	                    stopEvent(e);
+	                    globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+	                });
+				} else {
+					// private apps in shared folder, set cursor to default
+					tds[1].style.cursor = "default";
+				}
+				allcalendarobjects[calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position].addDiv(myappointment.id,myappointment);
+				/** Shown As **/
+				switch (calendarobject.shown_as) {
+					case 1:
+						tds[0].className = "appointmentRESERVED";
+						break;
+					case 2:
+						tds[0].className = "appointmentTEMPORARY";
+						break;
+					case 3:
+						tds[0].className = "appointmentABSENT";
+						break;
+					case 4:
+						tds[0].className = "appointmentFREE";
+						break;
+				}
+				
+				// title & location
+				var appTitle = [];
+				if (calendarobject.title) appTitle.push(calendarobject.title);
+				if (calendarobject.location) appTitle.push(calendarobject.location);
+				title.firstChild.data = appTitle.join(" - ") || "";
+									
+				// setting confirmation styles
+				if (calendarobject.participants.length) {
+					for (var i in calendarobject.participants) {
+						if (calendarobject.participants[i].id == owner) {
+							switch(calendarobject.participants[i].confirmation) {
+								case 0:
+									myappointment.style.opacity = ".6";
+									title.style.fontStyle = "italic";
+									calendarobject.title += " (" + _("waiting") + ")";
+									break;
+								case 2:
+									title.style.textDecoration = "line-through";
+									break;
+								case 3:											
+									title.style.fontStyle = "italic";
+									calendarobject.title += " (" + _("tentative") + ")";
+									break;
 							}
+							break;
 						}
 					}
-					
-					appointmentcontainer.appendChild(myappointment);
 				}
-			//}
-			//Zaehle Temp Startzaehler um 24 Stunden hoch
+				
+				appointmentcontainer.appendChild(myappointment);
+			}
 			sdttmp = sdttmp+oneday;
 		}
 	} else {
@@ -787,81 +779,55 @@ function cwwdrawAppointment(calendarobject) {
 					$2("cwwmoreappointments"+sdd).style.display = "";
 				} else {
 					var myappointment=$("cww_appointment_template").cloneNode(true);
-					myappointment.id=+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
-					myappointment.oxcalobj=calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
+					myappointment.id=+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;					
 					addTMPId(myappointment,"calendar/calendar/workweek");
-					zaehler3++
-					addDOMEvent(myappointment,"mousedown",function (e) {
-						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
-						cancelBubbling(e);
-					});				
+					zaehler3++;
+					
 					var	paramObj = { 
 						id: calendarobject.id, folder_id: calendarobject.folder_id,
 						recurrence_position: calendarobject.recurrence_position, recurrence_id: calendarobject.recurrence_id,
 						created_by: calendarobject.created_by
 					};	
 					var tds = myappointment.getElementsByTagName("td");			
-						var oInplEdit  = new inplaceEdit(tds[2].getElementsByTagName("div")[0], calendarobject.title, function (sStr,oObj){
-						editAppointment(paramObj,{title:sStr});
-						});
+					var oInplEdit  = new inplaceEdit(tds[2].getElementsByTagName("div")[0], calendarobject.title, function (sStr,oObj) {
+								editAppointment(paramObj,{title:sStr});
+							});
 	
-					oInplEdit.input_fontcolor = "#FFFFFF";
-					oInplEdit.input_fontsize = "8pt";
-					oInplEdit.input_height = "1.2em";
-											//fixed bug with auto selection													
+					oInplEdit.style.color = "white";
+					oInplEdit.style.fontSize = "8pt";
+					oInplEdit.style.height = "1.2em";
+					//fixed bug with auto selection													
 					calendarSelection.reset();
 					var myfunc1 = function(oInplEdit) {
 						return function(e) {
 							var SelObj = calendarSelection.getID();
-							if(SelObj && SelObj.id == paramObj.id &&
-							SelObj.folder == paramObj.folder_id &&
-							SelObj.recurrence_position == paramObj.recurrence_position)
-							{
+							if (SelObj && SelObj.id == paramObj.id &&
+									SelObj.folder == paramObj.folder_id &&
+									SelObj.recurrence_position == paramObj.recurrence_position) {
 								oInplEdit.on();
 								stopEvent(e);
 							}
-						} 
+						};
 					};
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[2].getElementsByTagName("span")[0];
-					addDOMEvent(tds[2], "mousedown", myfunc1(oInplEdit));		
-					addDOMEvent(myappointment, "click", function(e) {
-							var SelObj = calendarSelection.getID();
-							if(SelObj && SelObj.id == paramObj.id &&
-								SelObj.folder == paramObj.folder_id &&
-								SelObj.recurrence_position == paramObj.recurrence_position) {							
-							} else {
-								cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
-							}
-							cancelBubbling(e);
-						});								
-	
-					//addDOMEvent(myappointment,"click",function (e){cancelBubbling(e);});							
-					addDOMEvent(myappointment,"dblclick",cww_doDblClick);
-					var domdivs=myappointment.getElementsByTagName("div");
-					/* Cursor fuer Drag&Drop */
-					addDOMEvent(domdivs[1], "mouseover",
-						(function(obj){
-							return function(){ 
-								obj.style.cursor = "move"; };
-						})(domdivs[1]));
-					addDOMEvent(domdivs[0], "mouseover",
-						(function(obj){
-							return function(){ obj.style.cursor = "n-resize"; };
-						})(domdivs[0]));
-					addDOMEvent(domdivs[4], "mouseover",
-						(function(obj){ return function(){ obj.style.cursor = "s-resize"; }; })(domdivs[4]));
-					
-                    addDOMEvent(myappointment, "contextmenu", function(e) {
-                        stopEvent(e);
-                        globalContextMenus.calendar.display(e.clientX, e.clientY,
-                                                            calendarSelection);
-                    });
+                    
+                    var backColor = "appointmentTitleBG";
+                    if (calendarobject.categories) {
+            			// getting the first color out of the categories list
+            			var cat = ox.categories.getFirstMatch(calendarobject.categories);
+            			if (cat.color != 0) {
+            				backColor = "colorLabel" + cat.color;
+            			}
+            		}
+                    tds[2].className += " " + backColor;
+                    var domdivs=myappointment.getElementsByTagName("div");
+                    
 					function disabled(e) {
-						var iconNode=$2("cww_node_dd");
-						if(iconNode == undefined) {
+						var iconNode = $2("cww_node_dd");
+						if (iconNode == undefined) {
 							iconNode = newnode("img", {position:"absolute", left:(e.clientX + iconOffset) + "px", top:(e.clientY + iconOffset) + "px"},
-			 			    {src: getFullImgSrc("img/dnd_disabled.gif"), alt: ""});
+			 			    { src: getFullImgSrc("img/dnd_disabled.gif"), alt: ""});
 							iconNode.id="cww_node_dd";
 							body.appendChild(iconNode);
 							addTMPId(iconNode);
@@ -872,19 +838,59 @@ function cwwdrawAppointment(calendarobject) {
 						return false;
 					}
 					function disabledremove(e) {
-						
-						if($2("cww_node_dd")) {
+						if ($2("cww_node_dd")) {
 							$2("cww_node_dd").parentNode.removeChild($2("cww_node_dd"));
 							removeTMPId($2("cww_node_dd"));
 						}
-					}				
-					registerSource(domdivs[0],"CALENDAR_TOP",function () { return calendarobject; }, null,null,disabled,disabledremove);
-					registerSource(domdivs[4],"CALENDAR_BOTTOM",function () { return calendarobject; },null,null,disabled,disabledremove);
-					registerSource(domdivs[1],"calendar",function () { 
-						var mymove=new MoveCopy(); 
-						mymove.begin("calendar",[calendarobject]); 
-						return mymove; 
-					},null,null,calendardefaultdisabled,defaultdisabledremove);
+					}	
+					if (isPrivateShared == false) {
+						myappointment.oxcalobj = calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position+"-"+zaehler3;
+						
+                    	addDOMEvent(myappointment,"mousedown",function (e) {						
+							cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
+							cancelBubbling(e);
+						});
+						addDOMEvent(tds[2], "mousedown", myfunc1(oInplEdit));
+						addDOMEvent(myappointment, "click", function(e) {
+							var SelObj = calendarSelection.getID();
+							if(SelObj && SelObj.id == paramObj.id &&
+								SelObj.folder == paramObj.folder_id &&
+								SelObj.recurrence_position == paramObj.recurrence_position) {							
+							} else {
+								cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
+							}
+							cancelBubbling(e);
+						});	
+						addDOMEvent(myappointment,"dblclick",cww_doDblClick);
+						
+						/* Cursor fuer Drag&Drop */
+						addDOMEvent(domdivs[1], "mouseover",
+							(function(obj){
+								return function(){ 
+									obj.style.cursor = "move"; };
+							})(domdivs[1]));
+						addDOMEvent(domdivs[0], "mouseover",
+							(function(obj){
+								return function(){ obj.style.cursor = "n-resize"; };
+							})(domdivs[0]));
+						addDOMEvent(domdivs[4], "mouseover",
+							(function(obj){ return function(){ obj.style.cursor = "s-resize"; }; })(domdivs[4]));
+						
+	                    addDOMEvent(myappointment, "contextmenu", function(e) {
+	                        stopEvent(e);
+	                        globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
+	                    });
+						registerSource(domdivs[0],"CALENDAR_TOP",function () { return calendarobject; }, null,null,disabled,disabledremove);
+						registerSource(domdivs[4],"CALENDAR_BOTTOM",function () { return calendarobject; },null,null,disabled,disabledremove);
+						registerSource(domdivs[1],"calendar",function () { 
+							var mymove=new MoveCopy(); 
+							mymove.begin("calendar",[calendarobject]); 
+							return mymove; 
+						},null,null,calendardefaultdisabled,defaultdisabledremove);
+					} else {
+						// private apps in shared folder, set cursor to default
+						tds[1].style.cursor = "default";
+					}
 					allcalendarobjects[calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position].addDiv(myappointment.id,myappointment);			
 					
 					var appointmentcontainer=cwwdays[sdd].node;
@@ -935,38 +941,54 @@ function cwwdrawAppointment(calendarobject) {
 						}
 												
 						/** Recurrence Type **/
-						if(calendarobject.recurrence_type && calendarobject.recurrence_type!=0)
+						if (calendarobject.recurrence_type && calendarobject.recurrence_type!=0) {
 							tds[3].getElementsByTagName("img")[0].style.display = "inline";
-						else 
+						} else { 
 							tds[3].getElementsByTagName("img")[0].style.display = "none";
+						}
 												
 						/** Private or Group **/
-						if(calendarobject.participants && calendarobject.participants.length>1) {
+						if (calendarobject.participants && calendarobject.participants.length>1) {
 							tds[3].getElementsByTagName("img")[1].style.display = "inline";
 							tds[3].getElementsByTagName("img")[1].src=getFullImgSrc("img/calendar/group.gif");							
-						}
-						else {
+						} else {
 							tds[3].getElementsByTagName("img")[1].style.display = "none";
 						}
 		
 						/** Tagging **/
-						if(calendarobject.color_label && calendarobject.color_label!=0) {
+						if (calendarobject.color_label && calendarobject.color_label!=0) {
 							tds[3].getElementsByTagName("img")[2].style.display = "inline";
 							tds[3].getElementsByTagName("img")[2].src=getFullImgSrc("img/menu/tag_"+calendarobject["color_label"]+".gif");
-						}				
-						else 
+						} else { 
 							tds[3].getElementsByTagName("img")[2].style.display = "none";
+						}
 							
-						if(calendarobject.private_flag) {
+						if (calendarobject.private_flag) {
 							tds[3].getElementsByTagName("img")[3].style.display = "inline";
 							tds[3].getElementsByTagName("img")[3].src=getFullImgSrc("img/private_flag.gif");
-						}
-						else {
+						} else {
 							tds[3].getElementsByTagName("img")[3].style.display = "none";
 						}
 						
+						if (calendarobject.categories) {
+							var categories = clone(ox.categories.getByString(calendarobject.categories, ox.categories.match.MATCH));
+							categories.shift();
+							if (categories.length) {
+//								var tmpMap = {}, cats = [];
+//								// filter 
+//								for (var i=0; i < categories.length; i++) {
+//									if (!tmpMap[categories[i].color]) {
+//										cats.push(categories[i]);
+//										tmpMap[categories[i].color] = true
+//									}
+//								}
+//								tmpMap = null, categories = null;
+								ox.categories.ui.drawCategoriesList(categories, tds[3].getElementsByTagName("div")[0], true);								
+							}
+						}
+						
 						//New Element is Latest
-					if(allelements<tiefe+1) {
+					if (allelements<tiefe+1) {
 						allelements=tiefe+1;
 					}
 					myappointment.style.height=((endpoint-startpoint) * wwline) + "px";
@@ -1827,9 +1849,9 @@ function createPreviewNewAppointmentWW(object) {
 			storageCache.update();
  	});		
  	oInplEdit.really_edit_check = false;
-	oInplEdit.input_fontcolor = "#000000";
-	oInplEdit.input_fontsize = "8pt";
-	oInplEdit.input_height = "1.2em";
+ 	oInplEdit.style.color = "#000000";
+ 	oInplEdit.style.fontSize = "8pt";
+ 	oInplEdit.style.height = "1.2em";
 	oInplEdit.on();
 	register("OX_Dummy",dounregister);
 }
@@ -1886,7 +1908,14 @@ function openNewAppointmentWindow(object) {
 			createAppointment(object);
 		}
 		function myadvanced() {
-			newWindow("newAppointment.html#modul=new&folder_id="+object.folder_id+"&start_date="+object.start_date+"&end_date="+object.end_date+"", getWindowOptions());
+			ox.api.calendar.compose({
+				params: {
+					folder: object.folder_id,
+					start_date: object.start_date,
+					end_date: object.end_date
+				}
+			});
+			//newWindow("newAppointment.html#modul=new&folder_id="+object.folder_id+"&start_date="+object.start_date+"&end_date="+object.end_date+"", getWindowOptions(null, 680));
 		}
 		removeDDPreviewDivs();
 		newAppointmentObject(object,myok,function() {},myadvanced,null);
