@@ -21,6 +21,8 @@ register("OX_Configuration_Loaded", function() {
 		}
 	} catch (e) {
 		delete(config.gui);
+		//#. %s is the error message.
+		//#, c-format
 		alert(format(_("Syntax error in config: \n%s"), e.message));
 	}
 	if (!configContainsKey("identifier") || !configContainsKey("contact_id")) {
@@ -39,9 +41,6 @@ register("OX_Configuration_Loaded", function() {
  	if (!configContainsKey("modules.tasks.notifyNewModifiedDeleted")) {
 		configSetKey("modules.tasks.notifyNewModifiedDeleted",false);
     }
-    if (!configContainsKey("modules.tasks.notifyAcceptedDeclinedAsCreator")) {
-    	configSetKey("modules.tasks.notifyAcceptedDeclinedAsCreator",true);
-    }
     if (!configContainsKey("modules.tasks.notifyAcceptedDeclinedAsParticipant")) {
     	configSetKey("modules.tasks.notifyAcceptedDeclinedAsParticipant",true);
     }
@@ -49,7 +48,7 @@ register("OX_Configuration_Loaded", function() {
 		configSetKey("mail.deletemail",false);	
 	}	
 	if(!configContainsKey("gui.menu.menuiteration")) {
-		configSetKey("gui.menu.menuiteration",4);
+		configSetKey("gui.menu.menuiteration",2);
 	}
 	if(!configContainsKey("gui.mail.notifyacknoledge")) {
 		configSetKey("gui.mail.notifyacknoledge",true);
@@ -60,20 +59,17 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("mail.appendmailtext")) {
 		configSetKey("mail.appendmailtext",true);
 	}
-	if(!configContainsKey("mail.inlineattachments")) {
-		configSetKey("mail.inlineattachments",true);
-	}
 	if(!configContainsKey("gui.mail.htmlmessage")) {
 		configSetKey("gui.mail.htmlmessage",true);
 	}
 	if(!configContainsKey("mail.vcard")) {
 		configSetKey("mail.vcard",false);
 	}
-	if(!configContainsKey("mail.colorquoted")) {
-		configSetKey("mail.colorquoted",false);
-	}
-	if(!configContainsKey("mail.emoticons")) {
-		configSetKey("mail.emoticons",false);
+	if(!configContainsKey("gui.mail.editor_featureset")) {
+		configSetKey("gui.mail.editor_featureset", 2);
+		configSetKey("mail.inlineattachments",true);
+		configSetKey("mail.emoticons",true);
+		configSetKey("mail.colorquoted",true);
 	}
 	if(!configContainsKey("gui.mail.formatmessage")) {
 		configSetKey("gui.mail.formatmessage","ALTERNATIVE")
@@ -101,16 +97,32 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("gui.calendar.default_reminder")) {
 		configSetKey("gui.calendar.default_reminder",15);
 	}
-	if(!configContainsKey("gui.calendar.view")) {
-		configSetKey("gui.calendar.view","calendar/calendar/day");
-	} else if(!(configGetKey("modules.calendar.calendar_freebusy") && configGetKey("modules.calendar.calendar_teamview"))) {
-		var myconf=configGetKey("gui.calendar.view");
-		if(myconf == "calendar/team/day" && myconf == "calendar/team/workweek") {
-			configSetKey("gui.calendar.view","calendar/calendar/day");
-		}
-	}
-	if(!configContainsKey("gui.calendar.allfolders")) {
+	
+    if (!configContainsKey("gui.calendar.views")) {
+        if (configContainsKey("gui.calendar.view")) {
+            var view = configGetKey("gui.calendar.view");
+            if (!view || typeof view != "object") {
+                var match = /^calendar\/([^\/]+)\/([^\/]+)$/.exec(view)
+                    || [, "calendar", "day"];
+                view = { view: match[1], calendar: match[2], team: match[2],
+                         list: match[2], shared: true };
+            }
+            if(!(   configGetKey("modules.calendar.calendar_freebusy")
+                && configGetKey("modules.calendar.calendar_teamview")))
+            {
+                if (view.view == "team") view.view = "calendar";
+            }
+        } else {
+            var view = { view: "calendar", calendar: "workweek", team: "workweek",
+                         list: "weorkweek", shared: true };
+        }
+        configSetKey("gui.calendar.views", view);
+        configSetKey("gui.calendar.view", getDefaultCalendarView());
+    }
+	if (!configContainsKey("gui.calendar.allfolders")) {
 		configSetKey("gui.calendar.allfolders",true);
+		configSetKey("modules.calendar.notifyAcceptedDeclinedAsCreator",true);
+    	configSetKey("modules.tasks.notifyAcceptedDeclinedAsCreator",true);
 	}
 	if(!configContainsKey("gui.calendar.day.numberofappointments")) {
 		configSetKey("gui.calendar.day.numberofappointments",4);
@@ -130,12 +142,9 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("gui.calendar.custom.numberofappointments")) {
 		configSetKey("gui.calendar.custom.numberofappointments",3);
 	}
-   if (!configContainsKey("modules.calendar.notifyNewModifiedDeleted")) {
+	if (!configContainsKey("modules.calendar.notifyNewModifiedDeleted")) {
         configSetKey("modules.calendar.notifyNewModifiedDeleted",false);
-    }
-    if (!configContainsKey("modules.calendar.notifyAcceptedDeclinedAsCreator")) {
-        configSetKey("modules.calendar.notifyAcceptedDeclinedAsCreator",true);
-    }  
+    } 
     if (!configContainsKey("modules.calendar.notifyAcceptedDeclinedAsParticipant")) {
         configSetKey("modules.calendar.notifyAcceptedDeclinedAsParticipant",true);
     }
@@ -203,11 +212,9 @@ register("OX_Configuration_Loaded", function() {
 	if(!configContainsKey("gui.portal.infobox")) {
 		configSetKey("gui.portal.infobox",true);
 	}
-	if (!configContainsKey("global_categories")) {
-		configSetKey("global_categories","");
-	}
-	if (!configContainsKey("gui.private_categories")) {
-		configSetKey("gui.private_categories","");
+	if (!configContainsKey("gui.categories.local")) {
+		configSetKey("gui.categories.local", []);
+		ox.categories.utils.migrateTags();
 	}
 	if (!configContainsKey("gui.FolderTreeState")) {
 		configSetKey("gui.FolderTreeState",new Object);
@@ -348,6 +355,7 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
                 //#. HTTP Errors from the server
                 //#. %1$s is the numeric HTTP status code
                 //#. %2$s is the corresponding HTTP status text
+                //#, c-format
                 format(_("Error: %1$s - %2$s"), status, result);
         }
         if (openrequests==0) {
@@ -375,14 +383,15 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		}
 	}
 	
-	var ro_ConfigSettings = [ "folder", "defaultaddress", "addresses", "spambutton",
-	                    "availableModules", "context_id", "global_categories",
-	                    "reloadtimes", "folder", "identifier", "contact_id",
-	                    "currentTime", "serverVersion", "maxUploadIdleTimeout",
-	                    "mail.folder", "mail.defaultaddress", "mail.addresses",
-	                    "mail.spambutton", "participants.showWithoutEmail",
-	                    "participants.showDialog", "modules"
-	                  ];
+    var ro_ConfigSettings = [
+        "addresses", "availableModules", "availableTimeZones", "contact_id",
+        "context_id", "currentTime", "defaultaddress", "folder",
+        "global_categories", "identifier", "maxUploadIdleTimeout",
+        "mail.addresses", "mail.defaultaddress", "mail.folder",
+        "mail.spambutton", "modules", "participants.showDialog",
+        "participants.showWithoutEmail", "reloadtimes", "serverVersion",
+        "spambutton"
+    ];
 	
 	function saveConfigtoServer(path,params,success1,error1,myjson) {
 		showmessage=true;
@@ -451,7 +460,13 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		configuration_changed_fields["timezone"] = false;
 	}
 	if(configuration_changed_fields["language"] == true) {
-		saveConfigtoServer("language","language",myok,myerror,myjson);
+        saveConfigtoServer("language", "language", function() {
+            (new JSON).get(AjaxRoot + "/config/availableTimeZones?session=" +
+                session, null, function(tz) {
+                    configSetKey("availableTimeZones", tz.data);
+                    myok();
+                });
+        }, myerror, myjson);
 		openrequests++;
 		configuration_changed_fields["language"] = false;
 	}
@@ -509,53 +524,40 @@ function displaySignatureConfig(val) {
 	 sig.value = val;
 }
 
-function LogoutPopup() { }
+function LogoutPopup() { };
+// final logout call, can be overwritten
+LogoutPopup.doLogout = function() {
+	window.onbeforeunload = null;
+	new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
+		window.setTimeout( function() { 
+			window.location.replace(logout_location.format()); 
+		}, 0);
+	},function() { 
+		window.setTimeout( function() { 
+			window.location.replace(logout_location.format()); 
+		}, 0);			
+		return true;
+	});
+}
 LogoutPopup.openWindow = emptyFunction;
 LogoutPopup.closeWindow = emptyFunction;
-LogoutPopup.commityes = function () {	
-	triggerEvent("OX_Save_Configuration",true,true,function() {
-		//NO ERROR
-		window.onbeforeunload = null;
-		new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
-			window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-		},function() { 
-			window.setTimeout( function() { window.location.replace(logout_location.format()); },0);			
-			return true;
-		});
-	}, function(data) {
-		window.onbeforeunload = null;
-		if (typeof data != "object" || data.code == "SES-0203") {
-			window.setTimeout( function() { 
-				window.location.replace(logout_location.format()); 
-			},0);
-		} else {
-			newConfirm(_("Server Error:"),_("Your configuration settings could not be saved. All your changes will be lost. Do you really want to continue?") + "\n\n" + formatError(data), AlertPopup.YESNO,null,null,
-				function() {
-					
-					new JSON().get(AjaxRoot + "/login?action=logout&session=" + session, null, 
-						function() { 
-							window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-						},
-						function() { 
-							window.setTimeout( function() {
-								window.location.replace(logout_location.format()); 
-							},0);			
-							return true;
-						});
-				},
-				emptyFunction
-			);
-		}
-		return true;
-	});
-}
-LogoutPopup.commitno = function () {
-	window.onbeforeunload = null;
-	(new JSON()).get(AjaxRoot + "/login?action=logout&session=" + session, null, function() {
-		window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-	},function() { 
-		window.setTimeout( function() { window.location.replace(logout_location.format()); },0);
-		return true;
-	});
+LogoutPopup.commityes = function () {
+	triggerEvent("OX_Save_Configuration",true,true, LogoutPopup.doLogout, 
+			function(data) {
+				window.onbeforeunload = null;
+				if (typeof data != "object" || data.code == "SES-0203") {
+					window.setTimeout( function() { 
+						window.location.replace(logout_location.format()); 
+					}, 0);
+				} else {
+					newConfirm(_("Server Error:"),
+							_("Your configuration settings could not be saved. All your changes will be lost. Do you really want to continue?") + "\n\n" + formatError(data), 
+							AlertPopup.YESNO, null, null, LogoutPopup.doLogout, emptyFunction
+					);
+				}
+				return true;
+			}
+	);
 }
+LogoutPopup.commitno = LogoutPopup.doLogout;
 fileloaded();
\ No newline at end of file
