@@ -24,16 +24,14 @@ registerView("configuration/calendar/preferences",
 		cc_enter(); 
 		},
 	function () { 
-		//configuration_askforSave();
 		unregister("OX_SAVE_OBJECT",cc_saveConfiguration);
 		unregister("OX_Cancel_Object",cc_cancelConfiguration);
-		cc_leave(); 
 		},
 	function () { 
 		hideNode("config_calendar"); 
 		$("config_calendar").style.display="none";
     },
-	function () { cc_enter(); }
+	cc_enter
 );
 
 function cc_saveConfiguration() {
@@ -44,7 +42,12 @@ function cc_saveConfiguration() {
 		
 		configSetKey("gui.calendar.starttime",cc_work_start.getKey());
 		configSetKey("gui.calendar.endtime",cc_work_end.getKey());
-		configSetKey("gui.calendar.view",cc_default_level1.getKey());
+        cc_default_view_data.view = cc_default_view.getKey();
+        cc_default_view_data.calendar = cc_calendar_time_range.getKey();
+        cc_default_view_data.team = cc_team_time_range.getKey();
+        cc_default_view_data.list = cc_list_time_range.getKey();
+		configSetKey("gui.calendar.views", cc_default_view_data);
+		configSetKey("gui.calendar.view", getDefaultCalendarView());
 		configSetKey("gui.global.confirmpopup",getBoolofInt(getValueofRadioBox("cs_confirmpopup")));
 		
 		configSetKey("gui.calendar.day.numberofappointments",cc_countappointmentday.getKey());
@@ -57,7 +60,10 @@ function cc_saveConfiguration() {
 		configSetKey("gui.calendar.autoadd_participant_public",getBoolofInt(getValueofRadioBox("cs_calendar_add_participant_public")));	
 
 		configSetKey("gui.effects.hover.calendar",getBoolofInt(getValueofRadioBox("cc_enablehovercalendar")));	
-		menulastviews["calendar"]=cc_default_level1.getKey();
+        menulastviews.calendar = getDefaultCalendarView();
+        lastCalendarTimeRanges.calendar = cc_default_view_data.calendar;
+        lastCalendarTimeRanges.team = cc_default_view_data.team;
+        lastCalendarTimeRanges.list = cc_default_view_data.list;
 	}
 	if (configuration_changed_fields["modules"]) {
 		configSetKey("modules.calendar.defaultStatusPrivate",cc_defaultstatusprivate.getKey());
@@ -84,8 +90,16 @@ var cc_interval;
 var cc_default_reminder;
 var cc_work_start;
 var cc_work_end;
-var cc_default_level1;
 var cc_countappointmentww,cc_countappointmentday,cc_countappointmentcustom,cc_daysinworkweek,cc_daysincustom,cc_startdayofworkweek,cc_defaultstatusprivate,cc_defaultstatuspublic;
+var cc_default_view_data;
+var cc_default_view;
+var cc_calendar_time_range, cc_team_time_range, cc_list_time_range;
+
+function cc_team_view_upsell() {
+    if (!configGetKey('modules.calendar.calendar_teamview')) {
+        triggerEvent("Feature_Not_Available", "modules/calendar/team");
+    }
+}
 
 function cc_enter() {
 	if(!cc_init_bool) {
@@ -110,9 +124,30 @@ function cc_enter() {
 		cc_work_end.setKey(configGetKey("gui.calendar.endtime"));
 		configuration_changed_fields["gui"]=false;
 	}
-	if(configContainsKey("gui.calendar.view")) {
-		cc_default_level1.setKey(configGetKey("gui.calendar.view"));
-		configuration_changed_fields["gui"]=false;
+	if(   configContainsKey("gui.calendar.views")
+	   || configContainsKey("gui.calendar.view"))
+	{
+        cc_default_view_data = configGetKey("gui.calendar.views");
+        if (!cc_default_view_data) {
+            cc_default_view_data = configGetKey("gui.calendar.view");
+            if (   !cc_default_view_data
+                || typeof cc_default_view_data != "object")
+            {
+                var match = /^calendar\/([^\/]+)\/([^\/]+)$/.exec(
+                    cc_default_view_data) || [, "calendar", "day"];
+                cc_default_view_data = { view: match[1], calendar: match[2],
+                    team: match[2], list: match[2], shared: true };
+            }
+        }
+        cc_default_view.setKey(cc_default_view_data.view);
+        cc_calendar_time_range.setKey(cc_default_view_data.calendar);
+        cc_team_time_range.setKey(cc_default_view_data.team);
+        cc_list_time_range.setKey(cc_default_view_data.list);
+        setValueofRadioBox("cs_shared_time_range", cc_default_view_data.shared);
+        configuration_changed_fields["gui"]=false;
+        var hasTeam = configGetKey('modules.calendar.calendar_teamview');
+        ox.UI.Widget.setDisabledClass($("cc_team_time_range_label"), !hasTeam);
+        cc_team_time_range[hasTeam ? "enable" : "disable"]();
 	}
 	if(configContainsKey("gui.global.confirmpopup")) {
 		setValueofRadioBox("cs_confirmpopup",configGetKey("gui.global.confirmpopup"));
@@ -180,19 +215,25 @@ function cc_enter() {
 
 register("OX_Configuration_Loaded",cc_onconfigload);
 function cc_onconfigload() {
-	addDefaultView("calendar/calendar/day","Calendar day view");/*i18n*/
-	addDefaultView("calendar/calendar/workweek","Calendar workweek view");/*i18n*/
-	addDefaultView("calendar/calendar/month","Calendar month view");/*i18n*/
-	addDefaultView("calendar/calendar/week","Calendar week view");/*i18n*/
-	addDefaultView("calendar/calendar/custom","Calendar custom view");/*i18n*/
-	if(configGetKey("modules.calendar.calendar_freebusy") && configGetKey("modules.calendar.calendar_teamview")) {
-		addDefaultView("calendar/team/day","Team day view");/*i18n*/
-		addDefaultView("calendar/team/workweek","Team workweek view");/*i18n*/
-	}
-	addDefaultView("calendar/list/day","List day view");/*i18n*/
-	addDefaultView("calendar/list/workweek","List workweek view");/*i18n*/
-	addDefaultView("calendar/list/month","List month view");/*i18n*/
-	addDefaultView("calendar/list/week","List week view");/*i18n*/
+    addDefaultView("calendar/calendar/day", true);
+    addDefaultView("calendar/calendar/workweek", true);
+    addDefaultView("calendar/calendar/month", true);
+    addDefaultView("calendar/calendar/week", true);
+    addDefaultView("calendar/calendar/custom", true);
+    if (   configGetKey("modules.calendar.calendar_freebusy")
+        && configGetKey("modules.calendar.calendar_teamview"))
+    {
+        addDefaultView("calendar/team/day", true);
+        addDefaultView("calendar/team/workweek", true);
+        addDefaultView("calendar/team/month", true);
+        addDefaultView("calendar/team/week", true);
+        addDefaultView("calendar/team/custom", true);
+    }
+    addDefaultView("calendar/list/day", true);
+    addDefaultView("calendar/list/workweek", true);
+    addDefaultView("calendar/list/month", true);
+    addDefaultView("calendar/list/week", true);
+    addDefaultView("calendar/list/custom", true);
 }
 
  
@@ -233,12 +274,26 @@ function cc_init() {
 	}
 	cc_work_end.getDomNode();	
 	
-	cc_default_level1= new ComboBox3(window, "cc_default_level1", "22em", 1, true,"OX_Configuration_GUI_Changed", 5);
-	var calviews=getDefaultSubviews("calendar");
-	for (var i in calviews) {
-		cc_default_level1.addElement(calviews[i],i);
+    cc_default_view = new ComboBox3(window, "cc_default_view", "11em", 1, true, "OX_Configuration_GUI_Changed", 3);
+    cc_default_view.addElement("Calendar"/*i18n*/, "calendar");
+    cc_default_view.addElement("Team"/*i18n*/, "team");
+    cc_default_view.addElement("List"/*i18n*/, "list");
+    cc_default_view.getDomNode();
+    cc_calendar_time_range = new ComboBox3(window, "cc_calendar_time_range", "11em", 1, true, "OX_Configuration_GUI_Changed", 5);
+    cc_team_time_range = new ComboBox3(window, "cc_team_time_range", "11em", 1, true, "OX_Configuration_GUI_Changed", 5);
+    cc_list_time_range = new ComboBox3(window, "cc_list_time_range", "11em", 1, true, "OX_Configuration_GUI_Changed", 5);
+	var time_ranges = ["day", "workweek", "month", "week", "custom"];
+	var range_names = ["Day"/*i18n*/, "Work Week"/*i18n*/, "Month"/*i18n*/,
+	                   "Week"/*i18n*/, "Custom"/*i18n*/];
+    for (var i = 0; i < time_ranges.length; i++) {
+        cc_calendar_time_range.addElement(range_names[i], time_ranges[i]);
+        cc_team_time_range.addElement(range_names[i], time_ranges[i]);
+        cc_list_time_range.addElement(range_names[i], time_ranges[i]);
 	}
-	cc_default_level1.getDomNode();
+    cc_calendar_time_range.getDomNode();
+    cc_team_time_range.getDomNode();
+    cc_list_time_range.getDomNode();
+    
 	cc_countappointmentww= new ComboBox3(window, "cc_countappointmentww", "11em", 1, true,"OX_Configuration_GUI_Changed", 5);
 	cc_countappointmentday= new ComboBox3(window, "cc_countappointmentday", "11em",1, true,"OX_Configuration_GUI_Changed", 5);
 	cc_countappointmentcustom= new ComboBox3(window, "cc_countappointmentcustom", "11em",1, true,"OX_Configuration_GUI_Changed", 5);
@@ -280,8 +335,5 @@ function cc_init() {
 	cc_defaultstatusprivate.getDomNode();
 	cc_defaultstatuspublic.getDomNode();	
 }
-function cc_leave() {
-	
-}
 
 fileloaded();
\ No newline at end of file
