@@ -19,8 +19,9 @@ function ConfigTeams() {
 	this.cbcancel;
 }
 ConfigTeams.open = function () {
-	showNode("disable_background_window");
-	$("disable_background_window").style.display="block";
+    ox.api.setModal(true);
+	//showNode("modal-dialog");
+	//$("modal-dialog").style.display="block";
 	showNode("config_popups_win");
 	$("config_popups_win").style.display="block";
 	showNode("window_teams");
@@ -33,7 +34,7 @@ ConfigTeams.close = function () {
 	$("window_teams").style.display="none";
 	hideNode("config_popups_win");
 	$("config_popups_win").style.display="none";
-	var childs=	$("disable_background_window").childNodes;
+	var childs=	$("modal-dialog").childNodes;
 	var closeall=true;
 	for(var i=0;i<childs.length;i++) {
 		if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -43,8 +44,9 @@ ConfigTeams.close = function () {
 		}
 	}
 	if(closeall) {
-		hideNode("disable_background_window");
-		$("disable_background_window").style.display="none";
+	    ox.api.setModal(false);
+		//hideNode("modal-dialog");
+		//$("modal-dialog").style.display="none";
 	}
 }
 ConfigTeams.commitcancel = function () {
@@ -291,6 +293,7 @@ function cct_createParticipants_PopUp() {
 							null,null,true,true);
 	function newPermanentUsers(response) {
 		for(i in response) {
+		    delete response[i].contactID;
 			var available=false;
 			for(var z=0;z<configteams.teams.length;z++) {
 				if(configteams.teams[z].id==response[i].id) {
