@@ -113,8 +113,9 @@ Ci_import_data.prototype = {
 	},
 	
 	openWindow: function() {
-		showNode("disable_background_window");
-		$("disable_background_window").style.display="block";
+	    ox.api.setModal(true);
+		//showNode("modal-dialog");
+		//$("modal-dialog").style.display="block";
 		showNode("config_popups_win");
 		$("config_popups_win").style.display="block";
 		showNode("window_import_status");
@@ -127,8 +128,9 @@ Ci_import_data.prototype = {
 		$("window_import_status").style.display="none";
 		hideNode("config_popups_win");
 		$("config_popups_win").style.display="none";
-		hideNode("disable_background_window");
-		var childs=	$("disable_background_window").childNodes;
+		ox.api.setModal(false);
+		//hideNode("modal-dialog");
+		var childs=	$("modal-dialog").childNodes;
 		var closeall=true;
 		for(var i=0;i<childs.length;i++) {
 			if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -138,7 +140,8 @@ Ci_import_data.prototype = {
 			}
 		}
 		if(closeall) {
-			$("disable_background_window").style.display="none";
+		    ox.api.setModal(false);
+			//$("modal-dialog").style.display="none";
 		}
 		$("cms_import_status").firstChild.data = "";
 		$("cms_import_log").value = "";
@@ -193,7 +196,13 @@ Ci_import_data.prototype = {
 function import_getWarningsAsString(warnings) {
     var retVal = [];
     for (var i = 0; i < warnings.length; i++) {
-        retVal.push(escapeHTML(formatError(warnings[i], "%2$s (%1$s, %3$s)")) + "\n");
+        //#. Format string for warnings. The difference to the default
+        //#. is that it doesn't have "Error:" at the beginning.
+        //#. %1$s is the error code.
+        //#. %2$s is the formatted error message.
+        //#. %3$s is the unique error ID.
+        //#, c-format
+        retVal.push(escapeHTML(formatError(warnings[i], "%2$s (%1$s, %3$s)"/*i18n*/)) + "\n");
     }
     return retVal.join();
 }
@@ -210,8 +219,14 @@ function callback_import(arg) {
 		var importLog = "";
 		
 		for (var i=0; i<arg.data.length; i++) {
-			if (arg.data[i].error) {				
-				importLog += escapeHTML(formatError(arg.data[i], "%2$s (%1$s, %3$s)")) + "\n";
+			if (arg.data[i].error) {
+	            //#. Format string for warnings. The difference to the default
+			    //#. is that it doesn't have "Error:" at the beginning.
+                //#. %1$s is the error code.
+                //#. %2$s is the formatted error message.
+                //#. %3$s is the unique error ID.
+                //#, c-format
+				importLog += escapeHTML(formatError(arg.data[i], "%2$s (%1$s, %3$s)"/*i18n*/)) + "\n";
 				if (arg.data[i].warnings && arg.data[i].warnings.length) {
 					importLog += import_getWarningsAsString(arg.data[i].warnings);
 				}
@@ -226,7 +241,8 @@ function callback_import(arg) {
 		}
 		
 		$("cms_import_log").value = importLog.length != 0 ? importLog : _("None");
-		// #. %d is the number of successfully imported data records
+		//#. %d is the number of successfully imported data records
+		//#, c-format
 		textM = format(_("Successfully imported: %d"), successfullImported);		
 		oCi_import_data.openWindow();
 	} else {
