@@ -188,16 +188,28 @@ function cm_enter() {
 		configuration_changed_fields["modules"]=false;
 	}
 	var emailCollectEnabled = false;
-	if (configGetKey("modules.mail.contactCollectEnabled") && 
-			configGetKey("modules.mail.contactCollectEnabled") == true &&
-			configContainsKey("modules.mail.contactCollectFolder") &&
-			configGetKey("modules.mail.contactCollectFolder") != 0) {
+    if (   configContainsKey("modules.mail.contactCollectOnMailTransport")
+        && configContainsKey("modules.mail.contactCollectOnMailAccess"))
+    {
         setIntofRadioBox("cm_contactCollectOnMailTransport", configGetKey("modules.mail.contactCollectOnMailTransport"));
         setIntofRadioBox("cm_contactCollectOnMailAccess", configGetKey("modules.mail.contactCollectOnMailAccess"));
         configuration_changed_fields["modules"]=false;        
-        oMainFolderTree.cache.get_folder(configGetKey("modules.mail.contactCollectFolder"), function(folder) { 
-            $("cm_emailCollection_text").firstChild.nodeValue = format(_("Automatically collect contacts in the folder \"%s\""), [folder.oxfolder.data.title]);
-        });
+        if (   configContainsKey("modules.mail.contactCollectFolder")
+            && configGetKey("modules.mail.contactCollectFolder") != 0)
+        {
+            oMainFolderTree.cache.get_folder(
+                configGetKey("modules.mail.contactCollectFolder"),
+                function(folder) { 
+                    //#. %s is the folder name.
+                    //#, c-format
+                    $("cm_emailCollection_text").firstChild.nodeValue = format(
+                        _("Automatically collect contacts in the folder \"%s\""),
+                        [folder.oxfolder.data.title]);
+                });
+        } else {
+            $("cm_emailCollection_text").firstChild.nodeValue =
+                _("Automatically collect contacts");
+        }
         emailCollectEnabled=true;        
     }
 	$("cm_emailCollectionContent0").style.display=emailCollectEnabled ? "" : "none";
