@@ -20,6 +20,18 @@ var mail_accounts;
 register("OX_Configuration_Loaded", function () {	
 	mail_accounts = new Storage(0, [], 0, 0, 0, 0, function(data) { return data.id; });
 		
+    var account_folders = {};
+    function updateAccountFolders() {
+        account_folders = {};
+        mail_accounts.newIterate(mail_accounts.ids, emptyFunction,
+            function(index, account) {
+                for (var i in { trash: 1, sent: 1, drafts: 1, spam: 1 }) {
+                    var fullname = account[i + "_fullname"];
+                    if (fullname) account_folders[fullname] = i;
+                }
+            });
+    }
+	
 	function loadAccounts(cb) {
 		ox.JSON.get(AjaxRoot + "/account?action=all&session=" + session,
 	        	// data handler
@@ -30,6 +42,17 @@ register("OX_Configuration_Loaded", function () {
 	                	nData.push(mapArray2Object(reply.data[i]));
 	                }
 	                mail_accounts.append(nData);
+	                updateAccountFolders();
+	                var oldStdFolder = window.isStdFolder || function() {
+	                    return false;
+	                };
+                    window.isStdFolder = corewindow == window ? function(type) {
+                        return account_folders[activefolder] == type
+                            || oldStdFolder(type);
+                    } : function(type) {
+                        return account_folders[url.folder] == type
+                            || oldStdFolder(type);
+                    };
 	                if (cb) cb();
 	            },
 	            // error handler
@@ -43,10 +66,14 @@ register("OX_Configuration_Loaded", function () {
 	if (configGetKey("modules.mail.module") != null) {
 		loadAccounts(null);
 	}
-
+	
 	// if not enabled we won't continue
-	if (configGetKey("modules.mail.module") == null || !configGetKey("modules.mailaccount.module")) return;
-		
+	if (configGetKey("modules.mail.module") == null || 
+	        (configGetKey("modules.mail.module") === false && 
+	                configGetKey("modules.mailaccount.module") === false)) {
+	    return;
+	}
+	
 	var node = new ox.Configuration.LeafNode("configuration/mail/accounts", 
 			newnode("span",0,0,[ 
 			                    newnode("span",0,0,[document.createTextNode(_("Accounts"))]), 
@@ -118,6 +145,7 @@ register("OX_Configuration_Loaded", function () {
                             split.original.unified_inbox_enabled = enabled;
                             // thx to preuss' "brilliant" idea
                             mail_accounts.data.data[accountId].unified_inbox_enabled = enabled;
+                            updateAccountFolders();
                     });
                 }
             }
@@ -180,10 +208,16 @@ register("OX_Configuration_Loaded", function () {
 	    	}
 	    	delete(nData.transport_credentials);
 	    	
-	    	nData.pop3_expunge_on_quit = !nData.pop3_expunge_on_quit;
-	    	nData.mail_port = parseInt(nData.mail_port);
-	    	nData.transport_port = parseInt(nData.transport_port);
-	    	nData.transport_protocol = "smtp";
+            if ("pop3_expunge_on_quit" in nData) {
+                nData.pop3_expunge_on_quit = !nData.pop3_expunge_on_quit;
+            }
+            if ("mail_port" in nData) {
+                nData.mail_port = parseInt(nData.mail_port);
+            }
+            if ("transport_port" in nData) {
+                nData.transport_port = parseInt(nData.transport_port);
+            }
+            nData.transport_protocol = "smtp";
 	    	if (nData["mail_protocol"] == "pop3") {
 	    		nData.pop3_storage = "mailaccount";
 	    	}
@@ -197,6 +231,7 @@ register("OX_Configuration_Loaded", function () {
 	            				mail_accounts.localUpdate([data.id], function(old) {
 	                                if (!equals(reply.data, old)) return reply.data;
 	                            });
+	            				updateAccountFolders();
 	                            ox.Configuration.info(
 	                                _("Your settings have been saved."));
 	                            // updating folder tree
@@ -212,7 +247,7 @@ register("OX_Configuration_Loaded", function () {
 	    	
 	    	function handleNew(reply) {
 	    		if (!reply || !reply.data) {
-	    			triggerEvent("OX_New_Error", 4, format(_("Syntax error in server reply:\n%s"), "no error provided"));
+	    			triggerEvent("OX_New_Error", 4, _("Syntax error in server reply: no error provided"));
 	    			return;
 	    		}	    		
 	    		var data = reply.data;
@@ -243,7 +278,7 @@ register("OX_Configuration_Loaded", function () {
 	            });
 	    };
 	    
-	    split.onNew = function() {
+	    split.onNew = function() {	    	
 	    	split.right.scrollTop = 0;
 	    	this.addNew({ name: _("New account") });
 	    };
@@ -280,19 +315,37 @@ register("OX_Configuration_Loaded", function () {
 	    addMenuNode(accountsmenu.node, MenuNodes.FIXED, 31);
 	    changeDisplay(node.id, "mail.accounts");
 	    
-	    register("OX_SELECTED_ITEMS_CHANGED", function() {
+	    register("OX_SELECTED_ITEMS_CHANGED", function() {	    	
 	        var deleteenabled = selection.count >= 1;
+	        if (!configGetKey("modules.mailaccount.module")) {
+	        	deleteenabled = false;
+	        }
 	        if (grid.storage) {
 	            grid.storage.newIterate(selection.getSelected(), emptyFunction, emptyFunction, updateMenu);
 	        } else updateMenu();	        
 	        function updateMenu() {
 	            menuglobalzaehler = 0;
 	            menuarrows[node.id]["mail.accounts"] = [];
-	            menu_display_contents(node.id, "mail.accounts", deleteenabled,
-	                "mail.accounts.delete");
+	            menu_display_contents(node.id, "mail.accounts", deleteenabled, "mail.accounts.delete");
 	        }
 	    });
 	    
+	    // need to wait that panel has been initialized
+	    setTimeout(function() {
+	    	menu_display_contents(node.id, "mail.accounts", false, "mail.accounts.delete");
+	    	
+	    	// disable new button when no multiple-accounts are allowed
+	    	if (!configGetKey("modules.mailaccount.module")) {
+	    		menu_display_contents("configuration/modules/0", "menu_new", false, "menu_big_new");
+	    		
+	    		// register to new button
+		    	register("OX_NEW", function(enabled) {
+		    		//trigger upsell event
+		    		triggerEvent("Feature_Not_Available", "configuration/mail/accounts/new");
+		    	});
+	    	}
+	    }, 0);
+	    
 	    /*** new/edit fields on the right side ***/
 	    
 	    /*** blank line ***/
@@ -510,6 +563,8 @@ register("OX_Configuration_Loaded", function () {
 	    save_button.click = function(data, pata) {
 	    	function fail(field) {
 	    		setTimeout(function() { 
+	    		    //#. %1$s is the field name.
+	    		    //#, c-format
 	    			triggerEvent("OX_New_Error", 4, format(_("The mandatory field %1$s is not defined."), field)); 
 	    		}, 0);
 	    		return;
