@@ -29,7 +29,7 @@ function ConfigSignatures() {
 ConfigSignatures.initGrid = function() {
 	configsignatures.grid = new LiveGrid([
     { 
-        text: "Name",
+        text: "Name",/*i18n*/
         i18n: true,
         clear: LiveGrid.makeClear(""),
         set: function(div, data) {
@@ -40,7 +40,7 @@ ConfigSignatures.initGrid = function() {
         }
     },
     {
-        text: "Place",
+        text: "Place",/*i18n*/
         i18n: true,
         clear: LiveGrid.makeClear(""),
         width: "6em",
@@ -53,7 +53,7 @@ ConfigSignatures.initGrid = function() {
         }
     },
     {
-        text: "Default",
+        text: "Default",/*i18n*/
         i18n: true,
         clear: LiveGrid.makeClear(""),
         width: "6em",
@@ -114,8 +114,9 @@ ConfigSignatures.initGrid = function() {
     configsignatures.grid.getTable($("cms_signatures_grid"));
 }
 ConfigSignatures.open = function () {
-	showNode("disable_background_window");
-	$("disable_background_window").style.display="block";
+    ox.api.setModal(true);
+	//showNode("modal-dialog");
+	//$("modal-dialog").style.display="block";
 	showNode("config_popups_win");
 	$("config_popups_win").style.display="block";
 	showNode("window_signature");
@@ -128,8 +129,9 @@ ConfigSignatures.close = function () {
 	$("window_signature").style.display="none";
 	hideNode("config_popups_win");
 	$("config_popups_win").style.display="none";
-	hideNode("disable_background_window");
-	var childs=	$("disable_background_window").childNodes;
+	ox.api.setModal(false);
+	//hideNode("modal-dialog");
+	var childs=	$("modal-dialog").childNodes;
 	var closeall=true;
 	for(var i=0;i<childs.length;i++) {
 		if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -139,7 +141,8 @@ ConfigSignatures.close = function () {
 		}
 	}
 	if(closeall) {
-		$("disable_background_window").style.display="none";
+	    ox.api.setModal(false);
+		//$("modal-dialog").style.display="none";
 	}
 	if (configsignatures.grid && configsignatures.grid.focus != undefined) {
 		setFocus($("cms_signatures_grid"));
