@@ -19,8 +19,9 @@ function ConfigExternalPortalModules() {
 }
 ConfigExternalPortalModules.prototype = {
 	open : function (){
-		showNode("disable_background_window");
-		$("disable_background_window").style.display="block";
+        ox.api.setModal(true);
+		//showNode("modal-dialog");
+		//$("modal-dialog").style.display="block";
 		showNode("config_popups_win");
 		$("config_popups_win").style.display="block";
 		try {
@@ -36,8 +37,9 @@ ConfigExternalPortalModules.prototype = {
 		$("config_popups_win").style.display="none";
 		hideNode("window_external_module");
 		$("window_external_module").style.display="none";
-		hideNode("disable_background_window");
-		var childs=	$("disable_background_window").childNodes;
+		ox.api.setModal(false);
+		//hideNode("modal-dialog");
+		var childs=	$("modal-dialog").childNodes;
 		var closeall=true;
 		for(var i=0;i<childs.length;i++) {
 			if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -47,7 +49,8 @@ ConfigExternalPortalModules.prototype = {
 			}
 		}
 		if(closeall) {
-			$("disable_background_window").style.display="none";
+		    ox.api.setModal(false);
+			//$("modal-dialog").style.display="none";
 		}
 	},
 	cancel : function (){
@@ -84,7 +87,6 @@ registerView("configuration/portal/external",
 	function () { 
 		showNode("config_external"); 
 		$("config_external").style.display="block"; 
-		//#. The UWA module description at the user options. %s will be replaced with the PMG link.		
 		$("config.external.description").innerHTML = format(_(uwaLink.text), ["<a href=\"" + uwaLink.link.format() + "\" target=\"_blank\">", "</a>"]);
 	},
 	function() { 
