@@ -21,6 +21,9 @@ register("OX_Configuration_Settings_Changed_Modules",cs_changedModules);
 register("OX_Configuration_Settings_Changed_Calendar_Notification",cs_changedCalendarNotification);
 register("OX_Configuration_Settings_Changed_Task_Notification",cs_changedTaskNotification);
 register("OX_Configuration_Settings_Changed_Region_Date", cs_region_date_changed);
+register("OX_Configuration_Settings_Changed_Tree", function() {
+    configuration_changed_fields["modules"] = true;
+});
 
 function cs_changedMail() {
 	configuration_changed_fields["mail"]=true;
@@ -143,7 +146,9 @@ function cs_changeHeader() {
 var configSettingsTabsList = new Array('tabConfiguration1','tabConfiguration2');
 var configSettingsPanelsList = new Array('panelConfiguration1','panelConfiguration2');
 var configSettingsEventList = null;
-	
+
+var cc_actualTree = null;
+
 function cs_saveConfiguration() {
 	if(configuration_changed_fields["timezone"]) {
 		configSetKey("timezone",cs_timezone.getKey());
@@ -153,6 +158,21 @@ function cs_saveConfiguration() {
 		setLanguage(configGetKey("language"));
 		cs_region_enter();
 	}
+    if (configuration_changed_fields["modules"]) {
+        if (cc_actualTree === null) {
+            cc_actualTree = configGetKey("modules.folder.tree");
+        }
+        if (cc_actualTree !== null) {
+            var selectedTree = cs_tree.getKey();
+            if (selectedTree != cc_actualTree) {
+                ox.JSON.put(AjaxRoot + "/config/modules/folder/tree?session=" +
+                    session, selectedTree, function() {
+                        actualTree = selectedTree;
+                        ox.Configuration.info(_("The new folder tree setting will take effect after a new login."/*i18n*/));
+                });
+            }
+        }
+    }
 	if (configuration_changed_fields["gui"]) {		
 		var selectedTheme = cs_theme.getKey();		
 		if (selectedTheme != configGetKey("gui.theme").path && configContainsKey("modules.themes." + selectedTheme)) {
@@ -211,6 +231,7 @@ function cs_cancelConfiguration() {
 	configuration_changed_fields["gui"]=false;
 	configuration_changed_fields["language"]=false;
 	configuration_changed_fields["timezone"]=false;
+    configuration_changed_fields["modules"] = false;
 	cs_enter();	
 }
 
@@ -306,6 +327,12 @@ function cs_enter() {
 		cs_timezone.setKey(configGetKey("timezone"));
 		configuration_changed_fields["timezone"]=false;
 	}
+    if (configContainsKey("modules.folder.tree")) {
+        cs_tree.setKey(configGetKey("modules.folder.tree"));
+        configuration_changed_fields["modules"] = false;
+    } else {
+        $("cs_tree").parentNode.parentNode.style.display = "none";
+    }
 	if(configContainsKey("gui.theme")) {
 		cs_theme.setKey(configGetKey("gui.theme").path);
 		configuration_changed_fields["gui"]=false;
@@ -424,9 +451,15 @@ function cs_init() {
 	cs_language.getDomNode();
 	
 	cs_timezone = new ComboBox3(window, "cs_timezone", "25em", 1, true, "OX_Configuration_Settings_Changed_Timezone", 8);
-	for(var i=0;i<timezones.length;i++) {
-		cs_timezone.addElement(timezones[i], timezones[i].replace(/ /g, "_"));	
-	}
+    var timezones = configGetKey("availableTimeZones");
+    var tzarray = [];
+    for (var i in timezones) tzarray.push({key: i, value: timezones[i] });
+    tzarray.sort(function(a, b) {
+        return a.value < b.value ? -1 : a.value > b.value ? 1 : 0;
+    });
+    for(var i = 0; i < tzarray.length; i++) {
+        cs_timezone.addElement(tzarray[i].value, tzarray[i].key);
+    }
 	cs_timezone.getDomNode();
 	
 	cs_dateformat = new ComboBox3(window, "cs_dateformat", "9em", 0, true, "OX_Configuration_Settings_Changed_Region_Date", 8);
@@ -481,6 +514,12 @@ function cs_init() {
 		}
 	}	
 	cs_landingPage.getDomNode();
+	
+	cs_tree = new ComboBox3(window, "cs_tree", "15em", 0, true,
+	    "OX_Configuration_Settings_Changed_Tree", 2);
+	cs_tree.addElement("Classic"/*i18n*/, 0);
+	cs_tree.addElement("New"/*i18n*/, 1);
+	cs_tree.getDomNode();
 }
 
 function cs_leave() { }
@@ -492,5 +531,6 @@ var cs_theme;
 var cs_landingPage;
 var cs_dateformat;
 var cs_date_separator;
+var cs_tree;
 
 fileloaded();
\ No newline at end of file
