@@ -17,154 +17,148 @@
 /**
  * @namespace
  */
-var ox = {
-
-    /**
-     * @namespace
-     */
-    UI: {},
+ox.UI = {};
+    
+/**
+ * @namespace
+ */
+ox.Configuration = {
     
     /**
-     * @namespace
+     * Displays an error message to the user.
+     * @param {I18nString} text The error message to display.
      */
-    Configuration: {
-        
-        /**
-         * Displays an error message to the user.
-         * @param {I18nString} text The error message to display.
-         */
-        error: function(text) {
-            setTimeout(function() {
-                triggerEvent("OX_New_Error", 4, text());
-            }, 0);
-        },
+    error: function(text) {
+        setTimeout(function() {
+            triggerEvent("OX_New_Error", 4, text());
+        }, 0);
+    },
 
-        /**
-         * Displays an information message to the user.
-         * @param {I18nString} text The information message to display.
-         */
-        info: function(text) {
-            if (typeof text != "function") {
-                if (debug) {
-                    (console.warn || console.log || alert)(format(
-                        "The string \"%s\" is not internationalized!", text));
-                }
-                triggerEvent("OX_New_Info", 4, text);
-            } else {
-                triggerEvent("OX_New_Info", 4, text());
+    /**
+     * Displays an information message to the user.
+     * @param {I18nString} text The information message to display.
+     */
+    info: function(text) {
+        if (typeof text != "function") {
+            if (debug) {
+                (console.warn || console.log || alert)(format(
+                    "The string \"%s\" is not internationalized!", text));
             }
-        },
+            triggerEvent("OX_New_Info", 4, text);
+        } else {
+            triggerEvent("OX_New_Info", 4, text());
+        }
+    },
 
-        /**
-         * Adds a new node to the configuration tree.
-         * The parent node must already exist.
-         * @class Leaf node in the configuration tree
-         * @param {String} path The path in the configuration tree.
-         * Must start with "configuration" and contain at least one more
-         * element. Path elements are separated by a slash ("/"). There must be
-         * no slash at the end. If the parent of the node does not already
-         * exist, an Error exception is thrown.
-         * @param {I18nString} name The name of the page.
-         */
-        LeafNode: function(path, name) {
-            var Self = new ox.Configuration.Node(path, name, false, function() {
-                if (Self.click) return Self.click();
-            });
-            return Self;
-        },
+    /**
+     * Adds a new node to the configuration tree.
+     * The parent node must already exist.
+     * @class Leaf node in the configuration tree
+     * @param {String} path The path in the configuration tree.
+     * Must start with "configuration" and contain at least one more
+     * element. Path elements are separated by a slash ("/"). There must be
+     * no slash at the end. If the parent of the node does not already
+     * exist, an Error exception is thrown.
+     * @param {I18nString} name The name of the page.
+     */
+    LeafNode: function(path, name) {
+        var Self = new ox.Configuration.Node(path, name, false, function() {
+            if (Self.click) return Self.click();
+        });
+        return Self;
+    },
 
-        /**
-         * This callback is called when the user clicks on the node.
-         * @name ox.Configuration.LeafNode.prototype.click
-         * @type Function
-         */
+    /**
+     * This callback is called when the user clicks on the node.
+     * @name ox.Configuration.LeafNode.prototype.click
+     * @type Function
+     */
 
-        /**
-         * Adds a new inner node to the configuration tree.
-         * The parent node must already exist.
-         * @class Inner node in the configuration tree.
-         * @param {String} path The path in the configuration tree.
-         * Must start with "configuration" and contain at least one more
-         * element. Path elements are separated by a slash ("/"). There must be
-         * no slash at the end. If the parent of the node does not already
-         * exist, an Error exception is thrown.
-         * @param {I18nString} name The name of the page.
-         */
-        InnerNode: function(path, name) {
-            return new ox.Configuration.Node(path, name, true);
-        },
-        
-        /**
-         * @class
-         * @private
-         */
-        Node: function(path, name, folder, click) {
-            if (path in ox.Configuration.nodes)
-                return ox.Configuration.nodes[path];
-            var index = path.indexOf("/");
-            if (index < 0) throw Error("Invalid path: '" + path + "'");
-            this.id = folder ? path
-                : "configuration/modules/" + ox.Configuration.id++;
-            var txtNode = typeof(name) == "function" || typeof(name) == "string"
-                        ? addTranslated(name) : name; 
-            var obj = new cConfigObject(this.id, txtNode, folder);
-            if (click) obj.onClick = click;
-            if ("configTree" in window && configTree) {
-                var parent = configTree;
-                while (index >= 0) {
-                    parent = parent.children[path.substring(0, index)];
-                    if (!parent) throw Error("Invalid path: '" +
-                                             path.substring(0, index) + "'");
-                    index = path.indexOf("/", index + 1);
-                }
-                drawTreeNode(parent, obj);
-            } else {
-                var parent = oConfigTreeDef;
-                index = path.indexOf("/", index + 1);
-                while (index >= 0) {
-                    var subpath = path.substring(0, index);
-                    search: {
-                        for (var j = 0; j < parent.aObjects.length; j++) {
-                            if (parent.aObjects[j].sId == subpath) {
-                                parent = parent.aObjects[j];
-                                break search;
-                            }
-                        }
-                        throw Error("Invalid path: '" +
-                                    path.substring(0, index) + "'");
-                    }
-                    index = path.indexOf("/", index + 1);
-                }
-                parent.pushObject(obj);
-            }
-            ox.Configuration.nodes[path] = this;
-        },
-    
-        /**
-         * A map from paths to configuration tree nodes.
-         * @private
-         */
-        nodes: {},
-        
-        /**
-         * A counter for unique node IDs.
-         * @private
-         */
-        id: 0,
-        
-        /**
-         * An array with all created configuration pages.
-         * @private
-         */
-        pages: []
-        
+    /**
+     * Adds a new inner node to the configuration tree.
+     * The parent node must already exist.
+     * @class Inner node in the configuration tree.
+     * @param {String} path The path in the configuration tree.
+     * Must start with "configuration" and contain at least one more
+     * element. Path elements are separated by a slash ("/"). There must be
+     * no slash at the end. If the parent of the node does not already
+     * exist, an Error exception is thrown.
+     * @param {I18nString} name The name of the page.
+     */
+    InnerNode: function(path, name) {
+        return new ox.Configuration.Node(path, name, true);
     },
     
     /**
-     * @namespace
+     * @class
+     * @private
      */
-    JSON: {}
+    Node: function(path, name, folder, click) {
+        if (path in ox.Configuration.nodes)
+            return ox.Configuration.nodes[path];
+        var index = path.indexOf("/");
+        if (index < 0) throw Error("Invalid path: '" + path + "'");
+        this.id = folder ? path
+            : "configuration/modules/" + ox.Configuration.id++;
+        var txtNode = typeof(name) == "function" || typeof(name) == "string"
+                    ? addTranslated(name) : name; 
+        var obj = new cConfigObject(this.id, txtNode, folder);
+        if (click) obj.onClick = click;
+        if ("configTree" in window && configTree) {
+            var parent = configTree;
+            while (index >= 0) {
+                parent = parent.children[path.substring(0, index)];
+                if (!parent) throw Error("Invalid path: '" +
+                                         path.substring(0, index) + "'");
+                index = path.indexOf("/", index + 1);
+            }
+            drawTreeNode(parent, obj);
+        } else {
+            var parent = oConfigTreeDef;
+            index = path.indexOf("/", index + 1);
+            while (index >= 0) {
+                var subpath = path.substring(0, index);
+                search: {
+                    for (var j = 0; j < parent.aObjects.length; j++) {
+                        if (parent.aObjects[j].sId == subpath) {
+                            parent = parent.aObjects[j];
+                            break search;
+                        }
+                    }
+                    throw Error("Invalid path: '" +
+                                path.substring(0, index) + "'");
+                }
+                index = path.indexOf("/", index + 1);
+            }
+            parent.pushObject(obj);
+        }
+        ox.Configuration.nodes[path] = this;
+    },
+
+    /**
+     * A map from paths to configuration tree nodes.
+     * @private
+     */
+    nodes: {},
+    
+    /**
+     * A counter for unique node IDs.
+     * @private
+     */
+    id: 0,
+    
+    /**
+     * An array with all created configuration pages.
+     * @private
+     */
+    pages: []
+    
 };
+    
+/**
+ * @namespace
+ */
+ox.JSON = {};
 
 /**
  * Asynchronously requests a JSON object from the server.
@@ -1626,7 +1620,9 @@ ox.Configuration.Page = function(node, title, save_button) {
     ox.Configuration.View.apply(this, arguments);
     if (save_button == undefined) save_button = true;
     changeDisplay(node.id, save_button ? "menu_save" : "menu_nothing");
-    if (!save_button) this.viewModified = ox.Configuration.IFrame.viewModified;
+    if (!save_button) {
+        this.viewModified = ox.Configuration.IFrame.prototype.viewModified;
+    }
 };
 
 /**
@@ -1890,13 +1886,6 @@ ox.Configuration.EditableList = function(section, height, label) {
     this.height = height;
     this.label = label;
     this.storage = new Storage(0, []);
-    var Self = this;
-    this.storage.events.register("Changed", function() {
-        var newValues = [];
-        Self.storage.newIterate(Self.storage.ids, emptyFunction,
-            function(i, data) { newValues[i] = Self.values[data[0]]; },
-            function() { Self.values = newValues; });
-    });
 };
 
 /**
@@ -1912,6 +1901,20 @@ ox.Configuration.EditableList.id = 31;
  * an array of new elements as parameter.
  */
 
+/**
+ * This method is called when the "Remove" button is clicked.
+ * @name ox.Configuration.EditableList.prototype.onDelete
+ * @function
+ * @param {Array} removed An array with currently selected values.
+ * @param {Function} cont A callback function which should be called after all
+ * side effects have been performed. This function performs the actual removal.
+ * If it is not called, no entries are removed from the list.
+ * @param {Function} dontDelete A function which can be used to cancel
+ * the removal of individual values. For each value which should be kept, this
+ * function should be called with the index of the value in the array
+ * <code>removed</code> as parameter.
+ */
+
 ox.Configuration.EditableList.prototype = extend(ox.UI.Widget,
     /** @lends ox.Configuration.EditableList.prototype */
     {
@@ -1930,6 +1933,7 @@ ox.Configuration.EditableList.prototype = extend(ox.UI.Widget,
                 { height: this.height, position: "relative" });
             this.head.appendChild(this.grid.getHeader());
             this.grid.getTable(this.body);
+            this.applyEnabled();
             
             this.node = this.parent.addRow(newnode("div", 0, 0,
                 [this.head, this.body]));
@@ -1957,8 +1961,28 @@ ox.Configuration.EditableList.prototype = extend(ox.UI.Widget,
                 del);
             this.grid.events.register("Deleted", del);
             function del() {
-                Self.storage.removeIDs(selection.getSelected());
-            } 
+                var indices = Self.grid.selection.getSelected();
+                var deleted = {};
+                var values = new Array(indices.length);
+                for (var i = 0; i < indices.length; i++) {
+                    deleted[indices[i]] = true;
+                    values[i] = Self.values[indices[i]];
+                }
+                if (Self.onDelete) {
+                    Self.onDelete(values, cont, dontDelete);
+                } else {
+                    cont();
+                }
+                function cont() {
+                    for (var d = 0; d < Self.values.length && !deleted[d]; d++);
+                    for (var s = d + 1; s < Self.values.length; s++) {
+                        if (!deleted[s]) Self.values[d++] = Self.values[s];
+                    }
+                    Self.values.length = d;
+                    Self.set(Self.values);
+                }
+                function dontDelete(index) { delete deleted[indices[index]]; }
+            }
             addMenuNode(menu.node, MenuNodes.FIXED,
                         ox.Configuration.EditableList.id);
             changeDisplay(node_id, id);
@@ -1989,10 +2013,12 @@ ox.Configuration.EditableList.prototype = extend(ox.UI.Widget,
         get: function() { return this.values; },
         
         set: function(value) {
-            this.values = value;
+            this.values = new Array(value.length);
             var data = new Array(value.length);
-            for (var i = 0; i < value.length; i++)
+            for (var i = 0; i < value.length; i++) {
+                this.values[i] = value[i];
                 data[i] = [i, this.getText(value[i])];
+            }
             this.storage.remove(0, this.storage.ids.length);
             this.storage.append(data);
         },
