@@ -365,10 +365,15 @@ ContactFunctions.prototype = {
                     }
                 }
                 // open "new email" window
-                var newMail = newWindow("newMail.html", getWindowOptions(null, screen.availHeight-25));
-                newMail.focus();
-                // attach vCards
-                newMail.attachedObjects = contacts;
+                ox.api.mail.compose({
+                	data: {
+                		attachedObjects: contacts
+                	}
+                })
+//                var newMail = newWindow("newMail.html", getWindowOptions(null, screen.availHeight-25));
+//                newMail.focus();
+//                // attach vCards
+//                newMail.attachedObjects = contacts;
             }
         });
         
@@ -853,6 +858,7 @@ ContactCardFunctions.prototype = {
                 //#. Format string for the 'lastname, firstname' display name default
                 //#. %1$s is the first name
                 //#. %2$s is the last name
+                //#, c-format
                 return format(_("%2$s, %1$s"), firstname, lastname);
             } else {
                 return lastname;
@@ -1228,7 +1234,8 @@ function writeCards(currentCardId, columnForDisplyCards, oCurrentContent)
         }));
         newId = 'displayname_label_'+ currentCardId;
         child.id = newId;
-        child.appendChild(document.createTextNode(nameHeadline.length != 0 ? "\xa0" + nameHeadline : "\xa0"));
+        // "\u00a0" = non-breaking space; fixed missing names in safari
+        child.appendChild(document.createTextNode("\u00a0" + nameHeadline));
         
         var grandchild = getElement(child.firstChild);
         if (data.color_label) {
@@ -1402,10 +1409,26 @@ function editContact() {
 		// contact or distribution list?
 		if(isDistributionListSelected == 1) {
 			// edit as distribution list
-			openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html', {id:contactDetailId, folder: activefolder});
+			ox.api.contact.editDistributionList({
+				params: {
+					id: contactDetailId,
+					folder: activefolder,
+					currentView: objContactFunctions.lastView
+				},
+				id: {id:contactDetailId, folder: activefolder}
+			});
+			//openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html', {id:contactDetailId, folder: activefolder});
 		} else {
 			// edit as contact
-			openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html', {id:contactDetailId, folder: activefolder});
+			ox.api.contact.edit({
+				params: {
+					id: contactDetailId,
+					folder: activefolder,
+					currentView: objContactFunctions.lastView
+				},
+				id: {id:contactDetailId, folder: activefolder}
+			});
+			//openContactPopup("modul=edit&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html', {id:contactDetailId, folder: activefolder});
 		}
 	} else {
 		// no write permission
@@ -1423,13 +1446,21 @@ function duplicateContact()
 	}
 	
 	// contact or distribution list?
-	if(isDistributionListSelected == 1) {
-		// open as distribution list
-		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html');
-	} else {
-		// open as contract
-		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html');
-	}
+	var fn = isDistributionListSelected == 1 ? ox.api.contact.duplicateDistributionList : ox.api.contact.duplicate;
+	// open dialog
+	fn({
+		params: {
+			id: contactDetailId,
+			folder: activefolder,
+			currentView: objContactFunctions.lastView
+		},
+		id: {id:contactDetailId, folder: activefolder}
+	});
+//		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newDistributionList.html');
+//	} else {
+//		// open as contract
+//		openContactPopup("modul=duplicate&id="+contactDetailId+"&folder="+activefolder+"&session="+session+ "&currentView="+objContactFunctions.lastView, 'newContact.html');
+//	}
 }
 
 function DistributionLiveGrid() {
@@ -1619,8 +1650,15 @@ function showContactDetail(cb_function) {
 		        $('imageContactDetailTd').className = "contactDummyImage border-color-default";
 		        $('imageContactDetailTd').firstChild.className="border-color-content-default";
 		        $('imageContactDetailTd').firstChild.src = getFullImgSrc('img/contacts/dummypicture.gif');
-		    }                                                   
-						
+		    }   
+            var cat = (daten.categories || "");
+            if (cat.length) {
+                ox.categories.ui.drawCategoriesList(ox.categories.getByString(cat), 
+              		  $("contact_categories"));
+            } else {
+          	  removeChildNodes($("contact_categories"));
+            }
+            						
             var fields = ["telephone_business1", "telephone_business2",
                 "telephone_home1", "telephone_home2", "cellular_telephone1",
                 "cellular_telephone2", "telephone_company", "telephone_other",
@@ -1643,18 +1681,18 @@ function showContactDetail(cb_function) {
                 }
                 combobox.getDomNode();
             }
-            fillComboBox("combo_telephone_business1",
-                         "abstact_telephone_business1", 0);
-            fillComboBox("combo_privat_tel", "abstact_telephone_home1", 2);
-            fillComboBox("combo_fax_home", "abstact_fax_home", 10);
-            fillComboBox("combo_mobile_tel", "cellular_telephone1", 4);
+			fillComboBox("combo_telephone_business1",
+			             "abstact_telephone_business1", 0);
+			fillComboBox("combo_privat_tel", "abstact_telephone_home1", 2);
+			fillComboBox("combo_fax_home", "abstact_fax_home", 10);
+			fillComboBox("combo_mobile_tel", "cellular_telephone1", 4);
             
 			var myCombobox5 = new ComboBox3(window, "combo_email1", "100%", 0, false, "cb_abstact_email1", null);
 			myCombobox5.targetDiv = $('abstact_email1');
 			myCombobox5.viewValue = true;
-			myCombobox5.addElement(_("E-Mail (business):"), daten['email1'] || "");
-			myCombobox5.addElement(_("E-Mail (private):"), daten['email2'] || "");
-			myCombobox5.addElement(_("E-Mail (other):"), daten['email3'] || "");
+			myCombobox5.addElement(_("E-Mail (business)"), daten['email1'] || "");
+			myCombobox5.addElement(_("E-Mail (private)"), daten['email2'] || "");
+			myCombobox5.addElement(_("E-Mail (other)"), daten['email3'] || "");
 			myCombobox5.getDomNode();
 			
 			if((daten['email1'])) {
@@ -1665,12 +1703,12 @@ function showContactDetail(cb_function) {
 			    triggerEvent("cb_abstact_email1", daten['email2']);
 			}
 			                    
-			var myCombobox6 = new ComboBox3(window, "combo_instant_messenger1", "100%", 0, false, null, null);
-			myCombobox6.targetDiv = $('instant_messenger1');
-			myCombobox6.viewValue = true;
-			myCombobox6.addElement(_("IM (business)"), daten['instant_messenger1'] || "");
-			myCombobox6.addElement(_("IM (private)"), daten['instant_messenger2'] || "");
-			myCombobox6.getDomNode();
+			var myCombobox = new ComboBox3(window, "combo_instant_messenger1", "100%", 0, false, null, null);
+			myCombobox.targetDiv = $('instant_messenger1');
+			myCombobox.viewValue = true;
+			myCombobox.addElement(_("IM (business)"), daten['instant_messenger1'] || "");
+			myCombobox.addElement(_("IM (private)"), daten['instant_messenger2'] || "");
+			myCombobox.getDomNode();
 			
 			var myCombobox7 = new ComboBox3(window, "combo_telephone_ip", "100%", 0, false, null, null);
 			myCombobox7.targetDiv = $('telephone_ip');
@@ -1734,6 +1772,8 @@ function showContactDetail(cb_function) {
 				    if(i<10) { k = "0" + i; }
 			        else { k = i; }
 			        indexforData = 'userfield'+k;
+			        //#. %d is the number of the optional dynamic field (1-20).
+			        //#, c-format
 			        optinalCombobox[t].addElement(format(_("Optional %d"),i), daten[indexforData] || "");
 			    }                   
 			    optinalCombobox[t].getDomNode();                        
@@ -1836,7 +1876,12 @@ function sendMailToContactMail(mailAdress) {
 	}
 		
 	if (mailRecipientAdress != "") {
-		var newMail = newWindow("newMail.html#action=&id=&folder=&to=" + encodeURIComponent(mailRecipientAdress), getWindowOptions());
+		ox.api.mail.compose({
+			data: {
+				to: [[mailRecipientAdress]]
+			}
+		});
+		//var newMail = newWindow("newMail.html#action=&id=&folder=&to=" + encodeURIComponent(mailRecipientAdress), getWindowOptions());
 	}
 }
 
@@ -2091,23 +2136,36 @@ function initLiveGridContacts()
 }
 
 /********************************** New Contact *****************************************************************/
-function createNewContact(module,folder) {	
-	if(module=="contacts") {
-		openContactPopup('modul=new&currentView='+objContactFunctions.lastView+"&folder="+folder,'newContact.html');
+function createNewContact (module, folder) {
+	if (module == "contacts") {
+		ox.api.contact.compose({
+			params: {
+				currentView: objContactFunctions.lastView,
+				folder: folder
+			}
+		});
+		//openContactPopup('modul=new&currentView='+objContactFunctions.lastView+"&folder="+folder,'newContact.html');
 	}
-	if(module=="distributionlist") {
-		openContactPopup('modul=new&currentView='+objContactFunctions.lastView+"&folder="+folder, 'newDistributionList.html');		
+	else if ( module == "distributionlist") {
+		ox.api.contact.composeDistributionList({
+			params: {
+				currentView: objContactFunctions.lastView,
+				folder: folder
+			}
+		});
+		//openContactPopup('modul=new&currentView='+objContactFunctions.lastView+"&folder="+folder, 'newDistributionList.html');		
 	}
 }
 /********************************** open Popup *****************************************************************/
 
-function openContactPopup(params, url, id) {	
-	var url = (url) ? url : 'newContact.html';
-	var popContact = newWindow(url + "#" + params, getWindowOptions(), id);
-	if(popContact) {
-		popContact.focus;
-	}
-}
+//function openContactPopup(params, url, id) {	
+//    url = urlify(url || "newContact.html");
+//	var popContact = newWindow(url + "#" + params, getWindowOptions(), id);
+//	if(popContact) {
+//		popContact.focus;
+//	}
+//	return popContact;
+//}
 
 function closeContactPopUp(popContact, newFolderId)
 {
