@@ -148,6 +148,7 @@ var session = null;
 var lastTimestamp = 0;
 var modulPopup = "new";
 var contact_object = {};
+var contact_categories = "";
 var dataFromDb = null;
 var dateAction = new Array();
 var myNewContactFunctions = null;
@@ -157,12 +158,11 @@ var tmp_attachment = null;
 var treeVisible = false;
 var miniBirthdayVisible = false;
 var miniAnniversaryVisible = false;
-var configGetKey = window.opener.configGetKey;
-var configSetKey = window.opener.configSetKey;
-var configContainsKey = window.opener.configContainsKey;
+var configGetKey = corewindow.configGetKey;
+var configSetKey = corewindow.configSetKey;
+var configContainsKey = corewindow.configContainsKey;
 var optFolderState = corewindow.optFolderState;
 var bAttachmentGridCreated = false;
-var contactCategories = false;
 var newContactId = 0;
 var messageOnCancel = false;
 var birthdayCalendar = null;
@@ -188,22 +188,20 @@ function setBeforeUnload(on){
 }
 
 /********************************** Init *****************************************************************/
-function initAttachmentsGrid()
-{
-	var nId = (url['modul'] && url['modul'] == "edit")?url["id"]:false;
-	var nFolder = clickedItemForSave;	 //fukel
-	tmp_attachment = new attachmentGrid("attachmentsNewContactGrid",nId,nFolder,7,tmp_attachmentDialog);	
+function initAttachmentsGrid() {
+	tmp_attachment = new attachmentGrid("attachmentsNewContactGrid", (url.id || false),
+			 clickedItemForSave , 7, tmp_attachmentDialog);	
 }
-function NewContactFunctions()
-{
+
+function NewContactFunctions() {
 	this.salutationComboBox = null;
 	this.cardColumns = (Math.min(Math.ceil(corewindow.countContactCards / 4)));
-	this.oCategories = null;
 	this.imageExist = false;
 	this.deleteImageOnServer = false;
 	this.searchPath = "";
 	this.searchAlreadyActivated = false;
 }
+
 NewContactFunctions.prototype = {
 	deletePicture: function() {		
 		if(myNewContactFunctions.imageExist) {
@@ -217,8 +215,9 @@ NewContactFunctions.prototype = {
 	},	
 	applyUploadImage: function() {		
 		$('contact_upload_image').style.display = "none";
-		hideNode("disable_background_window");
-        $("disable_background_window").style.display="none"; 
+		ox.api.setModal(false);
+//		hideNode("modal-dialog");
+//        $("modal-dialog").style.display="none"; 
 		if(document.getElementById("image1").value != "" && document.getElementById("image1").value != myNewContactFunctions.searchPath) 
 			triggerEvent("OX_New_Info",4,_("Your selected picture will be displayed after saving"));
 	},	
@@ -228,12 +227,14 @@ NewContactFunctions.prototype = {
 			$("contactUploadImage").reset();
 		}
 		$('contact_upload_image').style.display = "none";
-		hideNode("disable_background_window");
-        $("disable_background_window").style.display="none";
+		ox.api.setModal(false);
+//		hideNode("modal-dialog");
+//        $("modal-dialog").style.display="none";
 	},
 	addPicutre: function() {
-		showNode("disable_background_window");
-		$('disable_background_window').style.display = "block";        
+	    ox.api.setModal(true);
+//		showNode("modal-dialog");
+//		$('modal-dialog').style.display = "block";        
 		centerPopupWindow($('contact_upload_image'));
 		$('contact_upload_image').style.display = "block";
 		if(document.getElementById("image1").value != "") {
@@ -246,39 +247,48 @@ NewContactFunctions.prototype = {
 	closeWindow : function() {
 		function cbyes() {
 			window.onbeforeunload=null;
-			window.close();			
+			ox.api.window.close(url.guid);
 		}
 		if(messageOnCancel)
 			newConfirm(_("Close Window"),_(messageCloseWindow),AlertPopup.YESNO,null,null,cbyes,null);	
 		else
 			cbyes();
 	},
-	initCategories : function() {
-		if(!contactCategories) {
-				this.oCategories = 	new Categories(	configGetKey("global_categories"),
-													configGetKey("gui.private_categories"),
-													'newcontact_div_cat',
-													document.forms.contactForm.categories,
-													'newcontact_but_categories', 
-													"newcontact_categories_divContent"
-												);
-				this.oCategories.getHTML();
-				contactCategories = true;
-			} else {
-				$("newcontact_div_cat").style.display = "block";
-			}	
-	},
-	addCategoriesToObject: function() {
-		if(document.forms.contactForm.categories.value != "") {
-			contact_object.categories = document.forms.contactForm.categories.value;
-		} else {
-			contact_object.categories = "";
-		}
+	initCategories: function() {		
+		// add click on categories button
+		addDOMEvent($("newcontact_categories_button"), "click", function(e) {
+			myNewContactFunctions.openCategoriesDialog();
+		});
 		
+		// handle dbl click which attachs an inplace input field to div
+		addDOMEvent($("newcontact_categories_list"), "dblclick", function(e) {
+			ox.categories.ui.attachInplaceInput($("newcontact_categories_list"),
+				function(value) {				
+					// handle value
+					var list = clone(ox.categories.getByString(contact_categories, ox.categories.match.ALL, true));
+					// add only if not empty!
+					if (value && trimStr(value).length && !ox.categories.utils.existsInObject(trimStr(value), list)) {
+						var category = { name: value, color: 0 };
+						list.push(category);
+						contact_categories = ox.categories.utils.paramToString(list, "name");				
+					}
+					ox.categories.ui.drawCategoriesList(
+							ox.categories.getByString(contact_categories), 
+							$("newcontact_categories_list"));
+				}
+			);		
+		});		
+	},
+	openCategoriesDialog: function() {
+		ox.categories.ui.open((contact_categories || ""), function(list, str) {
+			contact_categories = str;
+			ox.categories.ui.drawCategoriesList(ox.categories.getByString(contact_categories), 
+					$("newcontact_categories_list"));
+		});
 	},
 	folderPath : function() {
 		if(!clickedItemForSave || clickedItemForSave=="null")
-				clickedItemForSave = window.opener.configGetKey("folder.contacts");
+				clickedItemForSave = corewindow.configGetKey("folder.contacts");
 		oMainFolderTree.cache.get_folder(clickedItemForSave,function (ofolder){			
 			if(ofolder.oxfolder.data.type != 1){
 				$("newcontact_personal_tr").style.visibility = "hidden";
@@ -359,8 +369,7 @@ function toggleTree(){
 /**
  * init() onLoad
  */
-function newContactOnload()
-{
+function newContactOnload() {
 	activemodule="contact_new";	
 	initContents("contact_new");
 	initAll();
@@ -371,7 +380,10 @@ function newContactOnload()
 	
 	window.setTimeout(function() {
 		initContactContent();
-	},0);
+	}, 0);
+	
+	
+	
 }
 //register("Loaded",initContactContent);
 var internalCache = corewindow.internalCache;
@@ -381,31 +393,31 @@ var	configSetKey = corewindow.configSetKey;
 var oMainFolderTree = corewindow.oMainFolderTree;
 
 function initContactContent() {	
-	if(url["folder"]){
-		clickedItemForSave = url["folder"];
-	} else {
-		clickedItemForSave = configGetKey("folder.contacts");
-	}
+	// extend url object
+	url = jQuery.extend((url || {}), ox.api.window.getData(url.guid));
+	
+	// fixed extended fu.ck3l, don't use german vars
+	url.module = url.modul || "new";
+	
+	// instance is required now
+	myNewContactFunctions = new NewContactFunctions();
+	
+	clickedItemForSave = url.folder || configGetKey("folder.contacts");
 	session = corewindow.session;
 	activemoduleLocal = corewindow.activemodule;
-	if(window.location.hash != "")
-	{
-		setModulPopup();	
-	}
-	activefolderLocal =	url['folder'];
+	setModulPopup();
+	activefolderLocal =	url.folder;
 		
-	myNewContactFunctions = new NewContactFunctions();
-	myNewContactFunctions.initCategories();
-	
-	addOnClose($("contact_upload_image"),myNewContactFunctions.cancelUploadImage);
+	addOnClose($("contact_upload_image"), myNewContactFunctions.cancelUploadImage);
 		
 	register("OX_SAVE_OBJECT", saveContact);	
-	register("OX_Cancel_Object", function() {myNewContactFunctions.closeWindow()});	
+	register("OX_Cancel_Object", function() {
+		myNewContactFunctions.closeWindow()
+	});	
 		
 	loadingComplete();
 	
-	function callMeOnOK(parameter)
-	{
+	function callMeOnOK(parameter) {
 		tmp_attachment.updateGrid(parameter);
 	}
 	tmp_attachmentDialog = new attachmentDialog(0,callMeOnOK); 
@@ -422,13 +434,15 @@ function initContactContent() {
 		$("email1").removeAttribute("onkeydown");
 	}
 	
+	myNewContactFunctions.initCategories();
+	
 	window.setTimeout(function() {
 		  oMainFolderTree.get_folder_path(clickedItemForSave, cb_getpath);		
 	   },0);	
     setTabLists(tabsList, panelsList, eventList);
     window.setTimeout(function() {
             triggerEvent("OX_Switch_View","contact_new/business");
-        },0); 
+        },0);     
 }
 
 function callback_new(arg) {
@@ -587,6 +601,7 @@ function createBirthdayAppointment() {
 	bDayObj["end_date"] = Date.UTC(bday.getUTCFullYear(), bday.getUTCMonth(), bday.getUTCDate(), 0, 0, 0);
 	//#. New contact window: Used to create a pre-filled title at the new birthday appointment dialog  
 	//#. %s will be replaced with the display name of the contact
+	//#, c-format
 	bDayObj["title"] = format(_("Birthday of %s."), $("display_name").value);
 	bDayObj["full_time"] = true;
 	if (bDayObj["private_flag"] == undefined) bDayObj["private_flag"] = true;
@@ -716,30 +731,22 @@ function saveContact()
 			return;
 		}
 			
-		var birthdayData = $("birthday").value;
-		if(birthdayData != "" || typeof dataFromDb.data.birthday != "undefined") 
-		{
-			state = compareDate(birthdayData, dataFromDb.data.birthday, "birthday");
-			if(state[0] == "save") {
-				contact_object.birthday = dateAction[1];				
-			} 
-			else if(state[0] == "clear") {
-				contact_object.birthday = "";
-			}
+		var date = $("birthday").value;
+		if (date) {
+		    var d = parseDateString(date);
+		    if (d) contact_object.birthday = d.getTime();
+		} else if (dataFromDb.data.birthday != null) {
+		    contact_object.birthday = null;
 		}
-		
+
 		//check if anniversary changed
-		anniversaryData = $("anniversary").value;
-		if(anniversaryData != "" || typeof dataFromDb.data.anniversary != "undefined") {
-			stateAnn = compareDate(anniversaryData, dataFromDb.data.anniversary, "anniversary");
-			
-			if(stateAnn[0] == "save") {
-				contact_object.anniversary = dateAction[1];
-			} 
-			else if(stateAnn[0] == "clear") {
-					contact_object.anniversary = "";
-			}
-		}
+		date = $("anniversary").value;
+		if (date) {
+            var d = parseDateString(date);
+            if (d) contact_object.anniversary = d.getTime();
+        } else if (dataFromDb.data.anniversary != null) {
+            contact_object.anniversary = null;
+        }
 		
 		for (i=0; i<ct.elements.length; i++) {
 			if(ct.elements[i].value != "" && ct.elements[i].name != "")	{
@@ -747,8 +754,12 @@ function saveContact()
 					contact_object[ct.elements[i].name] = ct.elements[i].value;
 			}				
 		}
+		
+		if (typeof(contact_categories) != "undefined") {
+			contact_object.categories = contact_categories;
+		}
 				
-		if(activefolderLocal != clickedItemForSave) {
+		if (activefolderLocal != clickedItemForSave) {
 			contact_object.folder_id = clickedItemForSave;
 		}
 		
@@ -905,53 +916,23 @@ function checkDateFormat(field) {
  * @param {String} parameters from the url 
  */
 function setModulPopup(params) {
-	/////////
-	// Modul New
-	// do nothing
-	if (url["modul"] && url["modul"] == "new") {
-		if (url['folder'] && url['folder'] != ""){
-			clickedItemForSave = url['folder'];
-		} else {
-			clickedItemForSave = configGetKey("folder.contacts");
-		}
-		if (url["email1"]) {
-			document.getElementsByName("email1")[0].value=url["email1"]
-		}
-		if (url["last_name"]) {
-            document.getElementsByName("last_name")[0].value=url["last_name"]
-        }
-        if (url["first_name"]) {
-            document.getElementsByName("first_name")[0].value=url["first_name"]
-        }
-		if (url["display_name"]) {
-            document.getElementsByName("display_name")[0].value=url["display_name"]
-        }
+	clickedItemForSave= trimStr(url.folder) || configGetKey("folder.contacts");
+	
+	// new
+	if (url.module == "new") {
+		fillFields(url);
         autofillDN();
-        
         // disable loading screen
         $("loading_data_bg").style.display="none";
+	} else {
+		// edit or duplicate
+		modulPopup = url.module;
+		contactDetailId = url.id;
+		activefolder = url.folder;
+		session = url.session;
+		currentView = url.currentView;
+		fillFieldById();
 	}
-	/////////
-	// Modul Edit or Duplicate
-	if(url['modul'] && url['modul'] == "edit") 	{
-			modulPopup = "edit";
-			contactDetailId = url['id'];
-			clickedItemForSave= url['folder'];
-			activefolder = url['folder'];
-			session = url['session'];
-			currentView = url['currentView'];
-			fillFieldById();		
-		} 
-	else if(url['modul'] && url['modul'] == "duplicate") {
-			modulPopup = "duplicate";
-			clickedItemForSave= url['folder'];
-			contactDetailId = url['id'];
-			activefolder = url['folder'];
-			session = url['session'];
-			currentView = url['currentView'];
-			fillFieldById();		
-	}
-	
 }
 
 /********************************** get ContactById *****************************************************************/
@@ -967,83 +948,84 @@ function fillFieldById()
 		null,
 			function(reply) {
 				dataFromDb = reply;
-				for (field in reply.data) {													
-					if(document.getElementsByName(field)[0] && reply.data[field] != "") {								
-						document.getElementsByName(field)[0].value = reply.data[field];
-					}
-					//$('newcontact_distr_list').disabled = true;
-					
-					if(field=="birthday")
-					{
-						$("birthday").value = formatDate(reply.data[field],"date");								
-					}
-					if(field=="anniversary")
-					{
-						$("anniversary").value = formatDate(reply.data[field],"date");
-					}
-					
-					if(field=="number_of_attachments")
-					{
-						if(url['modul'] == "duplicate")
-							setContactsNewNumberOfAtt(0);
-						else
-							setContactsNewNumberOfAtt(reply.data.number_of_attachments);
-					}
-					
-					if(field=="private_flag" && reply.data[field] == true) {
-						$("newcontact_personal").checked = "checked";					
-					}
-					
-					if(field=="disribution_list")
-					{
-						if(reply.data[field] && reply.data[field].length > 0) {
-							
-							if(myDistrListAdressBook) {
-								
-								myDistrListAdressBook.findContactForDistrList 		= {};
-								myDistrListAdressBook.findContactForDistrList.data 	= new Array();
-								
-								for(i=0; i<reply.data[field].length;i++){
-									
-									myDistrListAdressBook.findContactForDistrList.data[i] 	= new Array();
-									
-									myDistrListAdressBook.findContactForDistrList.data[i][0] =
-																		reply.data[field][i].id; //ID
-																		
-									myDistrListAdressBook.tmpIdsForSave[i] = 
-																		reply.data[field][i].id; //ID
-															
-									myDistrListAdressBook.findContactForDistrList.data[i][1] =
-																		reply.data[field][i].display_name; //DISPLAYNAME
-																																			
-									myDistrListAdressBook.findContactForDistrList.data[i][2] =
-																		reply.data[field][i].mail; //Mail
-								}		
-							}									
-						}										
-					}
-					/* if an image is existing */
-					if (field == "contains_image1" && reply.data[field] > 0 && url['modul'] != "duplicate") {
-						myNewContactFunctions.imageExist = true;
-						removeChildNodes($('imageContactTd'));
-						$('imageContactTd').appendChild(newnode("img", 0, {src: reply.data.image1_url + "&random=" + new Date().getTime(), alt: ""}));
-					}
-				}
+				fillFields(reply.data);
 				lastTimestamp = reply.timestamp;
-				
-				try {
-					// dn autofill: check if the dn still matches						
-					var fn = reply.data.first_name || "";
-					var ln = reply.data.last_name || "";
-					var dn = reply.data.display_name || "";
-					autofillmatch = (dn == (ln + (fn && ln ? ", " : "") + fn));
-				} catch (e) { }
-				
 				// disable loading screen
                 $("loading_data_bg").style.display="none";
 			}
 		); 		
 }
+
+function fillFields(data) {
+    for (field in data) {
+        if(document.getElementsByName(field)[0] && data[field] != "") {
+            document.getElementsByName(field)[0].value = data[field];
+        }
+        
+        if(field=="birthday")
+        {
+            $("birthday").value = formatDate(data[field],"date");
+        }
+        if(field=="anniversary")
+        {
+            $("anniversary").value = formatDate(data[field],"date");
+        }
+        
+        if(field=="number_of_attachments")
+        {
+            if (url.module == "duplicate")
+                setContactsNewNumberOfAtt(0);
+            else
+                setContactsNewNumberOfAtt(data.number_of_attachments);
+        }
+        
+        if(field=="private_flag" && data[field] == true) {
+            $("newcontact_personal").checked = "checked";
+        }
+        
+        if(field=="disribution_list")
+        {
+            if(data[field] && data[field].length > 0) {
+                
+                if(myDistrListAdressBook) {
+                    
+                    myDistrListAdressBook.findContactForDistrList       = {};
+                    myDistrListAdressBook.findContactForDistrList.data  = new Array();
+                    
+                    for(i=0; i<data[field].length;i++){
+                        myDistrListAdressBook.findContactForDistrList.data[i] =
+                            [data[field][i].id, data[field][i].display_name,
+                             data[field][i].mail];
+                        myDistrListAdressBook.tmpIdsForSave[i] =
+                            data[field][i].id; //ID
+                    }
+                }
+            }
+        }
+        /* if an image is existing */
+        if (field == "number_of_images" && data[field] > 0 && url.module != "duplicate") {
+            myNewContactFunctions.imageExist = true;
+            removeChildNodes($('imageContactTd'));
+            $('imageContactTd').appendChild(newnode("img", 0, {src: data.image1_url + "&random=" + new Date().getTime(), alt: ""}));
+        }
+    }
+    if (data["categories"]) {
+        contact_categories = data["categories"];
+        // draw list
+        if ($("newcontact_categories_list")) {
+            ox.categories.ui.drawCategoriesList(ox.categories.getByString(contact_categories),
+                    $("newcontact_categories_list"));
+        }
+    }
+    try {
+        // dn autofill: check if the dn still matches                       
+        var fn = data.first_name || "";
+        var ln = data.last_name || "";
+        var dn = data.display_name || "";
+        autofillmatch = (dn == (ln + (fn && ln ? ", " : "") + fn));
+    } catch (e) { }
+}
+
 function setContactsNewNumberOfAtt(nNumAttParam) {
 	$('contact_number_of_attachments').firstChild.nodeValue = nNumAttParam;
 }
@@ -1113,7 +1095,11 @@ function writeNewContact()
 	}
 	contact_object.folder_id = activefolderLocal;
 
-	if(activefolderLocal != clickedItemForSave) {
+	if (contact_categories) {
+		contact_object.categories = contact_categories;
+	}
+	
+	if (activefolderLocal != clickedItemForSave) {
 		contact_object.folder_id = clickedItemForSave;
 	}
 	
@@ -1164,7 +1150,7 @@ function finalFunction(myObject) {
        corewindow.closeContactPopUp(window, clickedItemForSave);
     } else if(modulPopup = "edit") {
         setBeforeUnload(false);
-        corewindow.OXCache.newRequest(null, "contacts", { columns: [],
+        corewindow.OXCache.newRequest(null, "contacts", { columns: null,
             objects: [corewindow.OXContactMapping.createKeyFromObject({
                 module: "contacts", folder_id: clickedItemForSave,
                 id: contactDetailId
