@@ -56,7 +56,7 @@ function setBeforeUnload(on){
 function closeWindow() {
 	function cbyes() {
 		window.onbeforeunload=null;
-		window.close();			
+		ox.api.window.close(url.guid);
 	}
 	if(messageOnCancel) {
 		var messageCloseWindow = _("Do you really want to discard your changes and close the window?");
@@ -83,6 +83,8 @@ function initDistributionListLoaded() {
 	activemodule='contact_new';
 	initContents('contact_new');
 	initAll();
+	// extend url object
+	url = jQuery.extend((url || {}), ox.api.window.getData(url.guid));
 	window.setTimeout(function() {
 		var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
 	    removeCSSFilesForNewWindow(themeStyle.path);
@@ -92,7 +94,7 @@ function initDistributionListLoaded() {
 
 register("Loaded",viewDistributionMenu);
 function viewDistributionMenu() {		
-	activefolderLocal = corewindow.activefolder;
+	activefolderLocal = url.folder !== undefined ? url.folder : corewindow.activefolder;
 	session = corewindow.session;
 	activemodule="contact_new";	
 	json = new JSON();	
@@ -135,12 +137,12 @@ function viewDistributionMenu() {
 registerView("contact_new/distributionlist",
     null,
 	function () {
-		setTimeout(function() {	$("last_name").focus();	},0);
+		setTimeout(function() {	$("display_name").focus();	},0);
 	},
 	null,
 	null,
 	function () {
-		setTimeout(function() {	$("last_name").focus();	},0);
+		setTimeout(function() {	$("display_name").focus();	},0);
 	});
 
 
@@ -390,13 +392,17 @@ function appendExternalToBigGrid() {
 	var data = myDistrListExternEmails.storage;
 	// loop items
 	data.newIterate(data.ids, null, function(key, item) {
-		// copy items
-		distruBigGrid.storage.append([{
-			// use negative id for temporary contacts
-			'id': -distruBigGrid.storage.ids.length,
-			'display_name': item.display_name,
-			'email': item.email
-		}]);
+		var id = item.id || -distruBigGrid.storage.ids.length || -1;
+		// add to storage (live grid)
+		var cObj = { 'id': id, 'display_name': item.display_name || "",
+				'email': item.email || ""
+		};
+		// if not set, use default 1 - required to set recurrence
+		if (item.mail_field == undefined) {
+			item.mail_field = 1;
+		}
+		cObj.recurrence = item.mail_field - 1;
+		distruBigGrid.storage.append([cObj]);
 	});
 }
 
@@ -408,7 +414,9 @@ function distrFromAddressbookLive() {
 	// selection
 	var selection = new Selection();
 	// storage
-	var storage = new Storage(0, [], 0, 0, 0, 0, function(external) { return external.id; });
+	function serialize(id) { return id.id + "." + id.email; }
+    var storage = new Storage(0, [], 0, 0, 0, serialize,
+        function(data) { return { id: data.id, email: data.email }; });
 	// live grid
 	distruBigGrid = new LiveGrid([
         { 
@@ -470,17 +478,15 @@ function distrFromAddressbookLive() {
 					// contact
 					case 5:
 						var myObject = { 
-								'id': item.id,
+								'id': item.contactID,
 								'display_name': item.display_name || "",
-								'email': item.mail
+								'email': item.mail,
+								'recurrence': item.recurrence
 							};
 						// duplicate?
-						if ( typeof(storage.indices[item.id]) == 'undefined') {
+                        if (!(serialize(myObject) in storage.indices)) {
 							// add to list
 							storage.append([myObject]);
-						} else if (typeof(item.recurrence) != "undefined" && item.recurrence != 0) {
-							myObject.id = storage.ids.length;
-							storage.append([myObject]);
 						}
 						break;
 				}
@@ -536,8 +542,8 @@ function saveContact()
         
         /********************************** update Contact ********************************************************/	
 		
-		contact_object.last_name = $('last_name').value;
-		contact_object.display_name = $('last_name').value;
+		contact_object.last_name = $('display_name').value;
+		contact_object.display_name = $('display_name').value;
 		contact_object.folder_id = clickedItemForSave;
 		
 		var cb_put = function() {
@@ -581,7 +587,7 @@ function getDistrForSave(callback) {
 			"id": obj.id < 0 ? "" : obj.id,
 			"display_name": obj.display_name,
 			"mail": obj.email, 
-			"mail_field" : 1
+			"mail_field" : obj.id < 0 ? 0 : Number(obj.recurrence) + 1
 		});		
 	});
 	// done...
@@ -602,21 +608,15 @@ function setModulPopup(params) {
 	
 	/////////
 	// Modul Edit or Duplicate
-	if (url['modul'] && url['modul'] == "edit") 	{
-			modulPopup = "edit";
-			contactDetailId = url['id'];
-			activefolder = url['folder'];
-			session = url['session'];
-			currentView = url['currentView'];
-			fillFieldById();		
-	} else if(url['modul'] && url['modul'] == "duplicate") {
-			modulPopup = "duplicate";
+	if (url['modul'] && (url['modul'] == "edit" || url['modul'] == "duplicate")) {
+			modulPopup = url['modul'];
 			contactDetailId = url['id'];
 			activefolder = url['folder'];
 			session = url['session'];
 			currentView = url['currentView'];
 			fillFieldById();		
 	} else {
+		fillFields(url);		
 		// disable loading screen
         $("loading_data_bg").style.display="none";
 	}
@@ -642,29 +642,8 @@ function fillFieldById() {
 			dataFromDb = response;
 			
 			// shortcut			
-			var d = response.data;			
-			
-			// set "last_name" (text field) -> name of the distribution list
-			$('last_name').value = d['last_name'];
-			// set "display_name" (hidden field)
-			$('display_name').value = d['last_name'];
-			
-			// set color label
-			if (d['color_label']) color_label = d['color_label'];
-
-			if (d['distribution_list']) {
-				// shortcut
-				var dl = d['distribution_list'];				
-				// loop entries
-				for(i = 0; i < dl.length; i++ ) {
-					// add to storage (live grid)
-					distruBigGrid.storage.append([{ 
-						'id': dl[i].id || -distruBigGrid.storage.ids.length,
-						'display_name': dl[i].display_name || "",
-						'email': dl[i].mail || ""
-					}]);
-				}				
-			}
+			var d = response.data;	
+			fillFields(d);
 			
 			// remember timestamp
 			lastTimestamp = response.timestamp;
@@ -675,6 +654,41 @@ function fillFieldById() {
 	);
 }
 
+function fillFields(data) {
+	// map title to required fields
+	if (data.title && !data.display_name) {
+		data.display_name = data.title;
+	}
+	
+	// set "display_name" (text field) -> name of the distribution list
+	$('display_name').value = data['display_name'] || "";
+	// set(hidden field)
+	$('last_name').value = data['display_name'] || "";
+	data.file_as = data.display_name;
+	
+	// set color label
+	if (data['color_label']) color_label = data['color_label'];
+
+	if (data['distribution_list']) {
+		// shortcut
+		var dl = data['distribution_list'];				
+		// loop entries
+		for(i = 0; i < dl.length; i++ ) {
+			var id = dl[i].id || -distruBigGrid.storage.ids.length || -1;
+			// add to storage (live grid)
+			var cObj = { 'id': id, 'display_name': dl[i].display_name || "",
+					'email': dl[i].mail || ""
+			};
+			// if not set, use default 1 - required to set recurrence
+			if (dl[i].mail_field == undefined) {
+				dl[i].mail_field = 1;
+			}
+			cObj.recurrence = dl[i].mail_field - 1;
+			distruBigGrid.storage.append([cObj]);
+		}				
+	}
+}
+
 
 /********************************** Write new Contact *****************************************************************/
 /**
@@ -682,14 +696,14 @@ function fillFieldById() {
  * json.put -> contact_object
  */
 function writeNewContact() {
-	if($("last_name").value == "") {
+	if($("display_name").value == "") {
 		triggerEvent("OX_New_Error", 4, _("Mandatory Field(s) missing!"));
-		$("last_name").className += " borderDefault border-color-error";
-		$("last_name").focus();
+		$("display_name").className += " borderDefault border-color-error";
+		$("display_name").focus();
 		savePending = false;	
 	} else {		
-		contact_object.last_name = $('last_name').value;
-		contact_object.display_name = $('last_name').value;
+		contact_object.last_name = $('display_name').value;
+		contact_object.display_name = $('display_name').value;
 		contact_object.folder_id = clickedItemForSave;
 				
 		var tmpString = new Array;
