@@ -350,7 +350,9 @@ function setDefaultNodeType(node,active) {
 function nodeSetSubjectDefault(node,title) {
 	node.getElementsByTagName("div")[1].firstChild.data= (title) ? title : "";
 }
-function defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,pluralstring,field) {	
+function defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+                         getstring, field)
+{	
 	var iconNode = document.getElementById("dragdrop_default_node");
 	if (iconNode == undefined) {
 		iconNode=createDefaultNode()
@@ -360,8 +362,8 @@ function defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,plur
 		setDefaultNodeType(iconNode,false);
 		
 		// set default text
-		var text= format(ngettext("", pluralstring,draggedObjects.currentObjects.length),
-		      draggedObjects.currentObjects.length);		
+		var count = draggedObjects.currentObjects.length;
+		var text = count <= 1 ? "" : format(getstring(count), count);
 		nodeSetSubjectDefault(iconNode,text);
 		
 	    if (draggedObjects.currentObjects.length == 1) {
@@ -415,24 +417,44 @@ function mailaddressdefaultdisabled(e,dragType,draggedObjects,mouseposition,targ
 	return false;
 }
 function calendardefaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode) {
-	defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,"%s appointments",/*i18n*/
-	"title")
+    defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+	    function(n) {
+            //#. %d is the number of appointments.
+            //#, c-format
+            return ngettext("%d appointment", "%d appointments", n);
+        }, "title");
 }
 function taskdefaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode) {
-	defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,"%s tasks",/*i18n*/
-	"title")
+    defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+	    function (n) {
+            //#. %d is the number of tasks.
+            //#, c-format
+            return ngettext("%d task", "%d tasks", n);
+        }, "title");
 }
 function contactdefaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode) {
-	defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,"%s contacts",/*i18n*/
-	"display_name")
+    defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+        function (n) {
+            //#. %d is the number of contacts.
+            //#, c-format
+            return ngettext("%d contact", "%d contacts", n);
+        }, "display_name");
 }
 function infostoredefaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode) {
-	defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,"%s info items",/*i18n*/
-	"title")
+    defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+        function(n) {
+            //#. %d is the number of info items.
+            //#, c-format
+            return ngettext("%d info item", "%d info items", n);
+        }, "title");
 }
 function maildefaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode) {
-	defaultdisabled(e,dragType,draggedObjects,mouseposition,targetNode,"%s E-Mails",/*i18n*/
-	"subject")
+    defaultdisabled(e, dragType, draggedObjects, mouseposition, targetNode,
+        function(n) {
+            //#. %d is the number of e-mails.
+            //#, c-format
+            return ngettext("%d E-Mail", "%d E-Mails", n);
+        }, "subject");
 }
 function foldertreeenable(e,dragType,draggedObjects,mouseposition,targetNode,node) {
 	var oSubfolder = oMainFolderTree.cache.find_folder(oMainFolderTree.getFolderID(node.id));
