@@ -301,7 +301,14 @@ function formatError(result, formatString) {
         var join = new Join(function() { setLanguage(name); });
         for (var d in domains) {
             if (!(d in curr)) {
-                (new JSON()).get(format(domains[d], name), null,
+            	// get file name
+            	var file = format(domains[d], name);
+            	// add pre-compression (specific languages only)
+            	file = file.replace(/(de_DE|en_GB|en_US)\.js/, "$1.jsz");
+            	// inject version
+            	var url = urlify(file);
+            	// get language file
+                (new JSON()).get(url, null,
                     join.add((function(domain) {
                         return function(file) {
                             try {
@@ -365,11 +372,14 @@ function parsePO(file) {
     
     if (clause("msgid") != "") throw new Error("Missing PO file header");
     var header = clause("msgstr");
-    if (!parsePO.headerRegExp.exec(header))
-        throw new Error("Error in PO file header");
-    var po = (new Function("return " + header.replace(parsePO.headerRegExp,
-        "{ nplurals: $1, plural: function(n) { return $2; }, dictionary: {} }"
-        )))();
+    if (parsePO.headerRegExp.exec(header)) {
+        var po = (new Function("return " + header.replace(parsePO.headerRegExp,
+            "{ nplurals: $1, plural: function(n) { return $2; }, dictionary: {} }"
+            )))();
+    } else {
+        var po = { nplurals: 1, plural: function(n) { return 0; },
+                   dictionary: {} };
+    }
     while (lookahead) {
         var ctx = clause("msgctxt", true);
         var id = clause("msgid");
@@ -424,7 +434,7 @@ function I18nNode(callback, template) {
         if (debug) {
             (console.warn || console.log || alert)(format(
                 "The string \"%s\" is not internationalized!", callback));
-            debugger;
+            eval("debugger");
         }
         this.callback = function() { return _(callback); };
     } else {
@@ -667,8 +677,10 @@ var weekdays = [];
 		h: function(n, d) { return num(n, d.getUTCHours() % 12 || 12); },
 		m: function(n, d) { return num(n, d.getUTCMinutes()); },
 		s: function(n, d) { return num(n, d.getUTCSeconds()); },
-		S: function(n, d) { return num(n, d.getMilliseconds()); }
-		// TODO: z and Z 
+		S: function(n, d) { return num(n, d.getMilliseconds()); },
+        // TODO: z and Z 
+		z: function() { return ""; },
+		Z: function() { return ""; }
 	};
 	formatDateTime = function(format, date) {
 		return format.replace(regex,
@@ -862,17 +874,21 @@ var parseDateString;
             //#. The relative position of date and time.
             //#. %1$s is the date
             //#. %2$s is the time
+            //#, c-format
             datetime: format(pgettext("datetime", "%1$s %2$s"), date, time),
             //#. The date with the day of the week.
             //#. EEEE is the full day of the week,
             //#. EEE is the short day of the week,
             //#. %s is the date.
+            //#, c-format
             dateday: format(_("EEEE, %s"), date),
             //#. The date with the day of the week.
             //#. EEEE is the full day of the week,
             //#. EEE is the short day of the week,
             //#. %s is the date.
+            //#, c-format
             dateshortday: format(_("EEE, %s"), date),
+            dateshortdayreverse: format(_("%s, EEE"), date),
             //#. The format for calendar timescales
             //#. when the interval is at least one hour.
             //#. H is 1-24, HH is 01-24, h is 1-12, hh is 01-12, a is AM/PM,
