@@ -93,7 +93,8 @@ function lockItem() {
 		function cb_lock(arg) {
             for(var indx=0;indx<arg.length;indx++) {
                 if(arg[indx].error_id) { newServerError(arg[indx]); }       
-                OXInfoStoreMapping.editObjects(oItemToLock,{});
+                OXInfoStoreMapping.editObjectsInternal(oItemToLock,{});
+                checkLockUnLock(oItemToLock);
             }
         }
 		var aRequests = new Array();
@@ -212,14 +213,14 @@ function loadLiveGridInfo()
                     sortable: false,        
                     set: function(div, content) {
                         if (!div.firstChild)
-                            div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
                         div.firstChild.src = content["locked_until"] > 0 ? 
                                getFullImgSrc("img/folder/document_locked.gif") : 
                                getFullImgSrc("img/folder/document.gif");
                     },
                     clear: function(div) {
                         if (!div.firstChild)
-                            div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
                         div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
                     }
                 }, {
@@ -230,7 +231,7 @@ function loadLiveGridInfo()
                     style: { padding: 0, textAlign: "center" },
                     set: function(div, content) {
                         if (!div.firstChild) {
-                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14" },{ align: "top" }));
                         }
                         div.firstChild.src = (content["file_size"]>0) ? getFullImgSrc("img/mail/attachment.gif")
                                                      : getFullImgSrc("img/mail/noattachment.gif");
@@ -251,7 +252,7 @@ function loadLiveGridInfo()
                     },
                     clear: function(div) {
                         if (!div.firstChild) {
-                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14" },{ align: "top" }));
                         }
                         div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
                     }
@@ -349,12 +350,12 @@ function loadLiveGridInfo()
                     style: { padding: 0, textAlign: "center" },
                     set: function(div, content) {
                         if (!div.firstChild)
-                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
                         div.firstChild.src = getFullImgSrc("img/menu/tag_"+ (content || 0 ) +".gif");
                     },
                     clear: function(div) {
                         if (!div.firstChild)
-                            div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                            div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
                         div.firstChild.src = getFullImgSrc("img/menu/tag_0.gif");
                     }
                 }
@@ -375,14 +376,16 @@ function loadLiveGridInfo()
 		});
 		gridInfoList.events.register("Activated", function(ids){
 			if(ids && ids.length > 0) {
-                if(   menucheckRight("WRITE")
-                   && menucountlockable + menucounteditable == 1)
-                {
-					editItem();
-                } else {
-                    triggerEvent("OX_New_Error", 4,
-                        _("You do not have write permission for this object."));
-                }
+			    checkLockUnLock.wait(function() {
+                    if(   menucheckRight("WRITE")
+                       && menucountlockable + menucounteditable == 1)
+                    {
+    					editItem();
+                    } else {
+                        triggerEvent("OX_New_Error", 4,
+                            _("You do not have write permission for this object."));
+                    }
+			    });
 			} else {
 				triggerEvent("OX_Before_Create_InfoStore");
 			}
