@@ -262,7 +262,11 @@ function updateInfostoreSplit(object) {
                   }
                   var fnSetModifiedBy = (function fnSetModifiedBy(idfield, idvalue, lockedUntil) {
                       return function(arg) {
-                          $("infosplit." + idfield).firstChild.data = 
+                          $("infosplit." + idfield).firstChild.data =
+                                //#. Information about a locked InfoItem
+                                //#. %1$s is the name of the user who locked the Infoitem.
+                                //#. %2$s is the expiration date of the lock.
+                                //#, c-format
                                 format(_("by %1$s until %2$s"), arg[idvalue].display_name, 
                                         formatDate(lockedUntil, "datetime")); 
                       }
@@ -271,8 +275,17 @@ function updateInfostoreSplit(object) {
                   continue;
                   break;
             case "categories":
-                  $("infosplit."+idfield).style.display=idvalue && idvalue.length ? "" : "none";
-                  $("infosplit."+idfield).getElementsByTagName("TD")[1].firstChild.data=idvalue && idvalue.length ? idvalue : "";
+        		  var cat = (idvalue || "");
+                  $("infosplit."+idfield).style.display = cat.length ? "" : "none";                  
+                  if (cat.length) {
+	                  if (Object.prototype.toString.call(cat) == "[object Array]") {
+	                	  cat = cat.join(", ");
+	                  }
+	                  ox.categories.ui.drawCategoriesList(ox.categories.getByString(cat), 
+	                		  $("infosplit."+idfield+"_d"));
+                  } else {
+                	  removeChildNodes($("infosplit."+idfield+"_d"));
+                  }
                   continue;
                   break;
             case "folder_id":
@@ -339,7 +352,7 @@ function loadLiveGridInfoSplit() {
 				sortable: false,		
 				set: function(div, content) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
 					}
 					div.firstChild.src = content["locked_until"] > 0 ? 
 					       getFullImgSrc("img/folder/document_locked.gif") : 
@@ -347,7 +360,7 @@ function loadLiveGridInfoSplit() {
 				},
 				clear: function(div) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "1px" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "1px", width: "16", height: "16" },{ align: "top" }));
 					}
 					div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
 				}
@@ -359,7 +372,7 @@ function loadLiveGridInfoSplit() {
 				style: { padding: 0, textAlign: "center" },
 				set: function(div, content) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14"  },{ align: "top" }));
 					}
 					div.firstChild.src = (content["file_size"]>0) ? getFullImgSrc("img/mail/attachment.gif")
 					                             : getFullImgSrc("img/mail/noattachment.gif");
@@ -380,7 +393,7 @@ function loadLiveGridInfoSplit() {
 				},
 				clear: function(div) {
 					if (!div.firstChild) {
-						div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+						div.appendChild(newnode("img", { paddingTop: "2px", width: "7", height: "14" },{ align: "top" }));
 					}
 					div.firstChild.src = getFullImgSrc("img/mail/noattachment.gif");
 				}
@@ -478,13 +491,13 @@ function loadLiveGridInfoSplit() {
 				style: { padding: 0, textAlign: "center" },
 				set: function(div, content) {
                     if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
                     }
                     div.firstChild.src = getFullImgSrc("img/menu/tag_"+ (content || 0 ) +".gif");
                 },
                 clear: function(div) {
                     if (!div.firstChild) {
-                        div.appendChild(newnode("img", { paddingTop: "2px" },{ align: "top" }));
+                        div.appendChild(newnode("img", { paddingTop: "2px", width: "16", height: "16" },{ align: "top" }));
                     }
                     div.firstChild.src = getFullImgSrc("img/menu/tag_0.gif");
                 }
@@ -506,14 +519,16 @@ function loadLiveGridInfoSplit() {
 		});
 		gridInfoSplit.events.register("Activated", function(ids){
 			if(ids && ids.length > 0) {
-				if(   menucheckRight("WRITE")
-                   && menucountlockable + menucounteditable == 1)
-                {
-					editItem();
-                } else {
-                    triggerEvent("OX_New_Error", 4,
-                        _("You do not have write permission for this object."));
-                }
+			    checkLockUnLock.wait(function() {
+    				if(   menucheckRight("WRITE")
+                       && menucountlockable + menucounteditable == 1)
+                    {
+    					editItem();
+                    } else {
+                        triggerEvent("OX_New_Error", 4,
+                            _("You do not have write permission for this object."));
+                    }
+			    });
 			} else {
 				triggerEvent("OX_Before_Create_InfoStore");
 			}
@@ -673,7 +688,11 @@ function getVersions(cb_functionVersion) {
         bDetailVersionLoaded = true; 
         if(cb_functionVersion) cb_functionVersion();
     }
-    doAjaxFetchAllVersions(cb_versions);
+    if (gridVersionsInfoSplit) {
+        doAjaxFetchAllVersions(cb_versions);
+    } else {
+        if (cb_functionVersion) cb_functionVersion();
+    };
 }
 
 function doAjaxFetchAllVersions(callback) {
