@@ -310,15 +310,21 @@ function infostore_sendAttachment(bSendAsLink) {
 		}
 		
 		function cbyes() {
-			var newMail = newWindow("newMail.html", getWindowOptions());
-			if (newMail) {
-			    newMail.window.aInfoMailAttachmentFile = aInfoMailObj;
-			}
+		    // compose new mail
+		    ox.api.mail.compose({
+		        data: {
+		            aInfoMailAttachmentFile: aInfoMailObj
+		        }
+		    });
+//			var newMail = newWindow("newMail.html", getWindowOptions());
+//			if (newMail) {
+//			    newMail.window.aInfoMailAttachmentFile = aInfoMailObj;
+//			}
 		}
 		
 		if (hasLink) {
 			newConfirm(_("Send Attachment"),
-				_("This object does not contain a file, would you like to send link?"),
+				_("This object does not contain a file, would you like to send the link?"),
 				AlertPopup.YESNO,null,null, function() { infostore_sendLink(arg) },
 				null);
 		} else {
@@ -411,43 +417,64 @@ function checkLockUnLock(selected) {
 	var counteditlocked= 0;
 	var uid = configGetKey("identifier");
 
+    checkLockUnLock.callbacks = [];
 	triggerEvent("OX_Lockable",0,0,0);
-	setTimeout(function() {		
-		var collection = { objects : selected , columns : ["created_by","modified_by","locked_until"] };
-		OXCache.newRequest(null,"infostore",collection,null,function(daten) {
-		     for (var i=0;i<daten.objects.length;i++) {
-		         if (daten.objects[i]["locked_until"] != 0) { 
-	                if (daten.objects[i]["modified_by"] == uid) {
-	                    countunlocked ++;
-	                    counteditlocked ++;
-	                } else if (daten.objects[i]["created_by"] == uid) {
-	                    countunlocked ++;
-	                }
-	             } else {
-                    countlocked++;
-	             }
-			 }
-	         triggerEvent("OX_Lockable", countlocked, countunlocked, counteditlocked);
-	    }, false);
-	}, 100);
+    var collection = { objects : selected , columns : ["created_by","modified_by","locked_until"] };
+    OXCache.newRequest(null, "infostore", collection, null, function(daten) {
+        for (var i = 0; i < daten.objects.length; i++) {
+            if (daten.objects[i]["locked_until"] != 0) { 
+                if (daten.objects[i]["modified_by"] == uid) {
+                    countunlocked++;
+                    counteditlocked++;
+                } else if (daten.objects[i]["created_by"] == uid) {
+                    countunlocked++;
+                }
+            } else {
+                countlocked++;
+            }
+        }
+        triggerEvent("OX_Lockable", countlocked, countunlocked, counteditlocked);
+        for (var i = 0; i < checkLockUnLock.callbacks.length; i++) {
+            checkLockUnLock.callbacks[i]();
+        }
+        checkLockUnLock.callbacks = null;
+    }, false);
 }
+checkLockUnLock.callbacks = null;
+checkLockUnLock.wait = function(callback) {
+    if (this.callbacks) this.callbacks.push(callback); else callback();
+};
 
 function openNewInfoPopup(module,folder) {
 	if (module != "infostore")
 		return;
 		
-	if(editInfoItemId != -1)
-		propertiesPopUp = newWindow("newInfoItemMain.html#edit_id="+editInfoItemId.id + "&folder="+editInfoItemId.folder_id, getWindowOptions(), editInfoItemId);
-	else
-		propertiesPopUp = newWindow("newInfoItemMain.html#edit_id=" + -1 + "&folder="+folder, getWindowOptions());	
+	if (editInfoItemId != -1) {
+	    // edit item
+	    ox.api.infostore.edit({
+	        params: {
+	            id: editInfoItemId.id,
+	            folder: editInfoItemId.folder_id
+	        }
+	    });
+		//propertiesPopUp = newWindow("newInfoItemMain.html#edit_id="+editInfoItemId.id + "&folder="+editInfoItemId.folder_id, getWindowOptions(), editInfoItemId);
+	} else {
+	    // compose item
+	    ox.api.infostore.compose({
+	        params: {
+	            folder: folder
+	        }
+	    });
+		//propertiesPopUp = newWindow("newInfoItemMain.html#edit_id=" + -1 + "&folder="+folder, getWindowOptions());
+	}
 	
 	editInfoItemId = -1;	
-	propertiesPopUp.focus();
+	//propertiesPopUp.focus();
 }
 
-function closeInfoPopUp() {
-	propertiesPopUp.close();
-}
+//function closeInfoPopUp() {
+////	propertiesPopUp.close();
+//}
 
 function callback_error(arg) {
 	newServerError(arg);
