@@ -704,7 +704,7 @@ LiveGrid.prototype = {
 		this.scrollTimeout = setTimeout(function() {
 			Self.scrollTimeout = null;
 			Self.doScroll();
-		});
+		}, 0);
 	},
 	
 	/**
@@ -1788,7 +1788,7 @@ LiveGrid2.prototype = {
         this.scrollTimeout = setTimeout(function() {
             Self.scrollTimeout = null;
             Self.doScroll();
-        });
+        }, 0);
     },
     
     /**
@@ -1864,7 +1864,7 @@ LiveGrid2.prototype = {
                         }
                     }
                 }
-                delete this.listRequest;
+                delete Self.listRequest;
             },false);
 			if(this.listRequest) {
 				for(var i in this.listRequest.clear) {
@@ -1877,7 +1877,7 @@ LiveGrid2.prototype = {
 					var cellrow = Self.rows[objIndex-1].cells;
                     for (var i2 in cellrow) {
                         var col = Self.columns[i2];
-                        if(col.name.length==1) {
+                        if(col.name.length==1 && col.name[0].indexOf("/") < 0) {
                           col.set(cellrow[i2], this.listRequest.set[i][col.name[0]]);   
                         } else {
                           col.set(cellrow[i2], this.listRequest.set[i]);
