@@ -14,16 +14,16 @@
  * 
  */
 
-var refToMain = window.opener.getRefToMainForMailPopup();
-var session = window.opener.session;
-var config = window.opener.config;
+var refToMain = ox.api.window.core;
+var session = refToMain.session;
+var config = refToMain.config;
 var getPermAsString = refToMain.getPermAsString;
 var oMainFolderTree = refToMain.oMainFolderTree;
 var isPrintableView = refToMain.isPrintableView;
 var registerPrintView = refToMain.registerPrintView;
 var OXMailMapping = refToMain.OXMailMapping, OXCache = refToMain.OXCache;
 var oSel = -1, nested_msgs = "", detailmessage, propertiesPopUp;
-var attachExists=false, mailFetchTimestamp, detailrequest, message = new Object(), selectedAttachments = [];
+var attachExists=false, mailFetchTimestamp, detailrequest, message = new Object();
 var smilies = {
 	";-)": "wink.gif",
 	";)": "wink.gif",
@@ -83,12 +83,13 @@ registerPrintView("mail_detail");
 function loadDetailMail() {	
 	activemodule="mail_detail";
 	initContents("mail_detail");
+	mail_message = getMailDetailObject();
 	initAll();
 }
 
-function getRefToMainForMailPopup() {	
-	return refToMain || window.opener;
-}
+//function getRefToMainForMailPopup() {	
+//	return refToMain || window.opener;
+//}
 
 function triggerEventInOpener(eventToTrigger) {
 	refToMain.triggerEvent(eventToTrigger);
@@ -104,8 +105,8 @@ register("OX_Attachment_Open_Nested", function(){ openNestedMessage() });
 register("OX_Attachment_Save", function() { openAttachment("SAVE"); });
 register("OX_Attachment_SaveInfoStore", mail_saveAttachmentInDocStore);
 register("OX_Add_Flag", setFlagInMailView);
-register("OX_Mail_Close", function() {	window.close(); });
-register("OX_Cancel_Object", function() {	window.close(); });
+register("OX_Mail_Close", function() { corewindow.ox.api.window.close(url.guid); });
+register("OX_Cancel_Object", function() { corewindow.ox.api.window.close(url.guid); });
 register("OX_Mail_Delete", 
 		function() {
 			deleteMails(url["folder"], 
@@ -153,15 +154,29 @@ registerView("mail_detail",
 );
 
 function mail_saveAttachmentInDocStore() {
-	var selAttachment = selectedAttachments[0].data;
-	propertiesPopUp = corewindow.newWindow("newInfoItemMain.html#attachmail=" + selAttachment.id + "&edit_id=" + -1
-			+ "&filename=" + encodeURIComponent(selAttachment.filename)
-			+ "&mailid=" + encodeURIComponent(url["id"])
-			+ "&mailfolder=" + encodeURIComponent(url["folder"])
-			, getWindowOptions(), 
-			{ "folder": encodeURIComponent(message.folder_id), "id": encodeURIComponent(message.id), "attach_id": encodeURIComponent(selAttachment.id) });	
-	if (propertiesPopUp) propertiesPopUp.focus();
-	corewindow.propertiesPopUp = propertiesPopUp;
+    // get attachment
+	var a = selectedAttachments[0].data;
+	// compose from attachment
+	ox.api.infostore.composeFromAttachment({
+	    params: {
+	        attachmail: a.id,
+	        filename: a.filename,
+	        mailid: url.id,
+	        mailfolder: url.folder
+	    },
+	    id: { folder: message.folder_id, id: message.id, attach_id: a.id },
+	    success: function (win) {
+	        corewindow.propertiesPopUp = win;
+	    }
+	});
+//	propertiesPopUp = corewindow.newWindow("newInfoItemMain.html#attachmail=" + selAttachment.id + "&edit_id=" + -1
+//			+ "&filename=" + encodeURIComponent(selAttachment.filename)
+//			+ "&mailid=" + encodeURIComponent(url["id"])
+//			+ "&mailfolder=" + encodeURIComponent(url["folder"])
+//			, getWindowOptions(), 
+//			{ "folder": encodeURIComponent(message.folder_id), "id": encodeURIComponent(message.id), "attach_id": encodeURIComponent(selAttachment.id) });	
+//	if (propertiesPopUp) propertiesPopUp.focus();
+//	corewindow.propertiesPopUp = propertiesPopUp;
 }
 	
 /**
@@ -179,7 +194,7 @@ function deleteMails(folder, ids) {
             }            
         }
         setTimeout(function() { 
-        	window.close(); 
+        	corewindow.ox.api.window.close(url.guid);
         }, 0);
     }
     if (configGetKey("mail.deletemail") || configGetKey("mail.folder.trash") == url["folder"]) {
@@ -271,11 +286,16 @@ function setFlagInMailView(tag){
  * Open a new message window
  */
 function newMail(action) {
-	var newMail = corewindow.newWindow("newMail.html#folder=" 
-		+ encodeURIComponent(url["folder"])
-		+ "&id=" + encodeURIComponent(url["id"])
-		+ "&action=" + action, getWindowOptions());
-	newMail.focus;
+    // use api
+    ox.api.mail.open({ params: {
+        folder: url.folder, id: url.id, action: action
+    }});
+//	var newMail = corewindow.newWindow("newMail.html#folder=" 
+//		+ encodeURIComponent(url["folder"])
+//		+ "&id=" + encodeURIComponent(url["id"])
+//        + "&noimg=" + !corewindow.loadblockedimages
+//		+ "&action=" + action, getWindowOptions());
+//	newMail.focus;
 }
 	
 function initMailDetail() {
@@ -404,7 +424,12 @@ function fillContentsFromJson(message, folder) {
 		$("mail.detail.pop.detail.row.organization").style.display="";
 	}
 	
-	setAdressHeader("from", message["from"]);
+	var from = setAdressHeader("from", message["from"]);
+	if (from && message["headers"] && message["headers"]["Sender"] && 
+			message["from"] != message["headers"]["Sender"]) {
+    	from.insertBefore(newtext(format(_("%1$s on behalf of"), [ message["headers"]["Sender"] ]) + " "), 
+    			from.firstChild);
+	}
 	setAdressHeader("to", message["to"]);
 	setAdressHeader("cc", message["cc"]);
 	setAdressHeader("bcc", message["bcc"]);
@@ -445,7 +470,9 @@ function setAdressHeader(fType, address) {
     }
     setTimeout(function() { 
         setHeightOfEmailDiv(oDivEmails); 
-	}, 0);    
+	}, 0);   
+    
+    return oDivEmails;
 }
 
 function setPriority(priority) {
@@ -518,6 +545,10 @@ function setMessageText(message) {
                 
                 var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },[
 				  newnode("img", { verticalAlign: "middle" }, { src: aimg, padding: "3px" }),
+				  //#. Displayed label for attachments
+				  //#. %1$s is the file name.
+				  //#. %2$s is the file size.
+				  //#, c-format
                   newnode("span",0,{ className: "nothing" }, [ document.createTextNode(format(_(" %1$s (%2$s); "), 
                 		  conArr["filename"], bytesToString(conArr["size"]))) ])
                 ]); 
@@ -678,6 +709,7 @@ function selectAttachment(selAttach, multi, context) {
 }
 
 function openNestedMessage() {
+
 	var detailMail=corewindow.newWindow("detailMail.html#type=isNestedMessage&id="
 		+ encodeURIComponent(url["id"])
 		+ "&folder="+ encodeURIComponent(url["folder"])
@@ -692,6 +724,10 @@ function openNestedMessage() {
 
 function openAttachment(action) {	
 	var selAttach = selectedAttachments[0].data;
+    if (action != "SAVE" && (isVcard(selAttach.content_type) || isIcal(selAttach.content_type))) {
+        showIcalVcard(selAttach);
+        return;
+    }
 	var tF = $("mail.detail.pop.attachment.save");
 	var n_url = AjaxRoot + '/mail'
 		 + '?action=' + (action == "SAVE" && 
@@ -721,6 +757,7 @@ function openAttachment(action) {
 		tF.src = n_url + mattachments.substring(0, mattachments.length-1) + "&save=1";
 	} else {
 		//#. %s will be replaced with an internal error code
+	    //#, c-format
 		triggerEvent("OX_New_Error", 4, format(_("Internal Error: Unable to open the Attachment (%s)."), "MA01"));
 	}
 }
@@ -745,4 +782,4 @@ window.onbeforeunload = function() {
 		OXCache.unregister(detailrequest.uniqueName);
 		detailrequest=null; 
 	}
-}
\ No newline at end of file
+};
