@@ -53,11 +53,19 @@ function infostore_sendLink(obj) {
         }
         oInfoMailObj["content"] = content;
         oInfoMailObj["content_type"] = "text/plain";
-        var newMail = newWindow("newMail.html#subject="+encodeURIComponent(subject), getWindowOptions());
-
-        if (newMail) {
-            newMail.window.aInfoMailAttachmentLink = new Array(oInfoMailObj);
-        }
+        
+        // use new api
+        ox.api.mail.compose({
+            params: { subject: subject },
+            data: {
+                aInfoMailAttachmentLink: [oInfoMailObj] 
+            }
+        });
+//        var newMail = newWindow("newMail.html#subject="+encodeURIComponent(subject), getWindowOptions());
+//
+//        if (newMail) {
+//            newMail.window.aInfoMailAttachmentLink = new Array(oInfoMailObj);
+//        }
     }
     if (obj) {
         cb_openWindow(obj);
@@ -99,24 +107,7 @@ function infostore_sendLink(obj) {
 			"color_label": addTranslated("Flag")
 		};	
 		mail_folderPath = new FolderPath("mail");
-		
-		/* register import context node for ical/vcard attachments */
-		setTimeout(function() {
-			var wrapper = function() {
-				importIcalVcard(selectedAttachments[0].data);
-			};
-	        var importitem = new MenuItem("Import"/*i18n*/, wrapper);
-            importitem.onShow = function() {
-                this.setVisible(
-                       activemodule == "mail"
-                    && selectedAttachments && selectedAttachments[0] 
-                    && selectedAttachments[0].data.content_type
-                    && (isIcal(selectedAttachments[0].data.content_type)
-                        || isVcard(selectedAttachments[0].data.content_type)));
-            };
-            globalContextMenus.attachments.addItem(importitem);
-		}, 0);
-
+        
         var menu = new PulldownMenu($("menu_mail_mark"));
         var entries = { seen: "Read", /*i18n*/ unseen: "Unread", /*i18n*/
             answer: "Answered", /*i18n*/ answered: "Unanswered", /*i18n*/
@@ -198,7 +189,7 @@ function infostore_sendLink(obj) {
 	var hsplit = {name: "hsplit", grid: null, attachments: false, setAttachments: setAttachments};
 	var vsplit = {name: "vsplit", grid: null, attachments: false, setAttachments: setAttachments};
 	var list = {name: "list", grid: null};
-	var nSelId = -1, message, nested_msgs, old_focus, selectedAttachments = [];
+	var nSelId = -1, message, nested_msgs, old_focus;
 	var clear = LiveGrid.makeClear("");
 	var view = hsplit;
 	var mailFetchTimestamp;
@@ -362,7 +353,7 @@ function infostore_sendLink(obj) {
 				} 
 				// reset iframe container to blank src
 			    if ($("mail." + view.name + ".attachment.save")) {
-				   $("mail." + view.name + ".attachment.save").src="newInfoItemHidden.html";
+				   $("mail." + view.name + ".attachment.save").src = urlify("newInfoItemHidden.html");
 				}				
 			},
 			function() {
@@ -389,6 +380,8 @@ function infostore_sendLink(obj) {
 			}
 		);
 	}
+
+	var oldSent = false;
 	
 	/**
 	 * in folder 'Sent' and 'Drafts' we have to use other fields then the
@@ -398,7 +391,15 @@ function infostore_sendLink(obj) {
 	 * @param grid - {LiveGrid} - the current livegrid 
 	 */
 	function switchGridHeaders(grid) {
-        if (isStdFolder("sent") || isStdFolder("drafts")) {
+        // update folder name and unread count information for grid header
+        //setMailHeaderLabel();
+        view.grid.searchActive=false; // set search to inactive, not sure if 
+
+        var sent = isStdFolder("sent") || isStdFolder("drafts");
+        if (sent == oldSent) return;
+        oldSent = sent;
+        
+        if (sent) {
             columnFromTo.text = _("To");
             columnReceivedSent.text = _("Sent");
             change("from", "to");
@@ -410,13 +411,16 @@ function infostore_sendLink(obj) {
             change("sent_date", "received_date");
         }
         
-        function change(oldCol, newCol, column) {
+        function change(oldCol, newCol) {
             if (sort_id == oldCol) sort_id = newCol;
             for (var i = 0; i < grid.columns.length; i++) {
                 var name = grid.columns[i].name;
                 for (var j = 0; j < name.length; j++) {
                     if (name[j] == oldCol) name[j] = newCol;
-                }   
+                }
+                if (grid.columns[i].sort == oldCol) {
+                    grid.columns[i].sort = newCol;
+                }
             }
         }
 		
@@ -428,87 +432,101 @@ function infostore_sendLink(obj) {
         }
 
         grid.recreate();
-
-        // update folder name and unread count information for grid header
-        //setMailHeaderLabel();
-        view.grid.searchActive=false; // set search to inactive, not sure if 
 	}
 	
 	function mail_saveAttachmentInDocStore() {
-		if (!selectedAttachments || selectedAttachments.length != 1) return
-		var selAttach = selectedAttachments[0].data;
-		propertiesPopUp = newWindow("newInfoItemMain.html#attachmail=" 
-                + encodeURIComponent(selAttach.id) + "&edit_id=" + -1
-                + "&filename=" + encodeURIComponent(selAttach.filename)
-                + "&mailid=" + encodeURIComponent(message.id)
-                + "&mailfolder=" + encodeURIComponent(message.folder || message.folder_id),
-                getWindowOptions());
-        if (propertiesPopUp) propertiesPopUp.focus();		
+	    // single element selected?
+	    if (selectedAttachments && selectedAttachments.length == 1) {
+	        // get attachment
+	        var a = selectedAttachments[0].data;
+	        // new dialog
+	        ox.api.infostore.composeFromAttachment({
+	            params: {
+	                attachmail: a.id,
+	                filename: a.filename,
+	                mailid: message.id, // global magic var
+	                mailfolder: message.folder || message.folder_id
+	            }
+	        });
+	    }
+//	    if (!selectedAttachments && selectedAttachments.length != 1) return;
+//		var selAttach = selectedAttachments[0].data;
+//		propertiesPopUp = newWindow("newInfoItemMain.html#attachmail=" 
+//                + encodeURIComponent(selAttach.id) + "&edit_id=" + -1
+//                + "&filename=" + encodeURIComponent(selAttach.filename)
+//                + "&mailid=" + encodeURIComponent(message.id)
+//                + "&mailfolder=" + encodeURIComponent(message.folder || message.folder_id),
+//                getWindowOptions());
+//        if (propertiesPopUp) propertiesPopUp.focus();		
 	}	
 	
 	function mail_printList() {
-		var attachments = [];
 		// if only one object has been selected, print the detail message, otherwise the list
-		if (view.grid.selection.getSelected().length == 1) {
-			var collection={};
-			collection.objects=[view.grid.selection.getSelected()[0]];
-			// need to get mail out of cache, specially if we don't have all data (like on the list view)
-			var omsg = OXCache.newRequest(null, "mail", collection,	null,
-				function(data) {
-				    if (data.objects.length) {
-				    	var omsg = data.objects[0];
-				    	var cnn = "", attachmentParam=null;
-				        if(omsg["attachments_plain"] && !configGetKey("mail.inlineattachments")) { 
-				            attachmentParam = omsg["attachments_plain"]; 
-				        } else if (omsg["attachments_html"] && configGetKey("mail.inlineattachments")) { 
-				            attachmentParam = omsg["attachments_html"]; 
-				        } else if (omsg["attachments_html_noimage"] && configGetKey("mail.inlineattachments")) { 
-				            attachmentParam = omsg["attachments_html_noimage"];
-				        }
-			            for (idfield in attachmentParam) {
-			                var conArr = attachmentParam[idfield];
-			                var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
-			                var con = conArr["content"];
-			                if (ct.search(/text\//) != -1 && con != null) {
-			                    if (ct.search(/text\/plain/) != -1) {
-			                        var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
-			                        tmpcnn=replaceLeadingSpaces(tmpcnn);
-			                        cnn += "<div style=\"font-family: monospace; line-height: 1.5em;\">" + tmpcnn + "</div>";
-			                    } else { 
-			                        cnn += "<div>" + con + "</div>";
-			                    }           
-			                } else if(conArr["filename"]) {
-			                	attachments.push(conArr);
-			                }        
-			            }
-			            
-			            if (omsg["nested_msgs"] && omsg["nested_msgs"].length) {
-				            for (var nMessage = 0; nMessage < omsg["nested_msgs"].length; nMessage++) {
-				            	var nmg = omsg["nested_msgs"][nMessage];
-				            	attachments.push({ filename: nmg.filename || nmg.subject, content_type: "message/rfc822", size: nmg.size });	            
-				            }
-			            }
-				        var tmsg = new Object();
-				        //tmsg["whole_message"] = omsg;
-				        tmsg["message_text"] = cnn;
-				        tmsg["message_attachments"] = attachments;
-				        if (omsg.from) tmsg["from"] = getAdressString(omsg.from, false);
-				        if (omsg.to)  tmsg["to"] = getAdressString(omsg.to, false);
-				        if (omsg.cc)  tmsg["cc"] = getAdressString(omsg.cc, false);
-				        if (omsg.bcc) tmsg["bcc"] = getAdressString(omsg.bcc, false);
-				        tmsg["date"] = omsg.sent_date;
-				        tmsg["subject"] = omsg.subject;
-				        tmsg["priority"] = omsg.priority;
-				        tmsg["color-label"] = omsg.color_label;			
-				        mail_printDetailMail(tmsg);
-			        }			
-				}
-			); 
-		} else { 
-			globalprint.printLiveGrid(view.grid);
-		}		
+		if (view.grid.selection.getSelected().length != 1) {
+		    // print list
+		    globalprint.printLiveGrid(view.grid);
+		} else {
+		    // print single mail
+		    var collection={};
+            collection.objects=[view.grid.selection.getSelected()[0]];
+            // need to get mail out of cache, specially if we don't have all data (like on the list view)
+            OXCache.newRequest(null, "mail", collection, null, function (data) {
+                if (data.objects.length) {
+                    mail_printSingleMail(data.objects[0]);
+                }
+            });
+		}
 	}
 	
+	// magic global function
+	mail_printSingleMail = function (omsg, closer) { 
+    	var cnn = "", attachmentParam=null;
+    	var attachments = [];
+        if(omsg["attachments_plain"] && !configGetKey("mail.inlineattachments")) { 
+            attachmentParam = omsg["attachments_plain"]; 
+        } else if (omsg["attachments_html"] && configGetKey("mail.inlineattachments")) { 
+            attachmentParam = omsg["attachments_html"]; 
+        } else if (omsg["attachments_html_noimage"] && configGetKey("mail.inlineattachments")) { 
+            attachmentParam = omsg["attachments_html_noimage"];
+        }
+        for (idfield in attachmentParam) {
+            var conArr = attachmentParam[idfield];
+            var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
+            var con = conArr["content"];
+            if (ct.search(/text\//) != -1 && con != null) {
+                if (ct.search(/text\/plain/) != -1) {
+                    var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
+                    tmpcnn=replaceLeadingSpaces(tmpcnn);
+                    cnn += "<div style=\"font-family: monospace; line-height: 1.5em;\">" + tmpcnn + "</div>";
+                } else { 
+                    cnn += "<div>" + con + "</div>";
+                }           
+            } else if(conArr["filename"]) {
+            	attachments.push(conArr);
+            }        
+        }
+        
+        if (omsg["nested_msgs"] && omsg["nested_msgs"].length) {
+            for (var nMessage = 0; nMessage < omsg["nested_msgs"].length; nMessage++) {
+            	var nmg = omsg["nested_msgs"][nMessage];
+            	attachments.push({ filename: nmg.filename || nmg.subject, content_type: "message/rfc822", size: nmg.size });	            
+            }
+        }
+        var tmsg = new Object();
+        //tmsg["whole_message"] = omsg;
+        tmsg["message_text"] = cnn;
+        tmsg["message_attachments"] = attachments;
+        if (omsg.from) tmsg["from"] = getAdressString(omsg.from, false);
+        if (omsg.to)  tmsg["to"] = getAdressString(omsg.to, false);
+        if (omsg.cc)  tmsg["cc"] = getAdressString(omsg.cc, false);
+        if (omsg.bcc) tmsg["bcc"] = getAdressString(omsg.bcc, false);
+        tmsg["date"] = omsg.sent_date;
+        tmsg["subject"] = omsg.subject;
+        tmsg["priority"] = omsg.priority;
+        tmsg["color-label"] = omsg.color_label;
+        mail_printDetailMail(tmsg, closer); // closer is passed by ox.api
+    };
+	
 	function clearMailSplitDetail(cview) {	
 		$("mail." + view.name + ".detail.header.image_protection").style.display = "none";
 		$("mail." + view.name + ".detail.header.phishing_protection").style.display = "none";
@@ -531,7 +549,7 @@ function infostore_sendLink(obj) {
 	
 		$('mail.' + cview + '.detail.header.subject').firstChild.data = "";
 		$('mail.' + cview + '.detail.header.subject_small').firstChild.data = "";
-		$('mail.' + cview + '.detail.content').src = "newInfoItemHidden.html";
+		$('mail.' + cview + '.detail.content').src = urlify("newInfoItemHidden.html");
 		$('mail.' + cview + '.detail.header.received_date').firstChild.data = "";
 		$('mail.' + cview + '.detail.header.received_date_small').firstChild.data = "";
 		var mda = $("mail." + cview + ".detail.attachments");
@@ -588,6 +606,7 @@ function infostore_sendLink(obj) {
             //#. Number of unread mails in the header of the mail view
             //#. %1$s is the number of unread mails
             //#. %2$s is the total number of mails
+            //#, c-format
             panelText += format(_("%1$s of %2$s unread"), [numberOfMailsinFolder[1], numberOfMailsinFolder[0]]);
         } else {
             panelText += numberOfMailsinFolder[0] || 0;
@@ -651,12 +670,19 @@ function infostore_sendLink(obj) {
 		hv.setSize(OXMailHover.contentobject.node);
 		grid.events.register("Activated", function(ids) {
 			if (ids && ids.length > 0) {
-				var detailMail = newWindow("detailMail.html#"
-				    + "id="	+ encodeURIComponent(ids[0].id) 
-					+ "&folder=" + encodeURIComponent(ids[0].folder || ids[0].folder_id),
-					getWindowOptions(), 
-					[ ids[0].id, (ids[0].folder || ids[0].folder_id)]);
-				if (detailMail) detailMail.focus();
+			    // view mail
+			    ox.api.mail.view({
+			        params: {
+			            id: ids[0].id, folder: ids[0].folder || ids[0].folder_id
+			        },
+			        data: [ ids[0].id, (ids[0].folder || ids[0].folder_id)]
+			    });
+//				var detailMail = newWindow("detailMail.html#"
+//				    + "id="	+ encodeURIComponent(ids[0].id) 
+//					+ "&folder=" + encodeURIComponent(ids[0].folder || ids[0].folder_id),
+//					getWindowOptions(), 
+//					[ ids[0].id, (ids[0].folder || ids[0].folder_id)]);
+//				if (detailMail) detailMail.focus();
 			} else {
 				triggerEvent("OX_NEW_MAIL");
 			}
@@ -702,7 +728,7 @@ function infostore_sendLink(obj) {
 				} else
 					clearMailSplitDetail(viewObj.name);
 			} else {
-				message = mail_lastSelectedId;
+				mail_message = message = mail_lastSelectedId;
 			}
 		} else if (viewObj !== list)
 			clearMailSplitDetail(viewObj.name);
@@ -713,15 +739,14 @@ function infostore_sendLink(obj) {
     var columnFromTo, columnReceivedSent;
 	temporary.lists.mail = temporary.MakeList({
         addIcon: function(icon) {
-            var col = this.columns[0];
             if (icon.name) {
                 for (var i = 0; i < icon.name.length; i++) {
                     var n = icon.name[i];
                     Search: {
-                        for (var j = 0; j < col.name.length; j++) {
-                            if (n == col.name[j]) break Search;
+                        for (var j = 0; j < vSplitColumn.name.length; j++) {
+                            if (n == vSplitColumn.name[j]) break Search;
                         }
-                        col.name.push(n);
+                        vSplitColumn.name.push(n);
                     }
                 }
             }
@@ -842,18 +867,21 @@ function infostore_sendLink(obj) {
             }, {
                 text: "Subject", /*i18n*/
                 i18n: true,
-                name : ["subject","flags"],
+                name : ["subject","flags","account_name"],
                 sort : "subject",
                 sortable: true,
                 set: function(div, content) {
-                    if (!div.firstChild)
-                        div.appendChild(div.ownerDocument.createTextNode(content["subject"] || "\u00a0"));
-                    else
-                        div.firstChild.data = content["subject"] || "\u00A0";       
-                    //deleted       
+                    removeChildNodes(div);
+                    var accName = content.account_name;
+                    if (accName && accName != "E-Mail") {
+                        div.appendChild(newnode("span", 0,
+                            { className: "accountLabel" }, [newtext(accName)]));
+                    }
+                    div.appendChild(newtext(content.subject || "\u00a0"));
+                    //deleted
                     div.style.textDecoration =  content["flags"] & 2 ? "line-through" : "none";
                 },
-                clear: clear
+                clear: function(div) { removeChildNodes(div); }
             }, columnReceivedSent = {                
                 text: "Received", /*i18n*/
                 i18n: true,
@@ -1057,55 +1085,74 @@ function infostore_sendLink(obj) {
 		return grid;
 	}
 	
-	function getMailFlagImage(flag) {    
-        if (flag == 16 || flag == 0) {
-            return "unread.gif";
-        } else if (flag >= 289) {
-            return "reply_forward.gif";
-        } else if (flag >= 256) {
-            return "forward.gif";
-        } else if (flag == 34) {
-            return "deleted.gif"
-        } else if (flag == 33) {
-            return "reply.gif";
-        } else if (flag >= 32) {
-            return "read.gif"
-        }
-        return "read.gif"
+	function getMailFlagImage(flag) {
+	    if ((flag & 0x101) == 0x101) return "reply_forward.gif";
+	    if (flag & 0x100) return "forward.gif";
+	    if (flag & 0x001) return "reply.gif";
+	    if (flag & 0x002) return "deleted.gif";
+	    if (flag & 0x020) return "read.gif";
+	    return "unread.gif";
     }
 	
 	/**
 	 * Open a new message window
 	 */
 	function newMail(action) {
-		var folder = encodeURIComponent(activefolder), id="";		
-		if (message && trimStr(action).length != 0) {
-			 folder = encodeURIComponent(message.folder_id);
-			 id = encodeURIComponent(message.id);
-		}
-		var acc = corewindow.getMailAccountIdByFolder(folder);
-		// in case of unified we have to use the folder out of the id instead
-		if (id.match(/^default/)) {
-			acc = corewindow.getMailAccountIdByFolder(id);
-		}
-		var newMail = newWindow("newMail.html#"
-		    + "folder="	+ folder
-			+ "&id=" + id
-			+ "&account=" + acc
-			+ "&action=" + action,
-			getWindowOptions(null, screen.availHeight-25));
-		newMail.focus();
-		
-		// fill object for multiple selected messages, eg. on a forward
-		if (newMail && mailSelection.getSelected().length > 1) {
-		    var selected = mailSelection.getSelected();
-		    var fObj = [];
-		    for (var i in selected) {           
-		        fObj.push({"folder": selected[i].folder_id, "id": selected[i].id });
-		    }
-		    newMail.multiForward = fObj;
-		}
-		return newMail;
+
+	    var data = { multiForward: [] };
+	    
+	    // fill object for multiple selected messages, eg. on a forward
+	    var selection = mailSelection.getSelected(), i = 0, $l = selection.length;
+	    for (; $l > 1 && i < $l; i++) {
+	        data.multiForward.push({ folder: selection[i].folder_id, id: selection[i].id });
+        }
+
+        // compose message
+	    ox.api.mail.open({
+	        params: {
+	            action: action
+	        },
+	        message: message || undefined,
+	        data: data
+	    });
+	    
+//	    return;
+//	    
+//	    
+//		var folder = encodeURIComponent(activefolder), id="";		
+//		if (message && trimStr(action).length != 0) {
+//			 folder = encodeURIComponent(message.folder_id);
+//			 id = encodeURIComponent(message.id);
+//		}
+//		console.log("????", folder, id, message);
+//		var acc = corewindow.getMailAccountIdByFolder(folder);
+//		// in case of unified we have to use the folder out of the id instead
+//		if (id.match(/^default/)) {
+//			acc = corewindow.getMailAccountIdByFolder(id);
+//		}
+//		// get browser window height
+//		var clientHeight = Math.min(screen.availHeight, jQuery(document).height());
+//		// open new window
+//		var newMail = newWindow("newMail.html#"
+//		    + "folder="	+ folder
+//			+ "&id=" + id
+//			+ "&account=" + acc
+//            + "&noimg=" + !corewindow.loadblockedimages
+//			+ "&action=" + action,
+//			getWindowOptions(null, clientHeight));
+//		// focus new window
+//		newMail.focus();
+//		
+//		// fill object for multiple selected messages, eg. on a forward
+//		if (newMail && mailSelection.getSelected().length > 1) {
+//		    var selected = mailSelection.getSelected();
+//		    var fObj = [];
+//		    for (var i in selected) {           
+//		        fObj.push({"folder": selected[i].folder_id, "id": selected[i].id });
+//		    }
+//		    newMail.multiForward = fObj;
+//		}
+//		return newMail;
 	}
 
 	/**
@@ -1146,8 +1193,9 @@ function infostore_sendLink(obj) {
 	var oldMessage = null;
     var oldMessageTextType=null;
 	var oldView=null;
-	function fetchMessage(view, id,loadblockedimages) {	
-	    message = id;
+	function fetchMessage(view, id, loadblocked) {
+	    loadblockedimages = Boolean(loadblocked);
+	    mail_message = message = id;
 	    var collection={};
 		collection.objects=[id];
 		if (configGetKey("mail.inlineattachments")) {
@@ -1170,28 +1218,25 @@ function infostore_sendLink(obj) {
 		if (detailrequest) { 
 			OXCache.unregister(detailrequest.uniqueName); 
 		}
-		// bad, bad hack for bug #14865
-		setTimeout(function() {			
-			detailrequest = OXCache.newRequest(null, "mail", collection,		
-				function(daten) {			
-					if (daten.objects.length) {
-						mailFetchTimestamp = daten.timestamp;
-				        updateMessage(view, daten.objects[0], id.folder_id);
-				        lastID = id;
-				    }
-				},
-				function(daten) {
-				    if (daten.objects.length) {
-						mailFetchTimestamp = daten.timestamp;                
-				        markRead(daten.objects[0]);
-				        lastID = id;
-				        if (daten.objects[0]["headers"]) {
-			            	showMessage(view, daten.objects[0],id.folder_id);
-			            }
-			        }			
-				}
-			);
-		}, 0);
+		detailrequest = OXCache.newRequest(null, "mail", collection,
+			function(daten) {
+				if (daten.objects.length) {
+					mailFetchTimestamp = daten.timestamp;
+			        updateMessage(view, daten.objects[0], id.folder_id);
+			        lastID = id;
+			    }
+			},
+			function(daten) {
+			    if (daten.objects.length) {
+					mailFetchTimestamp = daten.timestamp;
+			        markRead(daten.objects[0]);
+			        lastID = id;
+			        if (daten.objects[0]["headers"]) {
+		            	showMessage(view, daten.objects[0],id.folder_id);
+		            }
+		        }
+			}
+		);
 	}
 	function updateMessage(view, message, folder) {		
         if ("color_label" in message) {
@@ -1233,8 +1278,10 @@ function infostore_sendLink(obj) {
 				case "to":
 				    $("mail." + view.name + ".detail.content").style.visibility="hidden";
 				case "from":
-				    $("mail." + view.name + ".detail.content").style.visibility="hidden";
+					$("mail." + view.name + ".detail.content").style.visibility="hidden";
 				    removeChildNodes(oDivEmails);
+				    removeChildNodes(oDivEmailsSmall);
+				    
                     getAdressStringLinked(oDivEmails, newField, false);
                     if (oDivEmails) {
                         oDivEmails.style.height = 1.6 + "em";
@@ -1242,10 +1289,11 @@ function infostore_sendLink(obj) {
                             oDivEmails.style.height = oDivEmails.clientHeight *2 + "px"; 
                         }                                                               
                     }
+                    
                     if (oDivEmailsSmall) {
-                        removeChildNodes(oDivEmailsSmall);          
-                        getAdressStringLinked(oDivEmailsSmall, newField, true);           
+                        getAdressStringLinked(oDivEmailsSmall, newField, true);
                     } 
+                    
                     newField = null;
             	    break;
             	case "received_date" :
@@ -1300,6 +1348,19 @@ function infostore_sendLink(obj) {
              }
         }
         
+        jQuery("#mail\\.hsplit\\.detail\\.header\\.from span.sender").remove();
+    	jQuery("#mail\\.hsplit\\.detail\\.header\\.from_small span.sender").remove();
+        
+        // append or clear 'on behalf of' string if sender != from
+        if (message["headers"] && message["headers"]["Sender"] &&
+        		message["from"] != message["headers"]["Sender"]) {
+        	var text = newtext(format(_("%1$s on behalf of"), [ message["headers"]["Sender"] ]) + " ");
+        	jQuery("#mail\\.hsplit\\.detail\\.header\\.from span").
+        		before(newnode("span", 0, { className: "sender" }, [ text.cloneNode(true) ]));
+        	jQuery("#mail\\.hsplit\\.detail\\.header\\.from_small span").
+        		before(newnode("span", 0, { className: "sender" }, [ text.cloneNode(true) ]));
+        }
+        
         // field organization
         if (message["headers"] && message["headers"]["Organization"]) {
         	$("mail." + view.name + ".detail.header.organization").firstChild.data = message["headers"]["Organization"];
@@ -1332,7 +1393,9 @@ function infostore_sendLink(obj) {
                 var conArr = attachmentParam[idfield];
                 var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
                 var con = conArr["content"];
-                if (ct.search(/text\//) != -1 && con != null) {
+                if (   conArr.disp == "inline"
+                    && ct.search(/text\//) != -1 && con != null)
+                {
                     if (ct.search(/text\/plain/) != -1) {
                         var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
                         tmpcnn=replaceLeadingSpaces(tmpcnn);
@@ -1347,6 +1410,10 @@ function infostore_sendLink(obj) {
                         
                         var oDOMDiv = newnode("div", { MozUserSelect: "none" }, { className: "mailDetailAttachmentsCont" },[
 						  newnode("img", { verticalAlign: "middle" }, { src: aimg, padding: "3px" }),
+                          //#. Displayed label for attachments
+                          //#. %1$s is the file name.
+                          //#. %2$s is the file size.
+                          //#, c-format
                           newnode("span",0,{ className: "nothing" }, [ document.createTextNode(format(_(" %1$s (%2$s); "), 
                         		  conArr["filename"], bytesToString(conArr["size"]))) ])
                         ]); 
@@ -1457,10 +1524,12 @@ function infostore_sendLink(obj) {
 			$("mail."+view.name+".detail.header.image_protection").style.display="none";
 		}
 		
+		
 		// iMIP
 		var methodRE = /;\s*method\s*=\s*(?:([-!#-'*+.0-9A-Z^-~]*)|"([\cA-\b\cK\cL\cN-\x1f!#-[\]-\x7f]*)")/i;
 		var iMIPRequest = $("mail." + view.name + ".detail.header.imip");
         var iMIPReply = $("mail." + view.name + ".detail.header.imipreply");
+        
         var iMIPAttachments = message.attachments_html ||
             message.attachments_html_noimage || message.attachments_plain;
 		checkiMIP: {
@@ -1557,6 +1626,7 @@ function infostore_sendLink(obj) {
                             if (!o.id || !o.folder) {
                                 ox.Configuration.error(format(
                                     //#. %s is the title of the appointment
+                                    //#, c-format
                                     _("Appointment '%s' not found."),
                                     reply.data[i].title));
                                 return;
@@ -1598,6 +1668,8 @@ function infostore_sendLink(obj) {
                 );
             };
         }
+        
+        triggerEvent("OX_Mail_load", message, view.name);
 		
 		// get frame
 		var ih = getFrameElement("mail." + view.name + ".detail.content");
@@ -1626,6 +1698,13 @@ function infostore_sendLink(obj) {
 					parseDirectLinksInMails(ih);
 					// reset scroll position
 					if (ihf) ihf.scrollTo(0,0);
+					
+					// tracking hasFocus
+					// using DOM level 0 events to overwrite previous handlers
+					if (!IE) {
+    					ih.onblur = function() { hasFocus = false; };
+                        ih.onfocus = function() { hasFocus = true; };
+					}
 				}, 0);
 			}
 		} else {
@@ -1725,7 +1804,7 @@ function infostore_sendLink(obj) {
 	function openAttachment(action) {		
 		var selAttach = selectedAttachments[0].data;
 		if (action != "SAVE" && (isVcard(selAttach.content_type) || isIcal(selAttach.content_type))) {
-			importIcalVcard(selAttach);
+			showIcalVcard(selAttach);
 			return;
 		}
 		var tF = $("mail." + view.name + ".attachment.save");
@@ -1754,55 +1833,10 @@ function infostore_sendLink(obj) {
 			tF.src = n_url + mattachments.substring(0, mattachments.length-1) + "&save=1";
 		} else {
 			//#. %s will be replaced with an internal error code
+		    //#, c-format
 			triggerEvent("OX_New_Error", 4, format(_("Internal Error: Unable to open the Attachment (%s)."), "MA01"));
 		}
 	}
-	
-	function isIcal(ct) {
-		return ct && ct.match(/text\/(x\-)?(calendar|ical)/i); // || ct.match(/application\/(ics)/i);
-	}
-	function isVcard(ct) {
-		return ct && ct.match(/text\/(x\-)?(vcard)/i);
-	}
-	
-	function importIcalVcard(selAttach) { 
-        var isIcal = true;
-        var dsIdent = "com.openexchange.mail.ical";
-        var dhIdent = { 
-                 "identifier": "com.openexchange.ical",
-                 "args":
-                      [{ "com.openexchange.groupware.task.folder": configGetKey("folder.tasks") },
-                       { "com.openexchange.groupware.calendar.folder": configGetKey("folder.calendar") }] };
-
-        if (isVcard(selAttach.content_type)) {
-        	dsIdent = "com.openexchange.mail.vcard";
-            dhIdent = { 
-            	"identifier": "com.openexchange.contact",
-				 "args":
-				      [{ "com.openexchange.groupware.contact.folder": configGetKey("folder.contacts") }] };
-		    isIcal = false;
-        }
-        var myObject = {
-        	"datasource": 
-            { "args":
-                [ {"com.openexchange.mail.conversion.fullname": message.folder_id},
-                  {"com.openexchange.mail.conversion.mailid": message.id},
-                  {"com.openexchange.mail.conversion.sequenceid": selAttach.id} 
-                ], "identifier": dsIdent},
-			  "datahandler": dhIdent };
-
-        new JSON().put(AjaxRoot + "/conversion?action=convert&session=" + session, myObject, null, 
-            function (cb) {     
-                if (cb.data && cb.data.length) {
-                    if (!isIcal) {
-                       openContactPopup("modul=edit&id="+cb.data[0].id+"&folder="+cb.data[0].folder_id+"&session="+session, 'newContact.html', {id:cb.data[0].id, folder:cb.data[0].folder_id});
-                    } else {
-                       newWindow("newAppointment.html#modul=edit&id="+cb.data[0].id+"&recurrence_position=0&folder_id="+cb.data[0].folder_id,"width=780px,height=655px,left=50,top=50,resizable=yes,menubar=no,toolbar=no,status=no", {id:cb.data[0].id, folder:cb.data[0].folder_id});
-                    }      
-                }
-            }
-        );
-    }
 		
 	function MailFunctions() { }
 	
@@ -1817,28 +1851,35 @@ function infostore_sendLink(obj) {
 			else
 			    mailViewSourceObject = mailSelection.getSelected()[0];						
 			
-			var showSourceCb = function() {
-				json.get(AjaxRoot + "/mail?action=get&session=" + session + "&folder=" 
-					+ encodeURIComponent(mailViewSourceObject.folder || mailViewSourceObject.folder_id ) + "&id=" + encodeURIComponent(mailViewSourceObject.id)+"&src=true",
-					null,
-					function(reply) {
-						OXMailMapping.editObjectsInternal([mailViewSourceObject],null,true,[{ flag : 32 , bool : true }]);
-						var text = _("Unable to display E-Mail source.");
-						if (reply.data) {
-							text = reply.data.replace(/[<&]/g, function(a,b,c) {
-									return (a == "&" ? "&amp;" : "&lt;");
-								});
-						}
-						if(mailSource && mailSource.document && mailSource.document.getElementsByTagName('body')[0])
-							mailSource.document.getElementsByTagName('body')[0].innerHTML = "<pre>"+text+"</pre>";
-							
-						unregister('OX_Popup_Cb', showSourceCb);
-					}
-				);
-			}
-			register('OX_Popup_Cb', showSourceCb);
-			mailSource=newWindow("popup_trigger_cb.html#triggerevent=OX_Popup_Cb", getWindowOptions(null, null, "scrollbars=yes"), 
-				{ "folder": encodeURIComponent(mailViewSourceObject.folder), "id": encodeURIComponent(mailViewSourceObject.id) });
+//			var showSourceCb = function() {
+//				json.get(AjaxRoot + "/mail?action=get&session=" + session + "&folder=" 
+//					+ encodeURIComponent(mailViewSourceObject.folder || mailViewSourceObject.folder_id ) + "&id=" + encodeURIComponent(mailViewSourceObject.id)+"&src=true",
+//					null,
+//					function(reply) {
+//						OXMailMapping.editObjectsInternal([mailViewSourceObject],null,true,[{ flag : 32 , bool : true }]);
+//						var text = _("Unable to display E-Mail source.");
+//						if (reply.data) {
+//							text = reply.data.replace(/[<&]/g, function(a,b,c) {
+//									return (a == "&" ? "&amp;" : "&lt;");
+//								});
+//						}
+//						if(mailSource && mailSource.document && mailSource.document.getElementsByTagName('body')[0])
+//							mailSource.document.getElementsByTagName('body')[0].innerHTML = "<pre>"+text+"</pre>";
+//							
+//						unregister('OX_Popup_Cb', showSourceCb);
+//					}
+//				);
+//			}
+			//register('OX_Popup_Cb', showSourceCb);
+			ox.api.mail.showSource({
+			    params: {
+			        folder: mailViewSourceObject.folder_id,
+			        id: mailViewSourceObject.id
+			    },
+			    mail: mailViewSourceObject
+			});
+//			mailSource=newWindow("popup_trigger_cb.html#triggerevent=OX_Popup_Cb", getWindowOptions(null, null, "scrollbars=yes"), 
+//				{ "folder": encodeURIComponent(mailViewSourceObject.folder), "id": encodeURIComponent(mailViewSourceObject.id) });
 		},
 		markAsFlag: function(mailFlag) {
             OXMailMapping.setMailFlags(mailFlag,menuselectedobjects);
@@ -1945,12 +1986,12 @@ function infostore_sendLink(obj) {
 					});
 	}
 	
-	function isStdFolder(folder) {
-		return (activefolder == configGetKey("mail.folder." + folder));
-	}
-
 })();
 
+function isStdFolder(folder) {
+    return (activefolder == configGetKey("mail.folder." + folder));
+}
+
 function updateDraftsFolderCache(delid, newid) {
 	if (delid)
 		OXMailMapping.deleteObjectsInternal( 
@@ -2022,8 +2063,13 @@ function getAdressString(addresses, personal) {
 
 function sendMailToRecipientMail(recipient) {
 	if(recipient && recipient != "") {
-		var newMail = newWindow("newMail.html#action=&id=&folder=&to=" + encodeURIComponent(recipient),
-		getWindowOptions());
+		ox.api.mail.compose({
+			data: {
+				to: [[recipient]]
+			}
+		});
+//		var newMail = newWindow("newMail.html#action=&id=&folder=&to=" + encodeURIComponent(recipient),
+//		getWindowOptions());
 	}
 }
 
@@ -2031,10 +2077,10 @@ function mail_quoteHTMLTags(val) {
 	return val || val.replace(/</gi,"&lt;").replace(/"/gi,"&quot;"); 
 }
 
-function mail_printDetailMail(messageobject) {	
+function mail_printDetailMail(messageobject, closer) {	
 	if(!messageobject)
 		messageobject=detailmessage;
-	
+
 	var mailprintarray=new Array();
 	mailprintarray.push(Print.createTitle(messageobject.subject));
 	mailprintarray.push(Print.createLine("5px"));
@@ -2079,7 +2125,7 @@ function mail_printDetailMail(messageobject) {
 	
 	//TODO MAIL
 	var mailprint=new Print(messageobject.subject);
-	mailprint.printDetail(mailprintarray);
+	mailprint.printDetail(mailprintarray, closer || jQuery.noop);
 }
 
 register("Loaded", function() {
