@@ -31,6 +31,9 @@ var default_font_size_tynmce = configGetKey("gui.mail.defaul_mail_font_size");
 // required for joining initializing processes
 var cb_initMessageContent = null;
 var cb_initAddressBook = null;
+// passed via window
+var aInfoMailAttachmentFile, aInfoMailAttachmentLink;
+var multiForward;
 
 //not valid for all circumstances but sufficient here
 function isSafari() { return navigator.userAgent.indexOf("AppleWebKit") >= 0; }
@@ -67,7 +70,7 @@ tinyMCE.init({
 	editor_selector: "mceEditorOX",
 	language: (corewindow && configGetKey("language") ? configGetKey("language").substring(0,2) : "en"),		
 	plugins: "inlinepopups,table,safari,paste" + (configGetKey("modules.mail.spellcheck") == "true" ? ",spellchecker" : ""),
-	content_css: getURL() + "css/mail/newmail.css",
+	content_css: getURL() + "newmail.css",
 	
 	theme_advanced_buttons1: (editorEnabled ? "newdocument,|,bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,|,formatselect,fontselect,fontsizeselect,|,forecolor,backcolor" : "") ,
 	theme_advanced_buttons2: (editorEnabled ? "cut,copy,paste,pastetext,pasteword,|,bullist,numlist,|,outdent,indent,|,undo,redo,|,image,link,unlink,|,hr,|,charmap,|,blockquote" + (configGetKey("modules.mail.spellcheck") == "true" ? ",|,spellchecker" : "") : "") ,
@@ -350,7 +353,7 @@ register("OX_Cancel_Object", function() {
 	function cbyes() {
 		oMailFunctionsNew.cleanUp();
 		window.onbeforeunload=null;
-		window.close();			
+		ox.api.window.close(url.guid);
 	}
 	if (ums) {
 		newConfirm(_("Close Window"),
@@ -395,6 +398,13 @@ function cb_resize_tinyMCE() {
  * will be executed if the body onload event gots triggered
  */
 function newMailWindowOnload() {
+    
+    // get passed data
+    var wd = ox.api.window.getData(url.guid);
+    aInfoMailAttachmentFile = wd.aInfoMailAttachmentFile;
+    aInfoMailAttachmentLink = wd.aInfoMailAttachmentLink;
+    multiForward = wd.multiForward;
+
 	activemodule='mail_new';
 	initContents('mail_new');
 	initAll();	
@@ -414,30 +424,45 @@ function newMailOnload() {
 	
 	loadingComplete();
 	
-	/*
-	// ugly hack to fix bug #12826	 
-    var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };   
-    var img = document.getElementsByTagName("img");
-    for (var i=0; i < img.length; i++) {
-        img[i].src = img[i].src.replace(/\/default\//g, "/"+themeStyle.path+"/")
-    }
-    */
+	// extend url object
+	url = jQuery.extend((url || {}), ox.api.window.getData(url.guid));
+	
+	// map url given addresses to valid objects
+	var tAddr = [ "to", "cc", "bcc" ];
+	for (var i=0; i < tAddr.lengt; i++) {
+		if (url[tAddr[i]] && jQuery.isArray([tAddr[i]]) == false) {
+			url[tAddr[i]] = [[ null, url[tAddr[i]]]];
+		}
+	}
+	
+	// prepare url object and take care
+	// everything set correctly
+	if (!url.attachments) {
+		url.attachments = [{}];
+	}
+	// wrap any mailtext parameter into valid object
+	if (url.mailtext) {
+		var attach = url.attachments[0];
+		attach.content_type = "text/plain";
+		attach.content = url.mailtext;
+		url.action = "new";
+	}
 	
 	triggerEvent("OX_Switch_View", "mail_new");
 	triggerEvent("OX_menu_Change_Height", true);
 	
 	internalCache = corewindow.internalCache;
-	action = url["action"];
+	action = url.action;
 	
 	if (corewindow && corewindow.mail_accounts) {
 		var acc =  "default0/INBOX";
-		if (url["account"]) {
-			acc = url["account"];
+		if (url.account) {
+			acc = url.account;
 		} else {
-			if (url["folder"] && url["folder"].length != 0) {
-				acc = url["folder"];
-			} else if (url["id"] && url["id"].length != 0) {
-				acc = url["id"];
+			if (url.folder && url.folder.length != 0) {
+				acc = url.folder;
+			} else if (url.id && url.id.length != 0) {
+				acc = url.id;
 			}
 			corewindow.getMailAccountIdByFolder(acc)
 		}
@@ -473,21 +498,8 @@ function newMailOnload() {
 	// initialize address book (async)
 	cb_initAddressBook = joint.add(emptyFunction);
 	// go!
-	initMessageContent(action);
+	initMessageContent(action, url.noimg == "true");
 	setTimeout("initAddressBook()", 100);
-	
-	// to, cc, bcc? (fallback)
-	if (url["to"]) {
-		setRecipients([[ null, url["to"]]], "to");
-	} else if (url["cc"]) {
-		setRecipients([[ null, url["cc"]]], "cc");
-	} else if (url["bcc"]) {
-		setRecipients([[ null, url["cc"]]], "bcc");
-	}
-	// subject given?
-	if (url["subject"]) {
-		setSubject(url["subject"]);
-	}
 		
 	// disable attachments first
 	triggerEvent("SubSelected", 0);
@@ -638,7 +650,11 @@ function cb_setSignatureText(obj, autoScroll) {
 			// create snippet
 			var signature_snippet = "" + signature_text + "<br/>";
 			// add via DOM (via id - not DOM node - would not work as expected)
-			ae.dom.setHTML("mceSignatureTop", signature_snippet);
+			try {
+                ae.dom.setHTML("mceSignatureTop", signature_snippet);
+            } catch (e) {
+                // IE throws "type conflict" in rare cases
+            }
 			// scroll into view
 			if (autoScroll) {
 			    newElement.scrollIntoView(false);
@@ -666,9 +682,13 @@ function cb_setSignatureText(obj, autoScroll) {
 				}, '');
 			docBody.appendChild(newElement);
 			// create snippet
-			var signature_snippet = signature_text;
+			var signature_snippet = signature_text + "";
 			// add via DOM (via id - not DOM node - would not work as expected)
-			ae.dom.setHTML("mceSignatureBottom", signature_snippet);
+			try {
+                ae.dom.setHTML("mceSignatureBottom", signature_snippet);
+            } catch (e) {
+                // IE throws "type conflict" in rare cases
+            }
 			// scroll into view
 			if (autoScroll) {
 			    newElement.scrollIntoView(false);
@@ -824,7 +844,7 @@ function initMessageHeader() {
     // add combobox (height depends on number of signatures (max 4 rows)
 	signature = new ComboBox3(window, "mail.signatureCombo", "15em", 0, true, "setSignature", Math.min(signature_count, 5));
 	// fill combobox
-	if(configContainsKey("gui.mail.signatures")) {
+	if (configContainsKey("gui.mail.signatures")) {
 		signature.addElement("None","");
 		for (var a=0; a < configGetKey("gui.mail.signatures").length; a++) {
 			var signatures = configGetKey("gui.mail.signatures")[a];
@@ -833,7 +853,7 @@ function initMessageHeader() {
 			}
 			var sig_name = signatures.signature_name.length == 0 ? _("Unnamed signature") /*i18n*/ : signatures.signature_name;
 			signature.addElement(sig_name, signatures, make_callback(sig_name));
-			if(configGetKey("gui.mail.signatures")[a].signature_default) {
+			if (configGetKey("gui.mail.signatures")[a].signature_default && action != "new") {
 				defaultSignature = a;
 				signature.selected = a+1;				
 			}
@@ -854,59 +874,43 @@ function cb_mailComboChanged() {
 	setBeforeUnload(true);
 }
 
-function initMessageContent(m_action) {
-	var addParam = "";
+function initMessageContent(m_action, noimg) {
+	var addParam = noimg ? "" : "&view=html";
 	if (m_action && m_action == "draft") {
-		m_action = "get", addParam = "&edit=1";
+		m_action = "get";
+		addParam += "&edit=1";
 	}
 	
 	// attached objects?
-	if (window.attachedObjects) {
-	    // clone
-	    window.attachedObjects = clone(window.attachedObjects, corewindow);
+	var wd = ox.api.window.getData(url.guid);
+	if (wd.attachedObjects !== undefined) {
 	    // loop objects
-	    for (var i = 0; i < window.attachedObjects.length; i++) {
-	        var obj = window.attachedObjects[i];
+	    for (var i = 0; i < wd.attachedObjects.length; i++) {
+	        var obj = wd.attachedObjects[i];
 	        // attach:
 	        oMailFunctionsNew.addObject(obj);
 	    }
 	}
+
+	// headers
+	if (wd.headers) {
+	    for (var i in wd.headers) oMailFunctionsNew.headers[i] = wd.headers[i];
+    }
 	
-	if (m_action && m_action != "") {
-        var sObj = [{ "folder": url["folder"], "id": url["id"] }]; 
-        if ("multiForward" in window) {
-        	sObj = window.multiForward = clone(window.multiForward, corewindow);
+	if (m_action && m_action != "" && m_action != "new") {
+        var sObj = [{ "folder": url.folder, "id": url.id }];
+        // multi forward?
+        if (jQuery.isArray(multiForward) && multiForward.length) {
+        	sObj = multiForward;
         }
-		
 		(new JSON()).put(AjaxRoot + "/mail?action=" + m_action + "&session=" + 
 			corewindow.session + addParam, sObj, null, 
 				function(cb) {
 					if (cb && cb.data) {
-						setRecipients(cb.data["to"], "to");
-						setRecipients(cb.data["cc"], "cc");
-						setRecipients(cb.data["bcc"], "bcc");
-						setSubject(cb.data["subject"]);
-						msgref = cb.data["msgref"];
-						if (cb.data["nested_msgs"] && cb.data["nested_msgs"].length > 0) {
-							for (var i = 0; i < cb.data["nested_msgs"].length; i++) {
-								var nobj = cb.data["nested_msgs"][i];
-								var textAttachment = nobj.subject || _("attachment");
-								oMailFunctionsNew.addAttachment(
-									{ id: nobj.id || "message/rfc822", 
-									filename: textAttachment, size: null, 
-									content_type: "message/rfc822", 
-									msgref: nobj.msgref || null, selected: false,
-									disk: nobj.disk || null});
-							}
+						if (action != "draft") {
+							delete(cb.data.disp_notification_to);
 						}
-						setMessageText(cb.data["attachments"]);	
-						
-						if(cb.data["priority"] && priority) {
-							priority.setKey(cb.data["priority"]);
-						}
-	                    if (action == "draft" && cb.data["disp_notification_to"] && $("acknowledge")) {
-	                        $("acknowledge").checked = true;
-	                    }
+						setMailFields(cb.data);
 					}
 					// callback
 					cb_initMessageContent();
@@ -921,7 +925,7 @@ function initMessageContent(m_action) {
 									oMailFunctionsNew.cleanUp();
 									corewindow.triggerEvent("OX_Mail_Delete");
 									window.onbeforeunload=null;
-									window.close();
+									ox.api.window.close(url.guid);
 								}
 						);
 						return true;
@@ -931,18 +935,45 @@ function initMessageContent(m_action) {
 				});
 		
 	} else {
+		setMailFields(url);
+		
 		if (typeof aInfoMailAttachmentFile != "undefined") {
 			setMessageText(aInfoMailAttachmentFile);
 		} else if (typeof aInfoMailAttachmentLink != "undefined") {
 			setMessageText(aInfoMailAttachmentLink);
-		} else {
-			setMessageText({}); // new message, call with blank text
 		}
+		
 		// callback
 		cb_initMessageContent();
 	}
 }
 
+function setMailFields(mailobject) {
+    setRecipients(mailobject.to, "to");
+	setRecipients(mailobject.cc, "cc");
+	setRecipients(mailobject.bcc, "bcc");
+	setSubject(mailobject.subject);
+	msgref = mailobject.msgref;
+	if (mailobject.nested_msgs && mailobject.nested_msgs.length > 0) {
+		for (var i = 0; i < mailobject.nested_msgs.length; i++) {
+			var nobj = mailobject.nested_msgs[i];
+			var textAttachment = nobj.subject || _("attachment");
+			oMailFunctionsNew.addAttachment(
+				{ id: nobj.id || "message/rfc822", 
+				filename: textAttachment, size: null, 
+				content_type: "message/rfc822", 
+				msgref: nobj.msgref || null, selected: false,
+				disk: nobj.disk || null});
+		}
+	}
+	setMessageText(mailobject.attachments);	
+	priority.setKey(mailobject.priority || 1);
+
+    if (mailobject.disp_notification_to && $("acknowledge")) {
+        $("acknowledge").checked = true;
+    }	
+}
+
 function setRecipients(to, field) {
 	if (to && to.length && $(field)) {
 		$(field).value = corewindow.getAdressString(to, false);
@@ -954,12 +985,11 @@ function setRecipients(to, field) {
 }
 
 function setSubject(subject) {
-	if (subject)
-		$("subject").value = subject;
+	if (subject) $("subject").value = subject;
 }
 
 function setMessageText(attachments) {
-
+	
 	var mda = $("newMailAttachmentDivExist"), cnn = "";
 	for (idfield in attachments) {
 		var conArr = attachments[idfield];
@@ -989,10 +1019,9 @@ function setMessageText(attachments) {
 	// extract body content (always)
 	cnn = extractBodyContent(cnn);
 	
-	//cnn = "<p><b><font size='5' face='Arial, Helvetica, sans-serif'><span style='font-family: Arial, Helvetica, sans-serif; font-size: 18pt; color: red'>Hallo Welt</span></font></b></p>" + cnn;
-	
-	// keep as is?
-	if (action == "draft" && cnn.search(/id="mceDummy"/)) {
+	// keep as is? if action is empty we assume it's a new message
+	// required for API calls
+	if ((action == "new" || action == "draft") && cnn.search(/id="mceDummy"/)) {
 	    
 	    // replace editor content (as is / draft)
         replaceEditorContent(cnn);
@@ -1205,6 +1234,7 @@ function trimLastBlockquote(str) {
 
 function MailFunctions() {
 	this.oo = new Object();
+	this.headers = new Object();
 	this.ooA = new Object();
 	this.attachContainer = new Array();
 	this.attachObj = new Array();
@@ -1230,6 +1260,8 @@ MailFunctions.prototype = {
 	            Self.oo["sendtype"] = 1;
 	        Self.sAction  = AjaxRoot + "/mail?action=new&session=" + corewindow.session;
 	        var sTargetParam = 'mailSendCB';
+	        if(!isEmpty(Self.headers))
+	        	Self.oo.headers = Self.headers;
 	        tmp_attachmentDialog.do_post(Self.oo,callback_new,Self.sAction,sTargetParam);
 		}
         if (trimStr(Self.oo["subject"]).length == 0) {
@@ -1447,9 +1479,17 @@ MailFunctions.prototype = {
 				[ newnode("img",0,
 					{ src: imgSrc, align: "absmiddle", padding: "3px"}),
 				  	newnode("span",0,{className: "_nothing"},
-				  		[ document.createTextNode(
-				  			format(_(" %1$s%2$s; "), label, 
-				  			(this.attachObj[i].size ? " (" + bytesToString(this.attachObj[i].size) + ")" : "")) ) ]
+				  		[ document.createTextNode(this.attachObj[i].size ?
+                            //#. Displayed label for attachments
+                            //#. %1$s is the file name.
+                            //#. %2$s is the file size.
+                            //#, c-format
+				  		    format(_(" %1$s (%2$s); "), label,
+				  		           bytesToString(this.attachObj[i].size)) :
+                            //#. Displayed label for attachments without file size
+				  		    //#. %1$s is the file name.
+				  		    //#, c-format
+                            format(_(" %1$s; "), label))]
 					  	)
 					]
 				);	
@@ -1518,7 +1558,7 @@ function callback_new(cb) {
 			window.onbeforeunload=null;
 			window.setTimeout(
 				function() {
-					window.close();
+				    ox.api.window.close(url.guid);
 				}, 250);
 		} else {
 			newServerError(cb);
@@ -1675,7 +1715,7 @@ function cb_mailFileBrowser(field_name, url, type, win) {
     doc.body.appendChild(nd1);
     doc.body.appendChild(nd2);   
 
-    doc.body.appendChild( newnode("script", null, { language: "javascript", type: "text/javascript", src: URL + "js/mail/mailFileBrowser.js" }, null, doc ) );
+    doc.body.appendChild( newnode("script", null, { language: "javascript", type: "text/javascript", src: URL + "mailFileBrowser.js" }, null, doc ) );
     doc.body.appendChild( newnode("iframe", { display: "none" }, { scrolling: "no", frameBorder: "0", src: URL + "newInfoItemHidden.html", name: "hiddenNMFrame", id: "hiddenNMFrame"}, null, doc) );
 
     /* *** Ugly workaround for IE Only *** */
