@@ -28,10 +28,6 @@ var activefolder = null;
  */
 var configparentfolder=-1;
 var superzaehler=1;
-/*ID des Reiters im Modul */
-// Remove this
-var menuarrows=new Object();
-
 
 register("OX_Direct_Linking",
 	function(modulename,object)
@@ -167,7 +163,7 @@ var menuminiteration = 2;
 var menuiterationheight=1.6;
 var menupadding=0.4;
 var menumaxiteration=6;		
-var menuiteration=4;
+var menuiteration=2;
 
 var menupictureiterationmin=3;
 var menupictureiterationheight=menupictureiterationmin-1;
@@ -188,16 +184,28 @@ var showhelp=false;
 
 /********************************** New Registrations ************************************************************/
 var menulastviews = new Object();
+var lastCalendarTimeRanges = { detail: "overview" };
 register("OX_Configuration_Set_Empty",loadDefaultModules);
 function loadDefaultModules() {
 	for (var i in modules) {
-		if(configContainsKey("gui."+modules[i].name+".view")) 
-		{
-			if(modules[i].name == "calendar" && !configGetKey("modules.calendar.calendar_teamview") &&(configGetKey("gui."+modules[i].name+".view").indexOf("calendar/team") == 0 )) {
-				configSetKey("gui."+modules[i].name+".view","calendar/calendar/day");
-			}
-			menulastviews[modules[i].name] = configGetKey("gui."+modules[i].name+".view");
-			
+	    var configPath = "gui." + modules[i].name + ".view";
+		if(!modules[i].disable && configContainsKey(configPath)) {
+		    var defaults = configGetKey(configPath);
+			if (modules[i].name == "calendar") {
+                defaults = configGetKey("gui.calendar.views");
+			    if (   !configGetKey("modules.calendar.calendar_teamview")
+			        && defaults.view == "team")
+			    {
+			        defaults.view = "calendar";
+				    configSetKey("gui.calendar.views.view", "calendar");
+			    }
+			    menulastviews.calendar = getDefaultCalendarView();
+			    lastCalendarTimeRanges.calendar = defaults.calendar;
+			    lastCalendarTimeRanges.team = defaults.team;
+			    lastCalendarTimeRanges.list = defaults.list;
+            } else {
+                menulastviews[modules[i].name] = configGetKey(configPath);
+            }
 		} else {
 			if(modules[i].name== "configuration") {
 				menulastviews[modules[i].name] = "configuration/settings";
@@ -226,10 +234,14 @@ function switchtoModule(newmodule,param,folder) {
 
 register("OX_Switch_View",switchtoView);
 function switchtoView(newview,param) {
-	var newmodule=newview.split("/")[0];
+    var elements = newview.split("/");
+	var newmodule= elements[0];
 	(newmodule!=activemodule) ? menuremoveErrors(2) : menuremoveErrors(3);
 	if(isDefaultableView(newview)) {
 		menulastviews[newmodule]=newview;
+		if (newmodule == "calendar" && elements[1] != "detail") {
+		    lastCalendarTimeRanges[elements[1]] = elements[2]; 
+		}
 	}
 	changeView(newview,param);
 	reloadDynamicContent();
@@ -267,8 +279,8 @@ function initDisplay(view,elementid,setwidth) {
  */
 function changeDisplay(name, id, hide) {
     var key = name + "\x00" + id;
+    var change = changeDisplay.changes[key];
     if (hide) {
-        var change = changeDisplay.changes[key];
         if (change) {
             change.view.show[change.index] = undefined;
             change.view.hide[change.index] = undefined;
@@ -276,9 +288,14 @@ function changeDisplay(name, id, hide) {
             console.error("Invalid changeDisplay", name, id);
         }
     } else {
-        var v = registerView(name, function() { showNode(id); },
-            null,null, function() { hideNode(id); });
-        changeDisplay.changes[key] = { view: v, index: v.show.length - 1 };
+        if (change) {
+            change.view.show[change.index] = function() { showNode(id); };
+            change.view.hide[change.index] = function() { hideNode(id); };
+        } else {
+            var v = registerView(name, function() { showNode(id); },
+                null,null, function() { hideNode(id); });
+            changeDisplay.changes[key] = { view: v, index: v.show.length - 1 };
+        }
     }
 }
 changeDisplay.changes = {};
@@ -349,77 +366,13 @@ changeDisplay("calendar/detail/attachment","menu_global_attachments");
 changeDisplay("calendar/detail","menu_global_confirmation");
 
 function menuswitchCalendarView(param) {
-	var newpath=currentpath2.slice(0);
-	newpath[1]=param;
-	if(!newpath[2]) {
-	}
-	switch (param)	{
-		case "list":
-			if(newpath[2]) {
-				if(newpath[2]!="day" && newpath[2]!="workweek" && newpath[2]!="month" && newpath[2]!="week") {
-					newpath.length=3;
-					var oldview=menulastviews["calendar"].split("/");
-					if(!oldview[2]) {
-						newpath[2]="day";
-					}
-					else if(oldview[2]!="day" && oldview[2]!="workweek" && oldview[2]!="month" && oldview[2]!="week") {
-						newpath[2]="day";
-					}
-					else {
-						newpath[2]=oldview[2];
-					}
-					break;
-				}
-			} else {
-				newpath[2]="day";
-			}
-			break;
-		case "calendar":
-			if(newpath[2]) {
-				if(newpath[2]!="day" && newpath[2]!="workweek" && newpath[2]!="month" && newpath[2]!="week" && newpath[2]!="custom") {
-					newpath.length=3;
-					var oldview=menulastviews["calendar"].split("/");
-					if(!oldview[2]) {
-						newpath[2]="day";
-					}
-					else if(oldview[2]!="day" && oldview[2]!="workweek" && oldview[2]!="month" && oldview[2]!="week" && oldview[2]!="custom") {
-						newpath[2]="day";
-					}
-					else {
-						newpath[2]=oldview[2];
-					}
-					break;
-				}
-			} else {
-				newpath[2]="day";
-			}
-			break;		
-		case "team":
-			if(newpath[2]) {
-				if(newpath[2]!="day" && newpath[2]!="workweek") {
-					newpath.length=3;
-					var oldview=menulastviews["calendar"].split("/");
-					if(!oldview[2]) {
-						newpath[2]="day";
-					}
-					else if(oldview[2]!="day" && oldview[2]!="workweek") {
-						newpath[2]="day";
-					}
-					else {
-						newpath[2]=oldview[2];
-					}
-					break;
-				}
-			} else {
-				newpath[2] = "day";
-			}
-			break;
-		case "detail":
-			newpath[2]="overview";
-			newpath.length=3;
-			break;
-	}
-	switchtoView(newpath.join("/"));
+    var range = lastCalendarTimeRanges[param];
+    if (  param != "detail" && currentpath2[1] != "detail"
+        && configGetKey("gui.calendar.views.shared"))
+    {
+        range = currentpath2[2];
+    }
+    switchtoView("calendar/" + param + "/" + range);
 }
 function menuswitchCalendarTimerange(param) {
 	var newpath=currentpath2.slice(0);
@@ -638,7 +591,7 @@ function menufollowLink(mymodule,object) {
 		    	object["directLink"] = true;
 			    selectedAppointment = object;
 		    } else {
-		        view = menulastviews[mymodule] || configGetKey("gui.calendar.view");
+		        view = getLastCalendarView();
 		    }
 			break;
 		case "tasks":
