@@ -1,9 +1,7 @@
 var corewindow=window;
 function configGetKey(key) {
 	var splitkey=key.split(".");
-	if(!"config" in window || !config) {
-		return null;
-	}
+	if (!window.config) return null;
 	var tmp=(corewindow) ? corewindow.config : config;
 	for(var i=0;i<splitkey.length;i++) {
 		if(tmp[splitkey[i]] != undefined) {
