@@ -686,9 +686,11 @@ Participants.prototype = {
 	openGroupMembersPopup: function (memberArray,group_id) {
 		var sGroupIdSplitDot = group_id.split(".")[0];
 		internalCache.getGroups([sGroupIdSplitDot.split('_')[1]],function (res){
-							$('memberPopup-h-c').innerHTML = format(_("Members of %s"), /*i18n*/
-												res[sGroupIdSplitDot.split('_')[1]].display_name);			
-																	});
+            //#. %s is the name of a group.
+		    //#, c-format
+		    $('memberPopup-h-c').innerHTML = format(_("Members of %s"), /*i18n*/
+                res[sGroupIdSplitDot.split('_')[1]].display_name);			
+        });
 
 		var Self = this;
 		if(typeof memberArray != "object")
@@ -810,9 +812,10 @@ Participants.prototype = {
 			$("headerSelMember").style.display ="none";
 			$("headerSelMember2").style.display ="none";										
 		}
-        if ($("disable_background_window")) {
-            showNode("disable_background_window");
-            $("disable_background_window").style.display = "block";
+        if ($("modal-dialog")) {
+            ox.api.setModal(true);
+//            showNode("modal-dialog");
+//            $("modal-dialog").style.display = "block";
         }
 		showNode("floatingdivParticipants");
 		centerPopupWindow($("floatingdivParticipants"));
@@ -850,17 +853,19 @@ Participants.prototype = {
 		var parts = [];
 		if (this.internalStorage2.data.data){
 			for(i in this.internalStorage2.data.data){
-				if(this.internalStorage2.data.data[i][4] != null){
-					var tmpObj = {id : getID(this.internalStorage2.data.data[i][0]), display_name : this.internalStorage2.data.data[i][2]};
-					switch (getTyp(this.internalStorage2.data.data[i][0])) {
+				if (!onlyInternal || this.internalStorage2.data.data[i][4] != null) {
+				    var part = this.internalStorage2.data.data[i];
+					var tmpObj = { id: getID(part[0]) };
+					if (part[2]) tmpObj.display_name = part[2];
+					switch (getTyp(part[0])) {
 						case "contact":
-							if(this.internalStorage2.data.data[i][1] == 6){
+							if(part[1] == 6){
 								tmpObj.type = 1;
-								tmpObj.id = this.internalStorage2.data.data[i][7];
+								tmpObj.id = part[7];
 							}
 							else {
 								tmpObj.type = 5;
-								tmpObj.mail = this.internalStorage2.data.data[i][5];
+								tmpObj.mail = part[5];
 							}
 							break;
 						case "group":
@@ -951,6 +956,8 @@ Participants.prototype = {
             } else if (configContainsKey("minimumSearchCharacters") &&
                 configGetKey("minimumSearchCharacters") != 0) {
             	this.displayError(
+            	   //#. %s is the number of characters.
+            	   //#, c-format
             	   format(_("The search pattern requires at least %s characters."), 
             	       configGetKey("minimumSearchCharacters")));
             	return;
@@ -960,6 +967,8 @@ Participants.prototype = {
         } else if (configContainsKey("minimumSearchCharacters") &&
             trimStr(inVal).length < configGetKey("minimumSearchCharacters")) {
             this.displayError(
+                //#. %s is the number of characters.
+                //#, c-format
                 format(_("The search pattern requires at least %s characters."), 
                     configGetKey("minimumSearchCharacters")));
             return;
@@ -1122,8 +1131,8 @@ Participants.prototype = {
 		var Self = this; // bind
 		this.opened = false;
 		
-        if ($("disable_background_window")) {
-        	var childs = $("disable_background_window").childNodes;
+        if ($("modal-dialog")) {
+        	var childs = $("modal-dialog").childNodes;
         	var closeall=true;
 		    for (var i=0;i<childs.length;i++) {
 		        if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -1133,8 +1142,9 @@ Participants.prototype = {
 		        }
 		    }
 		    if (closeall) {
-                hideNode("disable_background_window");
-                $("disable_background_window").style.display = "none";
+		        ox.api.setModal(false);
+//                hideNode("modal-dialog");
+//                $("modal-dialog").style.display = "none";
 		    }
         }
 		hideNode("floatingdivParticipants");
@@ -1334,21 +1344,16 @@ Participants.prototype = {
 				}
 				
 				// add as changed
-				if ( item.internal_userid && item.internal_userid > 0 ) {
-					// add as changed (internal user)
-					Self.changedParticipants.push({
-						"id": item.internal_userid, 
-						"display_name": item.display_name,
-						"mail": mail, "type": 1, "recurrence": recurrence 
-					});
-				} else {					
-					// add as changed (external contact)
-					Self.changedParticipants.push({
-						"id": item.id, 
-						"display_name": item.display_name, 
-						"mail": mail, "type": 5, "recurrence": recurrence
-					});
-				}
+				var participant = {
+                    "contactID": item.id, 
+                    "display_name": item.display_name,
+                    "mail": mail, "type": 5, "recurrence": recurrence 
+                };
+                if ( item.internal_userid && item.internal_userid > 0 ) {
+                    participant.type = 1;
+                    participant.id = item.internal_userid;
+                }
+                Self.changedParticipants.push(participant);
 			}
 			// add to grid (via storage)
 			Self.internalStorage2.append(tmpArray);
@@ -1544,8 +1549,20 @@ Participants.prototype = {
 		if(externalUser.length > 0){
 			var tmpArrayExternal = new Array();
 			var count = 0;
+			var confirmations = {};
+			for (var i in obj.confirmations) {
+			    var confirmation = obj.confirmations[i];
+			    confirmations[confirmation.mail] = confirmation;
+			}
 			for(i in externalUser){
-				tmpArrayExternal[count++] = ["contact_" + externalUser[i].id, 0, externalUser[i].display_name, "", "", externalUser[i].mail, "contact"];
+			    var confirmation = confirmations[externalUser[i].mail] ||
+                    { status: 0, message: "" };
+				tmpArrayExternal[count++] = [
+				    "contact_" + externalUser[i].id, 0,
+				    externalUser[i].display_name,
+				    _(this.stati[confirmation.status || 0]),
+				    confirmation.message || "",
+				    externalUser[i].mail, "contact"];
 				Self.internalStorage2.groups.push(false);
 			}
 			Self.internalStorage2.append(tmpArrayExternal);
@@ -1569,8 +1586,8 @@ Participants.prototype = {
 	closeParticipantsWindowCancel: function() {	
 		this.opened = false;
 		var Self = this;
-        if ($("disable_background_window")) {
-            var childs = $("disable_background_window").childNodes;
+        if ($("modal-dialog")) {
+            var childs = $("modal-dialog").childNodes;
             var closeall=true;
             for(var i=0;i<childs.length;i++) {
                 if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -1580,8 +1597,9 @@ Participants.prototype = {
                 }
             }
             if (closeall) {
-                hideNode("disable_background_window");
-                $("disable_background_window").style.display = "none";
+                ox.api.setModal(false);
+//                hideNode("modal-dialog");
+//                $("modal-dialog").style.display = "none";
             }
         }
 		hideNode("floatingdivParticipants");
@@ -1926,18 +1944,18 @@ function participantsFolderPath() {
 	folderViewSettingsNewContact["calendar"] = 4;
 	folderViewSettingsNewContact["tasks"] = 4;
 	folderViewSettingsNewContact["infostore"] = 4;
-	if(window.opener)
-		var oLocalState = window.opener.optFolderState.getState('folderAddressbookParticipant_tree_info');
+	if(corewindow)
+		var oLocalState = corewindow.optFolderState.getState('folderAddressbookParticipant_tree_info');
 	else
 		var oLocalState = new Object();
 	newAddressbookFolderTree = new cFolderTree(	$('folderAddressbookParticipant_tree_info'),
 									folderParticipantAction,
 									false,
-									window.opener.oMainFolderTree.cache,
-									window.opener.optFolderState.getState('folderAddressbookParticipant_tree_info'))
+									corewindow.oMainFolderTree.cache,
+									corewindow.optFolderState.getState('folderAddressbookParticipant_tree_info'))
 	newAddressbookFolderTree.enabled_modules = {contacts:true};			
-	if(window.opener)									
-		newAddressbookFolderTree.setSaveConfiguration(window.opener.optFolderState);		
+	if(corewindow)									
+		newAddressbookFolderTree.setSaveConfiguration(corewindow.optFolderState);		
 	if(!contactAddressbookTreeParticipantLoaded)
 	{
 		newAddressbookFolderTree.load();
