@@ -590,6 +590,8 @@ MenuItem.prototype = {
     
     close: function() { this.parent.close(); },
     
+    visible: true,
+    
     setVisible: function(visible) {
         this.visible = visible;
         this.node.style.display = visible ? "" : "none";
@@ -641,6 +643,21 @@ MenuItem.prototype = {
             Self.setWaiting(wait);
         });
     },
+
+    /**
+     * Automatically disables the menu item if its submenus do not have a single
+     * enabled option.
+     */
+    autoSetEnabled: function() { this.setEnabled(this.getAutoEnabled()); },
+    
+    getAutoEnabled: function() {
+        if (!this.submenu) return this.enabled && this.visible;
+        for (var i = 0; i < this.submenu.items.length; i++) {
+            var item = this.submenu.items[i];
+            if (item.getAutoEnabled && item.getAutoEnabled()) return true;
+        }
+        return false;
+    },
     
     /**
      * Returns the context in which this item is used. Usually, this is
