@@ -19,7 +19,7 @@ var	bPortalConfigChanged = false;
 var oPortalObject = null;
 
 registerView("portal",
-	function() { showNode("portal") }, 
+	function() { showNode("portal"); }, 
 	function() { 
 		if(oPortalObject != null)			
 		{	
@@ -66,7 +66,7 @@ register('OX_Configuration_Changed',function (param)
 
 function fn_clickedItem(sModule,oObj)
 {
-	triggerEvent("OX_Direct_Linking",sModule,oObj)
+	triggerEvent("OX_Direct_Linking",sModule,oObj);
 }
 
 function resizePortalHeaders()
