@@ -284,7 +284,7 @@ cPortal.prototype = {
 				function getPixels(value) {
 					if (!value) return value;
 					var match = /^([0-9.]+)(em|px)$/.exec(value);
-					if (!match) alert(format("Invalid ox:min or ox:max at id=\"%2\".", split.id));
+					if (!match) alert(format("Invalid ox:min or ox:max at id=\"%1\".", split.id));
 					var num = parseFloat(match[1]);
 					switch (match[2]) {
 						case "px": return num;
@@ -327,7 +327,7 @@ cPortal.prototype = {
 				addDOMEvent(body, "mouseup", u);
                 cPortal.setMovingClass(split, true);
 				cancelDefault(e);					
-			}
+			};
 		}
 		var oNewCell = newnode("div",{flt:"left",paddingLeft:"7px"});
 		var oDOMresize = newnode("div",{zIndex:"5",verticalAlign:"middle",cursor:"e-resize",position:"absolute",
@@ -355,7 +355,7 @@ cPortal.prototype = {
 		function get_closed_actionfn(){
 			return function (){
 				Self.header_action(sModule);
-			}
+			};
 		}
 		//enable action for internal module change
 		if(oObjExt == undefined)		
@@ -372,7 +372,7 @@ cPortal.prototype = {
 		function get_closed_closefn(){
 			return function (){
 				Self.close_section(sModule,sId);
-			}
+			};
 		}
         addDOMEvent(oCloseImg,"click",get_closed_closefn());
 		var oDOMHeaderTable = newnode('div',{paddingLeft:"8px"},0,[
@@ -398,7 +398,7 @@ cPortal.prototype = {
 		{
 			var newItem = new portalExternalItem(sId,sModule,container,header,oObjExt.parameter,oAdj,oNewCell,oDOMresize,oObjExt.url);
 			newItem.autorefresh = oObjExt.autorefresh;
-			newItem.standalone = oObjExt.standalone
+			newItem.standalone = oObjExt.standalone;
 		}
 			
 		this.matrix.add(newItem,oNewCell,oAdj.x,oAdj.y);		
@@ -435,7 +435,7 @@ cPortal.prototype = {
 					var nNumWidth = sStrWidth.replace(/px/,'');
 					var objDND_Header = draggedObjects.header.firstChild.cloneNode(true);
 					objDND_Header.style.width = "99%";
-					objDND_Obj = newnode('div',{paddingTop:"3px",paddingRight:"10px",paddingLeft:"10px",position:"absolute",border:"1px dotted #000000",width:sStrWidth,height:draggedObjects.div.style.height},0,[objDND_Header])
+					objDND_Obj = newnode('div',{paddingTop:"3px",paddingRight:"10px",paddingLeft:"10px",position:"absolute",border:"1px dotted #000000",width:sStrWidth,height:draggedObjects.div.style.height},0,[objDND_Header]);
 					addDOMEvent(objDND_Obj, "selectstart", function (e){stopEvent(e);return false;});
 					addDOMEvent(objDND_Obj, "drag", function (e){stopEvent(e);return false;});							
 					$('mailDnDPortal_anchor').appendChild(objDND_Obj);
@@ -462,7 +462,7 @@ cPortal.prototype = {
 								}					
 								clearTimeout(timeoutPortal);
 								timeoutPortal = setTimeout(local_tempst,100);
-							}
+							};
 		}
 	
 		function showPreview(e,dragType,draggedObjects,mouseposition,targetNode,node,saveX,saveY){
@@ -470,7 +470,7 @@ cPortal.prototype = {
 			if(node == tempViewPortalObj){
 				return;			
 			}
-			var absolutX = getAbsolutePositionLeft(node)
+			var absolutX = getAbsolutePositionLeft(node);
 			var sNewPosition;
 			
 			//coordinate system transformation
@@ -621,7 +621,7 @@ cPortal.prototype = {
 			{
 				var dwi = sPortalId;
 				return dwi;
-			}
+			};
 		}			
 		function leaveSourcePortal(){
 			if(objDND_Obj != null){
@@ -650,4 +650,4 @@ cPortal.prototype = {
 			
 		}
 
-}
\ No newline at end of file
+};
\ No newline at end of file
