@@ -49,17 +49,12 @@ portalExternalItem.prototype = {
 	deleteFrame: function (){
 		removeChildNodes(this.container);
 		this.uwa = null;
-		/*
-		this.uwa = oIfrExt.contentWindow.getWDG(this.container,this.url,this.params);
-		this.uwa.setPreferencesValues(this.params);	
-		*/
 	},
 	appendFrame:function (){
 		this.uwa =new UWAWidget({ inline: false,id:this.id, container: this.container,
 														    moduleUrl: this.url, standalone: this.standalone } );
 		this.uwa.setConfiguration( { 'title':'',  'borderWidth':'0', 
 							    'color':'#aaaaaa', 'displayTitle':false, 'displayFooter':false } );	 
-//		this.uwa = oIfrExt.contentWindow.getWDG(this.container,this.url,this.params);
 		this.uwa.setPreferencesValues(this.params);				
 	},
 	update_content:function (newdata){
@@ -595,7 +590,7 @@ portalItem.prototype = {
 			row.tr.style.top = (index * this.rowHeight) + "px";
 			row.tr.oxRowIndex = index;
 			this.unfetched[index] = true;
-		}
+		};
 		var Self = this;
 		sectionLG.events.register("Selected",function (ids)
 			{		
@@ -687,7 +682,7 @@ portalItem.prototype = {
 	update_grid: function (aData){
 		if(this.module == "calendar")
 			var storage = new Storage(0, [],null,null,null,null,function (x){
-							return x[0]+'_'+x[1]+'_'+x[(x.length-1)];
+                    return x[0] + "_" + x[1] + "_" + (x[5] || 0);
 				});							
 		else
 			var storage = new Storage(0, [],null,null,null,null,function (x){
@@ -704,7 +699,7 @@ portalItem.prototype = {
 		aData['lg'].enable(storage);	
 	}
 
-}
+};
 function getEmptyText(sModule)
 {
 	var sModuleName;
