@@ -37,7 +37,7 @@ register("OX_Configuration_Loaded_Complete", function() {
 	combobox.getDomNode();
 	
 	var startDateNode = new I18nNode(function() {
-        if (this.node)
+        if (this.node && this.node.parentNode && this.node.parentNode.parentNode)
             this.node.parentNode.parentNode.style.display = this.value ? ""
                                                                        : "none";
         return this.value ? formatDate(this.value, "datetime") : "";
@@ -45,7 +45,7 @@ register("OX_Configuration_Loaded_Complete", function() {
     $("reminderStartsRow").replaceChild(startDateNode.node,
                                         $("reminderStartsRow").firstChild);
     var endDateNode = new I18nNode(function() {
-        if (this.node)
+    	if (this.node && this.node.parentNode && this.node.parentNode.parentNode)
             this.node.parentNode.parentNode.style.display = this.value ? ""
                                                                        : "none";
         return this.value ? formatDate(this.value, "datetime") : "";
@@ -228,11 +228,13 @@ register("OX_Configuration_Loaded_Complete", function() {
 				function ok() {
 					hide();
 					if (mystatus.cancel) return;
+					var id = { id: reminder.id };
+					if (reminder.recurrence_position) {
+					    id.recurrence_position = reminder.recurrence_position;
+					}
 					json.put(AjaxRoot + "/reminder?action=delete&session=" + session
 						+ "&timestamp=" + encodeURIComponent(reminder.last_modified),
-						{id: reminder.id,
-						 recurrence_position: reminder.recurrence_position},
-						null, deletereply);
+                        id, null, deletereply);
 					function deletereply(reply) {
 						if (reply.data.length || queue.first !== reminder) // Just in case
 							update();
