@@ -64,8 +64,9 @@ RightsHandling.prototype = {
 		oMainFolderTree.cache.get_folder(folder,checkcreateRight);
 	},
 	openWindow : function() {
-		showNode("disable_background_window");
-		$("disable_background_window").style.display="block";
+	    ox.api.setModal(true);
+//		showNode("modal-dialog");
+//		$("modal-dialog").style.display="block";
 		showNode("rightshandling_window");
 		centerPopupWindow($("rightshandling_window"));
 		$("rightshandling_window").style.display="block";
@@ -89,7 +90,7 @@ RightsHandling.prototype = {
 		rightshandling_module=null;
 		hideNode("rightshandling_window");
 		$("rightshandling_window").style.display="none";
-		var childs=	$("disable_background_window").childNodes;
+		var childs=	$("modal-dialog").childNodes;
 		var closeall=true;
 		for(var i=0;i<childs.length;i++) {
 			if(childs[i].tagName && childs[i].tagName == "DIV") {
@@ -99,11 +100,12 @@ RightsHandling.prototype = {
 			}
 		}
 		if(closeall) {
-			hideNode("disable_background_window");
-			$("disable_background_window").style.display="none";
+		    ox.api.setModal(false);
+//			hideNode("modal-dialog");
+//			$("modal-dialog").style.display="none";
 		}
 	}
-}
+};
 var rightshandler=new RightsHandling();
 register("Loaded",function() {
 	addOnClose($('rightshandling_window'),function () { rightshandler.commitno(); });
