@@ -81,7 +81,7 @@ function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch
             Self.getResult();
             //$(liveGridDivResult).focus();
         }
-    }
+    };
     Self.enterInput = function(e) {
     	Self.blurTimer = setTimeout(function() {
 	        if (trimStr($(searchField).value).length == 0) {
@@ -89,7 +89,7 @@ function SearchListAddressBook(searchstring, floatingpopupdiv, liveGridDivSearch
 	            $(Self.searchField).style.color="silver";
 	        }
         }, 100);
-    } 
+    }; 
     
     addDOMEvent($(this.searchField), "keypress", Self.clickOnCombobox); 
     addDOMEvent($(this.searchField), "click", Self.clickOnCombobox);
@@ -134,6 +134,8 @@ SearchListAddressBook.prototype = {
             } else if (configContainsKey("minimumSearchCharacters") &&
                 configGetKey("minimumSearchCharacters") != 0) {
                 this.displayError(
+                   //#. %s is the number of characters.
+                   //#, c-format
                    format(_("The search pattern requires at least %s characters."), 
                        configGetKey("minimumSearchCharacters")));
                 return;
@@ -143,6 +145,8 @@ SearchListAddressBook.prototype = {
         } else if (configContainsKey("minimumSearchCharacters") &&
             trimStr(inVal).length < configGetKey("minimumSearchCharacters")) {
             this.displayError(
+                //#. %s is the number of characters.
+                //#, c-format
                 format(_("The search pattern requires at least %s characters."), 
                     configGetKey("minimumSearchCharacters")));
             return;
@@ -190,9 +194,9 @@ SearchListAddressBook.prototype = {
 							/* the finded "contact" is a distribution list */
 							if((Self.method && Self.method == "mail") || (Self.moreFields && Self.moreFields.length > 0)) {
 								var tmpDistArray = new Array();
-								tmpDistArray[0] = Self.findContactForDistrList.data[i][0]
-								tmpDistArray[1] = Self.findContactForDistrList.data[i][1]
-								tmpDistArray[2] = ""
+								tmpDistArray[0] = Self.findContactForDistrList.data[i][0];
+								tmpDistArray[1] = Self.findContactForDistrList.data[i][1];
+								tmpDistArray[2] = "";
 								tmpDistArray[3] = "true";
 								var tmpString = "";
 								if(Self.findContactForDistrList.data[i][7]) {
@@ -224,9 +228,9 @@ SearchListAddressBook.prototype = {
                             var findEmails = 0;
 							if(Self.findContactForDistrList.data[i][2]) {
 								var tmpDistArray = new Array();
-								tmpDistArray[0] = Self.findContactForDistrList.data[i][0]
+								tmpDistArray[0] = Self.findContactForDistrList.data[i][0];
 								tmpDistArray[1] = displayName;
-								tmpDistArray[2] = Self.findContactForDistrList.data[i][2]
+								tmpDistArray[2] = Self.findContactForDistrList.data[i][2];
 								Self.buildContactForDistrList.push(tmpDistArray);
 								findEmails = 1;		
 								Self.distrids.push(tmpDistArray[0]);
@@ -236,14 +240,14 @@ SearchListAddressBook.prototype = {
 							if(Self.findContactForDistrList.data[i][3]) {
 								var tmpDistArray = new Array();
 								tmpDistArray[1] = displayName;
-								tmpDistArray[2] = Self.findContactForDistrList.data[i][3]
+								tmpDistArray[2] = Self.findContactForDistrList.data[i][3];
 								
 								Self.buildContactForDistrList.push(tmpDistArray);
 								if(findEmails == 0) {
 									tmpDistArray[0] = Self.findContactForDistrList.data[i][0];
 								} else {
 									tmpDistArray[0] = Self.tmpDistId;
-									Self.findContactForDistrList.data.push(tmpDistArray)
+									Self.findContactForDistrList.data.push(tmpDistArray);
 									Self.tmpDistId++;
 								}
 								findEmails = 1;		
@@ -255,12 +259,12 @@ SearchListAddressBook.prototype = {
 							if(Self.findContactForDistrList.data[i][4]) {
 								var tmpDistArray = new Array();
 								tmpDistArray[1] = displayName;
-								tmpDistArray[2] = Self.findContactForDistrList.data[i][4]
+								tmpDistArray[2] = Self.findContactForDistrList.data[i][4];
 								if(findEmails == 0) {
 									tmpDistArray[0] = Self.findContactForDistrList.data[i][0];
 								} else {
 									tmpDistArray[0] = Self.tmpDistId;
-									Self.findContactForDistrList.data.push(tmpDistArray)
+									Self.findContactForDistrList.data.push(tmpDistArray);
 									Self.tmpDistId++;
 								}
 								
@@ -644,7 +648,7 @@ SearchListAddressBook.prototype = {
 			}, 0);
 		}
 	}
-}
+};
 
 
 function AddedSearchContacts() {
@@ -672,7 +676,7 @@ AddedSearchContacts.prototype = {
 		return (tmpItem) ? true : false;
 	}
 	
-}
+};
 
 var contactAddressbookTreeLoaded = false;
 var treeAddressbookVisible = false;
@@ -684,7 +688,7 @@ function addressbookFolderPath() {
     corewindow.oMainFolderTree.checkGAL(function(GAL) {
         clickedItem = GAL ? 6 : corewindow.configGetKey("folder.contacts");
     });
-	session = window.opener.session;
+	session = corewindow.session;
 	var folderViewSettingsNewContact = new Object();
 	var folderViewSettingsNewContactById = new Object();
 	//Disable Email... 
@@ -693,21 +697,21 @@ function addressbookFolderPath() {
 	folderViewSettingsNewContact["calendar"] = 4;
 	folderViewSettingsNewContact["tasks"] = 4;
 	folderViewSettingsNewContact["infostore"] = 4;
-	if(window.opener)
-		var oLocalState = window.opener.optFolderState.getState('folderAddressbook_tree_info');
+	if(corewindow || window.parent)
+		var oLocalState = corewindow.optFolderState.getState('folderAddressbook_tree_info');
 	else
 		var oLocalState = new Object();	
 	if(!contactAddressbookTreeLoaded){
 	/*		
 			var LocalFolderCache = new ox_folder_cache();
-			LocalFolderCache.folders = window.opener.oMainFolderTree.cache.folders;		
-			LocalFolderCache.fast_access = window.opener.oMainFolderTree.cache.fast_access;		
-			LocalFolderCache.timestamp = window.opener.oMainFolderTree.cache.timestamp;
+			LocalFolderCache.folders = corewindow.oMainFolderTree.cache.folders;		
+			LocalFolderCache.fast_access = corewindow.oMainFolderTree.cache.fast_access;		
+			LocalFolderCache.timestamp = corewindow.oMainFolderTree.cache.timestamp;
 */
 			newAddressbookFolderTree = new cFolderTree(	$('folderAddressbook_tree_info'),
 									folderAction,
 									false,	
-									window.opener.oMainFolderTree.cache,								
+									corewindow.oMainFolderTree.cache,								
 									oLocalState);
 			newAddressbookFolderTree.enabled_modules = {contacts:true};	
 			newAddressbookFolderTree.load();
@@ -715,8 +719,8 @@ function addressbookFolderPath() {
 			contactAddressbookTreeLoaded = true;
 	}
 								
-	if(window.opener)									
-		newAddressbookFolderTree.setSaveConfiguration(window.opener.optFolderState);		
+	if(corewindow || window.parent)									
+		newAddressbookFolderTree.setSaveConfiguration(corewindow.optFolderState);		
 
 
 	newAddressbookFolderTree.cache.get_folder(clickedItem, cb_AddressbookGetpath);
