@@ -5,48 +5,57 @@ function ox_folder_cache(){
 	/* contains all folders which are stored hierarchically in storagecaches */
 	this.folders = {"root":{children:null,parent:null,oxfolder:null}};
 	var Self = this;
-	this.columns = "1,301,300,307,304,306,302,305,308,311,2,314,313,315,3010";
+	this.columns = "1,301,300,307,304,306,302,305,308,311,2,314,313,315,3010,3020";
 	this.fast_access = new Object();
 	this.timestamp = 0;
+	this.treeID = configGetKey("modules.folder.tree") || 0;
 }
 
 ox_folder_cache.prototype = {
 
 	/* load the root folders or all folder defined in oState */
 	load_folders : function (oState, join_param, bReplace) {
-		var Self = this;
-		var join_fn = join_param.add( function (arg){ join_param.arg = arg; } );
+        var Self = this;
+        this.loading = [];
+        var join = new Join(join_param.add(function() {
+            join_param.arg = this.arg;
+            var l = Self.loading;
+            Self.loading = null;
+            for (var i = 0; i < l.length; i++) l[i]();
+        }));
+        var join_fn = join.add( function (arg){ join.arg = arg; } );
 		if (Self.folders["root"].children != null && !bReplace) {
-			for (var nfldrN in Self.folders["root"].children[nfldrN]) {											
-				if(oState && oState[Self.folders["root"].children[nfldrN].oxfolder.data.id]) {
+			for (var i = 0; i < Self.folders["root"].children.length; i++) {											
+				if(oState && oState[Self.folders["root"].children[i].oxfolder.data.id]) {
 					Self.load_subfolders(
-					       Self.folders["root"].children[nfldrN].oxfolder.data.id,
-					       Self.folders["root"].children[nfldrN],
-					       oState[nfldrN], join_param, bReplace 
+					       Self.folders["root"].children[i].oxfolder.data.id,
+					       Self.folders["root"].children[i],
+					       oState[nfldrN], join, bReplace 
 				    );
 				}														
 			}		
-			join_fn(Self.folders);			
+			join_fn(Self.folders);
 		} else {
-			var locJson = new JSON();		
-			locJson.get(AjaxRoot + "/folders?action=root&columns="+this.columns
-					+ (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
-					+"&session="+session,null,
+			var locJson = new JSON();
+            var action = this.treeID == 1 ? "list&parent=1&all=1" : "root";
+            locJson.get(AjaxRoot + "/folders?action=" + action
+                + "&columns=" + this.columns + "&tree=" + this.treeID
+                + "&session=" + session, null,
                 function(arg) {		
-                    Self.folders["root"].children = {};
+                    Self.folders["root"].children = [];
                     Self.timestamp = arg.timestamp;
                     for (var nfldr=0; nfldr<arg.data.length; nfldr++) {
                         var id = arg.data[nfldr][0];
-                        var child = Self.folders.root.children[id] = {
+                        var child = Self.fast_access[id] = {
                             oxfolder: new ox_folder(arg.timestamp,
                                                     arg.data[nfldr]),
                             parent: Self.folders.root,
                             children: null
                         };
-                        Self.fast_access[child.oxfolder.data.id] = child;
+                        Self.folders.root.children.push(child);
                         if(oState && oState[id]) {
                             Self.load_subfolders(id, child, oState[id],
-                                                 join_param, bReplace);
+                                                 join, bReplace);
                         }														
                     }		
                     join_fn(Self.folders);							
@@ -74,44 +83,52 @@ ox_folder_cache.prototype = {
 		);
 	
 		if (refer.children != null && !bReplace) {
-			for (var nfldrN in refer.children) {
-				if(oState && oState[nfldrN]) {
-					Self.load_subfolders(nfldrN, refer.children[nfldrN], oState[nfldrN], join_param, bReplace);
+            for (var i = 0; i < refer.children.length; i++) {
+                var id = refer.children[i].oxfolder.data.id;
+                if(oState && oState[id]) {
+                    Self.load_subfolders(id, refer.children[i], oState[id],
+                                         join_param, bReplace);
 				}													
 			}					
 			join_fn(refer);		
 		} else {
 			var callback = (function(nId, refer, oState, join_param, bReplace, join_fn) {
 			    return function(arg) {			    	
-    	            // if children loaded before server responsed
+    	            // if children loaded before server responded
     	            if(refer.children != null && !bReplace) {
+    	                for (var i = 0; i < refer.children.length; i++) {
+    	                    var id = refer.children[i].oxfolder.data.id;
+    	                    if (oState && oState[id]) {
+    	                        Self.load_subfolders(id, refer.children[i],
+    	                            oState[id], join_param, bReplace);
+    	                    }
+    	                }
     	                join_fn(refer); 
     	                return;
     	            }
-    	            refer.children = {};
+    	            refer.children = [];
     	            if (nId == 2) Self.GALPresent = false;
     	            for (var nfldr=0; nfldr<arg.data.length; nfldr++) {
     	                var id = arg.data[nfldr][0];
     	                if (id == 6) Self.GALPresent = true;
-    	                refer.children[id] = 
+    	                var newChild =
                             { "oxfolder": new ox_folder(arg.timestamp, arg.data[nfldr]),
                               "parent"  : refer,
                               "children": null
                             };
+    	                refer.children.push(newChild);
     	                var oldrefer = null;
     	                if (refer.oxfolder.data.id == configGetKey("folder.infostore") && Self.fast_access[id] != undefined) {
-    	                	var child = Self.fast_access[id].children;
-    	                    refer.children[id] = 
-    	                        { "oxfolder": new ox_folder(arg.timestamp, arg.data[nfldr]),
-                                  "parent"  : refer, 
-                                  "children": (isEmpty(child) ? null : child) 
-                                };
+    	                	var children = Self.fast_access[id].children;
+    	                	if (children && children.length) {
+    	                	    newChild.children = children;
+    	                	}
     	                }
     	                    
-    	                Self.fast_access[refer.children[id].oxfolder.data.id] = refer.children[id]; 
+    	                Self.fast_access[id] = newChild; 
     	                if (oState && oState[id]) {
-    	                    Self.load_subfolders(id, refer.children[id],
-                                                 oState[id], join_param, bReplace);
+                            Self.load_subfolders(id, newChild, oState[id],
+                                                 join_param, bReplace);
     	                }                                                   
     	            }
     	            join_fn(refer);
@@ -121,7 +138,7 @@ ox_folder_cache.prototype = {
 			(new JSON()).get(AjaxRoot + "/folders?action=list&all=1"
 			     + "&columns=" + this.columns 
 			     + "&parent=" + getUrlEncodedString(nId) 
-			     + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
+                 + "&tree=" + this.treeID
 			     + "&session=" + session, null, callback);
 		}
 	},
@@ -147,9 +164,7 @@ ox_folder_cache.prototype = {
         var _reqParams = new Array();
         for (var i in folderIDs) {
         	var obj = { module: "folder", action: "get", id: folderIDs[i], columns: this.columns };
-        	if (configContainsKey("modules.folderstorage")) {
-        		obj["tree"]="1";
-        	}		
+        	obj.tree = this.treeID;
             _reqParams.push( obj );
         }
         locJson.put(AjaxRoot + "/multiple?session=" + session, _reqParams, null, 
@@ -173,66 +188,74 @@ ox_folder_cache.prototype = {
 		var sAjaxRequest = AjaxRoot + '/folders?action=path'		                
 		                 + '&id=' + getUrlEncodedString(nId) 
 		                 + '&columns=1,300'
-		                 + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
+		                 + "&tree=" + this.treeID
 		                 + '&session=' + session ;
 		
-		var callback = (function(nId, join_param, bNOReplace) {
-		    return function(arg) {
-		        
-    			var oState = {};
-    			var statetmp  = oState;
-    			var bFoundFolder = false;
-    			var oRefer;
-    			/*
-    			 * fixed bug, in this case is the requested folder a first level folder and it must be present
-    			 * return the path
-    			 */
-    			if (arg.data.length <= 1) {
-    				var join_fn = join_param.add(
-    			        function (arg, arg2) {
-    			            if (arg) join_param.arg = arg;
-    			            if( arg2) join_param.arg2 = arg2;
-    			        }
-    				);		
-    				join_fn(Self.fast_access[nId], arg.data);
-    				return;
-    			}
-    			join_param.arg2 = arg.data;
-    			for (var indx=(arg.data.length-1); indx>0; indx--) {
-    				//found the last loaded node and load the rest
-    				if (!bFoundFolder && Self.fast_access[arg.data[indx][0]] != undefined) {
-    					oRefer = Self.fast_access[arg.data[indx][0]];
-    				} else {
-    					if (!bFoundFolder) {
-    						nParentId = arg.data[indx][0];				
-    					}
-    					bFoundFolder = true;
-    					statetmp[arg.data[indx][0]] = {};
-    					statetmp = statetmp[arg.data[indx][0]];
-    				}
-    			}
-    			var join_fn = join_param.add(
-    			    function (arg, arg2) {
-    			    	if (arg) join_param.arg = arg;
-    			        if (arg2) join_param.arg2 = arg2;
-    			    }
-    			);				
-    			//if node not found, load complete path
-    			if (oRefer == undefined) {
-    				join_param.count--;
-    				Self.load_folders(oState, join_param, true);
-    				
-    			} else if(oRefer.children == null || oRefer.children != null && oRefer.children[nId] == undefined) {
-    				join_param.count--;			
-    				Self.load_subfolders(oRefer.oxfolder.data.id, oRefer, oState, join_param, (true && !bNOReplace));
-    				
-    			} else {
-    				join_fn(oRefer.children[nId], arg.data);
-    			}
-    		};
-		})(nId, join_param, bNOReplace);
+		var arg;
+		function callback() {
+	        if (Self.loading) {
+	            Self.loading.push(callback);
+	            return;
+	        }
+			var oState = {};
+			var statetmp  = oState;
+			var bFoundFolder = false;
+			var oRefer;
+            if (Self.treeID == 1 && arg.data[arg.data.length - 1][0] == 1) {
+			    arg.data.length--;
+			}
+			/*
+			 * fixed bug, in this case is the requested folder a first level folder and it must be present
+			 * return the path
+			 */
+			if (arg.data.length <= 1) {
+				var join_fn = join_param.add(
+			        function (arg, arg2) {
+			            if (arg) join_param.arg = arg;
+			            if( arg2) join_param.arg2 = arg2;
+			        }
+				);		
+				join_fn(Self.fast_access[nId], arg.data);
+				return;
+			}
+			join_param.arg2 = arg.data;
+			for (var indx = arg.data.length - 1; indx >= 0; indx--) {
+				//found the last loaded node and load the rest
+				if (!bFoundFolder && Self.fast_access[arg.data[indx][0]] != undefined) {
+					oRefer = Self.fast_access[arg.data[indx][0]];
+				} else {
+					if (!bFoundFolder) {
+						nParentId = arg.data[indx][0];				
+					}
+					bFoundFolder = true;
+					statetmp[arg.data[indx][0]] = {};
+					statetmp = statetmp[arg.data[indx][0]];
+				}
+			}
+			var join_fn = join_param.add(
+			    function (arg, arg2) {
+			    	if (arg) join_param.arg = arg;
+			        if (arg2) join_param.arg2 = arg2;
+			    }
+			);				
+			//if node not found, load complete path
+			if (oRefer == undefined) {
+				join_param.count--;
+				Self.load_folders(oState, join_param, !bNOReplace);
+				
+			} else if (!Self.fast_access[nId]) {
+				join_param.count--;			
+				Self.load_subfolders(oRefer.oxfolder.data.id, oRefer, oState, join_param, (true && !bNOReplace));
+				
+			} else {
+				join_fn(Self.fast_access[nId], arg.data);
+			}
+		}
 		
-		(new JSON()).get(sAjaxRequest, null, callback);
+		(new JSON()).get(sAjaxRequest, null, function(a) {
+		    arg = a;
+		    callback();
+		});
 	},
 	
 	/* updates all folders; fetches new subfolder if availible, removes deleted folder from cache */
@@ -240,9 +263,9 @@ ox_folder_cache.prototype = {
 		var Self = this;
 		var locJson = new JSON();
 		var sAjaxRequest = AjaxRoot + "/folders?action=updates"
-	            + "&columns=1,300&mail=" + (bWith_mail ? 1 : 0) 
+	            + "&columns=1,20&mail=" + (bWith_mail ? 1 : 0) 
 	            + "&timestamp=" + this.timestamp
-	            + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
+                + "&tree=" + this.treeID
 	            + "&session=" + session;
 	            		
 		function cb_fn_updates(arg){
@@ -250,61 +273,60 @@ ox_folder_cache.prototype = {
 			if (arg.data) {
 				Self.timestamp = arg.timestamp;
 						
-				//separate folder, which will be updated in cache
-				var aRootNodes = new Object();
-				function fn_traverse(refer) {
-					for (var indx in refer.children) {
-						var nFound = 0;
-						for (var indxResp=0; indxResp<arg.data.length; indxResp++) {
-							//first condition is for deleted folder identification
-							if (arg.data[indxResp][1] != undefined && arg.data[indxResp][0] == indx) {						
-								nFound = 1;
-								break;
-							} else if (arg.data[indxResp][1] == undefined && arg.data[indxResp][0] == indx) {					
-								nFound = 2;
-								break;
-							}
-						}
-						//don't traverse the subtree, if the parent of the sub tree must be updated;
-						//all subtree elements will be updated automatically
-						//->added != 10 condition to update links correcty
-						if (nFound != 0 && Self.fast_access[indx].parent.oxfolder && Self.fast_access[indx].parent.oxfolder.data.id != 10) {					
-							if (aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id] == undefined) {
-								aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id] = new Array();
-							}
-							aRootNodes[Self.fast_access[indx].parent.oxfolder.data.id].push({id:indx,type:nFound});
-							
-						} else if (nFound != 0) {					
-							if (aRootNodes[Self.fast_access[indx].oxfolder.data.id] == undefined) {
-								aRootNodes[Self.fast_access[indx].oxfolder.data.id] = new Array();
-							}
-							aRootNodes[Self.fast_access[indx].oxfolder.data.id].push({id:indx,type:nFound});
-						} else {
-							fn_traverse(refer.children[indx]);
-						}
-					}
-				}
-				fn_traverse(Self.folders["root"]);
-				if (!fn_callback_opt) {
-					fn_callback_opt = function () {};
-				}
-				var outer_join = new Join(fn_callback_opt);
-				for (var nNum in aRootNodes) {
+                if (Self.treeID == 1) {
+                    for (var i = 0; i < arg.data.length; i++) {
+                        if (arg.data[i][0] == 1 || arg.data[i][1] == 1) {
+                            Self.load_folders(
+                                Self.compute_state(Self.folders.root),
+                                new Join(function() {
+                                    Self.events.trigger("Changed",
+                                                        Self.folders.root);
+                                    if (fn_callback_opt) fn_callback_opt();
+                                }), true);
+                            return;
+                        }
+                    }
+                }
+				
+				var top = {};
+                for (var i = 0; i < arg.data.length; i++) {
+                    var id = arg.data[i][0];
+                    var parent = arg.data[i][1];
+                    if (Self.fast_access[parent]) {
+                        top[parent] = true;
+                    } else if (Self.fast_access[id]) {
+                        top[id] = true;
+                    }
+                }
+                
+                for (var i in top) {
+                    for (var p = Self.fast_access[i].parent; p; p = p.parent) {
+                        if (p.oxfolder && (p.oxfolder.data.id in top)) {
+                            top[i] = false;
+                            break;
+                        }
+                    }
+                }
+                
+				var outer_join = new Join(fn_callback_opt || emptyFunction);
+				for (var nNum in top) {
+				    if (!top[nNum]) continue;
 					var oRefer = Self.fast_access[nNum];
 					var oReferState = Self.compute_state(oRefer);
 					var fn_out_join = outer_join.add();
 		//			delete oRefer.parent.children;
-		//			oRefer.parent.children = {};			
-					function close_it(obj,aFolders,fn_out_join_close) {
+		//			oRefer.parent.children = [];			
+					function close_it(obj, fn_out_join_close) {
 						return function () {
 							Self.events.trigger("Changed",obj);
 							if (fn_out_join_close) {
 								fn_out_join_close();
 							}
-					    }
+					    };
 					}
-					Self.load_subfolders(oRefer.oxfolder.data.id, oRefer, oReferState, 
-					       new Join(close_it(oRefer, aRootNodes[nNum], fn_out_join)), true);
+                    Self.load_subfolders(oRefer.oxfolder.data.id, oRefer,
+                        oReferState, new Join(close_it(oRefer, fn_out_join)),
+                        true);
 				}
 			}
 		}
@@ -314,13 +336,13 @@ ox_folder_cache.prototype = {
 	compute_state : function (refer){
 		function fn_traverse(refer) {
 			var retval = {};
-			for (var i in refer.children) {
-				var bSubChilds = false
-				for (var j in refer.children[i].children) {
-					bSubChilds=true;				
-				}
-				if (bSubChilds) {
-				    retval[refer.children[i].oxfolder.data.id] = fn_traverse(refer.children[i]);
+			if (!refer.children) return retval;
+            for (var i = 0; i < refer.children.length; i++) {
+                if (   refer.children[i].children
+                    && refer.children[i].children.length)
+                {
+                    retval[refer.children[i].oxfolder.data.id] =
+                    fn_traverse(refer.children[i]);
 				}			
 			}
 			return retval;
@@ -333,11 +355,12 @@ ox_folder_cache.prototype = {
 		var Self = this;
 		var oFolder = null;		
 		function fn_traverse(refer) {
-			for (var indx in refer.children) {
-				if (indx != nId) {
-					fn_traverse(refer.children[indx]);				
+		    if (!refer.children) return;
+			for (var i = 0; i < refer.children.length; i++) {
+				if (refer.children[i].oxfolder.data.id != nId) {
+					fn_traverse(refer.children[i]);				
 				} else {
-					oFolder = refer.children[indx];
+					oFolder = refer.children[i];
 					return;
 				}
 			}
@@ -349,26 +372,27 @@ ox_folder_cache.prototype = {
 	/*loads a folder if not loaded*/
 	get_folder : function (nId,callback){
 		var Self = this;
-		var oFolder = null;
-		// trying fast acess cache
-		oFolder = this.fast_access[nId];
-		if (oFolder == undefined) {
-			// not found, so trying to find it in regular cache
-			oFolder = this.find_folder(nId);
-		}
+		var oFolder = this.fast_access[nId] || this.find_folder(nId);
 		//request the folder if that could not be found
 		if (oFolder == null) {		
 			this.load_path(nId, 
 			     new Join(
 				     function () {
-				    	 Self.get_folder(nId, callback);
+				         oFolder = Self.fast_access[nId] ||
+				                   Self.find_folder(nId);
+				         if (!oFolder) {
+				             triggerEvent("OX_New_Error", 4,
+				                 "Server error: wrong path for folder " + nId);
+				         } else {
+				             callback(oFolder);
+				         }
 				     }
 				 ), true);
 		} else if (callback) {	
 			callback(oFolder);
 		}
 	}
-}
+};
 
 function ox_folder(timestamp, dataArray) {
 	this.data = new Object();	
@@ -388,6 +412,7 @@ function ox_folder(timestamp, dataArray) {
 		this.data.capabilities = dataArray[12];
 		this.data.subscr_subflds = dataArray[13];
 		this.data["com.openexchange.publish.publicationFlag"] = dataArray[14];
+		this.data["com.openexchange.subscribe.subscriptionFlag"] = dataArray[15];
 	}
 	
 	this.timestamp = timestamp;
