@@ -88,8 +88,8 @@ registerView("configuration/folder/rights",
 					style: {padding: 0},
 					//using in infostore defined functions here
 					set: function  (div, text) {
-						var sImgStr = (text.groupflag)?getFullImgSrc("img/calendar/group.gif"):getFullImgSrc("img/calendar/user.gif")					
-						var sAlt = (text.groupflag)?"Group":"User"					
+						var sImgStr = (text.groupflag)?getFullImgSrc("img/calendar/group.gif"):getFullImgSrc("img/calendar/user.gif");
+						var sAlt = (text.groupflag)?"Group":"User";
 						if(div.firstChild.src)
 							div.firstChild.src = sImgStr;
 						else{
@@ -111,7 +111,7 @@ registerView("configuration/folder/rights",
 									div.firstChild.data = arg[nId].display_name;
 								else
 									div.appendChild(document.createTextNode(arg[nId].display_name));
-							}						
+							};
 						}
 						if(text.groupflag)
 						{
@@ -125,7 +125,7 @@ registerView("configuration/folder/rights",
 					clear: LiveGrid.makeClear("...")
 				}, {
 					index: 2,				
-					text: "Admin", /*i18n*/
+					text: "Folder admin", /*i18n*/
 					i18n: true,				
 					width: "7em",
 					set: function  (div, text){
@@ -136,7 +136,7 @@ registerView("configuration/folder/rights",
 					clear: LiveGrid.makeClear("...")
 				}, {
 					index: 3,	
-					text: "Folder rights", /*i18n*/
+					text: "Admin", /*i18n*/
 					i18n: true,				
 					width: "12em",
 					set: function  (div, text){
@@ -147,7 +147,7 @@ registerView("configuration/folder/rights",
 					clear: LiveGrid.makeClear("...")
 				}, {
 					index: 4,	
-					text: "Read rights", /*i18n*/
+					text: "Read objects", /*i18n*/
 					i18n: true,				
 					width: "9em",
 					set: function  (div, text){
@@ -158,7 +158,7 @@ registerView("configuration/folder/rights",
 					clear: LiveGrid.makeClear("...")
 				}, {
 					index: 5,					
-					text: "Modify rights", /*i18n*/
+					text: "Modify objects", /*i18n*/
 					i18n: true,				
 					width: "9em",
 					set: function  (div, text){
@@ -169,7 +169,7 @@ registerView("configuration/folder/rights",
 					clear: LiveGrid.makeClear("...")
 				}, {
 					index: 6,					
-					text: "Delete rights", /*i18n*/
+					text: "Delete objects", /*i18n*/
 					i18n: true,				
 					width: "9em",
 					set: function  (div, text){
@@ -255,7 +255,7 @@ function cf_cancelConfiguration() {
 	configuration_changed_fields["folder"] = false;
 }
 
-register("OX_Configuration_Switch_Folder_View", function(param) { menuswitchConfigurationFolderView(param) });
+register("OX_Configuration_Switch_Folder_View", function(param) { menuswitchConfigurationFolderView(param); });
 
 var fdpropsTabsList = new Array('tab_props1','tab_props2');
 var fdpropsPanelsList = new Array('panel_props1','panel_props2', 'panel_props3');
@@ -388,7 +388,7 @@ function removeFolderUser() {
 	//fixed bug #10380
 	oPermissionsLiveGrid.selection.reset();		
 	oPermissionsLiveGrid.focus=undefined;
-	oPermissionsLiveGrid.updateStyles()
+	oPermissionsLiveGrid.updateStyles();
 	for (var indx=0;indx<aIdToDel.length;indx++) {
 		delete aGlobalPermissions[aIdToDel[indx]];
 	}
@@ -553,8 +553,10 @@ function setPropsHeadLine(stitle, bNewFolderDia){
 		$("folder_prop_headline").appendChild(oTextNodeDOM.node);
 	} else {
 		var oTextNodeDOM = new I18nNode(function() {
-						return format(_("Folder Properties: %s"),stitle);
-				});		
+            //#. %s is the folder name.
+		    //#, c-format
+            return format(_("Folder Properties: %s"),stitle);
+        });		
 		$("folder_prop_headline").appendChild(oTextNodeDOM.node);
 	}
 }
@@ -632,7 +634,7 @@ function changeRights(sType,sRight) {
 			data[5] = oPermissions[2].string;						
 			data[6] = oPermissions[3].string;	
 			return data;								
-		}
+		};
 	}
 	oPermissionsLiveGrid.storage.localUpdate([editEntity],cb_loc_updt());
 	return bits;
@@ -709,8 +711,11 @@ function saveFolder(fn_opt) {
 				oConfigFolderTree.cache.get_folder(configparentfolder, 
 					function (oFolder) {					
 						oMainFolderTree.update(null, 
-								(oFolder.oxfolder.data.module=="mail" || String(oFolder.oxfolder.data.id).match(/^default(\d+)?/)), 
-								emptyFunction);
+                            oFolder.oxfolder.data.module=="mail" ||
+                                String(oFolder.oxfolder.data.id).match(
+                                    /^default(\d+)?/) ||
+                                configGetKey("modules.folder.tree") == 1,
+                            emptyFunction);
 					}
 				);
 			}			
@@ -727,7 +732,10 @@ function saveFolder(fn_opt) {
 					activefolder = (oFolder.oxfolder.data.module=="mail")?arg.data:configfolder;	
 					configfolder = activefolder;						
 					triggerEvent("OX_New_Info",4,_("Your settings have been saved"));						
-					oMainFolderTree.update(null, (oFolder.oxfolder.data.module=="mail"), emptyFunction);	
+					oMainFolderTree.update(null,
+					    oFolder.oxfolder.data.module=="mail" ||
+					       configGetKey("modules.folder.tree") == 1,
+					    emptyFunction);	
 				} else {				
 					oMainFolderTree.update();															
 					disableNodeActions = false;		
