@@ -38,11 +38,15 @@ register("OX_Configuration_Load_Foldertree", loadFolderTree);
 register('OX_Refresh', quickTreeUpdate);
 registerView("configuration",
 	function() {
+        $("newfolder").style.display = "none";
 		$("folder_tree").style.display="none";
 	},
 	null,
 	function() {
 		$("folder_tree").style.display="block";
+        if (configGetKey("modules.folder.tree") == 1) {
+            $("newfolder").style.display = "";
+        }
 	},
 	null
 );
@@ -65,14 +69,20 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
 		if (parentFolder) {
 			oMainFolderTree.update_sub_tree(parentFolder);			
 		}
-	}	
+	};
     register("OX_Dummy", fn_subfolder_keyHandler);
 	
-    var submenu = new PopupMenu();
+    var addRootFolder = configGetKey("modules.folder.tree") == 1;
+    if (addRootFolder) {
+        $("newfolder").style.display = "";
+        var rootMenu = new PulldownMenu($("newfolder"));
+    }
+    
+    globalContextMenus.newFolderType = new PopupMenu();
     
     var PIM = { calendar: 1, tasks: 1, contacts: 1, system: 1 };
     var mail = { mail: 1 };
-    if (configContainsKey("modules.folderstorage")) {
+    if (addRootFolder) {
     	PIM["mail"] = 1;
     	mail = PIM;
     }
@@ -94,11 +104,21 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
             this.setEnabled(   (this.getContext().type in def.when)
                             && configGetKey(key));
         };
-        submenu.addItem(item);
+        globalContextMenus.newFolderType.addItem(item);
+        if (addRootFolder) {
+            item = new MenuItem(def.name,
+                function() {
+                    createNewFolderInpl(oMainFolderTree.tree, type);
+                });
+            item.onShow = function() {
+                this.setEnabled(("system" in def.when) && configGetKey(key));
+            };
+            rootMenu.addItem(item);
+        }
     })(i);
     
     var menu = globalContextMenus.folders = new ContextMenu();
-    var new_folder = new MenuItem("New subfolder"/*i18n*/, submenu);
+    var new_folder = new MenuItem("New subfolder"/*i18n*/, globalContextMenus.newFolderType);
     new_folder.setIcon("img/folder/newfolder.gif",
                        "img/folder/newfolder_d.gif");
     menu.addItem(new_folder);
@@ -121,29 +141,33 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
     menu.addItem(link);
     
     // "Extended" (submenu)
-    extended_folder_menu = new PopupMenu();
+    globalContextMenus.extended_folder_menu = new PopupMenu();
         // Import
         var import_data = new MenuItem("Import",
     			function() { 
         			importFolderDestination = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
         			triggerEvent("OX_Switch_View","configuration/import");
         		});
-        extended_folder_menu.addItem(import_data);
+        globalContextMenus.extended_folder_menu.addItem(import_data);
         // Export (Submenu)
     	var export_submenu = new PopupMenu();
+            var export_submenu_ical = new MenuItem("iCalendar",
+                function() { exportContacts(this.getContext().data, "ICAL");
+            });
+            export_submenu.addItem(export_submenu_ical);
             var export_submenu_vcard = new MenuItem("vCard", 
-                    	function() { exportContacts(this.getContext().data, "VCARD");
-                    	});
+            	function() { exportContacts(this.getContext().data, "VCARD");
+        	});
            	export_submenu.addItem(export_submenu_vcard);
             var export_submenu_csv = new MenuItem("CSV",
-            			function() { exportContacts(this.getContext().data, "CSV");
-            		});
+    			function() { exportContacts(this.getContext().data, "CSV");
+    		});
            	export_submenu.addItem(export_submenu_csv);
         var export_contact = new MenuItem("Export", /*i18n*/
                 export_submenu);
-        extended_folder_menu.addItem(export_contact);
+        globalContextMenus.extended_folder_menu.addItem(export_contact);
     // add to menu
-    var extended = new MenuItem("Extended" /*i18n*/, extended_folder_menu);
+    var extended = new MenuItem("Extended" /*i18n*/, globalContextMenus.extended_folder_menu);
     menu.addItem(extended);
     
     // separator
@@ -215,10 +239,13 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
                     (oxfolder.own_rights & 127) >= 2 && 
                     (oxfolder.module == "calendar" || oxfolder.module == "contacts" || oxfolder.module == "tasks")
             );
-            export_contact.setEnabled(
-                    oxfolder.type != 3 && oxfolder.module == "contacts" && 
-                    !(oxfolder.module != "contacts" || oxfolder.type == 3)
-            );
+            export_contact.setEnabled(oxfolder.type != 3 &&
+                (oxfolder.module == "contacts" ||
+                 oxfolder.module == "calendar"));
+            export_submenu_ical.setVisible(oxfolder.module == "calendar");
+            export_submenu_vcard.setVisible(oxfolder.module == "contacts");
+            export_submenu_csv.setVisible(oxfolder.module == "contacts");
+            extended.autoSetEnabled();
         } else {
             new_folder.setEnabled(false);
             subscribe.setEnabled(false);
@@ -278,7 +305,7 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
 			oFolderTreeScrollDiv.scrollTop = 0;
 		}
 		else (oFolderTreeScrollDiv.scrollTop-15 < 0)
-	 	{
+		{
 			oFolderTreeScrollDiv.scrollTop = oFolderTreeScrollDiv.scrollTop - 15;
 	 	}
 		nTimeOutScrollTree = setTimeout(treeScrollUp,150);
@@ -291,7 +318,7 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
 	 	}
 		nTimeOutScrollTree = setTimeout(treeScrollDown,150);		
 	}
-	var emptyfunction = function() {}
+	var emptyfunction = function() {};
 	var callbacks = new Object();
 	callbacks["folder/1"]=emptyfunction;
 	callbacks["folder/2"]=emptyfunction;
@@ -321,27 +348,23 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
  * Execute if folder clicked
  */
 function folderAction(cacheFolder, treeNode) {
+    if (activemodule == "configuration") {
+        configuration_askforSave(performFolderAction);
+    } else {
+        performFolderAction();
+    }
+    function performFolderAction() {
+        folderActionImpl(cacheFolder, treeNode);
+    }
+}
+    
+function folderActionImpl(cacheFolder, treeNode) {
 	var OXFolder = cacheFolder.oxfolder;
 	var sameFolder = false;
 	var sModule =  OXFolder.data.module;
 	treeNode = treeNode || oMainFolderTree.nodes[oMainFolderTree.getDOMID(OXFolder.data.id)];
 	
-	if (sModule == "system" && String(OXFolder.data.id).match(/^default(\d+)?/)) {
-		// If user clicks on the root folder 'E-Mail' we directly jump to the inbox 
-		var jmp = "default" + getMailAccountIdByFolder(OXFolder.data.id);
-		oMainFolderTree.cache.do_load_subfolders(jmp, oMainFolderTree.cache.find_folder(jmp),{},
-			function(cb) { 
-				activemodule = "mail";
-				if (treeNode && !treeNode.open) treeNode.setOpen(!treeNode.open);
-		        setActiveFolder(jmp + "/INBOX", 
-	        		function() {
-		        	   triggerEvent("OX_Switch_Module", "mail");
-		        	}
-		        );
-			}
-		);
-        return;
-	} else if (onlyParentFunc(OXFolder)) {
+	if (onlyParentFunc(OXFolder)) {
 		// folder has no read permission, so we just open/close it	
 		treeNode.setOpen(!treeNode.open);
 		return;		
@@ -368,9 +391,6 @@ function contextAction(nNumber,evt,node,type) {
 			//viewProperties(node,bNew);
 			createNewFolderInpl(node,type);
 			break;
-		case 4:
-			editFolder(node.widgetId);
-			break;
 		case 3:
 			node.inpl_edit.on();		
 			break;												
@@ -397,10 +417,11 @@ function contextAction(nNumber,evt,node,type) {
 /*function to create new folders with inplace method*/
 function createNewFolderInpl(parentFolderNode,type) {
 	var parentId = parentFolderNode.id.replace(/\$link$/,"");
-	var oCacheFolder = oMainFolderTree.get_folder_by_node_id(parentId);	
+	var oCacheFolder = oMainFolderTree.get_folder_by_node_id(parentId)
+	                || { oxfolder: { data: { type: 5, id: 1 } } };	
 	function uniqueName(aChildren,sName) {
 		for (var nChild in aChildren) {			
-			var oCurrChild = oMainFolderTree.get_folder_by_node_id(parentFolderNode.children[nChild].id)			
+			var oCurrChild = oMainFolderTree.get_folder_by_node_id(parentFolderNode.children[nChild].id);
 			if(sName == oCurrChild.oxfolder.data.title)
 				return false;		
 		}
@@ -438,37 +459,38 @@ function createNewFolderInpl(parentFolderNode,type) {
 	oFolder["unread"] = null;		
     oMainFolderTree.display_folder(oCacheFolder.oxfolder.data.id, function() {
     	parentFolderNode = oMainFolderTree.nodes[parentFolderNode.id.replace(/\$link$/,"")];
-        oMainFolderTree.scroll_to(parentFolderNode);
-        oMainFolderTree.expand_node(parentFolderNode, function() {
-        	function cb_final() {
-        		// hack to get childrens of main infostore folder
-        		// instead of the my-infostore folder
-        		if (parentId.match(/^folder_tree\$60/)) {
-        			oCacheFolder = oMainFolderTree.get_folder_by_node_id(parentId);
-        		}
-                var nCounter = 1;
-                while(!uniqueName(parentFolderNode.children, oFolder['title'])) {
-                	oFolder['title'] = _("New Folder") + " " + nCounter;     
-                    nCounter++;
-                }
-                if (oCacheFolder.children == undefined) oCacheFolder.children = new Object();	                
-                oCacheFolder.children[oFolder["id"]] = { 
-                              oxfolder: { data: oFolder, ENABLED: true, timestamp: null }, 
-                              parent: parentFolderNode, children: null 
-                          };
-                          
-                oMainFolderTree.cache.fast_access[oFolder["id"]] = oCacheFolder.children[oFolder["id"]];  
-                oMainFolderTree.update_sub_tree(oCacheFolder);
-                oMainFolderTree.set_selected(oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])]);
-                oMainFolderTree.set_dashed(oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])]);
-                setTimeout(function() {
-                    oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])].inpl_edit.really_edit_check=false;
-                    oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])].inpl_edit.on();
-                }, 0);
+        if (parentFolderNode) {
+            oMainFolderTree.scroll_to(parentFolderNode);
+            oMainFolderTree.expand_node(parentFolderNode, function() {
+                if (!parentFolderNode.open) parentFolderNode.setOpen(true);
+                setTimeout(cb_final, 0);
+            })
+        } else {
+            parentFolderNode = oMainFolderTree.tree;
+            cb_final();
+        }
+    	function cb_final() {
+            var nCounter = 1;
+            while(!uniqueName(parentFolderNode.children, oFolder['title'])) {
+            	oFolder['title'] = _("New Folder") + " " + nCounter;     
+                nCounter++;
             }
-            if (!parentFolderNode.open) parentFolderNode.setOpen(true);
-            setTimeout(cb_final, 0);
-        });
+            if (oCacheFolder.children == undefined) oCacheFolder.children = [];	                
+            var newfolder = { 
+                oxfolder: { data: oFolder, ENABLED: true, timestamp: null }, 
+                parent: parentFolderNode, children: null 
+            };
+            oCacheFolder.children.push(newfolder);
+                      
+            oMainFolderTree.cache.fast_access[oFolder["id"]] = newfolder;  
+            oMainFolderTree.load_view(oCacheFolder, parentFolderNode, true);
+            oMainFolderTree.set_selected(oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])]);
+            oMainFolderTree.set_dashed(oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])]);
+            setTimeout(function() {
+                oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])].inpl_edit.really_edit_check=false;
+                oMainFolderTree.nodes[oMainFolderTree.getDOMID(oFolder["id"])].inpl_edit.on();
+            }, 0);
+        }
     });	
 }
 
@@ -540,7 +562,7 @@ function emptyFolder(node) {
 		var id;
 		var folderobject;
 		function cbcache(myid) {
-			folderobject=myid
+			folderobject=myid;
 			newFolderJson.put(AjaxRoot + "/mail?action=clear&session="+session, [id],null,
 			function(cb){
 				if (cb.data.length) { }
@@ -556,11 +578,6 @@ function emptyFolder(node) {
 	newConfirm(_("Empty folder"),_(text),AlertPopup.YESNO,null,null,cbok,null,null);
 }
 
-function editFolder(node) {
-	propertiesPopUp = newWindow("editProps.html", getWindowOptions());
-	propertiesPopUp.focus();
-}
-
 var oChangedParentFolder = null;
 function viewProperties(node,bNew) {		
 	var oCacheFolder = oMainFolderTree.get_folder_by_node_id(node.id);
@@ -579,7 +596,7 @@ function viewProperties(node,bNew) {
 		if (bRightsSupported) {
 			openNewDialog(function (bY) {openJumpToNewForm(oCacheFolder,bY,true);}, oCacheFolder);
 		} else {
-			openJumpToNewForm(oCacheFolder,false,true)
+			openJumpToNewForm(oCacheFolder,false,true);
 		}
 	} else {
 		fn_actionFolder(oCacheFolder);
@@ -596,26 +613,29 @@ function renameFolder(sId,oFolder) {
             removeVirtualFolder(virtualFolderId);			
 			if (!arg.error) {				
 				// redraw view and, if possible, scroll to new position
-                oMainFolderTree.update(null, (oCacheFolder.oxfolder.data.module=="mail"), function() {
-				    if (arg.data) {				    	
-				    	oMainFolderTree.display_folder(arg.data, function() {				    		
-				    		if (activefolder && sId && sId == activefolder) {
-	                            oMainFolderTree.scroll_to(
-	                                oMainFolderTree.nodes[oMainFolderTree.getDOMID(arg.data)]
-	                            );	                           
-	                            setActiveFolder(arg.data, null, true);
-	                            folderAction(oMainFolderTree.cache.fast_access[arg.data]);
-				    		}
-				    	});
-				    }
-				});
+                oMainFolderTree.update(null,
+                    oCacheFolder.oxfolder.data.module == "mail" ||
+                        configGetKey("modules.folder.tree") == 1,
+                    function() {
+                        if (!arg.data) return;
+                        oMainFolderTree.display_folder(arg.data, function() {				    		
+                            if (activefolder && sId && sId == activefolder) {
+                                oMainFolderTree.scroll_to(oMainFolderTree.nodes[
+                                    oMainFolderTree.getDOMID(arg.data)]);	                           
+                                setActiveFolder(arg.data, null, true);
+                                folderAction(oMainFolderTree.cache.fast_access[
+                                    arg.data]);
+                            }
+                        });
+                    });
 			}
 		}
 		if (oCacheFolder != undefined) {
 			// if it's the virtual folder node we do have to fire-up a new call 
 			// instead of an update
-		    if (sId && sId == virtualFolderId) {		    	
-		    	var parentId = oMainFolderTree.get_folder_by_node_id(oCacheFolder.parent.id.replace(/\$link$/,"")).oxfolder.data.id;
+		    if (sId && sId == virtualFolderId) {
+		        var parentNode = oMainFolderTree.get_folder_by_node_id(oCacheFolder.parent.id.replace(/\$link$/,""));
+		    	var parentId = parentNode ? parentNode.oxfolder.data.id : 1;
 		    	// prepare folder object for the new request
 		    	var nFolder = clone(oCacheFolder.oxfolder.data);
 		    	nFolder.title = oFolder.title;
@@ -645,7 +665,10 @@ function removeFolder(folderId, optional_fn) {
 			function cb_remove_fd(arg) {
 				if (!arg.error) {
 					oMainFolderTree.delete_node(folderId); // manually remove anything before updating!
-	                oMainFolderTree.update(null, (oCacheFolder.oxfolder.data.module=="mail"), function() {
+	                oMainFolderTree.update(null,
+                        oCacheFolder.oxfolder.data.module == "mail" ||
+                            configGetKey("modules.folder.tree") == 1,
+                        function() {
 	                	var parentFolder = oCacheFolder.parent.id ? 
                                 oMainFolderTree.get_folder_by_node_id(oCacheFolder.parent.id) : 
                                 oCacheFolder.parent;
