@@ -17,7 +17,7 @@ var taskobject = new Object();
 var json = new JSON();
 var activefolder;
 var taskDetailId = 0;
-var lastTimestamp = (window.opener.taskTimestamp > 0) ? window.opener.taskTimestamp : 1;
+var lastTimestamp = (corewindow.taskTimestamp > 0) ? corewindow.taskTimestamp : 1;
 var modulPopup = "new";
 var c = 0;
 var bCreated = false;
@@ -29,35 +29,20 @@ var gridatt;
 var taskTreeLoaded = false;
 var session;
 var config;
-var configContainsKey = window.opener.configContainsKey;
-var configGetKey = window.opener.configGetKey;
-var configSetKey = window.opener.configSetKey;	
+var configContainsKey = corewindow.configContainsKey;
+var configGetKey = corewindow.configGetKey;
+var configSetKey = corewindow.configSetKey;	
 var internalCache;
 var newFolderName = "";
 var treeVisible = false;
 var miniStartVisible = false;
 var miniEndVisible = false;
 var miniReminderVisible = false;
-var bAttachmentGridCreated = false;
-var bParticipantGridCreated = false;
-var treeLoaded = false;
-var tmp_attachment;
-var tmp_participant;
-var newTaskFolderTree;
-var miniRemindVisible = false;
-var taskCategories = false;
-var allOk = 0;
-var checkTaskNumberFormat = 0;
-var taskCloseBit = false;
-var savePending = false;
-var globalseries;
-var externalParticipants = null; 
-register("Loaded",function () {		
-	globalseries=new SeriesView();
-	globalseries.initView();
-	addOnClose($('series_window'),function () { globalseries.hideView() });
-});
-register ("OX_Timestamp_Changed_By_Attach",fn_changeTimstamp);
+var bAttachmentGridCreated = false, bParticipantGridCreated = false, treeLoaded = false;
+var tmp_attachment, tmp_participant, newTaskFolderTree;
+var miniRemindVisible = false, task_categories = "", allOk = 0;
+var checkTaskNumberFormat = 0, taskCloseBit = false, savePending = false;
+var globalseries, externalParticipants = null, externalCounter = 0;
 
 function initNewTaskLoaded() {
 	var themeStyle = corewindow.oxThemeStyle || { name: "Default", path: "default" };
@@ -65,25 +50,25 @@ function initNewTaskLoaded() {
 	loadCSSFileForNewWindow("themes/"+themeStyle.path+"/css/popup.css");
 }
 
-function fn_changeTimstamp(newTStamp)
-{
+function fn_changeTimstamp(newTStamp) {
 	lastTimestamp = newTStamp;
 }
 
-function setNumberOfAttNewTask(nCountParam)
-{
+function setNumberOfAttNewTask(nCountParam) {
 	$("tasks_number_of_attachments").firstChild.data = nCountParam;
 }
 
+register("Loaded", function () {
+	globalseries = new SeriesView();
+	globalseries.initView();
+	addOnClose($('series_window'), function () { 
+		globalseries.hideView(); 
+	});
+	newTaskOnload();
+});
 
-register("Loaded",newTaskOnload);
-
-registerView("task_new",
-	null,
-	null, 
-	null,
-	null
-);
+register("OX_Timestamp_Changed_By_Attach", fn_changeTimstamp);
+registerView("task_new", null, null, null, null);
 
 registerView("task_new/task",
 	function() { 
@@ -92,10 +77,8 @@ registerView("task_new/task",
 	},
 	function () {
 		try {
-			setTimeout(function() {	$("title").focus();	},0);
-		} catch (e) {
-			
-		}		
+			setTimeout(function() {	$("title").focus();	}, 0);
+		} catch (e) { }		
 	}, 
 	null,
 	function() {
@@ -104,19 +87,18 @@ registerView("task_new/task",
 	},
 	function () {
 		try {
-			setTimeout(function() {	$("title").focus();	},0);
-		} catch (e) {
-			
-		}
+			setTimeout(function() {	$("title").focus();	}, 0);
+		} catch (e) { }
 	}
 );
+
 registerView("task_new/detail",
 	function() { 
 		$("tab2").style.display="block";
 		$("panel2").className="tabPanelHi tabPanelHiColor background-color-content font-style-lable border-color-content-default";	
 	},
 	function () {
-		setTimeout(function() {	$("target_duration").focus();	},0);
+		setTimeout(function() {	$("target_duration").focus(); }, 0);
 	}, 
 	null,
 	function() {
@@ -124,48 +106,45 @@ registerView("task_new/detail",
 		$("panel2").className="tabPanel tabPanelColors font-color-disabled background-color-additional-content border-color-design font-weight-default";		
 	},
 	function () {
-		setTimeout(function() {	$("target_duration").focus();	},0);
+		setTimeout(function() {	$("target_duration").focus(); }, 0);
 	}
 );
+
 registerView("task_new/participant",
 	function() { 
 		$("tab3").style.display="block";
 		$("panel3").className="tabPanelHi tabPanelHiColor background-color-content font-style-lable border-color-content-default";	
 	},
 	function() {
-		if(!bParticipantGridCreated)
-		{
-			var nId = (url['modul'] && url['modul'] == "edit")?url["id"]:false;
-		/*	if (url['modul'] && url['modul'] == "edit") {
-				tmp_participant.initalFillBigGrid(taskobject);
-			} */
+		if (!bParticipantGridCreated) {
+			var nId = url.id || false;
 			bParticipantGridCreated = true;
 			tmp_participant.getParticipants();
 			tmp_participant.enableTheGrid();
-		}
-		else {
+		} else {
 			tmp_participant.enableTheGrid();
 		}
 		/* external participants */
 		if (externalParticipants == null) {
-            function on_ok(data) {
+            function on_ok(parts) {
                 if (!bParticipantGridCreated || !tmp_participant.participantsGridBig) {
                     return;
                 }                
                 var extStorage = tmp_participant.participantsGridBig.storage;
-                for (var i in data) {
+                for (var i in parts) {
                     var found = new Array();
                     for (var j in extStorage.data.data) {
-                        if (extStorage.data.data[j][5] === data[i].email) {
-                            found.push(data[i].email);                          
+                        if (extStorage.data.data[j][5] === parts[i].email) {
+                            found.push(parts[i].email);                          
                         }
                     }
                     if (found.length) {
+                        //#, c-format
                         newAlert(_("Info"), format(_("The following addresses are already on the list of participants and therefore not been added: %s"), found.join(",")));
                     } else {
                         extStorage.append(
-                            [[ "contact_ext_" + new Date().getTime(), 0, 
-                               data[i].displayName, _("not sent"), "", data[i].email, 
+                            [[ "contact_ext_" + externalCounter++, 0, 
+                               parts[i].displayName, _("not sent"), "", parts[i].email, 
                                "contact", null ]]
                         );
                     }
@@ -180,15 +159,14 @@ registerView("task_new/participant",
 			if (tmp_participant.getParticipants().length > 0) {
 				ce();
 			}
-		} catch (e) {
-			//TODO: throw an error
-		}
+		} catch (e) { }
 	},
 	function() {
-		$("tab3").style.display="none";
-		$("panel3").className="tabPanel tabPanelColors font-color-disabled background-color-additional-content border-color-design font-weight-default";		
+		$("tab3").style.display = "none";
+		$("panel3").className = "tabPanel tabPanelColors font-color-disabled background-color-additional-content border-color-design font-weight-default";		
 	}
 );
+
 registerView("task_new/attachment",
 	function() { 
 		$("tab4").style.display="block";
@@ -219,24 +197,24 @@ registerView("task_new/attachment",
 );
 
 function initAttachmentsGrid() {
-	var nId = (url['modul'] && url['modul'] == "edit")?url["id"]:false;
-	var nFolder = url['folder'];
-	tmp_attachment = new attachmentGrid("attachmentsNewTaskGrid",nId,nFolder,4,tmp_attachmentDialog);	
+	tmp_attachment = new attachmentGrid("attachmentsNewTaskGrid", (url.id || false), 
+			(url.folder || corewindow.configGetKey("folder.tasks")), 
+			4, tmp_attachmentDialog);	
 }
 
 function initParticipantsGrid() {
-	var nId = (url['modul'] && url['modul'] == "edit")?url["id"]:false;
-	if (url['modul'] && url['modul'] == "edit") {
+	var nId = url.id || false;
+	if (nId == false) {
 		tmp_participant = new Participants("participantsNewTask",
 							function(cb){
-							$("partCounterTasksNew").firstChild.data = 
-							tmp_participant.getParticipants().length;
+								$("partCounterTasksNew").firstChild.data = 
+								tmp_participant.getParticipants().length;
 							}, true, true, false, true, "Select Participants", /*i18n*/
 							false); /*i18n*/
 	} else {
 		tmp_participant = new Participants("participantsNewTask", function(cb){
-							$("partCounterTasksNew").firstChild.data = 
-							tmp_participant.getParticipants().length;
+								$("partCounterTasksNew").firstChild.data = 
+								tmp_participant.getParticipants().length;
 							}, true, true, false, true, "Select Participants", /*i18n*/
 							false); 
 	}
@@ -254,12 +232,19 @@ function setBeforeUnload(on){
 
 function newTaskOnload() {
 	loadingComplete();
-	session = window.opener.session;
-	config = window.opener.config;
-	internalCache = window.opener.internalCache;
-	check0GroupDisplayName = window.opener.check0GroupDisplayName;
+	
+	// extend url object
+	url = jQuery.extend((url || {}), ox.api.window.getData(url.guid));
+	
+	// fixed extended fu.ck3l, don't use german vars
+	url.module = url.modul || "new";
+	
+	session = corewindow.session;
+	config = corewindow.config;
+	internalCache = corewindow.internalCache;
+	check0GroupDisplayName = corewindow.check0GroupDisplayName;
 	initParticipantsGrid();
-	activefolder = url["folder"];
+	activefolder = url.folder || corewindow.configGetKey("folder.tasks");
 	
 	var btnClose = $("hider");
 	register("OX_SAVE_OBJECT", saveTask);
@@ -268,21 +253,18 @@ function newTaskOnload() {
 	register("doneModifyEvent", function(param) {
 		doneModifyDown(param);
 	});
-	internalCache = window.opener.internalCache;
+	internalCache = corewindow.internalCache;
 
 	setTabLists(tabsList, panelsList, eventList);
-	createMiniCalendar();
-	if(window.location.hash != "") {
-		setModulPopup();	
-	}
-	$("taskSequence").value =globalseries.getSeriesString();
-	function callMeOnOK(parameter)
-	{
+	function callMeOnOK(parameter) {
 		tmp_attachment.updateGrid(parameter);
 	}
 	tmp_attachmentDialog = new attachmentDialog(0,callMeOnOK); 
 	triggerEvent("OX_Switch_View",'task_new/task');
 	fillSelectBoxes();
+	createMiniCalendar();
+	setModulPopup();
+	$("taskSequence").value = globalseries.getSeriesString();
 	setBeforeUnload(taskCloseBit);
 	register("OX_Series_Data_Init",function() {
 		$("taskSequence").value=globalseries.getSeriesString();
@@ -309,54 +291,71 @@ function newTaskOnload() {
 		$("newtask_ends_date").value=formatDate(tmpend,"date");	
 	});
 	
+	initTaskCategories();
 	initParticipantContent();
 	triggerEvent("OX_menu_Change_Height",true);
-	taskobject.categories = new Categories(
-		window.opener.configGetKey("global_categories"),
-		window.opener.configGetKey("gui.private_categories"),
-		"newtask_categories_div",
-		document.forms.newTaskCat.categories,
-		"newtask_categories_button",
-		"newtask_categories_divContent");
-	taskobject.categories.getHTML();
+	
 	initTaskTree();
 }
 
+function initTaskCategories() {
+	// add click on categories button
+	addDOMEvent($("newtask_categories_button"), "click", function(e) {
+		openTaskCategoriesDialog();
+	});
+	
+	// handle dbl click which attachs an inplace input field to div
+	addDOMEvent($("newtask_categories_list"), "dblclick", function(e) {
+		ox.categories.ui.attachInplaceInput($("newtask_categories_list"),
+			function(value) {				
+				// handle value
+				var list = clone(ox.categories.getByString(task_categories, ox.categories.match.ALL, true));
+				// add only if not empty!
+				if (value && trimStr(value).length && !ox.categories.utils.existsInObject(trimStr(value), list)) {
+					var category = { name: value, color: 0 };
+					list.push(category);
+					task_categories = ox.categories.utils.paramToString(list, "name");				
+				}
+				ox.categories.ui.drawCategoriesList(
+						ox.categories.getByString(task_categories), 
+						$("newtask_categories_list"));
+			}
+		);		
+	});		
+}
+
+function openTaskCategoriesDialog() {
+	ox.categories.ui.open((task_categories || ""), function(list, str) {
+		task_categories = str;
+		ox.categories.ui.drawCategoriesList(ox.categories.getByString(task_categories), 
+				$("newtask_categories_list"));
+	});
+}
+
 function setModulPopup() {
-	if(url["modul"]) {
-		switch(url["modul"]) {
-			case "edit":
-				modulPopup = "edit";
-				break;
-			case "duplicate":
-				modulPopup = "duplicate";
-				break;
-		}
-	}
-	if(url['id']) 
-		taskDetailId = url['id'];
-	if(url['folder']) 		
-		activefolder = url['folder'];
-	if(url['session'])
-		session = url['session'];
-	if(url['currentView'])
-		currentView = url['currentView'];
+	modulPopup = url.module || "new";
+	taskDetailId = url.id;
+	activefolder = url.folder;
+	session = url.session;
+	currentView = url.currentView;
+		
 	if (modulPopup != "new") {
-		fillTaskFields();
+		fillTaskFieldsById(taskDetailId);
 	} else {
+		fillTaskFields(url);
 		// disable loading screen
         $("loading_data_bg").style.display="none";
 	}
 }
 
 function initNewTask() {
-	activemodule="task_new";
+	activemodule = "task_new";
 	initContents(activemodule);
 	initAll();
 	window.setTimeout(function() {
 		initNewTaskLoaded();
-	},0);
-	document.title = (url["modul"]) ? _("Change Task") : _("New Task");
+	}, 0);
+	document.title = (url.module == "new") ? _("New Task") : _("Change Task");
 }
 
 function nt_ends_date_changed() {
@@ -404,66 +403,25 @@ function nt_remind_hour_changed() {
 	}
 }
 
-function fillTaskFields() {
+function fillTaskFieldsById(id) {
 	var duration_type_sel = 0;
 	var ta = $("newTaskForm");
 	var sf = document.sequenceForm;
-	json.get(AjaxRoot + "/tasks?action=get&folder=" + activefolder + "&session=" + session + "&id=" + taskDetailId, null, 
+	json.get(AjaxRoot + "/tasks?action=get&folder=" + activefolder + "&session=" + session + "&id=" + id, null, 
 		function(reply) {
 			if (reply) {
-				taskobject=reply.data;
 				if (reply.error) {
 					newServerError(reply);
 				} else {
-					if (taskobject.title) $("title").value = taskobject.title;
-					if (taskobject.color_label) $("color_label").value = taskobject.color_label;
-					if (taskobject.status) comboStatusTask.setKey(parseInt(taskobject.status) - 1);
-					if (taskobject.start_date) {
-						var mydatestart=new Date(taskobject.start_date);
-						$("newtask_begins_date").value=formatDate(taskobject.start_date,"date");
-						nt_begins_date_changed();
-					}
-					if (taskobject.end_date) {
-						var mydateend=new Date(taskobject.end_date);
-						$("newtask_ends_date").value=formatDate(taskobject.end_date,"date");
-						nt_ends_date_changed();
-					}
-					
-					if(taskobject.private_flag && taskobject.private_flag == true) {
-						$("newtask_personal").checked = "checked";					
-					}
-					if (taskobject.participants != [] && modulPopup != "duplicate") $("partCounterTasksNew").firstChild.data = taskobject.participants.length;
-					if (taskobject.priority) comboPriorityTask.setKey(parseInt(taskobject.priority) - 1);
-					if (taskobject.percent_completed) $("percent_completed").value = taskobject.percent_completed;
-					if (taskobject.alarm) {
-						$("newtask_reminder_date").value = formatDate(new Date(taskobject.alarm),"date");
-						$("newtask_reminder_hour").value = formatDate(new Date(taskobject.alarm),"time");
-					}
-					if (taskobject.note) $("note").value = taskobject.note;
-					if (taskobject.categories) $("categories").value = taskobject.categories;
-					if (taskobject.actual_duration) $("actual_duration").value = taskobject.actual_duration;
-					if (taskobject.target_duration) $("target_duration").value = taskobject.target_duration;
-
-					if (taskobject.currency) comboCostsTask.setKey(taskobject.currency);
-					if (taskobject.target_costs) $("target_costs").value = round(taskobject.target_costs);
-					if (taskobject.actual_costs) $("actual_costs").value = round(taskobject.actual_costs);
-					if (taskobject.billing_information) $("billing_information").value = taskobject.billing_information;
-					if (taskobject.companies) $("companies").value = taskobject.companies;
-					if(taskobject.number_of_attachments != undefined){
-						if(modulPopup == "duplicate") 
-							setNumberOfAttNewTask(0);
-						else
-							setNumberOfAttNewTask(taskobject.number_of_attachments);
-						
-					}								
-					globalseries.setParameters(taskobject);
-					$("taskSequence").value=globalseries.getSeriesString();
-					if (taskobject.trip_meter) $("trip_meter").value = taskobject.trip_meter;
 					lastTimestamp = reply.timestamp;
-					if (url['modul'] && url['modul'] == "edit") {
-						tmp_participant.initalFillBigGrid(taskobject);
+					taskobject = reply.data;
+					if (url.module == "edit") {
+						tmp_participant.initalFillBigGrid(reply.data);
+					} else if (url.module == "duplicate") {
+						taskobject.number_of_attachments = 0;
+						taskobject.participants = [];
 					}
-					
+					fillTaskFields(taskobject);
 				}
 			} else {
 				triggerEvent("OX_New_Error", 4, _("No server connection"));
@@ -474,15 +432,65 @@ function fillTaskFields() {
 	);
 }
 
+function fillTaskFields(taskobject) {
+	if (taskobject.title) $("title").value = taskobject.title;
+	if (taskobject.color_label) $("color_label").value = taskobject.color_label;
+	if (taskobject.status) comboStatusTask.setKey(parseInt(taskobject.status) - 1);
+	if (taskobject.start_date) {
+		var mydatestart=new Date(taskobject.start_date);
+		$("newtask_begins_date").value=formatDate(taskobject.start_date,"date");
+		nt_begins_date_changed();
+	}
+	if (taskobject.end_date) {
+		var mydateend=new Date(taskobject.end_date);
+		$("newtask_ends_date").value=formatDate(taskobject.end_date,"date");
+		nt_ends_date_changed();
+	}
+	
+	if(taskobject.private_flag && taskobject.private_flag == true) {
+		$("newtask_personal").checked = "checked";					
+	}
+	if (taskobject.participants && taskobject.participants.length) $("partCounterTasksNew").firstChild.data = taskobject.participants.length;
+	if (taskobject.priority) comboPriorityTask.setKey(parseInt(taskobject.priority) - 1);
+	if (taskobject.percent_completed) $("percent_completed").value = taskobject.percent_completed;
+	if (taskobject.alarm) {
+		$("newtask_reminder_date").value = formatDate(new Date(taskobject.alarm),"date");
+		$("newtask_reminder_hour").value = formatDate(new Date(taskobject.alarm),"time");
+	}
+	if (taskobject.note) $("note").value = taskobject.note;
+	if (taskobject.categories) {
+		task_categories = taskobject.categories;
+		// draw list
+		if ($("newtask_categories_list")) {
+			ox.categories.ui.drawCategoriesList(ox.categories.getByString(task_categories), 
+					$("newtask_categories_list"));
+		}
+	}	
+	if (taskobject.actual_duration) $("actual_duration").value = taskobject.actual_duration;
+	if (taskobject.target_duration) $("target_duration").value = taskobject.target_duration;
+
+	if (taskobject.currency) comboCostsTask.setKey(taskobject.currency);					
+	if (taskobject.target_costs) $("target_costs").value = round(taskobject.target_costs);
+	if (taskobject.actual_costs) $("actual_costs").value = round(taskobject.actual_costs);
+	if (taskobject.billing_information) $("billing_information").value = taskobject.billing_information;
+	if (taskobject.companies) $("companies").value = taskobject.companies;
+	if (taskobject.number_of_attachments){
+		setNumberOfAttNewTask(taskobject.number_of_attachments);
+	}								
+	globalseries.setParameters(taskobject);
+	$("taskSequence").value = globalseries.getSeriesString();
+	if (taskobject.trip_meter) $("trip_meter").value = taskobject.trip_meter;
+}
+
 function canselProcessTaskWindow() {
 	function cbyes() {
 		window.onbeforeunload=null;
-		window.close();			
+		ox.api.window.close(url.guid);
 	}
 	if(taskCloseBit)
 		newConfirm(_("Close Window"),_(messageCloseWindow),AlertPopup.YESNO,null,null,cbyes,null);		
 	else
-		cbyes()
+		cbyes();
 }
 
 function closeTaskWindow() {	
@@ -490,7 +498,7 @@ function closeTaskWindow() {
 	setBeforeUnload(taskCloseBit);
 	window.setTimeout(
 		function() {
-			window.close()
+		    ox.api.window.close(url.guid);
 		},50
 	);
 }
@@ -535,6 +543,8 @@ function readTaskFields() {
 	
 	var tmpval = trimStr($("target_costs").value);
 	if (tmpval.length != 0 && tmpval > 130000 || tmpval < -130000) {
+	    //#. %s is a field name (estimated costs or current costs).
+	    //#, c-format
 		error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -130000 to 130000."), _("estimated costs"));
 		allOk = 4;
 	} else if (tmpval != taskobject.target_costs || taskobject.target_costs != ta_object.target_costs) {
@@ -542,6 +552,8 @@ function readTaskFields() {
 	}
 	var tmpval = trimStr($("actual_costs").value);
     if (tmpval.length != 0 && tmpval > 130000 || tmpval < -130000) {
+        //#. %s is a field name (estimated costs or current costs).
+        //#, c-format
         error_msg = format(_("The entered value for %s is not within the allowed range. Please use a value from -130000 to 130000."), _("current costs"));
         allOk = 4;
     } else if (tmpval != taskobject.actual_costs || taskobject.actual_costs != ta_object.actual_costs) {
@@ -615,6 +627,10 @@ function readTaskFields() {
 	if ($("target_costs").value || $("actual_costs").value) {
 		ta_object.currency = comboCostsTask.getKey();
 	}
+	
+	if (typeof(task_categories) != 'undefined') {
+		ta_object.categories = task_categories;
+	}
 		
 	if ($("newtask_reminder_date").value) {
 		var ta1 = 0;
@@ -633,6 +649,8 @@ function readTaskFields() {
 			}
 		}
 		ta_object.alarm = ta1.getTime() + ta2.getTime();
+	} else if (taskobject.alarm) {
+		ta_object.alarm = null;
 	}
 	
 	if (comboPriorityTask.getKey()) {
@@ -699,7 +717,8 @@ function updateTask() {
 							closeTaskWindow();
 						}
 					}
-					corewindow.OXTaskMapping.editObjects([oldObject],newObject);
+					corewindow.OXTaskMapping.editObjects([oldObject],
+					    corewindow.clone(newObject));
 					if (tmp_attachmentDialog.attach_changed()) {
 						corewindow.triggerEvent("OX_Quota_Update");
 					}
@@ -834,7 +853,7 @@ function reselectView() {
 		}
 	}
 }
-register("OX_Task_New_Switch",function(param) { menuswitchTaskNew(param) });
+register("OX_Task_New_Switch",function(param) { menuswitchTaskNew(param); });
 var tabsList = new Array('tab1','tab2', 'tab3', 'tab4');
 var panelsList = new Array('panel1','panel2', 'panel3', 'panel4');
 var eventList = new Array(
@@ -875,8 +894,8 @@ function fillSelectBoxes() {
 	comboRemindTask=new ComboBox3(window,"remindmeSelectBox","8em",16,true,"changeRemindTime",4);
 	register("changeRemindTime", changeRemindTimeFunction);
 	iv=60;
-	if(window.opener.configContainsKey("gui.tasks.interval")) {
-		iv = window.opener.configGetKey("gui.tasks.interval");
+	if(corewindow.configContainsKey("gui.tasks.interval")) {
+		iv = corewindow.configGetKey("gui.tasks.interval");
 	}
 	interv = 60 / iv;
 	for (var i = 0; i < 24; i++) {
@@ -1193,7 +1212,7 @@ function toggleTreeTasks(){
 }
 
 function initTaskTree() {		
-	window.opener.oMainFolderTree.get_folder_path(url["folder"],
+	corewindow.oMainFolderTree.get_folder_path(url.folder,
 				function (sPath) {document.getElementsByName('newtask_folder')[0].value = sPath;} );
 	var folderViewSettingsNewTask = new Object();
 	//Disable Email... 
@@ -1203,13 +1222,13 @@ function initTaskTree() {
 		newTaskFolderTree = new cFolderTree($('folder_tree_tasks'),
 										folderTasksAction,
 										false,
-										window.opener.oMainFolderTree.cache,
-										window.opener.optFolderState.getState('folder_tree_tasks'));
+										corewindow.oMainFolderTree.cache,
+										corewindow.optFolderState.getState('folder_tree_tasks'));
 		newTaskFolderTree.enabled_modules = {tasks:true};					
 
 		treeLoaded = true;
 	}							
-	newTaskFolderTree.setSaveConfiguration(window.opener.optFolderState);			
+	newTaskFolderTree.setSaveConfiguration(corewindow.optFolderState);			
 }
 
 function folderTasksAction(ofolder) {
