@@ -58,7 +58,7 @@ function() {
     register("Loaded",init_Tasks);
     
     register("OX_Tasks_Switch_Split_Detail",function(param) { 
-        menuswitchTaskDetail(param) 
+        menuswitchTaskDetail(param);
     });
     
     function init_Tasks() {
@@ -200,7 +200,7 @@ function() {
                 unregister("OX_Task_MarkAsDone", tasks_markAsDone);
              },
              function() {
-                latestRenderedTask = null
+                latestRenderedTask = null;
                 hideNode("taskssplit");  
                 $("taskssplit").style.display="none";
              },
@@ -283,7 +283,7 @@ function() {
         latestRenderedTask = currentTask;
         // now process selection
         if (!tasksSelection2.getSelected().length) return;
-        tasks_setFocus(gridsplit)         
+        tasks_setFocus(gridsplit);         
         fn_tasks_getDetails(tasksSelection2.getSelected());        
     }
     
@@ -313,7 +313,7 @@ function() {
     function taskSearch(module, pattern) {
         if (module != "tasks") { return ; }
         var criteria= { "folder_id" : activefolder };
-        var search= { "note" : "*"+pattern+"*" , "title" : "*"+pattern+"*", "categories" : "*"+pattern+"*" }
+        var search= { "note" : "*"+pattern+"*" , "title" : "*"+pattern+"*", "categories" : "*"+pattern+"*" };
         if (currentpath2[1] == "split") {
           gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
           gridsplit.enable(criteria,search,false);
@@ -787,7 +787,7 @@ function() {
         
         grid.events.register("Delete", function() {
                 if(menucheckRight("DELETE"))
-                    deleteTask()
+                    deleteTask();
                 else
                     triggerEvent("OX_New_Error", 4, _("You do not have write permission for this object."));
             }       
@@ -812,13 +812,21 @@ function() {
             activeTaskId = id = gridsplit.getSelectedIDs();
         }
         if (activeTaskId.length == 1) {
-            editTask = newWindow("newTask.html#modul=edit&id=" 
-                + activeTaskId[0].id 
-                + "&session=" 
-                + session 
-                + "&folder=" 
-                + activeTaskId[0].folder_id, getWindowOptions(), activeTaskId[0]);
-            if (editTask) editTask.focus();
+            // edit task
+            ox.api.task.edit({
+                params: {
+                    id: activeTaskId[0].id,
+                    folder: activeTaskId[0].folder_id
+                },
+                id: activeTaskId[0]
+            });
+//            editTask = newWindow("newTask.html#modul=edit&id=" 
+//                + activeTaskId[0].id 
+//                + "&session=" 
+//                + session 
+//                + "&folder=" 
+//                + activeTaskId[0].folder_id, getWindowOptions(), activeTaskId[0]);
+//            if (editTask) editTask.focus();
         }
     }
     
@@ -828,23 +836,37 @@ function() {
             triggerEvent("OX_New_Error", 4, _("Please select at least one task!"));
         }
         if (id.length == 1) {
-            duplicatetask = newWindow("newTask.html#modul=duplicate&id=" 
-                + activeTaskId[0].id 
-                + "&session=" 
-                + session 
-                + "&folder=" 
-                + activeTaskId[0].folder_id, getWindowOptions());
-            if (duplicatetask) duplicatetask.focus();
+            // duplicate task
+            ox.api.task.duplicate({
+                params: {
+                    id: activeTaskId[0].id,
+                    folder: activeTaskId[0].folder_id
+                }
+            });
+//            duplicatetask = newWindow("newTask.html#modul=duplicate&id=" 
+//                + activeTaskId[0].id 
+//                + "&session=" 
+//                + session 
+//                + "&folder=" 
+//                + activeTaskId[0].folder_id, getWindowOptions());
+//            if (duplicatetask) duplicatetask.focus();
         }
     }
     register("OX_Create_Object",createNewTask);
     
     function createNewTask(module,folder) {
         if(module=="tasks") {
-            if(!folder)
+            if(!folder) {
                 folder = configGetKey("folder.tasks");
-            newTaskWindow = newWindow("newTask.html#folder="+folder, "width=780px,height=640px,left=5,top=5,resizable=yes");
-            newTaskWindow.focus();
+            }
+            // create task
+            ox.api.task.compose({
+                params: {
+                    folder: folder
+                }
+            });
+//            newTaskWindow = newWindow("newTask.html#folder="+folder, "width=780px,height=640px,left=5,top=5,resizable=yes");
+//            newTaskWindow.focus();
         }
     }
     
@@ -959,7 +981,7 @@ function fn_tasks_getDetails(objects, forceUpdate) {
     
     enableTaskLoadingScreen(true);
         
-    var collection={}
+    var collection={};
     collection.objects=[objects[0]];
     collection.columns=null;
     if (tmpDetailRequest) {
@@ -1061,7 +1083,7 @@ function updateTaskSplit(object) {
                   var fnSetPrincipal = (function fnSetPrincipal(idfield, idvalue) {
                       return function(arg) {
                           $("tasks.split." + idfield).firstChild.data = arg[idvalue].display_name; 
-                      }
+                      };
                   })(idfield, idvalue);
                   internalCache.getUsers([idvalue],fnSetPrincipal);
                   continue;
@@ -1073,12 +1095,23 @@ function updateTaskSplit(object) {
                   var endDate = idvalue;
                   var startDate = object["start_date"];
                   if (endDate && startDate) {
+                      //#. Task details of a task with start and due date.
+                      //#. %1$s is the start date.
+                      //#. %2$s is the due date.
+                      //#, c-format
                       idvalue = format(_("Starts on %1$s, due on %2$s."), formatDate(startDate, "date"), formatDate(endDate, "date"));
                   } else if (startDate) {
+                      //#. Task details of a task with only a start date.
+                      //#. %s is the start date.
+                      //#, c-format
                       idvalue = format(_("Starts on %s."), formatDate(startDate, "date"));
                   } else if (endDate) {
+                      //#. Task details of a task with only a due date.
+                      //#. %s is the due date.
+                      //#, c-format
                       idvalue = format(_("Due on %s."), formatDate(endDate, "date"));
                   } else {
+                      //#. Task details of a task with no start or due date.
                       idvalue = _("Not set");
                   }
                   
@@ -1100,9 +1133,21 @@ function updateTaskSplit(object) {
                                break;
                            default:
                                if (pastDays < -1) {
-                                    text = format(_("Due in %s days."), Math.abs(pastDays));
+                                    //#. Task details (due date).
+                                    //#. %d is the number of days.
+                                    //#, c-format
+                                    text = format(ngettext("Due in %d day.",
+                                                           "Due in %d days.",
+                                                           Math.abs(pastDays)),
+                                                  Math.abs(pastDays));
                                } else {
-                                    text = format(_("Overdue by %s days."), pastDays);
+                                    //#. Task details (due date).
+                                    //#. %d is the number of days.
+                                    //#, c-format
+                                    text = format(ngettext("Overdue by %d day.",
+                                                           "Overdue by %d days.",
+                                                           pastDays),
+                                                  pastDays);
                                }
                                break;
                       }
@@ -1152,6 +1197,17 @@ function updateTaskSplit(object) {
                   $("tasks.split." + idfield).src = getFullImgSrc(img);
                   continue;
                   break;
+            case "categories":
+            	var cat = (idvalue || "");
+                $("tasks.split."+idfield).style.display = cat.length ? "" : "none";                  
+                if (cat.length) {
+	                  ox.categories.ui.drawCategoriesList(ox.categories.getByString(cat), 
+	                		  $("tasks.split."+idfield));
+                } else {
+              	  removeChildNodes($("tasks.split."+idfield));
+                }
+                continue;
+                break;
         }
         
         if ($("tasks.split." + idfield)) {
@@ -1252,7 +1308,7 @@ TaskDetailParticipants.prototype = {
             if(this.nPart < 6 ) {   
                 if(arg[this.idUserArr[i]]) {                            
                     this.sText = arg[this.idUserArr[i]].display_name;                                       
-                    $("a_d_participants_" + (this.nPart+1)).firstChild.data = this.sText                                        
+                    $("a_d_participants_" + (this.nPart+1)).firstChild.data = this.sText;
                     aDetailFieldsToClear["a_d_participants_" + (this.nPart+1)] = "set";
                     this.nPart++;               
                 }       
@@ -1283,7 +1339,7 @@ TaskDetailParticipants.prototype = {
                 refTaskDetailParticipantTab.users= Self.usersD;
                 refTaskDetailParticipantTab.makeGrid();
             },20
-        )
+        );
         setTimeout(                                                 
             function() {
                 internalCache.getGroups(objTaskDetailParticipants.idGroupArr,fnSetTaskGroupColumn);
@@ -1299,7 +1355,7 @@ TaskDetailParticipants.prototype = {
             if(this.nPart < 6 ) 
             {                                       
                 this.sText = arg[this.idGroupArr[i]].display_name;                              
-                $("a_d_participants_" + (this.nPart+1)).firstChild.data = this.sText                                        
+                $("a_d_participants_" + (this.nPart+1)).firstChild.data = this.sText;
                 aDetailFieldsToClear["a_d_participants_" + (this.nPart+1)] = "set";     
                 this.nPart++;                                   
             }
@@ -1338,7 +1394,7 @@ TaskDetailParticipants.prototype = {
             if(i < 2 ) 
             {                                       
                 this.sText = arg[this.idResourceArr[i]].display_name;                                   
-                $("a_d_resources_" + (i+1)).firstChild.data = this.sText                                        
+                $("a_d_resources_" + (i+1)).firstChild.data = this.sText;
                 aDetailFieldsToClear["a_d_resources_" + (i+1)] = "set";     
             }
             else
@@ -1354,7 +1410,7 @@ TaskDetailParticipants.prototype = {
         this.gridIndex++;
         }
     }
-}
+};
 
 function TaskDetailParticipantTab() {
     this.users = null;
@@ -1476,7 +1532,7 @@ TaskDetailParticipantTab.prototype = {
     
     enableGrid : function () {
         this.appendToStorage();
-        var tmp_participants = new Array()
+        var tmp_participants = new Array();
         for(var i = 0; i < objTaskDetailParticipants.gridData.length; i++) {
             tmp_participants[i] = objTaskDetailParticipants.gridData[i];
         }
@@ -1492,7 +1548,7 @@ TaskDetailParticipantTab.prototype = {
         if(taskParticipantsGrid)
             taskParticipantsGrid.disable(); 
     }
-}
+};
 
 function tasks_HeaderUpdate(data) {
     contactsFolderPath.additionalNode=document.createTextNode(" ("+ data.objects.length + ")");
