@@ -21,9 +21,9 @@
  * Creates a tree widget inside the specified DOM element.
  * @class A basic tree widget.
  * @param {Object} container The DOM element to which the root nodes of the tree
+ * will be added.
  * @param {Object] state Optional state object previously retrieved with
  * {@link getState}.
- * will be added.
  */
 function Tree(container, state, id) {
 	/**
@@ -95,14 +95,11 @@ Tree.prototype = {
 	},
 	replaceChild: function(node,oldnode) {
 		this.container.replaceChild(node.div,oldnode.div);
-		node.hasChildren = oldnode.hasChildren;
 		node.tree_id = oldnode.tree_id;
 		node.tree = oldnode.tree;
 		this.children[node.id] = node;			
-		if (oldnode.open && this.state[node.id]) {
-            node.setState(this.state[node.id]);
-            node.setOpen(true);
-        }
+        node.setState(oldnode.getState());
+		node.setOpen(oldnode.open);
 	},
 	/**
 	 * @private
@@ -393,11 +390,8 @@ TreeNode.prototype = {
 		node.tree = oldnode.tree;	
 		node.parent = this;
 		this.children[node.id] = node;
-        if (this.state && this.state[node.id]) {
-            node.setState(this.state[node.id]);
-            node.setOpen(true);
-        }
-        
+        node.setState(oldnode.getState());
+        node.setOpen(node.open);
 	},
 	/**
 	 * @private
