@@ -143,6 +143,8 @@ split.init = function() {
                     var match = /[^!#$&'+-[^-z|-~]/.exec(act.tags);
                     if (match) {
                         ox.Configuration.error(format(
+                            //#. %s is the invalid character.
+                            //#, c-format
                             _("Invalid tag name. Tags may not contain the character '%s'."),
                             match[0]));
                         return;
@@ -162,6 +164,8 @@ split.init = function() {
                     }
                     if (!validateEmail(act.to)) {
                         ox.Configuration.error(format(
+                            //#. %s is the invalid address
+                            //#, c-format
                             _("The E-Mail address \"%s\" is not valid."),
                             act.to));
                         return;
@@ -605,6 +609,9 @@ split.init = function() {
                         }, false, oMainFolderTree.cache,
                         optFolderState.getState("mailfilter.folder"));
                     tree.enabled_modules = { mail: true };
+                    tree.enable_check_fn = function(folder) {
+                        return /^default0?\b/.test(folder.oxfolder.data.id);
+                    };
                     tree.load();
                     tree.setSaveConfiguration(optFolderState);
                     Self.folderpopup.style.display = "block";
