@@ -55,6 +55,8 @@ if (configGetKey("modules")["com.openexchange.wizard"]) {
             removeChildNodes(title);
             if (!this.title) {
                 this.title = addTranslated(format(
+                    //#. %d is the step number.
+                    //#, c-format
                     _("Step %d. Download OXUpdater"), this.position));
             }
             title.appendChild(this.title);
@@ -79,25 +81,19 @@ if (configGetKey("modules")["com.openexchange.wizard"]) {
         }
     };
     temporary.services.provide("com.openexchange.wizard", tab);
-} else {
-    var coou = "com.openexchange.oxupdater";
-    var menu = MenuNodes.createSmallButtonContext(coou + ".menu",
-        _("Microsoft Outlook"));
-    MenuNodes.createSmallButton(menu, coou + ".button", _("Download OXtender"),
-        getFullImgSrc("img/infostore/infostore_save.gif"),
-        getFullImgSrc("img/infostore/infostore_save_d.gif"),
-        function() { triggerEvent("OX_Switch_View", node.id); });
-    addMenuNode(menu.node, MenuNodes.FIXED, 3);
-    changeDisplay("portal", coou + ".menu");
-    menuarrows[coou] = {};
-    register("OX_SELECTED_ITEMS_CHANGED", function() {
-        menuglobalzaehler = 0;
-        menuarrows[coou][coou + ".menu"] = [];
-        menu_display_contents(coou, coou + ".menu", true, coou + ".button");
-    });
-    if (currentpath2[0] == "portal") showNode(coou + ".menu");
 }
 
+var coou = "com.openexchange.oxupdater";
+var menuID = "com.openexchange.synchronization.menu";
+var menu = new MenuNodes.Section("com.openexchange.synchronization",
+    _("Synchronization"), -1);
+var button = new MenuNodes.Button(_("Microsoft Outlook"));
+button.icon = "img/infostore/infostore_save.gif";
+button.disabledIcon = "img/infostore/infostore_save_d.gif";
+button.click = function() { triggerEvent("OX_Switch_View", node.id); };
+menu.add(button);
+menu.show("portal");
+
 var page = new ox.Configuration.Page(node, _("Outlook OXtender"), false);
 page.viewModified = function() { return false; };
 var widget = new ox.UI.Widget();
