@@ -5,7 +5,6 @@ var tab = new temporary.VTab(newnode("span", 0, 0, [
                       color:"white" }, 0, [ addTranslated("New") ])
 ]), 0.2);
 temporary.folderTabs.addTab(tab);
-
 var widgets = {
     input: function(def) { return new ox.UI.Input(noI18n(def.displayName)); },
     password: function(def) {
@@ -84,8 +83,14 @@ com_openexchange_publish.folderMenuItem.onShow = function() {
     var folder = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
     // support for this folder?
     this.setVisible(com_openexchange_publish.supportsFolder(folder.oxfolder));
-}
-extended_folder_menu.addItem(com_openexchange_publish.folderMenuItem);
+    return this.visible && this.enabled;
+};
+com_openexchange_publish.folderMenuItem.getAutoEnabled = function() {
+    // get folder
+    var folder = oMainFolderTree.get_folder_by_node_id(this.getContext().data.id);
+    return com_openexchange_publish.supportsFolder(folder.oxfolder);
+};
+globalContextMenus.extended_folder_menu.addItem(com_openexchange_publish.folderMenuItem);
 
 tab.init = function() {
 
@@ -135,6 +140,11 @@ tab.init = function() {
                 storage.remove(0, storage.ids.length);
                 storage.append(reply.data);
                 grid.enable(storage);
+                if(reply.data.length < 1) {
+                	tab.addNew({});
+                } else {
+                	grid.selection.click(0);
+                }
             });
     };
     
@@ -145,7 +155,20 @@ tab.init = function() {
 
     tab.load = function(cont) { load(selection.getSelected()[0], cont); };
     
+    // temporary fix for bug #16710
+    // @todo: needs to be re-viewed by vp
+    tab.leave = function() {
+    	grid.selection.reset();
+    	tab.cancelView();
+    }
+    
     tab.save = function(data, cont) {
+    	// temporary fix for bug #16710
+    	// @todo: needs to be re-viewed by vp
+    	if (isEmpty(data)) {
+    		return;
+    	}    	
+    	
         if ("id" in data) {
             ox.JSON.put(AjaxRoot + "/publications/?action=update&session=" +
                 session, data, function(reply) {
@@ -289,7 +312,44 @@ tab.init = function() {
     };
     tab.addWidget(entry, ox.Configuration.Group.NoField);
 
-    var privacy = new ox.UI.Text("");
+
+    // Option for sending an e-mail about this subscription
+	var info_mail_button = new ox.UI.Button(_("Send E-Mail about this publication"));
+	info_mail_button.click = function() {
+	    // compose mail
+	    var pub_url = this.url || "";
+	    ox.api.mail.compose({
+	        params: {
+	            subject: _("Publication") /*i18n*/
+	        },
+	        data: {
+	            headers: {
+                    "X-OX-PubURL": pub_url,
+                    "X-OX-PubType": this.pubType
+                },
+	            aInfoMailAttachmentLink: [{
+	                content_type: "text/plain",
+	                content: pub_url
+                }]
+	        }
+	    });
+	}
+	var on_off_switcher = { 
+		get: function(data, value) {},
+	    set: function(data) {
+            info_mail_button.pubType = data.entityModule + "," + data.target;
+            var url = null;
+            if (data.target && data[data.target]) {
+                url = data[data.target].url;
+                info_mail_button.url = url;
+            }
+			info_mail_button.setEnabled(!isEmpty(url));
+		}
+	};
+	tab.addWidget(info_mail_button, on_off_switcher);
+
+
+    var privacy = new ox.UI.Button("");
     privacy.addContent = function() {
     	this.text = newnode("div",{lineHeight:"1.2em",marginTop:"1.5em"});
     	this.text.appendChild(newnode("p", { fontWeight: "bold" }, 0, [ document.createTextNode(_("Attention"))]));
