@@ -150,16 +150,16 @@ function processXML(name, level) {
     return [xml, js];
 }
 
-function processHTML(name, varname) {
+function processHTML(name, varname, path) {
     var xml, js, page = processXML(name);
-    var flat = name.replace(/^(.*\/)*/, "");
+    var base = args["final"] + "/" + name.replace(/^(.*\/)*/, "");
     if (!page) {
         var srcXMLName = format("%s/%s.xml", args.dest, name);
         var srcJSName = format("%s/%s.js", args.dest, name);
         var srcXML = new File(srcXMLName).lastModified();
         var srcJS = new File(srcJSName).lastModified();
-        var destXML = new File(flat + ".html").lastModified();
-        var destJS = new File(flat + ".js").lastModified();
+        var destXML = new File(base + ".html").lastModified();
+        var destJS = new File(base + ".js").lastModified();
         if (destXML >= srcXML && destJS >= srcJS) return;
         xml = loadXML(srcXMLName);
         js = eval("(" + read(srcJSName) + ")");
@@ -167,9 +167,16 @@ function processHTML(name, varname) {
         [xml, js] = page;
     }
     
+    if (path) {
+        for each (var img in xml..img.(String(@src))) {
+            img.@src = path + String(img.@src);
+        }
+        for (var i in js.images) js.images[i] = path + js.images[i];
+    }
+    
     var xmlns = new Namespace("http://www.w3.org/2000/xmlns/");
     delete xml..@xmlns::*;
-    var w = new Writer(flat + ".html");
+    var w = new Writer(base + ".html");
     w.writeln(/*src*/<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
     "http://www.w3.org/TR/html4/strict.dtd">
 <!--/Creative Commons License-->
@@ -192,139 +199,13 @@ function processHTML(name, varname) {
     for each (var child in xml.*) toHTML(child).writeHTML(w);
     w.close();
 
-    var w = new Writer(flat + ".js");
+    var w = new Writer(base + ".js");
     w.writeln(format("var %s = ", varname || "init"));
     writeJSON(w, js);
     w.writeln(";");
     w.close();
 }
 
-function processXSLT(page, dir, varname, prefix) {
-    prefix += "d";
-    var filecontent = processIncludes(format("%s/%s.xml", dir, page));
-    ox = filecontent.namespace("ox");
-    var xml = <top>{ filecontent }</top>;
-    xml.addNamespace(ox);
-    
-    js = new Writer(page + ".js");
-    js.writeln(format("var %s = {", varname || "init"));
-
-    var id = 0;
-    for each (var e in xml..*) {
-        if (e.nodeKind() == "element") {
-            e.@ox::id = String(e.@id) || prefix + ++id;
-        }
-    }
-
-    for each (var button in xml..ox::button) processButton(button);
-    
-    var list = xml..ox::notag;
-    while (list.length()) {
-        for each (var notag in list) replaceXML(notag, notag.*);
-        list = xml..ox::notag;
-    }
-    
-    js.writeln("help: {");
-    js.writeln(collectIDs(xml..*.(@ox::help.length()), "help"));
-    
-    js.writeln("}, min: {");
-    js.writeln(collectIDs(xml..*.(@ox::min.length()), "min"));
-    
-    js.writeln("}, max: {");
-    js.writeln(collectIDs(xml..*.(@ox::max.length()), "max"));
-
-    for each (var version in xml..ox::version) {
-        replaceXML(version, new XML(args.version));
-    }
-    for each (var pversion in xml..ox::pversion) {
-        replaceXML(pversion, new XML(args.pversion));
-    }
-    
-    js.writeln("}, images: {");
-    a = [];
-    for each (var img in xml..img.(String(@src))) {
-        a.push(format('"%s": "%s"', img.@ox::id, img.@src));
-        processImg(img);
-    }
-    js.writeln(a.join(",\n"));
-    
-    js.writeln("}, hide: {");
-    a = [];
-    for each (var iframe in xml..ox::iframe) {
-        a.push(format('"%s": true', iframe.@ox::id));
-        processIFrame(iframe);
-    }
-    js.writeln(a.join(",\n"));
-    
-    js.writeln("}, movable: [");
-    var a = [];
-    for each (var movable in xml..ox::popupwindow) {
-        a.push(format('"%s"', movable.@ox::id + "-h"));
-        processMovable(movable);
-    }
-    js.writeln(a.join(",\n"));
-
-    for each (var timestamp in xml..ox::timestamp) processTimestamp(timestamp);
-    
-    var list = xml..ox::border;
-    while (list.length()) {
-        for each (var border in list) processBorder(border);
-        list = xml..ox::border;
-    }
-    
-    js.writeln("], size: [");
-    processAlign(xml);
-    
-    for each (var attr in xml..*.(@ox::align.length())) {
-        processID(attr, "align");
-    }
-    
-    js.writeln("], split: {");
-    js.writeln(collectIDs(xml..*.(@ox::split.length()), "split"));
-    
-    for each (var node in xml..*.(@ox::padding.length())) {
-        node.@style = format("padding:%s;", node.@ox::padding) + node.@style;
-    }
-    for each (var node in xml..*.(@ox::border.length())) {
-        node.@style = format("border-width:%s;", node.@ox::border) + node.@style;
-    }
-    for each (node in xml..*.(@ox::margin.length())) {
-        node.@style = format("margin:%s;", node.@ox::margin) + node.@style;
-    }
-    
-    js.writeln("}, i18n: {");
-    js.writeln(collectIDs(xml..*.(@ox::i18n.length()) , "i18n"));
-    
-    js.writeln("} };");
-    js.close();
-    
-    delete xml..@ox::*;
-    var xmlns = new Namespace("http://www.w3.org/2000/xmlns/");
-    delete xml..@xmlns::*;
-    var w = new Writer(page + ".html");
-    w.writeln(/*src*/<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
-    "http://www.w3.org/TR/html4/strict.dtd">
-<!--/Creative Commons License-->
-<!--
-    <rdf:RDF>
-        <Work rdf:about="">
-            <license rdf:resource="http://creativecommons.org/licenses/by-nc-sa/2.5/" />
-        </Work>
-        <License rdf:about="http://creativecommons.org/licenses/by-nc-sa/2.5/">
-            <permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
-            <permits rdf:resource="http://web.resource.org/cc/Distribution"/>
-            <requires rdf:resource="http://web.resource.org/cc/Notice"/>
-            <requires rdf:resource="http://web.resource.org/cc/Attribution"/>
-            <prohibits rdf:resource="http://web.resource.org/cc/CommercialUse"/>
-            <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
-            <requires rdf:resource="http://web.resource.org/cc/ShareAlike"/>
-        </License>
-    </rdf:RDF>
--->/*end*/);
-    for each (var child in xml.*) toHTML(child).writeHTML(w, "");
-    w.close();
-};
-
 function writeJSON(w, x) {
     switch (typeof x) {
         case "object":
@@ -678,52 +559,31 @@ function toHTML(xml) {
     }
 }
 
-if (args.newhtml) {
-    var varnames = ["init", "preload"];
-    var pages = {
-        "index": 0, "ox": 0, "mainpage": 1, "mail/mail_core": 1,
-        "calendar/calendar_core": 1, "calendar/calendarmini": 1,
-        "mail/mailcheck": 1, "contacts/contacts_core": 1,
-        "infostore/infostore_core": 1, "tasks/tasks_core": 1,
-        "tasks/newTask": 0, "calendar/newAppointment": 0,
-        "contacts/newContact": 0, "contacts/newDistributionList": 0,
-        "mail/newMail": 0, "mail/detailMail": 0,
-        "infostore/newInfoItemHidden": 0, "popup_trigger_cb": 0,
-        "infostore/newInfoItemMain": 0, "messaging/messaging": 1
-    };
-    
-    var depsFile = new File(args.dest + "/deps.js");
-    if (depsFile.exists()) {
-        deps = eval("(" + (read(depsFile) || "null") + ")");
-        depsFile["delete"]();
-    } else {
-        deps = {};
-    }
-    var newdeps = {};
-    for (var i in pages) processHTML(i, varnames[pages[i]]);
-    var w = new Writer(args.dest + "/deps.js");
-    writeJSON(w, newdeps);
-    w.close();
+var varnames = ["init", "preload", "init"];
+var paths = [args.build + "/", args.build + "/", ""];
+var pages = {
+    "mainpage": 1, "index": 0, "ox": 0, "mail/mail_core": 1,
+    "calendar/calendar_core": 1, "calendar/calendarmini": 1,
+    "mail/mailcheck": 1, "contacts/contacts_core": 1,
+    "infostore/infostore_core": 1, "tasks/tasks_core": 1,
+    "tasks/newTask": 2, "calendar/newAppointment": 2,
+    "contacts/newContact": 2, "contacts/newDistributionList": 2,
+    "mail/newMail": 2, "mail/detailMail": 2,
+    "infostore/newInfoItemHidden": 2, "popup_trigger_cb": 2,
+    "infostore/newInfoItemMain": 2, "messaging/messaging": 1
+};
+
+var depsFile = new File(args.dest + "/deps.js");
+if (depsFile.exists()) {
+    deps = eval("(" + (read(depsFile) || "null") + ")");
+    depsFile["delete"]();
 } else {
-    processXSLT("index", "html", "init", "");
-    processXSLT("ox", "html", "init", "");
-    processXSLT("mainpage", "html", "preload", "core");
-    processXSLT("mail_core", "html/mail", "preload", "mailcore");
-    processXSLT("calendar_core", "html/calendar", "preload", "calcore");
-    processXSLT("calendarmini", "html/calendar", "preload", "calendarmini");
-    processXSLT("mailcheck", "html/mail", "preload", "mailcheck");
-    processXSLT("contacts_core", "html/contacts", "preload", "contcore");
-    processXSLT("infostore_core", "html/infostore", "preload", "infocore");
-    processXSLT("tasks_core", "html/tasks", "preload", "taskcore");
-    processXSLT("newTask", "html/tasks", "init", "");
-    processXSLT("newAppointment", "html/calendar", "init", "");
-    processXSLT("newContact", "html/contacts", "init", "");
-    processXSLT("newDistributionList", "html/contacts", "init", "");
-    processXSLT("newMail", "html/mail", "init", "");
-    processXSLT("detailMail", "html/mail", "init", "");
-    processXSLT("newInfoItemHidden", "html/infostore", "init", "");          
-    processXSLT("popup_trigger_cb", "html", "init", "");  
-    processXSLT("newInfoItemMain", "html/infostore", "init", "");
-    processXSLT("messaging", "messaging", "preload", "messaging");
+    deps = {};
 }
+var newdeps = {};
+for (var i in pages) processHTML(i, varnames[pages[i]], paths[pages[i]]);
+var w = new Writer(args.dest + "/deps.js");
+writeJSON(w, newdeps);
+w.close();
+
 /*end*/
\ No newline at end of file
